@@ -2,13 +2,13 @@
 
 =head1 NAME
 
-to-3.5-pf.conf.pl - 3.5 upgrade script for conf/pf.conf
+to-3.0-pf.conf.pl - 3.0 upgrade script for conf/pf.conf
 
 =head1 USAGE
 
 Basically: 
 
-  addons/upgrade/to-3.5-pf.conf.pl < conf/pf.conf > pf.conf.new
+  addons/upgrade/to-3.0-pf.conf.pl < conf/pf.conf > pf.conf.new
 
 Then look at pf.conf.new and if it's ok, replace your conf/pf.conf with it.
 
@@ -18,9 +18,21 @@ Here's what this script fixes:
 
 =over
 
-=item per-interface gateway
+=item mode vlan removal
 
-No longer required. We just drop it.
+No longer required.
+
+=item dhcpd / named changes
+
+They changed section and they default to enabled so if we see them as enabled we simply get rid of the entries.
+
+=item scan.live_tids dropped
+
+We just drop it.
+
+=item trapping.testing
+
+We just drop it.
 
 =back
 
@@ -31,17 +43,12 @@ use warnings;
 
 while (<>) {
 
-    # a special case of gateway which we won't change
-    print if (/^\s*gateway\s*=\s*authorize_net\s*$/i);
-
-    # removing gateway parameter
-    next if (/^\s*gateway\s*=.*$/i);
-
-    # removing the caching parameter
-    next if (/^\s*caching\s*=.*$/i);
-
-    # removing nessus_clientfile parameter
-    next if (/^\s*nessus_clientfile\s*=.*$/i);
+    # removing
+    next if (/^mode=vlan\s*$/i);
+    next if (/^named=\s*enabled\s*$/i);
+    next if (/^dhcpd=\s*enabled\s*$/i);
+    next if (/^live_tids=.*$/i);
+    next if (/^testing=.*$/i);
 
     # if we didn't skip, we keep
     print;
@@ -53,9 +60,9 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
-=head1 LICENSE 
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
