@@ -1,3 +1,17 @@
+--
+-- Setting the major/minor/sub-minor version of the DB
+--
+
+SET @MAJOR_VERSION = 5;
+SET @MINOR_VERSION = 6;
+SET @SUBMINOR_VERSION = 0;
+
+--
+-- The VERSION_INT to ensure proper ordering of the version in queries
+--
+
+SET @VERSION_INT = @MAJOR_VERSION << 16 | @MINOR_VERSION << 8 | @SUBMINOR_VERSION;
+
 --
 -- Table structure for table `class`
 --
@@ -18,6 +32,8 @@ CREATE TABLE class (
   enabled char(1) NOT NULL default "N",
   vlan varchar(255),
   target_category varchar(255),
+  delay_by int(11) NOT NULL default 0,
+  external_command varchar(255) DEFAULT NULL,
   PRIMARY KEY (vid)
 ) ENGINE=InnoDB;
 
@@ -69,6 +85,8 @@ CREATE TABLE person (
   `custom_field_7` varchar(255) default NULL,
   `custom_field_8` varchar(255) default NULL,
   `custom_field_9` varchar(255) default NULL,
+  `portal` varchar(255) default NULL,
+  `source` varchar(255) default NULL,
   PRIMARY KEY (pid)
 ) ENGINE=InnoDB;
 
@@ -109,7 +127,7 @@ INSERT INTO `node_category` (category_id,name,notes) VALUES ("3","gaming","Gamin
 
 CREATE TABLE node (
   mac varchar(17) NOT NULL,
-  pid varchar(255) NOT NULL default "admin",
+  pid varchar(255) NOT NULL default "default",
   category_id int default NULL,
   detect_date datetime NOT NULL default "0000-00-00 00:00:00",
   regdate datetime NOT NULL default "0000-00-00 00:00:00",
@@ -124,10 +142,17 @@ CREATE TABLE node (
   last_arp datetime NOT NULL default "0000-00-00 00:00:00",
   last_dhcp datetime NOT NULL default "0000-00-00 00:00:00",
   dhcp_fingerprint varchar(255) default NULL,
+  dhcp6_fingerprint varchar(255) default NULL,
+  dhcp_vendor varchar(255) default NULL,
+  dhcp6_enterprise varchar(255) default NULL,
+  device_type varchar(255) default NULL,
+  device_class varchar(255) default NULL,
   bypass_vlan varchar(50) default NULL,
   voip enum('no','yes') NOT NULL DEFAULT 'no',
   autoreg enum('no','yes') NOT NULL DEFAULT 'no',
   sessionid varchar(30) default NULL,
+  machine_account varchar(255) default NULL,
+  bypass_role_id int default NULL,
   PRIMARY KEY (mac),
   KEY pid (pid),
   KEY category_id (category_id),
@@ -192,6 +217,7 @@ CREATE TABLE violation (
   KEY vid (vid),
   KEY status (status),
   KEY ind1 (mac,status,vid),
+  KEY violation_release_date (release_date),
   CONSTRAINT `0_60` FOREIGN KEY (`mac`) REFERENCES `node` (`mac`) ON DELETE CASCADE ON UPDATE CASCADE,
   CONSTRAINT `0_61` FOREIGN KEY (`vid`) REFERENCES `class` (`vid`) ON DELETE CASCADE ON UPDATE CASCADE,
   PRIMARY KEY (id)
@@ -203,43 +229,51 @@ CREATE TABLE violation (
 
 CREATE TABLE iplog (
   mac varchar(17) NOT NULL,
-  ip varchar(15) NOT NULL,
+  ip varchar(45) NOT NULL,
   start_time datetime NOT NULL,
   end_time datetime default "0000-00-00 00:00:00",
-  KEY mac (mac),
-  KEY `ip_view_open` (`ip`, `end_time`),
-  KEY `mac_view_open` (`mac`, `end_time`),
-  CONSTRAINT `0_63` FOREIGN KEY (`mac`) REFERENCES `node` (`mac`) ON DELETE CASCADE ON UPDATE CASCADE
+  PRIMARY KEY (ip),
+  KEY iplog_mac_end_time (mac,end_time),
+  KEY iplog_end_time (end_time)
 ) ENGINE=InnoDB;
 
-CREATE TABLE os_type (
-  os_id int(11) NOT NULL,
-  description varchar(255) NOT NULL,
-  PRIMARY KEY os_id (os_id)
+--
+-- Trigger to insert old record from 'iplog' in 'iplog_history' before updating the current one
+--
+
+DROP TRIGGER IF EXISTS iplog_insert_in_iplog_history_before_update_trigger;
+DELIMITER /
+CREATE TRIGGER iplog_insert_in_iplog_history_before_update_trigger BEFORE UPDATE ON iplog
+FOR EACH ROW
+BEGIN
+  INSERT INTO iplog_history SET ip = OLD.ip, mac = OLD.mac, start_time = OLD.start_time, end_time = CASE
+    WHEN OLD.end_time = '0000-00-00 00:00:00' THEN NOW()
+    WHEN OLD.end_time > NOW() THEN NOW()
+    ELSE OLD.end_time
+  END;
+END /
+DELIMITER ;
+
+--
+-- Table structure for table `iplog_history`
+--
+
+CREATE TABLE iplog_history (
+  mac varchar(17) NOT NULL,
+  ip varchar(45) NOT NULL,
+  start_time datetime NOT NULL,
+  end_time timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
 ) ENGINE=InnoDB;
 
-CREATE TABLE dhcp_fingerprint (
-  fingerprint varchar(255) NOT NULL,
-  os_id int(11) NOT NULL,
-  PRIMARY KEY fingerprint (fingerprint),
-  KEY os_id_key (os_id),
-  CONSTRAINT `0_65` FOREIGN KEY (`os_id`) REFERENCES `os_type` (`os_id`) ON DELETE CASCADE ON UPDATE CASCADE
-) ENGINE=InnoDB;
+--
+-- Table structure for table `iplog_archive`
+--
 
-CREATE TABLE os_class (
-  class_id int(11) NOT NULL,               
-  description varchar(255) NOT NULL,     
-  PRIMARY KEY class_id (class_id)
-) ENGINE=InnoDB;     
-
-CREATE TABLE os_mapping (   
-  os_type int(11) NOT NULL,  
-  os_class int(11) NOT NULL,
-  PRIMARY KEY  (os_type,os_class),
-  KEY os_type_key (os_type),
-  KEY os_class_key (os_class),
-  CONSTRAINT `0_66` FOREIGN KEY (`os_type`) REFERENCES `os_type` (`os_id`) ON DELETE CASCADE ON UPDATE CASCADE,
-  CONSTRAINT `0_67` FOREIGN KEY (`os_class`) REFERENCES `os_class` (`class_id`) ON DELETE CASCADE ON UPDATE CASCADE
+CREATE TABLE iplog_archive (
+  mac varchar(17) NOT NULL,
+  ip varchar(45) NOT NULL,
+  start_time datetime NOT NULL,
+  end_time datetime NOT NULL
 ) ENGINE=InnoDB;
 
 CREATE TABLE `locationlog` (
@@ -247,30 +281,42 @@ CREATE TABLE `locationlog` (
   `switch` varchar(17) NOT NULL default '',
   `port` varchar(8) NOT NULL default '',
   `vlan` varchar(50) default NULL,
+  `role` varchar(255) default NULL,
   `connection_type` varchar(50) NOT NULL default '',
+  `connection_sub_type` varchar(50) default NULL,
   `dot1x_username` varchar(255) NOT NULL default '',
   `ssid` varchar(32) NOT NULL default '',
   `start_time` datetime NOT NULL default '0000-00-00 00:00:00',
   `end_time` datetime default NULL,
   `switch_ip` varchar(17) DEFAULT NULL,
   `switch_mac` varchar(17) DEFAULT NULL,
+  `stripped_user_name` varchar (255) DEFAULT NULL,
+  `realm`  varchar (255) DEFAULT NULL,
+  `session_id` VARCHAR(255) DEFAULT NULL,
   KEY `locationlog_view_mac` (`mac`, `end_time`),
+  KEY `locationlog_end_time` ( `end_time`),
   KEY `locationlog_view_switchport` (`switch`,`port`,`end_time`,`vlan`)
 ) ENGINE=InnoDB;
 
-CREATE TABLE `locationlog_history` (
+CREATE TABLE `locationlog_archive` (
   `mac` varchar(17) default NULL,
   `switch` varchar(17) NOT NULL default '',
   `port` varchar(8) NOT NULL default '',
   `vlan` varchar(50) default NULL,
+  `role` varchar(255) default NULL,
   `connection_type` varchar(50) NOT NULL default '',
+  `connection_sub_type` varchar(50) default NULL,
   `dot1x_username` varchar(255) NOT NULL default '',
   `ssid` varchar(32) NOT NULL default '',
   `start_time` datetime NOT NULL default '0000-00-00 00:00:00',
   `end_time` datetime default NULL,
   `switch_ip` varchar(17) DEFAULT NULL,
   `switch_mac` varchar(17) DEFAULT NULL,
-  KEY `locationlog_history_view_mac` (`mac`, `end_time`),
+  `stripped_user_name` varchar (255) DEFAULT NULL,
+  `realm`  varchar (255) DEFAULT NULL,
+  `session_id` VARCHAR(255) DEFAULT NULL,
+  KEY `locationlog_archive_view_mac` (`mac`, `end_time`),
+  KEY `locationlog_end_time` ( `end_time`),
   KEY `locationlog_view_switchport` (`switch`,`port`,`end_time`,`vlan`)
 ) ENGINE=InnoDB;
 
@@ -294,16 +340,6 @@ CREATE TABLE `ifoctetslog` (
   PRIMARY KEY  (`switch`,`port`,`read_time`)
 ) ENGINE=InnoDB;
 
-CREATE TABLE `switchlocation` (
-  `switch` varchar(17) NOT NULL default '',
-  `port` varchar(8) NOT NULL default '',
-  `start_time` datetime NOT NULL default '0000-00-00 00:00:00',
-  `end_time` datetime default NULL,
-  `location` varchar(50) default NULL,
-  `description` varchar(50) default NULL,
-  PRIMARY KEY  (`switch`,`port`,`start_time`)
-) ENGINE=InnoDB;
-
 CREATE TABLE `traplog` (
   `switch` varchar(30) NOT NULL default '',
   `ifIndex` smallint(6) NOT NULL default '0',
@@ -320,28 +356,10 @@ CREATE TABLE `configfile` (
 ) ENGINE=InnoDB default CHARSET=latin1;
 
 --
--- Table structure for table `email_activation`
+-- Table structure for table `password`
 --
 
-CREATE TABLE email_activation (
-  `code_id` int NOT NULL AUTO_INCREMENT,
-  `pid` varchar(255) default NULL,
-  `mac` varchar(17) default NULL,
-  `email` varchar(255) NOT NULL, -- email were approbation request is sent 
-  `activation_code` varchar(255) NOT NULL,
-  `expiration` datetime NOT NULL,
-  `status` varchar(60) default NULL,
-  `type` varchar(60) default NULL,
-  PRIMARY KEY (code_id),
-  KEY `identifier` (pid, mac),
-  KEY `activation` (activation_code, status)
-) ENGINE=InnoDB;
-
---
--- Table structure for table `temporary_password`
---
-
-CREATE TABLE temporary_password (
+CREATE TABLE `password` (
   `pid` varchar(255) NOT NULL,
   `password` varchar(255) NOT NULL,
   `valid_from` datetime default NULL,
@@ -355,42 +373,26 @@ CREATE TABLE temporary_password (
 ) ENGINE=InnoDB;
 
 --
--- Insert 'default' admin user
+-- Insert default users
 --
 
 INSERT INTO `person` (pid,notes) VALUES ("admin","Default Admin User - do not delete");
-INSERT INTO temporary_password (pid, password, valid_from, expiration, access_duration, access_level, category) VALUES ('admin', 'admin', NOW(), '2038-01-01', NULL, 'ALL', NULL);
+INSERT INTO `person` (pid,notes) VALUES ("default","Default User - do not delete");
+INSERT INTO password (pid, password, valid_from, expiration, access_duration, access_level, category) VALUES ('admin', 'admin', NOW(), '2038-01-01', NULL, 'ALL', NULL);
 
 --
--- Trigger to delete the temp password from 'temporary_password' when deleting the pid associated with
+-- Trigger to delete the temp password from 'password' when deleting the pid associated with
 --
 
-DROP TRIGGER IF EXISTS temporary_password_delete_trigger;
+DROP TRIGGER IF EXISTS password_delete_trigger;
 DELIMITER /
-CREATE TRIGGER temporary_password_delete_trigger AFTER DELETE ON person
+CREATE TRIGGER password_delete_trigger AFTER DELETE ON person
 FOR EACH ROW
 BEGIN
-  DELETE FROM temporary_password WHERE pid = OLD.pid;
+  DELETE FROM `password` WHERE pid = OLD.pid;
 END /
 DELIMITER ;
 
---
--- Table structure for table `sms_activation`
---
-
-CREATE TABLE sms_activation (
-  `code_id` int NOT NULL AUTO_INCREMENT,
-  `mac` varchar(17) default NULL,
-  `phone_number` varchar(255) NOT NULL, -- phone number where sms is sent
-  `carrier_id` int(11) NOT NULL,
-  `activation_code` varchar(255) NOT NULL,
-  `expiration` datetime NOT NULL,
-  `status` varchar(60) default NULL,
-  PRIMARY KEY (code_id),
-  KEY `identifier` (mac),
-  KEY `activation` (activation_code, status)
-) ENGINE=InnoDB;
-
 --
 -- Table structure for table `sms_carrier`
 -- 
@@ -480,7 +482,10 @@ VALUES
     (100115, 'E-Plus', '%s@smsmail.eplus.de', now()),
     (100116, 'Cellular South', '%s@csouth1.com', now()),
     (100117, 'ChinaMobile (139)', '%s@139.com', now()),
-    (100118, 'Dialog Axiata', '%s@dialog.lk', now());
+    (100118, 'Dialog Axiata', '%s@dialog.lk', now()),
+    (100119, 'Swisscom', '%s@sms.bluewin.ch', now()),
+    (100120, 'Orange (CH)', '%s@orange.net', now()),
+    (100121, 'Sunrise', '%s@gsm.sunrise.ch', now());
 
 -- Adding RADIUS nas client table
 
@@ -493,6 +498,9 @@ CREATE TABLE radius_nas (
   community varchar(50),
   description varchar(200) default 'RADIUS Client',
   config_timestamp BIGINT,
+  start_ip INT UNSIGNED DEFAULT 0,
+  end_ip INT UNSIGNED DEFAULT 0,
+  range_length INT DEFAULT 0,
   PRIMARY KEY nasname (nasname)
 ) ENGINE=InnoDB;
 
@@ -575,9 +583,9 @@ BEGIN
   DECLARE Previous_Session_Time int(12);
 
   # Collect traffic previous values in the update table
-  SELECT SUM(acctinputoctets), SUM(acctoutputoctets), SUM(acctsessiontime)
+  SELECT acctinputoctets, acctoutputoctets, acctsessiontime
     INTO Previous_Input_Octets, Previous_Output_Octets, Previous_Session_Time
-    FROM radacct_log
+    FROM radacct
     WHERE acctsessionid = p_acctsessionid
     AND username = p_username
     AND nasipaddress = p_nasipaddress;
@@ -696,9 +704,9 @@ BEGIN
   DECLARE Previous_Session_Time int(12);
 
   # Collect traffic previous values in the update table
-  SELECT SUM(acctinputoctets), SUM(acctoutputoctets), SUM(acctsessiontime)
+  SELECT acctinputoctets, acctoutputoctets, acctsessiontime
     INTO Previous_Input_Octets, Previous_Output_Octets, Previous_Session_Time
-    FROM radacct_log
+    FROM radacct
     WHERE acctsessionid = p_acctsessionid
     AND username = p_username
     AND nasipaddress = p_nasipaddress;
@@ -893,3 +901,113 @@ CREATE TABLE wrix (
   `MAC_Address` varchar(255) NULL DEFAULT NULL,
    PRIMARY KEY (id)
 ) ENGINE=InnoDB;
+
+--
+-- Table structure for table `activation`
+--
+
+CREATE TABLE activation (
+  `code_id` int NOT NULL AUTO_INCREMENT,
+  `pid` varchar(255) default NULL,
+  `mac` varchar(17) default NULL,
+  `contact_info` varchar(255) NOT NULL, -- email or phone number were approbation request is sent 
+  `carrier_id` int(11) NULL,
+  `activation_code` varchar(255) NOT NULL,
+  `expiration` datetime NOT NULL,
+  `status` varchar(60) default NULL,
+  `type` varchar(60) NOT NULL,
+  `portal` varchar(255) default NULL,
+  PRIMARY KEY (code_id),
+  KEY `mac` (mac),
+  KEY `identifier` (pid, mac),
+  KEY `activation` (activation_code, status)
+) ENGINE=InnoDB;
+
+
+--
+-- Table structure for table `keyed`
+--
+
+CREATE TABLE keyed (
+  id VARCHAR(255),
+  value LONGBLOB,
+  PRIMARY KEY(id)
+) ENGINE=InnoDB;
+
+--
+-- Table structure for table 'pf_version'
+--
+
+CREATE TABLE pf_version ( `id` INT NOT NULL PRIMARY KEY, `version` VARCHAR(11) NOT NULL UNIQUE KEY);
+
+--
+-- Table structure for table 'radius_audit_log'
+--
+
+CREATE TABLE radius_audit_log (
+  id int NOT NULL AUTO_INCREMENT,
+  created_at TIMESTAMP NOT NULL,
+  mac char(17) NOT NULL,
+  ip varchar(255) NULL,
+  computer_name varchar(255) NULL,
+  user_name varchar(255) NULL,
+  stripped_user_name varchar(255) NULL,
+  realm varchar(255) NULL,
+  event_type varchar(255) NULL,
+  switch_id varchar(255) NULL,
+  switch_mac varchar(255) NULL,
+  switch_ip_address varchar(255) NULL,
+  radius_source_ip_address varchar(255),
+  called_station_id varchar(255) NULL,
+  calling_station_id varchar(255) NULL,
+  nas_port_type varchar(255) NULL,
+  ssid varchar(255) NULL,
+  nas_port_id varchar(255) NULL,
+  ifindex varchar(255) NULL,
+  nas_port varchar(255) NULL,
+  connection_type varchar(255) NULL,
+  nas_ip_address varchar(255) NULL,
+  nas_identifier varchar(255) NULL,
+  auth_status varchar(255) NULL,
+  reason TEXT NULL,
+  auth_type varchar(255) NULL,
+  eap_type varchar(255) NULL,
+  role varchar(255) NULL,
+  node_status varchar(255) NULL,
+  profile varchar(255) NULL,
+  source varchar(255) NULL,
+  auto_reg char(1) NULL,
+  is_phone char(1) NULL,
+  pf_domain varchar(255) NULL,
+  uuid varchar(255) NULL,
+  radius_request TEXT,
+  radius_reply TEXT,
+  PRIMARY KEY (id),
+  KEY `created_at` (created_at),
+  KEY `mac` (mac),
+  KEY `ip` (ip),
+  KEY `user_name` (user_name)
+) ENGINE=InnoDB;
+
+--
+-- Updating to current version
+--
+
+INSERT INTO pf_version (id, version) VALUES (@VERSION_INT, CONCAT_WS('.', @MAJOR_VERSION, @MINOR_VERSION, @SUBMINOR_VERSION));
+
+--
+-- Creating auth_log table
+--
+
+CREATE TABLE auth_log (
+  `id` int NOT NULL AUTO_INCREMENT,
+  `process_name` varchar(255) NOT NULL,
+  `mac` varchar(17) NOT NULL,
+  `pid` varchar(255) NOT NULL default "default",
+  `status` varchar(255) NOT NULL default "incomplete",
+  `attempted_at` datetime NOT NULL,
+  `completed_at` datetime,
+  `source` varchar(255) NOT NULL,
+  PRIMARY KEY (id),
+  KEY pid (pid)
+) ENGINE=InnoDB;
