@@ -18,10 +18,9 @@ use namespace::autoclean;
 use pf::authentication;
 use pf::config;
 use pf::enforcement qw(reevaluate_access);
-use pf::iplog;
+use pf::ip4log;
 use pf::node
   qw(node_attributes node_modify node_register node_view is_max_reg_nodes_reached);
-use pf::useragent;
 use pf::util;
 use pf::violation qw(violation_count);
 use pf::web::constants;
@@ -39,7 +38,7 @@ sub showError {
     utf8::decode($text_message);
     $c->stash(
         template    => 'error.html',
-        txt_message => $text_message,
+        message => $text_message,
     );
     $c->detach;
 }
@@ -67,7 +66,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
