@@ -2,9 +2,12 @@ package captiveportal::PacketFence::Controller::WirelessProfile;
 use Moose;
 use namespace::autoclean;
 use File::Slurp qw(read_file);
+use pf::constants;
+use pf::util qw (isenabled);
 
 BEGIN { extends 'captiveportal::Base::Controller'; }
-use pf::config;
+
+use pf::config qw($reverse_fqdn);
 
 __PACKAGE__->config( namespace => 'wireless-profile.mobileconfig', );
 
@@ -26,7 +29,6 @@ Catalyst Controller.
 
 sub index : Path : Args(0) {
     my ( $self, $c ) = @_;
-    my $username = $c->session->{username} || '';
     my $mac = $c->portalSession->clientMac;
     my $user_cache = $c->user_cache;
     my $pki_session = $user_cache->get("pki_session");
@@ -35,22 +37,32 @@ sub index : Path : Args(0) {
     }
     my $stash = $c->stash;
     my $logger = $c->log;
-    my $provisioner = $c->profile->findProvisioner($mac);
+    my $provisioner = $c->profile->findProvisioner($mac, $c->stash->{application}->root_module->node_info);
     $provisioner->authorize($mac) if (defined($provisioner));
     my $profile_template = $provisioner->profile_template;
+    my $psk;
+    if (isenabled($provisioner->dpsk)) {
+        $psk = $provisioner->generate_dpsk($c->session->{username});
+    } else {
+        $psk = $provisioner->passcode;
+    }
+
     $c->stash(
-        template     => $profile_template,
-        current_view => 'MobileConfig',
-        provisioner  => $provisioner,
-        username     => $username,
-        cert_content => $pki_session->{b64_cert},
-        cert_cn      => $pki_session->{certificate_cn},
-        for_windows  => ($provisioner->{type} eq 'windows'),
-        ca_cn        => $pki_session->{ca_cn},
-        server_cn    => $pki_session->{server_cn},
-        ca_content   => $pki_session->{ca_content},
-        passwcode    => $provisioner->{passcode},
-        reverse_fqdn => $reverse_fqdn,
+        template         => $profile_template,
+        current_view     => 'MobileConfig',
+        provisioner      => $provisioner,
+        username         => $c->session->{username} ? $c->session->{username} : '',
+        cert_content     => $pki_session->{b64_cert},
+        cert_cn          => $pki_session->{certificate_cn},
+        for_windows      => ($provisioner->{type} eq 'windows'),
+        for_android      => ($provisioner->{type} eq 'android'),
+        ca_cn            => $pki_session->{ca_cn},
+        server_cn        => $pki_session->{server_cn},
+        server_content   => $pki_session->{server_content},
+        ca_content       => $pki_session->{ca_content},
+        reverse_fqdn     => $reverse_fqdn,
+        raw              => $TRUE,
+        psk              => $psk,
     );
 }
 
@@ -66,7 +78,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -87,6 +99,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
