@@ -5,52 +5,19 @@ use warnings;
 use Locale::gettext qw(gettext ngettext);
 use Moose;
 use utf8;
-extends 'Catalyst::View::TT';
+extends 'Catalyst::View';
 
-__PACKAGE__->config(
-    TEMPLATE_EXTENSION => '.html',
-    ENCODING           => 'utf-8',
-    render_die         => 1,
-    expose_methods     => [qw(i18n ni18n i18n_format)],
-);
 
-before process => sub {
-    my ( $self, $c ) = @_;
-    my $include_path = $c->portalSession->templateIncludePath;
-    @{ $self->include_path } = @$include_path;
-};
+=head2 process
 
-sub i18n {
-    my ( $self, $c, $msgid ) = @_;
-
-    my $msg = gettext($msgid);
-    utf8::decode($msg);
-
-    return $msg;
-}
-
-sub ni18n {
-    my ( $self, $c, $singular, $plural, $category ) = @_;
-
-    my $msg = ngettext( $singular, $plural, $category );
-    utf8::decode($msg);
-
-    return $msg;
-}
-
-=head2 i18n_format
-
-Pass message id through gettext then sprintf it.
-
-Meant to be called from the TT templates.
+Process the view using the informations in the stash
 
 =cut
 
-sub i18n_format {
-    my ( $self, $c, $msgid, @args ) = @_;
-    my $msg = sprintf( gettext($msgid), @args );
-    utf8::decode($msg);
-    return $msg;
+sub process {
+    my ($self, $c) = @_;
+    $c->stash->{application}->render($c->stash->{template}, $c->stash);
+    $c->response->body($c->stash->{application}->template_output);
 }
 
 =head1 NAME
@@ -71,7 +38,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
