@@ -1,8 +1,10 @@
+/* -*- Mode: javascript; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+
 /**
  * PacketFence Javascript Library
  *
  * @author      Inverse inc. <info@inverse.ca>
- * @copyright   2005-2015 Inverse inc.
+ * @copyright   2005-2017 Inverse inc.
  * @license     http://opensource.org/licenses/gpl-2.0.php      GPL
  */
 
@@ -12,6 +14,7 @@
    Called when access to the network outside registration or quarantine works
  */
 var network_redirected = false;
+var network_logoff_popup = "";
 function networkAccessCallback(destination_url) {
 
   network_redirected = true;
@@ -19,6 +22,8 @@ function networkAccessCallback(destination_url) {
   //show a web notification
   if (txt_web_notification) showWebNotification(txt_web_notification, '/content/images/unlock.png');
 
+  if(network_logoff_popup != "") window.open(network_logoff_popup);
+
   // Try to redirect browser in 3 seconds
   setTimeout(function() {
     performRedirect(destination_url);
@@ -104,7 +109,6 @@ function initWebNotifications(){
       // This allows to use Notification.permission with Chrome/Safari
       if (Notification.permission !== status) {
         Notification.permission = status;
-        console.log(Notification.status);
       }
     });
   }
@@ -129,6 +133,64 @@ function canWebNotifications(){
 */
 function showWebNotification(message, icon){
   if (canWebNotifications()){
-    var notification = new Notification(message, {icon:icon});
+    try {
+      var notification = new Notification(message, {icon:icon});
+    } catch(err) {
+      console.log("Error while creating notification...", err);
+    }
   }  
 }
+
+/**
+   getQueryParams
+
+   Read a page's GET URL variables and return them as an associative array.
+*/
+function getQueryParams() {
+  var vars = [], hash;
+  var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1).split('&');
+  for(var i = 0; i < hashes.length; i++){
+    hash = hashes[i].split('=');
+    vars.push(hash[0]);
+    vars[hash[0]] = hash[1];
+  }
+  return vars;
+}
+
+/**
+  getPortalUrl
+
+  Get a URL for the portal while taking in consideration the portal preview
+*/
+
+function getPortalUrl(url) {
+  if(/\/portal_preview\//.test(window.location.href)) {
+    return "/portal_preview"+url;
+  }
+  else {
+    return url;
+  }
+}
+
+
+$(function() {
+  'use strict';
+
+  /**
+    Will record the destination URL on the server if the browser has a javascript interpreter
+    This prevents the destination URL from being computed from an API call.
+  */
+  var wanted_destination_url = getQueryParams()["destination_url"];
+  if (wanted_destination_url){
+    $.post(
+      "/record_destination_url",
+      { destination_url: wanted_destination_url }
+    );
+  }
+
+  $(document).on('keyup', '.tabbable',function(e){
+    if(e.which==13 || e.which==32) {
+      this.click()
+    }
+  });
+});
