@@ -8,7 +8,7 @@ pfappserver::Base::Controller::Crud::Config add documentation
 
 =head1 DESCRIPTION
 
-PortalProfile
+ConnectionProfile
 
 =cut
 
@@ -35,6 +35,7 @@ sub sort_items : Local: Args(0) {
     my $items = $params_handler->expand_hash($c->request->params);
     my $itemsKey = $model->itemsKey;
     my ($status,$status_msg) = $model->sortItems($items->{$itemsKey});
+    $self->audit_current_action($c, status => $status);
     $c->stash(
         current_view => 'JSON',
         status_msg => $status_msg,
@@ -78,7 +79,7 @@ sub _commitChanges {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
