@@ -14,15 +14,20 @@ Authentication::Rule).
 
 use HTML::FormHandler::Moose;
 extends 'pfappserver::Base::Form';
+with qw(
+    pfappserver::Base::Form::Role::AllowedOptions
+    pfappserver::Role::Form::RolesAttribute
+);
 
 use HTTP::Status qw(:constants is_success);
 use List::MoreUtils qw(uniq);
-use pf::config;
+use pf::config qw(%Config);
 use pf::web::util;
 use pf::Authentication::constants;
 use pf::Authentication::Action;
 use pf::admin_roles;
 use pf::log;
+use pf::constants::config qw($TIME_MODIFIER_RE);
 
 has 'source_type' => ( is => 'ro' );
 
@@ -65,10 +70,16 @@ our %ACTION_FIELD_OPTIONS = (
         element_attr => {'data-placeholder' => 'Click to add a access right'},
         options_method => \&options_access_level,
     },
+    $Actions::SET_TENANT_ID => {
+        type          => 'Text',
+        do_label      => 0,
+        wrapper       => 0,
+    },
     $Actions::SET_ROLE => {
         type           => 'Select',
         do_label       => 0,
         wrapper        => 0,
+        element_class => ['chzn-deselect'],
         options_method => \&options_roles,
     },
     $Actions::SET_ACCESS_DURATION => {
@@ -82,7 +93,19 @@ our %ACTION_FIELD_OPTIONS = (
         type     => 'DatePicker',
         do_label => 0,
         wrapper  => 0,
-    }
+    },
+    $Actions::SET_TIME_BALANCE => {
+        type           => 'Select',
+        do_label       => 0,
+        wrapper        => 0,
+        options_method => \&options_durations_absolute,
+        default_method => sub { $Config{'guests_admin_registration'}{'default_access_duration'} }
+    },
+    $Actions::SET_BANDWIDTH_BALANCE => {
+        type           => 'Text',
+        do_label       => 0,
+        wrapper        => 0,
+    },
 );
 
 =head2 field_list
@@ -127,8 +150,16 @@ sub options_actions {
         $self->form->ctx->log->error($@);
     }
     else {
-        $actions_ref = $classname->available_actions();
-        @actions = map { { value => $_, label => $self->_localize($_), attributes => { 'data-rule-class' => pf::Authentication::Action->getRuleClassForAction($_) } } } @{$actions_ref};
+        my @allowed_actions = $self->form->_get_allowed_options('allowed_actions');
+        unless (@allowed_actions) {
+            @allowed_actions = @{$classname->available_actions()};
+        }
+        @actions = map { 
+          { value => $_, 
+            label => $self->_localize($_), 
+            attributes => { 'data-rule-class' => pf::Authentication::Action->getRuleClassForAction($_) } 
+          } 
+        } @allowed_actions;
     }
 
     return @actions;
@@ -159,24 +190,13 @@ sub options_roles {
     my $self = shift;
     my @options_values = $self->form->_get_allowed_options('allowed_roles');
     unless( @options_values ) {
-        my ($status, $result) = $self->form->ctx->model('Roles')->list();
-        @options_values = map { $_->{name} } @$result if (is_success($status));
+        my $result = $self->form->roles;
+        @options_values = map { $_->{name} } @$result;
     }
     # Build a list of existing roles
     return map { { value => $_, label => $_ } } @options_values;
 }
 
-=head2 _get_allowed_options
-
-Get the allowed options for the current user based off their role.
-
-=cut
-
-sub _get_allowed_options {
-    my ($self,$option) = @_;
-    return admin_allowed_options([$self->ctx->user->roles],$option);
-}
-
 =head2 options_durations
 
 Populate the access duration select field with the available values defined
@@ -191,14 +211,45 @@ sub options_durations {
     if(@options_values) {
         $durations = pf::web::util::get_translated_time_hash(
             \@options_values,
-            $self->form->ctx->languages()->[0]
+            $self->form->languages()->[0]
         );
     } else {
         my $default_choices = $Config{'guests_admin_registration'}{'access_duration_choices'};
-        my @choices = uniq admin_allowed_options_all([$self->form->ctx->user->roles],'allowed_access_durations'), split (/\s*,\s*/, $default_choices);
+        my @choices = uniq admin_allowed_options_all([$self->form->user_roles],'allowed_access_durations'), split (/\s*,\s*/, $default_choices);
         $durations = pf::web::util::get_translated_time_hash(
             \@choices,
-            $self->form->ctx->languages()->[0]
+            $self->form->languages()->[0]
+        );
+    }
+    my @options = map { $durations->{$_}[0] => $durations->{$_}[1] } sort { $a <=> $b } keys %$durations;
+
+    return \@options;
+}
+
+=head2 options_durations_absolute
+
+Populate the absolute access duration select field with the available values defined
+in the pf.conf configuration file.
+
+=cut
+
+sub options_durations_absolute {
+    my $self = shift;
+    my @options_values = $self->form->_get_allowed_options('allowed_access_durations');
+    @options_values = grep { $_ =~ /^(\d+)($TIME_MODIFIER_RE)$/} @options_values;
+    my $durations;
+    if(@options_values) {
+        $durations = pf::web::util::get_translated_time_hash(
+            \@options_values,
+            $self->form->languages()->[0]
+        );
+    } else {
+        my $default_choices = $Config{'guests_admin_registration'}{'access_duration_choices'};
+        my @choices = uniq admin_allowed_options_all([$self->form->user_roles],'allowed_access_durations'), split (/\s*,\s*/, $default_choices);
+        @choices = grep { $_ =~ /^(\d+)($TIME_MODIFIER_RE)$/} @choices;
+        $durations = pf::web::util::get_translated_time_hash(
+            \@choices,
+            $self->form->languages()->[0]
         );
     }
     my @options = map { $durations->{$_}[0] => $durations->{$_}[1] } sort { $a <=> $b } keys %$durations;
@@ -230,7 +281,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -251,5 +302,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
