@@ -28,6 +28,8 @@ my %OP_MAP = (
     starts_with => 'LIKE',
     in          => 'IN',
     not_in      => 'NOT IN',
+    is_null     => 'IS NULL',
+    is_not_null => 'IS NOT NULL',
 );
 
 =head2 Methods
@@ -37,7 +39,7 @@ my %OP_MAP = (
 =item process_query
 
 transform search queries from search form
-To create where arguements for the sql builder
+To create where arguments for the sql builder
 
 =cut
 
@@ -51,7 +53,8 @@ sub process_query {
     my @escape;
     my @where_args = ($query->{name}, $sql_op);
     my $value = $query->{value};
-    return unless defined $value;
+    return unless defined $value || $sql_op eq 'IS NULL' || $sql_op eq 'IS NOT NULL';
+    my @values;
     if($sql_op eq 'LIKE' || $sql_op eq 'NOT LIKE') {
         #escaping the % and _ charcaters
         if($value =~ s/([%_])/\\$1/g) {
@@ -65,7 +68,8 @@ sub process_query {
             $value = "\%$value";
         }
     }
-    push @where_args, $value, @escape;
+    push @values, $value if defined $value;
+    push @where_args, @values, @escape;
     return \@where_args;
 }
 
@@ -103,13 +107,13 @@ add joins to the sql builder
 
 sub add_joins {}
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
