@@ -130,11 +130,17 @@ has_field 'searches.value' =>
    do_label => 0,
   );
 
+has_field 'filter' =>
+ (
+   type => 'Text',
+   do_label => 0,
+ );
+
 =back
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -155,5 +161,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
