@@ -21,28 +21,46 @@ has_field 'id' => (
 );
 
 has_field 'dhcp_fingerprint_id' => (
-    type => 'Text',
-    label => 'DHCP Fingerprint ID',
+    type => 'FingerbankField',
+    label => 'DHCP Fingerprint',
+    fingerbank_model => "fingerbank::Model::DHCP_Fingerprint",
 );
 
 has_field 'dhcp_vendor_id' => (
-    type => 'Text',
-    label => 'DHCP Vendor ID',
+    type => 'FingerbankField',
+    label => 'DHCP Vendor',
+    fingerbank_model => "fingerbank::Model::DHCP_Vendor",
+);
+
+has_field 'dhcp6_fingerprint_id' => (
+    type => 'FingerbankField',
+    label => 'DHCPv6 Fingerprint',
+    fingerbank_model => "fingerbank::Model::DHCP6_Fingerprint",
+);
+
+has_field 'dhcp6_enterprise_id' => (
+    type => 'FingerbankField',
+    label => 'DHCPv6 Enterprise',
+    fingerbank_model => "fingerbank::Model::DHCP6_Enterprise",
 );
 
 has_field 'mac_vendor_id' => (
-    type => 'Text',
-    label => 'MAC Vendor ID',
+    type => 'FingerbankField',
+    label => 'MAC Vendor (OUI)',
+    fingerbank_model => "fingerbank::Model::MAC_Vendor",
 );
 
 has_field 'user_agent_id' => (
-    type => 'Text',
-    label => 'User Agent ID',
+    type => 'FingerbankField',
+    label => 'User Agent',
+    fingerbank_model => "fingerbank::Model::User_Agent",
 );
 
 has_field 'device_id' => (
-    type => 'Text',
-    label => 'Device ID',
+    type => 'FingerbankField',
+    label => 'Device',
+    fingerbank_model => "fingerbank::Model::Device",
+    required => 1,
 );
 
 has_field 'version' => (
@@ -51,8 +69,9 @@ has_field 'version' => (
 );
 
 has_field 'score' => (
-    type => 'Text',
+    type => 'PosInteger',
     label => 'Score',
+    required => 1,
 );
 
 has_field created_at => (
@@ -64,12 +83,12 @@ has_field updated_at => (
 );
 
 has_block definition => (
-    render_list => [qw(dhcp_fingerprint_id dhcp_vendor_id mac_vendor_id user_agent_id device_id version score created_at updated_at)],
+    render_list => [qw(dhcp_fingerprint_id dhcp_vendor_id dhcp6_fingerprint_id dhcp6_enterprise_id mac_vendor_id user_agent_id device_id version score created_at updated_at)],
 );
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -90,5 +109,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
