@@ -11,6 +11,9 @@ Form definition for Fingerbank onboarding procedure
 =cut
 
 use HTML::FormHandler::Moose;
+use pf::log;
+use fingerbank::API;
+use pf::error qw(is_error);
 
 extends 'pfappserver::Base::Form';
 
@@ -20,13 +23,23 @@ has_field 'api_key' => (
     required => 1,
 );
 
+sub validate_api_key {
+    my ($self, $field) = @_;
+    get_logger->info("Validating API key: " . $field->value);
+
+    my ($status, $msg) = fingerbank::API->new_from_config->test_key($field->value);
+    if(is_error($status)) {
+        $field->add_error($msg);
+    }
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -47,6 +60,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
