@@ -40,7 +40,11 @@ sub field_list {
 #                element_attr => { 'placeholder' => $config_defaults->{$field_name} },
                 tags => {
                     after_element   => \&help,
-                    help            => $field_doc->{description},
+                    help            => do {
+                        my $d = $field_doc->{description};
+                        $d = join("\n", @$d) if ref($d) eq 'ARRAY';
+                        $d
+                    },
                 },
             };
 
@@ -49,8 +53,13 @@ sub field_list {
                 $field->{type}            = 'Toggle';
                 $field->{checkbox_value}  = 'enabled';
                 $field->{unchecked_value} = 'disabled';
-            } else {
+            } 
+            elsif ($type eq 'numeric') {
+                $field->{type} = 'PosInteger';
+            }
+            else {
                 $field->{type} = 'Text';
+                $field->{element_class} = ['input-xxlarge'];
             }
 
             push ( @$list, $field_name => $field );
@@ -62,7 +71,7 @@ sub field_list {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -83,5 +92,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
