@@ -50,6 +50,22 @@ has_field 'dhcp_max_lease_time' =>
    required_when => { 'fake_mac_enabled' => sub { $_[0] ne '1' } },
    messages => { required => 'Please specify the maximum DHCP lease time.' },
   );
+has_field 'ip_reserved' =>
+  (
+   type => 'TextArea',
+   label => 'IP Addresses reserved',
+   messages => { required => "Range or IP addresses to exclude from the DHCP pool." },
+   tags => { after_element => \&help,
+             help => 'Range like 192.168.0.1-192.168.0.20 and or IP like 192.168.0.22,192.168.0.24 will be excluded from the DHCP pool' },
+  );
+has_field 'ip_assigned' =>
+  (
+   type => 'IPAssigned',
+   label => 'IP Addresses assigned',
+   messages => { required => "List of MAC:IP statically assigned." },
+   tags => { after_element => \&help,
+             help => 'List like 00:11:22:33:44:55:192.168.0.12,11:22:33:44:55:66:192.168.0.13' },
+  );
 has_field 'dns' =>
   (
    type => 'IPAddresses',
@@ -57,7 +73,7 @@ has_field 'dns' =>
    required_when => { 'fake_mac_enabled' => sub { $_[0] ne '1' } },
    messages => { required => "Please specify the DNS server's IP address(es)." },
    tags => { after_element => \&help,
-             help => 'Should match the IP of a registration interface or the production DNS server if the network is Inline L3' },
+             help => 'Should match the IP of a registration interface or the production DNS server(s) if the network is Inline L2/L3 (space delimited list of IP addresses)' },
   );
 
 =head2 validate
@@ -83,7 +99,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -104,5 +120,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
