@@ -23,6 +23,7 @@ has_field 'id' => (
         after_element   => \&help,
         help            => 'The unique ID of the PKI provider',
     },
+   apply => [ pfappserver::Base::Form::id_validator('PKI provider name') ]
 );
 
 has_field 'type' => (
@@ -81,7 +82,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -102,6 +103,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
