@@ -23,6 +23,7 @@ has_field 'id' => (
         after_element   => \&help,
         help            => 'The unique ID of the PKI provider',
     },
+   apply => [ pfappserver::Base::Form::id_validator('PKI provider name') ]
 );
 
 has_field 'type' => (
@@ -72,7 +73,7 @@ has_field 'username' => (
 );
 
 has_field 'password' => (
-    type        => 'Password',
+    type        => 'ObfuscatedText',
     label       => 'Password',
     tags        => {
         after_element   => \&help,
@@ -137,6 +138,16 @@ has_field 'cn_attribute' => (
     },
 );
 
+has_field 'cn_format' => (
+    type    => 'Text',
+    label   => 'Common Name Format',
+    default => '%s',
+    tags    => {
+        after_element   => \&help,
+        help            => 'Defines how the common name will be formated. %s will expand to the defined Common Name Attribute value',
+    },
+);
+
 has_field 'server_cert_path' => (
     type        => 'Path',
     label       => 'Server cert path',
@@ -158,7 +169,7 @@ has_field 'revoke_on_unregistration' => (
 );
 
 has_block 'definition' => (
-    render_list => [ qw(type proto host port username password profile country state organization cn_attribute revoke_on_unregistration ca_cert_path server_cert_path) ],
+    render_list => [ qw(type proto host port username password profile country state organization cn_attribute cn_format revoke_on_unregistration ca_cert_path server_cert_path) ],
 );
 
 =head1 AUTHOR
@@ -167,7 +178,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -188,6 +199,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
