@@ -6,7 +6,7 @@ pfappserver::Form::Config::Profile
 
 =head1 DESCRIPTION
 
-Portal profile.
+Connection profile.
 
 =cut
 
@@ -18,6 +18,7 @@ extends 'pfappserver::Base::Form';
 with 'pfappserver::Form::Config::ProfileCommon';
 
 use pf::config;
+use pf::condition_parser;
 use List::MoreUtils qw(uniq);
 
 =head1 FIELDS
@@ -31,15 +32,9 @@ The filter container field
 has_field 'filter' =>
   (
    type => 'DynamicTable',
-   'num_when_empty' => 2,
+   label => 'Filters',
    'do_label' => 0,
    'sortable' => 1,
-   inflate_default_method => sub {
-       [
-        map { pfappserver::Form::Field::ProfileFilter->filter_inflate($_) }
-        @{$_[1]}
-       ]
-   }
   );
 
 =head2 filter.conatains
@@ -51,7 +46,6 @@ The filter container field contents
 has_field 'filter.contains' =>
   (
    type => '+ProfileFilter',
-   label => 'Filter',
    widget_wrapper => 'DynamicTableRow',
   );
 
@@ -70,10 +64,29 @@ has_field 'filter_match_style' =>
     element_class => ['input-mini'],
 );
 
+=head2 status
+
+The status of the profile if it is enabled or disabled
+
+=cut
+
+has_field 'status' =>
+  (
+   type => 'Toggle',
+   label => 'Enable profile',
+   checkbox_value => 'enabled',
+   unchecked_value => 'disabled',
+   default => 'enabled'
+  );
+
 sub options_filter_match_style {
     return  map { { value => $_, label => $_ } } qw(all any);
 }
 
+has_field 'advanced_filter' => 
+(
+    type => 'TextArea',
+);
 
 =head1 METHODS
 
@@ -93,10 +106,42 @@ sub update_fields {
     $self->SUPER::update_fields();
 }
 
+=head2 validate
+
+=cut
+
+sub validate {
+    my ($self) = @_;
+    my $value = $self->value;
+    my $advanced_filter = $value->{advanced_filter};
+    if (@{$value->{filter}} == 0 && !defined $advanced_filter) {
+        $self->field('filter')->add_error("A filter or an advanced filter must be specified");
+        $self->field('advanced_filter')->add_error("A filter or an advanced filter must be specified");
+    }
+
+    if (defined $advanced_filter) {
+        my ($conditions, $err) = pf::condition_parser::parse_condition_string($advanced_filter);
+        if ($err) {
+            $self->field('advanced_filter')->add_error("Advanced filter is invalid");
+        }
+    }
+}
+
+=head2 definition
+
+The main definition block
+
+=cut
+
+has_block 'definition' =>
+  (
+    render_list => [qw(id description status root_module preregistration autoregister reuse_dot1x_credentials dot1x_recompute_role_from_portal dpsk default_psk_key unreg_on_acct_stop)],
+  );
+
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -117,5 +162,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
