@@ -6,7 +6,7 @@ pfappserver::Form::Config::Profile::Default
 
 =head1 DESCRIPTION
 
-Portal profile.
+Connection profile.
 
 =cut
 
@@ -21,10 +21,12 @@ has_field '+redirecturl' => ( required => 1 );
 
 has_field '+logo' => ( required => 1 );
 
+has_field '+status' => (is_inactive => 1, noupdate => 1, );
+
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -45,5 +47,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
