@@ -22,6 +22,7 @@ has_field 'ssid' =>
   (
    type => 'Text',
    label => 'SSID',
+   required => 1,
   );
 
 has_field 'broadcast' =>
@@ -60,8 +61,36 @@ has_field 'passcode' =>
   (
    type => 'Text',
    label => 'Wifi Key',
+   tags => { after_element => \&help,
+             help => 'The WiFi key to join the SSID' },
   );
 
+has_field 'dpsk' =>
+  (
+   type => 'Checkbox',
+   label => 'Enable DPSK',
+   tags => { after_element => \&help,
+             help => 'Define if the PSK needs to be generated' },
+  );
+
+has_field 'psk_size' =>
+  (
+   type => 'PSKLength',
+   default => 8,
+   label => 'PSK length',
+   tags => { after_element => \&help,
+             help => 'This is the length of the PSK key you want to generate. The minimum length is eight characters.' },
+  );
+
+has_field 'server_certificate_path' =>
+ (
+  type => 'Path',
+  required_when => { 'eap_type' => 25 },
+  label => 'RADIUS server certificate path',
+  tags => { after_element => \&help,
+            help => 'The path to the RADIUS server certificate' },       
+ );
+
 has_field 'cert_chain' =>
   (
    type => 'TextArea',
@@ -121,7 +150,7 @@ sub filter_deflate {
 
 has_block definition =>
   (
-   render_list => [ qw(id description type category ssid broadcast eap_type security_type passcode pki_provider) ],
+   render_list => [ qw(id description type category ssid broadcast eap_type security_type dpsk passcode pki_provider server_certificate_path) ],
   );
 
 has_block signing =>
@@ -150,7 +179,7 @@ sub option_security {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -171,5 +200,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
