@@ -18,7 +18,7 @@ has_field username => (
 );
 
 has_field password => (
-    type => 'Password',
+    type => 'ObfuscatedText',
     required => 1,
 );
 
@@ -59,7 +59,7 @@ has_block definition =>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -80,5 +80,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
