@@ -18,9 +18,6 @@ use pf::config;
 use pf::util;
 use File::Find qw(find);
 
-## Definition
-has 'roles' => (is => 'ro', default => sub {[]});
-
 has_field 'ip' =>
   (
    type => 'Text',
@@ -64,13 +61,24 @@ has_field 'scannername' =>
              help => 'Name of the scanner to use on the nessus server' },
   );
 
+has_field 'verify_hostname' =>
+  (
+   type => 'Toggle',
+   label => 'Verify Hostname',
+   tags => { after_element => \&help,
+             help => 'Verify hostname of server' },
+   checkbox_value  => 'enabled',
+   unchecked_value => 'disabled',
+   default => 'enabled',
+  );
+
 =over
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -91,5 +99,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
