@@ -215,7 +215,8 @@ sub options_UTC_Timezone {
     local $_;
     my @options = map {
         {   group   => $self->_localize($_),
-            options => options_UTC_Timezone_group($self, $_)
+            options => options_UTC_Timezone_group($self, $_),
+            value => '',
         }
     } DateTime::TimeZone->categories;
     unshift @options, { value => '', label => ''  };
@@ -230,7 +231,7 @@ sub options_UTC_Timezone_group {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -251,5 +252,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
