@@ -18,9 +18,33 @@ use namespace::autoclean;
 
 has '+type_attr'        => ( default => 'password' );
 
+sub BUILD {
+    my ($self, @args) = @_;
+    $self->add_element_class(qw(pf-obfuscated-text));
+    $self->set_tag('input_append_button', '<i class="icon-eye"></i>');
+}
+
+=head2 element_attributes
+
+Add the x-placeholder attribute if the placeholder field exists
+
+=cut
+
+sub element_attributes {
+    my ( $self, @args ) = @_;
+    my $attr = $self->SUPER::element_attributes(@args);
+    if (exists $attr->{placeholder} && defined $attr->{placeholder}) {
+        $attr->{'x-placeholder'} = $attr->{placeholder};
+        $attr->{placeholder} =~ s/./\*/g;
+    }
+
+    $attr->{autocomplete} = 'off';
+    return $attr;
+}
+
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -41,5 +65,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
+
 1;
