@@ -11,7 +11,7 @@ Form definition to create or update a network interface.
 =cut
 
 use HTML::FormHandler::Moose;
-use List::MoreUtils qw(firstidx);
+use List::MoreUtils qw(firstidx any);
 
 extends 'pfappserver::Base::Form';
 with 'pfappserver::Base::Form::Role::Help';
@@ -26,14 +26,22 @@ has_field 'name' =>
 has_field 'ipaddress' =>
   (
    type => 'IPAddress',
-   label => 'IP Address',
+   label => 'IPv4 Address',
   );
 has_field 'netmask' =>
   (
    type => 'IPAddress',
-   label => 'Netmask',
+   label => 'IPv4 Netmask',
    element_attr => { 'placeholder' => '255.255.255.0' },
   );
+has_field 'ipv6_address' => (
+    type => 'IP6Address',
+    label => 'IPv6 Address',
+);
+has_field 'ipv6_prefix' => (
+    type=> 'Text',
+    label => 'IPv6 Prefix',
+);
 has_field 'type' =>
   (
    type => 'Select',
@@ -55,7 +63,7 @@ has_field 'dns' =>
   (
    type => 'IPAddresses',
    label => 'DNS',
-   wrapper_attr => { 'style' => 'display: none' },
+   wrapper_attr => { 'class' => 'hide' },
    tags => { after_element => \&help,
              help => 'The primary DNS server of your network.' },
   );
@@ -76,12 +84,6 @@ has_field 'high_availability' =>
     default => 0,
    );
 
-has_field 'vip' =>
-  (
-   type => 'IPAddress',
-   label => 'Virtual IP Address',
-  );
-
 has_field 'nat_enabled' => (
     type => 'Toggle',
     checkbox_value => 1,
@@ -90,6 +92,25 @@ has_field 'nat_enabled' => (
     label => 'Enable NATting',
 );
 
+has_field 'split_network' => (
+    type => 'Toggle',
+    checkbox_value => 1,
+    unchecked_value => 0,
+    default => 0,
+    label => 'Split network by role',
+    tags => { after_element => \&help,
+             help => 'This will create a small network for each roles.' },
+);
+
+has_field 'reg_network' =>
+  (
+   type => 'Text',
+   label => 'Registration IP Address CIDR format',
+   tags => { after_element => \&help,
+             help => 'When split network by role is enabled then this network will be used as the registration network (example: 192.168.0.1/24).' },
+  );
+
+
 =head2 options_type
 
 =cut
@@ -119,7 +140,7 @@ sub options_additional_listening_daemons {
     my $self = shift;
 
     return map { { value => $_, label => $_ } }
-        qw(portal);
+        qw(portal radius);
 }
 
 =head2 validate
@@ -142,18 +163,28 @@ sub validate {
 
     # Remove 'portal' additional listening daemon on already enabled httpd.portal interfaces
     # TODO: Make a list of interface type rather than this ugly "or" - dwuelfrath@inverse.ca 2015.06.11
-    if ( defined $self->value->{type} && ( $self->value->{type} eq 'vlan-registration' or $self->value->{type} eq 'vlan-isolation' or $self->value->{type} eq 'inline' or $self->value->{type} eq 'inlinel2' or $self->value->{type} eq 'portal' ) ) {
+    my @types = qw(vlan-registration vlan-isolation dns-enforcement inline inlinel2 portal);
+    if ( defined $self->value->{type} && any { $_ eq $self->value->{type} } @types ) {
         my %daemons = map { $_ => 1 } @{$self->value->{additional_listening_daemons}};
         if ( exists($daemons{'portal'}) ) {
             my $index = firstidx { $_ eq 'portal' } @{$self->value->{additional_listening_daemons}};
             splice @{$self->value->{additional_listening_daemons}}, $index, 1;
         }
     }
+    # Remove double radius type if exist
+    @types = qw(radius);
+    if ( defined $self->value->{type} && any { $_ eq $self->value->{type} } @types ) {
+        my %daemons = map { $_ => 1 } @{$self->value->{additional_listening_daemons}};
+        if ( exists($daemons{'radius'}) ) {
+            my $index = firstidx { $_ eq 'radius' } @{$self->value->{additional_listening_daemons}};
+            splice @{$self->value->{additional_listening_daemons}}, $index, 1;
+        }
+    }
 }
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -174,5 +205,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
