@@ -2,11 +2,11 @@ package pfappserver::Form::Portal;
 
 =head1 NAME
 
-pfappserver::Form::Portal - portal profiles
+pfappserver::Form::Portal - connection profiles
 
 =head1 DESCRIPTION
 
-Sortable list of portal profiles.
+Sortable list of connection profiles.
 
 =cut
 
@@ -49,11 +49,21 @@ has_field 'items.description' =>
    do_label => 0,
   );
 
+=item items.status
+
+=cut
+
+has_field 'items.status' =>
+  (
+   type => 'Text',
+   do_label => 0,
+  );
+
 =back
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -74,5 +84,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
