@@ -15,6 +15,7 @@ use HTTP::Status qw(:constants is_success);
 use HTML::FormHandler::Moose;
 
 extends 'pfappserver::Base::Form::Authentication::Action';
+with 'pfappserver::Base::Form::Role::Help';
 
 has '+source_type' => ( default => 'SQL' );
 
@@ -111,6 +112,20 @@ has_field 'notes' =>
    label => 'Notes',
   );
 
+=head2 login_remaining
+
+=cut
+
+has_field 'login_remaining' =>
+  (
+   type => 'PosInteger',
+   label => 'Login remaining',
+   default => undef,
+   disabled => 1,
+   tags => { after_element => \&help,
+             help => 'Unlimited logins when empty.' },
+  );
+
 =head2 valid_from
 
 =cut
@@ -131,16 +146,133 @@ has_field 'expiration' =>
    messages => { required => 'Please specify the end date of the registration window.' },
   );
 
-has_field [qw( anniversary birthday gender lang nickname organization cell_phone
-  work_phone title building_number apartment_number room_number)] =>
+has_field 'anniversary' =>
   (
    type => 'Text',
+   label => 'anniversary',
   );
 
-
-has_field [qw(custom_field_1 custom_field_2 custom_field_3 custom_field_4 custom_field_5 custom_field_6 custom_field_7 custom_field_8 custom_field_9)] =>
+has_field 'birthday' =>
   (
-       type => 'Text',
+   type => 'Text',
+   label => 'birthday',
+  );
+
+has_field 'gender' =>
+  (
+   type => 'Text',
+   label => 'gender',
+  );
+
+has_field 'lang' =>
+  (
+   type => 'Text',
+   label => 'lang',
+  );
+
+has_field 'nickname' =>
+  (
+   type => 'Text',
+   label => 'nickname',
+  );
+
+has_field 'cell_phone' =>
+  (
+   type => 'Text',
+   label => 'cell_phone',
+  );
+
+has_field 'work_phone' =>
+  (
+   type => 'Text',
+   label => 'work_phone',
+  );
+
+has_field 'title' =>
+  (
+   type => 'Text',
+   label => 'title',
+  );
+
+has_field 'building_number' =>
+  (
+   type => 'Text',
+   label => 'building_number',
+  );
+
+has_field 'apartment_number' =>
+  (
+   type => 'Text',
+   label => 'apartment_number',
+  );
+
+has_field 'room_number' =>
+  (
+   type => 'Text',
+   label => 'room_number',
+  );
+
+has_field 'custom_field_1' =>
+  (
+   type => 'Text',
+   label => 'custom_field_1',
+  );
+
+has_field 'custom_field_2' =>
+  (
+   type => 'Text',
+   label => 'custom_field_2',
+  );
+
+has_field 'custom_field_3' =>
+  (
+   type => 'Text',
+   label => 'custom_field_3',
+  );
+
+has_field 'custom_field_4' =>
+  (
+   type => 'Text',
+   label => 'custom_field_4',
+  );
+
+has_field 'custom_field_5' =>
+  (
+   type => 'Text',
+   label => 'custom_field_5',
+  );
+
+has_field 'custom_field_6' =>
+  (
+   type => 'Text',
+   label => 'custom_field_6',
+  );
+
+has_field 'custom_field_7' =>
+  (
+   type => 'Text',
+   label => 'custom_field_7',
+  );
+
+has_field 'custom_field_8' =>
+  (
+   type => 'Text',
+   label => 'custom_field_8',
+  );
+
+has_field 'custom_field_9' =>
+  (
+   type => 'Text',
+   label => 'custom_field_9',
+  );
+
+has_field 'psk' =>
+  (
+   type => 'Text',
+   Label => 'PSK key',
+   minlength => 8,
+   tags => { after_element => \&help,
+         help => 'Minimum of 8 characters.' },
   );
 
 =head2 Blocks
@@ -160,7 +292,7 @@ has_block 'user' =>
 
 has_block 'miscellaneous' =>
   (
-   render_list => [qw(anniversary birthday gender lang nickname organization cell_phone work_phone title building_number apartment_number room_number)]
+   render_list => [qw(anniversary birthday gender lang nickname cell_phone work_phone title building_number apartment_number room_number psk)]
   );
 
 has_block 'custom_fields' =>
@@ -214,7 +346,7 @@ sub update_fields {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -235,5 +367,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
