@@ -14,6 +14,7 @@ Ex: guest[1-10]
 
 use HTML::FormHandler::Moose;
 extends 'pfappserver::Base::Form';
+with 'pfappserver::Base::Form::Role::Help';
 
 # Form fields
 has_field 'prefix' =>
@@ -28,6 +29,14 @@ has_field 'quantity' =>
    label => 'Quantity',
    required => 1,
   );
+has_field 'pid_overwrite' => (
+    type    => 'Checkbox',
+    label   => 'Username (PID) overwrite',
+    tags    => {
+        after_element   => \&help,
+        help            => 'Overwrite the username (PID) if it already exists',
+    },
+);
 has_field 'firstname' =>
   (
    type => 'Text',
@@ -48,10 +57,19 @@ has_field 'notes' =>
    type => 'TextArea',
    label => 'Notes',
   );
+has_field 'login_remaining' =>
+  (
+   type => 'PosInteger',
+   label => 'Login remaining',
+   default => undef,
+   tags => { after_element => \&help,
+             help => 'Leave it empty to allow unlimited logins.' },
+  );
+
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -72,5 +90,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
