@@ -23,6 +23,14 @@ has_field 'pid' =>
    tags => { after_element => \&help,
              help => 'The username to use for login to the captive portal.' },
   );
+has_field 'pid_overwrite' => (
+    type    => 'Checkbox',
+    label   => 'Username (PID) overwrite',
+    tags    => {
+        after_element   => \&help,
+        help            => 'Overwrite the username (PID) if it already exists',
+    },
+);
 has_field 'password' =>
   (
    type => 'Password',
@@ -45,6 +53,11 @@ has_field 'company' =>
    type => 'Text',
    label => 'Company',
   );
+has_field 'telephone' =>
+  (
+   type => 'Text',
+   label => 'Telephone',
+  );
 has_field 'email' =>
   (
    type => 'Email',
@@ -61,10 +74,19 @@ has_field 'notes' =>
    type => 'TextArea',
    label => 'Notes',
   );
+has_field 'login_remaining' =>
+  (
+   type => 'PosInteger',
+   label => 'Login remaining',
+   default => undef,
+   tags => { after_element => \&help,
+             help => 'Leave it empty to allow unlimited logins.' },
+  );
+
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -85,5 +107,5 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
