@@ -16,7 +16,7 @@ use warnings;
 use Moose;
 use namespace::autoclean;
 
-use pf::file_paths;
+use pf::file_paths qw($conf_dir);
 use pf::log;
 
 =head1 METHODS
@@ -68,7 +68,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -89,6 +89,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
