@@ -22,11 +22,11 @@ extends 'pfappserver::Base::Model::Config';
 
 sub _buildConfigStore { pf::ConfigStore::AdminRoles->new }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
