@@ -15,7 +15,6 @@ pfappserver::Model::Config::Fingerbank::Combination
 use fingerbank::Model::Combination();
 use Moose;
 use namespace::autoclean;
-use pf::config::cached;
 use HTTP::Status qw(:constants :is);
 use Readonly;
 
@@ -58,11 +57,11 @@ sub update {
     $self->SUPER::update($id, $assignments);
 }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
