@@ -15,7 +15,6 @@ pfappserver::Model::Config::Pfdetect
 use HTTP::Status qw(:constants is_error is_success);
 use Moose;
 use namespace::autoclean;
-use pf::config::cached;
 use pf::config;
 use pf::ConfigStore::Pfdetect;
 
@@ -24,13 +23,11 @@ extends 'pfappserver::Base::Model::Config';
 
 sub _buildConfigStore { pf::ConfigStore::Pfdetect->new }
 
-__PACKAGE__->meta->make_immutable;
-
-=back
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
