@@ -13,11 +13,14 @@ Catalyst Model.
 use Moose;
 use namespace::autoclean;
 use Net::Netmask;
+use pf::config qw($DISTRIB $DIST_VERSION);
 
 use pf::log;
 use pf::error qw(is_error is_success);
 use pf::util;
 
+our $DB_SERVICE_NAME = "packetfence-mariadb";
+
 extends 'Catalyst::Model';
 
 =head1 METHODS
@@ -29,12 +32,13 @@ extends 'Catalyst::Model';
 sub check_mysqld_status {
     my ( $self ) = @_;
     my $logger = get_logger();
-
+    my $cmd = "systemctl show -p MainPID $DB_SERVICE_NAME";
     # -x: this causes the program to also return process id's of shells running the named scripts.
-    my $pid;
-    chomp($pid = `pidof -x mysqld`);
+    my $mainpid;
+    chomp($mainpid = `$cmd`);
+    my (undef,$pid) = split('=', $mainpid);
     $pid = 0 if ( !$pid );
-    $logger->info("pidof -x mysqld returned $pid");
+    $logger->info("$cmd returned $pid");
 
     return ($pid);
 }
@@ -93,7 +97,7 @@ sub setDefaultRoute {
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
 
-    my $cmd = "LANG=C sudo ip route replace to default via $gateway 2>&1";
+    my $cmd = "sudo ip route replace to default via $gateway 2>&1";
     $logger->debug("Replace default gateway: $cmd");
     $status = pf_run($cmd, accepted_exit_status => [ $_EXIT_CODE_EXISTS ]);
 
@@ -128,11 +132,9 @@ sub start_mysqld_service {
         return ($STATUS::OK, $status_msg);
     }
 
-    my $mysql_script = 'mysqld';
-    $mysql_script = 'mysql' if ( -e "/etc/init.d/mysql" );
     # please keep LANG=C in case we need to fetch the output of the command
-    my $cmd = "LANG=C setsid sudo service $mysql_script start 2>&1";
-    $logger->debug("Starting mysqld service: $cmd");
+    my $cmd = "setsid sudo service $DB_SERVICE_NAME start 2>&1";
+    $logger->debug("Starting $DB_SERVICE_NAME service: $cmd");
     $status = pf_run($cmd);
 
     # Everything goes as expected
@@ -141,9 +143,9 @@ sub start_mysqld_service {
         $logger->info($status_msg);
         return ($STATUS::OK, $status_msg);
     }
-    # Something wen't wrong
+    # Something went wrong
     else {
-        $status_msg = "Something wen't wrong while starting MySQL server";
+        $status_msg = "Something went wrong while starting MySQL server";
         $logger->warn($status_msg);
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
@@ -159,8 +161,7 @@ sub restart_pfconfig {
 
     my ($status, $status_msg);
 
-    # please keep LANG=C in case we need to fetch the output of the command
-    my $cmd = "LANG=C setsid sudo service packetfence-config restart 2>&1";
+    my $cmd = "setsid sudo service packetfence-config restart 2>&1";
     $logger->debug("Restarting packetfence-config service: $cmd");
     $status = pf_run($cmd);
 
@@ -170,9 +171,9 @@ sub restart_pfconfig {
         $logger->info($status_msg);
         return ($STATUS::OK, $status_msg);
     }
-    # Something wen't wrong
+    # Something went wrong
     else {
-        $status_msg = "Something wen't wrong while restarting packetfence-config";
+        $status_msg = "Something went wrong while restarting packetfence-config";
         $logger->warn($status_msg);
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
@@ -348,6 +349,8 @@ sub writeNetworkConfigs {
             hwaddr          => $interfaces_ref->{$interface}->{'hwaddress'},
             ipaddr          => $interfaces_ref->{$interface}->{'ipaddress'},
             netmask         => $interfaces_ref->{$interface}->{'netmask'},
+            ipv6_address    => $interfaces_ref->{$interface}->{'ipv6_address'},
+            ipv6_prefix     => $interfaces_ref->{$interface}->{'ipv6_prefix'},
         };
 
         my $template = Template->new({
@@ -363,9 +366,9 @@ sub writeNetworkConfigs {
         }
         my $cmd = "cat $var_dir$_interface_conf_file$interface | sudo tee $_network_conf_dir$_interfaces_conf_dir$_interface_conf_file$interface 2>&1";
         my $status = pf_run($cmd);
-        # Something wen't wrong
+        # Something went wrong
         if ( !(defined($status) ) ) {
-            $status_msg = "Something wen't wrong while writing the network interface file";
+            $status_msg = "Something went wrong while writing the network interface file";
             $logger->warn($status_msg);
             return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
         }
@@ -385,18 +388,18 @@ sub writeNetworkConfigs {
 
     my $cmd = "echo @content | sudo tee $_network_conf_dir$_network_conf_file";
     my $status = pf_run($cmd);
-    # Something wen't wrong
+    # Something went wrong
     if ( !(defined($status) ) ) {
-        $status_msg = "Something wen't wrong while writing the network file";
+        $status_msg = "Something went wrong while writing the network file";
         $logger->warn($status_msg);
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
     $cmd = "echo GATEWAY=$gateway | sudo tee -a $_network_conf_dir$_network_conf_file";
 
     $status = pf_run($cmd);
-    # Something wen't wrong
+    # Something went wrong
     if ( !(defined($status) ) ) {
-        $status_msg = "Something wen't wrong while writing the network file";
+        $status_msg = "Something went wrong while writing the network file";
         $logger->warn($status_msg);
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
@@ -466,9 +469,9 @@ sub writeNetworkConfigs {
         $logger->info($status_msg);
         return ($STATUS::OK, $status_msg);
     }
-    # Something wen't wrong
+    # Something went wrong
     else {
-        $status_msg = "Something wen't wrong while writing the network interface file";
+        $status_msg = "Something went wrong while writing the network interface file";
         $logger->warn($status_msg);
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
@@ -480,7 +483,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -501,6 +504,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
