@@ -15,11 +15,11 @@ pfappserver::Model::Config::Violations
 use Moose;
 use namespace::autoclean;
 
-use pf::config::cached;
-use pf::config;
+use pf::config qw(%CAPTIVE_PORTAL %Profiles_Config);
 use pf::violation_config;
 use HTTP::Status qw(:constants is_error is_success);
 use pf::ConfigStore::Violations;
+use List::MoreUtils qw(uniq);
 
 extends 'pfappserver::Base::Model::Config';
 
@@ -34,11 +34,15 @@ Return the list of available remediation templates
 =cut
 
 sub availableTemplates {
-    opendir(DIR, $CAPTIVE_PORTAL{TEMPLATE_DIR} . '/violations');
-    my @templates = grep { /^[^\.]+\.html$/ } readdir(DIR);
-    s/\.html// for @templates;
-    closedir(DIR);
-
+    my @dirs = map { uniq(@{pf::Connection::ProfileFactory->_from_profile($_)->{_template_paths}}) } keys(%Profiles_Config);
+    my @templates;
+    foreach my $dir (@dirs) {
+        next unless opendir(my $dh, $dir . '/violations');
+        push @templates, grep { /^[^\.]+\.html$/ } readdir($dh);
+        s/\.html// for @templates;
+        closedir($dh);
+    }
+    @templates = sort(uniq(@templates));
     return \@templates;
 }
 
@@ -86,7 +90,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
