@@ -20,6 +20,7 @@ use namespace::autoclean;
 
 use pf::log;
 use pf::config;
+use pf::file_paths qw($install_dir $conf_dir);
 use pf::error;
 use pf::util;
 use Perl::Version;
@@ -127,7 +128,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -148,6 +149,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
