@@ -24,20 +24,24 @@ use pf::accounting qw(
     node_accounting_daily_time node_accounting_weekly_time node_accounting_monthly_time node_accounting_yearly_time
 );
 use pf::constants;
-use pf::config;
+use pf::config qw($EAP);
 use pf::error qw(is_error is_success);
 use pf::node;
 use pf::nodecategory;
-use pf::iplog;
+use pf::ip4log;
 use pf::locationlog;
 use pf::log;
 use pf::node;
 use pf::person;
 use pf::enforcement qw(reevaluate_access);
-use pf::useragent qw(node_useragent_view);
 use pf::util;
 use pf::config::util;
 use pf::violation;
+use pf::SwitchFactory;
+use pf::Connection;
+use Text::CSV;
+use pf::import;
+use pf::fingerbank;
 
 =head1 METHODS
 
@@ -75,57 +79,7 @@ Field names to be displayed. The first one is the default sort field.
 =cut
 
 sub field_names {
-    return [qw(mac detect_date regdate unregdate computername pid last_ip status dhcp_fingerprint category)];
-}
-
-=head2 countAll
-
-=cut
-
-sub countAll {
-    my ( $self, %params ) = @_;
-
-    my $logger = get_logger();
-    my ($status, $status_msg);
-
-    my $count;
-    eval {
-        my @result = node_count_all(undef, %params);
-        $count = pop @result;
-    };
-    if ($@) {
-        $status_msg = "Can't count nodes from database.";
-        $logger->error($status_msg);
-        return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
-    }
-
-    return ($STATUS::OK, $count->{nb});
-}
-
-=head2 search
-
-Used to perform a simple search
-
-=cut
-
-sub search {
-    my ( $self, %params ) = @_;
-
-    my $logger = get_logger();
-    my ($status, $status_msg);
-
-    my @nodes;
-    eval {
-        @nodes = node_view_all(undef, %params);
-        @nodes = grep { keys %$_ ? $_ : undef } @nodes;
-    };
-    if ($@) {
-        $status_msg = "Can't fetch nodes from database.";
-        $logger->error($status_msg);
-        return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
-    }
-
-    return ($STATUS::OK, \@nodes);
+    return [qw(mac detect_date regdate unregdate computername pid last_ip status device_class category)];
 }
 
 =head2 view
@@ -143,7 +97,6 @@ sub view {
     my $node = {};
     eval {
         $node = node_view($mac);
-        $node->{vendor} = oui_to_vendor($mac);
         for my $date (qw(regdate unregdate)) {
             my $timestamp = "${date}_timestamp";
             if ($node->{$timestamp}) {
@@ -152,7 +105,7 @@ sub view {
             }
         }
         foreach (qw[detect_date regdate unregdate]) {
-            $node->{$_} = '' if exists $node->{$_} && $node->{$_} eq '0000-00-00 00:00:00';
+            $node->{$_} = '' if exists $node->{$_} && $node->{$_} eq $ZERO_DATE;
         }
 
         # Show 802.1X username only if connection is of type EAP
@@ -162,19 +115,20 @@ sub view {
         }
 
         # Fetch IP information
-        $node->{iplog} = pf::iplog::view($mac);
+        $node->{iplog} = pf::ip4log::view($mac);
+        $node->{ip6log} = pf::ip6log::view($mac);
 
         # Fetch the IP activity of the past 14 days
 #        my $start_time = time() - 14 * 24 * 60 * 60;
 #        my $end_time = time();
-#        my @iplog_history = iplog_history($mac,
+#        my @iplog_history = pf::ip4log::get_history($mac,
 #                                              (start_time => $start_time, end_time => $end_time));
 #        $node->{iplog}->{history} = \@iplog_history;
 #        _graphIplogHistory($node, $start_time, $end_time);
 
         # Fetch IP address history
-        my @iplog_history = iplog_history($mac);
-        map { $_->{end_time} = '' if ($_->{end_time} eq '0000-00-00 00:00:00') } @iplog_history;
+        my @iplog_history = pf::ip4log::get_history($mac);
+        map { $_->{end_time} = '' if ($_->{end_time} eq $ZERO_DATE) } @iplog_history;
         $node->{iplog}->{history} = \@iplog_history;
 
         if ($node->{iplog}->{'ip'}) {
@@ -185,17 +139,22 @@ sub view {
             $node->{iplog}->{end_time} = $last_iplog->{end_time};
         }
 
-        # Fetch switch location history
-        my @locationlog_history = locationlog_history_mac($mac);
-        #                                                  (start_time => $start_time, end_time => $end_time));
-        if (scalar @locationlog_history > 0) {
-            $node->{locationlog}->{history} = \@locationlog_history;
+        my @ip6log_history = pf::ip6log::get_history($mac);
+        map { $_->{end_time} = '' if ($_->{end_time} eq $ZERO_DATE) } @ip6log_history;
+        $node->{ip6log}->{history} = \@ip6log_history;
+
+        if ($node->{ip6log}->{'ip'}) {
+            $node->{ip6log}->{active} = 1;
+        } else {
+            my $last_ip6log = shift @ip6log_history;
+            $node->{ip6log}->{ip} = $last_ip6log->{ip};
+            $node->{ip6log}->{end_time} = $last_ip6log->{end_time};
         }
 
-        # Fetch user-agent information
-        if ($node->{user_agent}) {
-            $node->{useragent} = node_useragent_view($mac);
-        }
+        $node->{fingerbank_info} = pf::node::fingerbank_info($mac);
+
+        # Check for multihost
+        $node->{'multihost'} = [pf::node::check_multihost($mac, {'switch_id' => $node->{'last_switch'}, 'switch_port' => $node->{'last_port'}, 'connection_type' => $node->{'last_connection_type'}})];
 
         #    my $node_accounting = node_accounting_view($mac);
         #    if (defined($node_accounting->{'mac'})) {
@@ -228,13 +187,13 @@ sub create {
     my ($self, $data) = @_;
 
     my $logger = get_logger();
-    my ($status, $result) = ($STATUS::CREATED);
+    my ($status, $result, $status_msg) = ($STATUS::CREATED);
     my $mac = $data->{mac};
     my $pid = $data->{pid} || $default_pid;
 
     # Adding person (using modify in case person already exists)
-    $result = node_register($mac, $pid, %{$data});
-    if ($result) {
+    ( $result, $status_msg ) = pf::node::node_register($mac, $pid, %{$data});
+    if ( $result ) {
         $logger->info("Created node $mac");
     }
     else {
@@ -255,24 +214,21 @@ sub update {
     my ($self, $mac, $node_ref) = @_;
 
     my $logger = get_logger();
-    my ($status, $result) = ($STATUS::OK);
+    my ($status, $result, $status_msg) = ($STATUS::OK);
     my $previous_node_ref;
 
     $previous_node_ref = node_view($mac);
+    $node_ref->{pid} ||= $default_pid;
     if ($previous_node_ref->{status} ne $node_ref->{status}) {
         # Status was modified
-        my $option;
         if ($node_ref->{status} eq $pf::node::STATUS_REGISTERED) {
-            $option = "register";
-            $result = node_register($mac, $previous_node_ref->{pid}, %{$node_ref});
+            ( $result, $status_msg ) = pf::node::node_register($mac, $node_ref->{pid}, %{$node_ref});
         }
         elsif ($node_ref->{status} eq $pf::node::STATUS_UNREGISTERED) {
-            $option = "deregister";
             $result = node_deregister($mac, %{$node_ref});
         }
     }
     unless (defined $result) {
-        $node_ref->{pid} ||= $default_pid;
         $result = node_modify($mac, %{$node_ref});
     }
     if ($result) {
@@ -299,116 +255,8 @@ See pf::import::nodes
 =cut
 
 sub importCSV {
-    my ($self, $data, $user) = @_;
-
-    my $logger = get_logger();
-    my ($status, $message);
-    my $filename = $data->{nodes_file}->filename;
-    my $tmpfilename = $data->{nodes_file}->tempname;
-    my $delimiter = $data->{delimiter};
-    my $default_node_pid = $data->{default_pid};
-    my $default_category_id = $data->{default_category_id};
-    my $default_voip = $data->{default_voip};
-
-    $logger->debug("CSV file import nodes from $tmpfilename ($filename, \"$delimiter\")");
-
-    # Build hash table for columns order
-    my $count = 0;
-    my $skipped = 0;
-    my %index = ();
-    foreach my $column (@{$data->{columns}}) {
-        if ($column->{enabled} || $column->{name} eq 'mac') {
-            # Add checked columns and mandatory columns
-            $index{$column->{name}} = $count;
-            $count++;
-        }
-    }
-
-    # Map delimiter to its actual character
-    if ($delimiter eq 'comma') {
-        $delimiter = ',';
-    } elsif ($delimiter eq 'semicolon') {
-        $delimiter = ';';
-    } elsif ($delimiter eq 'colon') {
-        $delimiter = ':';
-    } elsif ($delimiter eq 'tab') {
-        $delimiter = "\t";
-    }
-
-    # Read CSV file
-    $count = 0;
-    my $has_pid = exists $index{'pid'};
-    if (open (my $import_fh, "<", $tmpfilename)) {
-        my $csv = Text::CSV->new({ binary => 1, sep_char => $delimiter });
-        while (my $row = $csv->getline($import_fh)) {
-            my ($pid, $mac, $node, %data, $result);
-
-            if($has_pid) {
-                $pid = $row->[$index{'pid'}] || undef;
-                if ( $pid && ($pid !~ /$pf::person::PID_RE/ || !person_exist($pid))) {
-                    $logger->debug("Ignored unknown PID ($pid)");
-                    $skipped++;
-                    next;
-                }
-            }
-
-            $mac = $row->[$index{'mac'}] || undef;
-            if (!$mac || !valid_mac($mac)) {
-                $logger->debug("Ignored invalid MAC ($mac)");
-                $skipped++;
-                next;
-            }
-            $mac = clean_mac($mac);
-            $pid ||= $default_node_pid || $default_pid;
-            $node = node_view($mac);
-            %data =
-              (
-               'mac'         => $mac,
-               'pid'         => $pid,
-               'category'    => $index{'category'}  ? $row->[$index{'category'}]  : undef,
-               'category_id' => $index{'category'}  ? undef                       : $default_category_id,
-               'unregdate'   => $index{'unregdate'} ? $row->[$index{'unregdate'}] : undef,
-               'voip'        => $index{'voip'}      ? $row->[$index{'voip'}]      : $default_voip,
-               'notes'       => $index{'notes'}     ? $row->[$index{'notes'}]     : undef,
-              );
-            if (exists $index{'bypass_vlan'}) {
-                    $data{'bypass_vlan'} = $row->[$index{'bypass_vlan'}];
-            }
-            if (exists $index{'bypass_role'}) {
-                $data{'bypass_role_id'} = nodecategory_lookup($row->[$index{'bypass_role'}]);
-            }
-            if (!defined($node) || (ref($node) eq 'HASH' && $node->{'status'} ne $pf::node::STATUS_REGISTERED)) {
-                $logger->debug("Register MAC $mac ($pid)");
-                $result = node_register($mac, $pid, %data);
-            }
-            else {
-                $logger->debug("Modify already registered MAC $mac ($pid)");
-                $result = node_modify($mac, %data);
-            }
-            if ($result) {
-                $count++;
-            }
-            else {
-                $skipped++;
-            }
-        }
-        unless ($csv->eof) {
-            $logger->warn("Problem with CSV file importation: " . $csv->error_diag());
-            ($status, $message) = ($STATUS::INTERNAL_SERVER_ERROR, ["Problem with importation: [_1]" , $csv->error_diag()]);
-        }
-        else {
-            ($status, $message) = ($STATUS::CREATED, { count => $count, skipped => $skipped });
-        }
-        close $import_fh;
-    }
-    else {
-        $logger->warn("Can't open CSV file $filename: $@");
-        ($status, $message) = ($STATUS::INTERNAL_SERVER_ERROR, "Can't read CSV file.");
-    }
-
-    $logger->info("CSV file ($filename) import $count nodes, skip $skipped nodes");
-
-    return ($status, $message);
+    my ($self, @args) = @_;
+    return pf::import::nodes(@args);
 }
 
 =head2 delete
@@ -438,7 +286,7 @@ sub reevaluate {
     my $logger = get_logger();
     my ($status, $status_msg) = ($STATUS::OK);
 
-    unless(reevaluate_access($mac, "node_modify")){
+    unless(reevaluate_access($mac, "admin_modify")){
         $status = $STATUS::INTERNAL_SERVER_ERROR;
         $status_msg = "The access couldn't be reevaluated.";
     }
@@ -446,6 +294,55 @@ sub reevaluate {
     return ($status, $status_msg);
 }
 
+sub refresh_fingerbank_device {
+    my ($self, $mac) = @_;
+
+    my $logger = get_logger();
+    my ($status, $status_msg) = ($STATUS::OK);
+
+    unless(pf::fingerbank::process($mac, $TRUE)){
+        $status = $STATUS::INTERNAL_SERVER_ERROR;
+        $status_msg = "Couldn't refresh device profiling through Fingerbank";
+    }
+
+    return ($status, $status_msg);
+}
+
+=head2 restartSwitchport
+
+Restart the switchport for a MAC address.
+
+=cut
+
+sub restartSwitchport {
+    my ($self, $mac) = @_;
+    my $logger = get_logger();
+    my ($status, $status_msg) = ($STATUS::OK);
+
+    my $locationlog = locationlog_view_open_mac($mac);
+    unless($locationlog) {
+        return ($STATUS::INTERNAL_SERVER_ERROR, "Unable to find node location.");
+    }
+
+    my $connection = pf::Connection->new;
+    $connection->backwardCompatibleToAttributes($locationlog->{connection_type});
+    unless($connection->transport eq "Wired") {
+        return ($STATUS::INTERNAL_SERVER_ERROR, "Trying to restart the port of a non-wired connection");
+    }
+
+    my $switch = pf::SwitchFactory->instantiate($locationlog->{switch});
+    unless($switch) {
+        return ($STATUS::INTERNAL_SERVER_ERROR, "Unable to instantiate switch ".$locationlog->{switch});
+    }
+
+    unless($switch->bouncePort($locationlog->{port})) {
+        $status = $STATUS::INTERNAL_SERVER_ERROR;
+        $status_msg = "Couldn't restart port.";
+    }
+
+    return ($status, $status_msg);
+}
+
 =head2 availableStatus
 
 =cut
@@ -473,7 +370,7 @@ sub violations {
     my @violations;
     eval {
         @violations = violation_view_desc($mac);
-        map { $_->{release_date} = '' if ($_->{release_date} eq '0000-00-00 00:00:00') } @violations;
+        map { $_->{release_date} = '' if ($_->{release_date} eq $ZERO_DATE) } @violations;
     };
     if ($@) {
         $status_msg = "Can't fetch violations from database.";
@@ -481,7 +378,10 @@ sub violations {
         return ($STATUS::INTERNAL_SERVER_ERROR, $status_msg);
     }
 
-    return ($STATUS::OK, \@violations);
+    # Check for multihost
+    my @multihost = pf::node::check_multihost($mac);
+
+    return ($STATUS::OK, { 'violations' => \@violations, 'multihost' => \@multihost });
 }
 
 =head2 addViolation
@@ -551,7 +451,7 @@ sub _closeViolation{
     my $violation = violation_exist_id($id);
     if ($violation) {
         if (violation_force_close($violation->{mac}, $violation->{vid})) {
-            pf::enforcement::reevaluate_access($violation->{mac}, 'manage_vclose');
+            pf::enforcement::reevaluate_access($violation->{mac}, "admin_modify");
             $result = 1;
         }
     }
@@ -566,7 +466,7 @@ sub bulkApplyViolation {
     my ($self, $violation_id, @macs) = @_;
     my $count = 0;
     foreach my $mac (@macs) {
-        my ($last_id) = violation_add( $mac, $violation_id);
+        my ($last_id) = violation_add( $mac, $violation_id, ('force' => $TRUE) );
         $count++ if $last_id > 0;;
     }
     return ($STATUS::OK, ["[_1] violation(s) were opened.",$count]);
@@ -803,6 +703,22 @@ sub bulkApplyBypassRole {
     return ($STATUS::OK, ["Bypass Role was changed for [_1] node(s)", $count]);
 }
 
+=head2 bulkRestartSwitchport
+
+Restart the switchport for a list of MAC addresses
+
+=cut
+
+sub bulkRestartSwitchport {
+    my ($self, @macs) = @_;
+    my $count = 0;
+    foreach my $mac (@macs) {
+        my ($status, undef) = $self->restartSwitchport($mac);
+        $count ++ if(is_success($status));
+    }
+    return ($STATUS::OK, ["Switchport was restarted for [_1] node(s)", $count]);
+}
+
 =head2 bulkReevaluateAccess
 
 =cut
@@ -811,7 +727,7 @@ sub bulkReevaluateAccess {
     my ($self, @macs) = @_;
     my $count = 0;
     foreach my $mac (@macs) {
-        if (reevaluate_access($mac, "node_modify")){
+        if (reevaluate_access($mac, "admin_modify")){
             $count++;
         }
     }
@@ -824,7 +740,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -845,6 +761,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
