@@ -8,7 +8,10 @@ use Try::Tiny;
 
 use pf::log;
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $management_network
+    %Config
+);
 use pfconfig::manager;
 
 =head1 NAME
@@ -81,7 +84,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -102,6 +105,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
