@@ -15,7 +15,6 @@ use Moose;  # automatically turns on strict and warnings
 use namespace::autoclean;
 
 use pfappserver::Form::Config::Switch;
-use pf::config::cached;
 
 BEGIN {
     extends 'pfappserver::Base::Controller';
@@ -75,7 +74,7 @@ sub index :Path :Args(0) {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -96,6 +95,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
