@@ -14,10 +14,9 @@ use HTTP::Status qw(:constants is_error is_success);
 use Moose;  # automatically turns on strict and warnings
 use namespace::autoclean;
 
-use pf::config::cached;
 use pf::util;
 use pf::domain;
-use pf::config;
+use pf::config qw(%ConfigDomain);
 
 BEGIN {
     extends 'pfappserver::Base::Controller';
@@ -35,7 +34,7 @@ __PACKAGE__->config(
         create          => { AdminRole => 'DOMAIN_CREATE' },
         clone           => { AdminRole => 'DOMAIN_CREATE' },
         update          => { AdminRole => 'DOMAIN_UPDATE' },
-        refresh_domains => { AdminRole => 'DOMAIN_UPDATE' },
+        update_rejoin   => { AdminRole => 'DOMAIN_UPDATE' },
         rejoin          => { AdminRole => 'DOMAIN_UPDATE' },
         remove          => { AdminRole => 'DOMAIN_DELETE' },
     },
@@ -47,26 +46,35 @@ __PACKAGE__->config(
 
 =head1 METHODS
 
+=head2 before create clone update_rejoin
+
+Set the bind_dn and the bind_pass as required
+
+=cut
+
+before [qw(create clone update_rejoin)] => sub {
+    my ($self, $c) = @_;
+    my $form = $self->getForm($c);
+    for my $f (qw(bind_dn bind_pass)) {
+        my $field = $form->field($f);
+        $field->required(1);
+    }
+    $c->stash->{current_form_instance} = $form;
+};
+
 =head2 after create clone
 
-Show the 'view' template when creating or cloning domain.
+Join the after creating or cloning domain
 
 =cut
 
 after [qw(create clone)] => sub {
     my ($self, $c) = @_;
-    if (!(is_success($c->response->status) && $c->request->method eq 'POST' )) {
-        $c->stash->{template} = 'config/domain/view.tt';
-    }
-};
-
-after [qw(create update)] => sub {
-    my ($self, $c) = @_;
-    if($c->request->method eq 'POST' ){
+    if( $c->request->method eq 'POST' && !$c->stash->{form}->has_errors ) {
         pf::domain::regenerate_configuration();
         my $output = pf::domain::join_domain($c->req->param('id'));
         $c->stash->{items}->{join_output} = $output;
-        $c->forward('reset_password',[$c->req->param('id')]);
+        $c->forward('reset_credentials',[$c->req->param('id')]);
     }
 };
 
@@ -80,7 +88,7 @@ after list => sub {
     $c->log->debug("Checking if user can edit the domain config");
     # we block the editing if the user has an OS configuration and no configured domains
     # this means he hasn't gone through the migration script
-    $c->stash->{block_edit} = ( pf::domain::has_os_configuration() && !keys(%ConfigDomain) ); 
+    $c->stash->{block_edit} = ( pf::domain::has_os_configuration() && !keys(%ConfigDomain) );
 };
 
 =head2 after view
@@ -123,19 +131,6 @@ sub index :Path :Args(0) {
     $c->forward('list');
 }
 
-=head2 refresh_domains
-
-Usage: /config/domain/refresh_domains
-
-=cut
-
-sub refresh_domains :Local {
-    my ($self, $c) = @_;
-    pf::domain::regenerate_configuration();
-    $c->stash->{status_msg} = "Refreshed the domains";
-    $c->stash->{current_view} = 'JSON';
-}
-
 =head2 rejoin
 
 Usage: /config/domain/rejoin/:domainId
@@ -146,23 +141,33 @@ Usage: /config/domain/rejoin/:domainId
 sub rejoin :Local :Args(1) {
     my ($self, $c, $domain) = @_;
     my $info = pf::domain::rejoin_domain($domain);
-    $c->forward('reset_password',[ $domain ]);
+    $c->forward('reset_credentials',[ $domain ]);
     $c->stash->{status_msg} = "Rejoined the domain";
     $c->stash->{items} = $info;
     $c->stash->{current_view} = 'JSON';
 }
 
-=head2 set_password
+=head2 set_credentials
 
-Usage: /config/domain/set_password/:domainId
+Usage: /config/domain/set_credentials/:domainId
 
 =cut
 
-sub set_password :Local :Args(1) {
+sub set_credentials :Local :Args(1) {
     my ($self, $c, $domain) = @_;
+    my $username = $c->request->param('username');
     my $password = $c->request->param('password');
+    if ( (!defined $username) || length ($username) == 0 || (!defined $password) || length($password) == 0) {
+        $c->stash(
+            status_msg   => 'Username or Password not set',
+            current_view => 'JSON',
+        );
+        $c->response->status(HTTP_BAD_REQUEST);
+        return;
+    }
+
     my $model = $self->getModel($c);
-    my ($status,$result) = $model->update($domain, { bind_pass => $password } );
+    my ($status,$result) = $model->update($domain, { bind_dn => $username, bind_pass => $password } );
     ($status,$result) = $model->commit();
     $c->stash(
         status_msg   => $result,
@@ -172,16 +177,16 @@ sub set_password :Local :Args(1) {
 
 }
 
-=head2 reset_password
+=head2 reset_credentials
 
 Resets the password of the specified domain
 
 =cut
 
-sub reset_password :Private {
+sub reset_credentials :Private {
     my ($self, $c, $domain) = @_;
     my $model = $self->getModel($c);
-    my ($status,$result) = $model->update($domain, { bind_pass => '' } );
+    my ($status,$result) = $model->update($domain, { bind_dn => undef, bind_pass => undef } );
     ($status,$result) = $model->commit();
     $c->stash(
         status_msg   => $result,
@@ -190,9 +195,25 @@ sub reset_password :Private {
     $c->response->status($status);
 }
 
+=head2 update_rejoin
+
+Usage: /config/domain/update_rejoin/:domainId
+
+=cut
+
+
+sub update_rejoin :Local :Args(1) {
+    my ($self, $c, $domain) = @_;
+    $c->stash->{id} = $domain;
+    $c->forward('update');
+    if (!$c->stash->{form}->has_errors) {
+        $c->forward('rejoin');
+    }
+}
+
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -213,6 +234,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
