@@ -14,50 +14,36 @@ Customizations can be made using L<pfappserver::Controller::Config::Fingerbank::
 
 use Moose;  # automatically turns on strict and warnings
 use namespace::autoclean;
+use pf::constants;
+use pf::util;
+use pf::config::util;
+use pf::error qw(is_success);
 
 BEGIN { extends 'pfappserver::Base::Controller'; }
 
-=head2
+=head2 update_upstream_db
 
 Update "local" upstream Fingerbank database from Fingerbank project
 
 =cut
 
-sub update :Local :Args(0) :AdminRole('FINGERBANK_UPDATE') {
+sub update_upstream_db :Local :Args(0) :AdminRole('FINGERBANK_UPDATE') {
     my ( $self, $c ) = @_;
 
     $c->stash->{current_view} = 'JSON';
 
-    my $apiclient = pf::client::getClient();
-    $apiclient->notify('fingerbank_update_upstream_db');
+    pf::cluster::notify_each_server('fingerbank_update_component', action => "update-upstream-db", email_admin => $TRUE, fork_to_queue => $TRUE);
 
     $c->stash->{status_msg} = $c->loc("Successfully dispatched update request for Fingerbank upstream DB. An email will follow for status");
 }
 
-=head2 submit
-
-Allow submission of "unknown" and "unmatched" fingerprints to upstream Fingerbank project
-
-=cut
-
-sub submit :Local :Args(0) :AdminRole('FINGERBANK_READ') {
-    my ( $self, $c ) = @_;
-
-    $c->stash->{current_view} = 'JSON';
-
-    my $apiclient = pf::client::getClient();
-    $apiclient->notify('fingerbank_submit_unmatched');
-
-    $c->stash->{status_msg} = $c->loc("Successfully dispatched submit request for unknown/unmatched fingerprints to Fingerbank. An email will follow for status");
-}
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -78,6 +64,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
