@@ -33,6 +33,7 @@ __PACKAGE__->config(
         list   => { AdminRole => 'SWITCHES_READ' },
         create => { AdminRole => 'SWITCHES_CREATE' },
         clone  => { AdminRole => 'SWITCHES_CREATE' },
+        import => { AdminRole => 'SWITCHES_CREATE' },
         update => { AdminRole => 'SWITCHES_UPDATE' },
         remove => { AdminRole => 'SWITCHES_DELETE' },
     },
@@ -55,16 +56,13 @@ sub begin :Private {
 
     $model = $c->model("Config::Switch");
     ($status, $switch_default) = $model->read('default');
-    ($status, $roles) = $c->model('Roles')->list;
-    $roles = undef unless(is_success($status));
-    $c->stash->{roles} = $roles;
-
     $c->stash->{current_model_instance} = $model;
     $c->stash->{switch_default} = $switch_default;
-
     $c->stash->{model_name} = "Switch";
     $c->stash->{controller_namespace} = "Config::Switch";
-    $c->stash->{current_form_instance} = $c->form("Config::Switch", roles => $c->stash->{roles});
+    my $form = $c->form("Config::Switch");
+    $c->stash->{current_form_instance} = $form;
+    $c->stash->{roles} = $form->roles;
 }
 
 after qw(list search) => sub {
@@ -88,6 +86,7 @@ sub after_list {
     my @switches;
     my $groupsModel = $c->model("Config::SwitchGroup");
     my $groupPrefix = $groupsModel->configStore->group;
+    my $cs = $c->model('Config::Switch')->configStore;
     foreach my $switch (@{$c->stash->{items}}) {
         next if($switch->{id} =~ /^$groupPrefix /);
         my $id = $switch->{id};
@@ -97,10 +96,11 @@ sub after_list {
                 $switch->{floatingdevice} = pop @$floatingdevice;
             }
         }
-        my $cs = $c->model('Config::Switch')->configStore;
-        $switch->{type} = $cs->fullConfigRaw($id)->{type};
+        my $fullConfig = $cs->fullConfigRaw($id);
+        $switch->{type} = $fullConfig->{type};
         $switch->{group} ||= $cs->topLevelGroup;
-        $switch->{mode} = $cs->fullConfigRaw($id)->{mode};
+        $switch->{mode} = $fullConfig->{mode};
+        $switch->{description} //= $fullConfig->{description};
         push @switches, $switch;
     }
     $c->stash->{switch_groups} = [ sort @{$groupsModel->readAllIds} ];
@@ -129,12 +129,12 @@ sub search : Local : AdminRole('SWITCHES_READ') {
     my ($status, $status_msg, $result, $violations);
     my %search_results;
     my $model = $self->getModel($c);
-    my $form = $self->getForm($c);
+    my $form = $c->form('AdvancedSearch');
     $form->process(params => $c->request->params);
     if ($form->has_errors) {
         $status = HTTP_BAD_REQUEST;
         $status_msg = $form->field_errors;
-        $c->stash(current_view => 'JSON');
+        $c->stash(current_view => 'JSON', status_msg => $status_msg);
     } else {
         my $query = $form->value;
         $c->stash(current_view => 'JSON') if ($c->request->params->{'json'});
@@ -144,6 +144,7 @@ sub search : Local : AdminRole('SWITCHES_READ') {
             $c->stash($result);
         }
     }
+    $c->response->status($status);
 }
 
 =head2 after create
@@ -183,6 +184,7 @@ Usage: /config/switch/
 sub index :Path :Args(0) {
     my ($self, $c) = @_;
     $c->stash->{action} = 'list';
+    $c->stash->{import_form} = $c->form('Config::SwitchImport');
     $c->forward('list');
 }
 
@@ -246,9 +248,115 @@ sub create_in_group :Local :Args(1) :AdminRole('SWITCHES_CREATE') {
     $c->stash->{form}->update_fields($c->stash->{item});
 }
 
+=head2 invalidate_cache
+
+Usage /config/switch/:id/invalidate_cache
+
+Invalidate switch distributed cache
+
+=cut
+
+sub invalidate_cache :Chained('object') :PathPart('invalidate_cache') :Args(0) {
+    my ( $self, $c ) = @_;
+    my $model = $self->getModel($c);
+    my $idKey = $model->idKey;
+
+    my $switch = pf::SwitchFactory->instantiate($c->stash->{$idKey});
+    unless ( ref($switch) ) {
+        $c->log->error("Unable to instantiate switch object using switch_id '" . $c->stash->{$idKey} . "'");
+    }
+
+    $switch->invalidate_distributed_cache();
+
+    my $id = $c->stash->{$idKey};
+    $c->stash(
+        status_msg   => "Cleared distributed cache for switch ID '$id'",
+        current_view => 'JSON',
+    );
+    $c->response->status(200);
+}
+
+=head1 import_csv
+
+A method to be able to import switches from a CSV
+
+=cut
+
+sub import_csv :Local :Args(0) :AdminRole('SWITCHES_CREATE') {
+    my ( $self, $c ) = @_;
+   
+    my $logger = pf::log->get_logger();
+    my $upload = $c->req->upload('importcsv');
+    my $file = $upload->fh;
+    my $model = $c->model("Config::Switch");
+    my $delimiter = $c->req->param('delimiter');
+    my $model_group = $c->model("Config::SwitchGroup");
+
+    # Map delimiter to its actual character
+    if ($delimiter eq 'comma') {
+        $delimiter = ',';
+    } elsif ($delimiter eq 'semicolon') {
+        $delimiter = ';';
+    } elsif ($delimiter eq 'colon') {
+        $delimiter = ':';
+    } elsif ($delimiter eq 'tab') {
+        $delimiter = "\t";
+    }
+
+    my $skip = 0;
+    my $skip1 = 0;
+    my $switches = 0;
+    my %seen;
+    my $csv = Text::CSV->new({ binary => 1, sep_char => $delimiter });
+    my $line_count = 0;
+    while (my $fields = $csv->getline($file)) {
+        $line_count++;
+        unless($skip1) {
+            $skip1 = 1;
+            next;
+        }
+
+        if (@$fields < 3) {
+            $skip++;
+            $logger->warn("This entry has been skipped because this line: $line_count contains more fields than required");
+            next;
+        }
+
+        my $hostname = @$fields[0];
+        $hostname =~ s/[^a-zA-Z0-9 _-]//g;
+        $hostname =~ tr/\r\n//d;
+
+        my $switch_ip = @$fields[1];
+        my $switch_group = @$fields[2];
+        my ( $status, $msg ) = $model_group->hasId($switch_group);
+        if (is_error($status)) {
+            $skip++;
+            $logger->warn("This entry has been skipped because the switch group: $switch_group does not exist in the switch configutaion.");
+            next;
+        }
+
+        my $assignements = {
+            group => $switch_group,
+        };
+
+        # Only update the description if its non-empty
+        $assignements->{description} = $hostname if(length($hostname) > 0);
+
+        $model->update_or_create($switch_ip, $assignements);
+        $switches++;
+    }
+    unless ($csv->eof) {
+        $logger->warn("Problem with CSV file importation: " . $csv->error_diag());
+        $c->stash( status_msg => $c->loc("Problem with importation: [_1]" , $csv->error_diag()));
+    }
+    $model->commit();
+    $c->stash( status_msg => $c->loc("[_1] switches have been imported, [_2] switches have been skipped", $switches, $skip));
+}
+
+
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -269,6 +377,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
