@@ -14,8 +14,9 @@ use HTML::Entities;
 use HTTP::Status qw(:constants is_error is_success);
 use Moose;
 
-use pf::config;
+use pf::config qw(%Config);
 use List::MoreUtils qw(all);
+use fingerbank::Config;
 #use namespace::autoclean;
 
 BEGIN { extends 'Catalyst::Controller'; }
@@ -38,6 +39,9 @@ my @steps = (
     { id          => 'admin',
       title       => 'Administration',
       description => 'Configure access to the admin interface' },
+    { id          => 'fingerbank',
+      title       => 'Fingerbank',
+      description => 'Configure Fingerbank' },
     { id          => 'services',
       title       => 'Confirmation',
       description => 'Start the services' }
@@ -207,7 +211,7 @@ sub networks :Chained('object') :PathPart('networks') :Args(0) {
         my @missing = ();
 
         foreach my $enforcement (keys %{$c->session->{enforcements}}) {
-            my $types_ref = $c->model('Enforcement')->getAvailableTypes($enforcement);
+            my $types_ref = $c->model('Enforcement')->getRequiredTypes($enforcement);
             foreach my $type (@{$types_ref}) {
                 unless (exists $selected_types{$type} ||
                         $type eq 'other' ||
@@ -245,6 +249,10 @@ sub networks :Chained('object') :PathPart('networks') :Args(0) {
         $c->stash->{interfaces} = $interfaces_ref;
         $c->stash->{seen_networks} = $c->model('Interface')->map_interface_to_networks($c->stash->{interfaces});
     }
+
+    # Remove some CSP restrictions to accomodate Chosen (the select-on-steroid widget):
+    #  - Allows use of inline source elements (eg style attribute)
+    $c->stash->{csp_headers} = { style => "'unsafe-inline'" };
 }
 
 =head2 database
@@ -277,6 +285,8 @@ sub database :Chained('object') :PathPart('database') :Args(0) {
             if (is_success($status)) {
                 # everything has been done successfully
                 $c->session->{completed}->{$c->action->name} = 1;
+                # we need to restart mariadb so that it applies the network configuration
+                system("sudo /usr/bin/systemctl restart packetfence-mariadb");
             }
         }
     }
@@ -290,6 +300,7 @@ PacketFence minimal configuration (step 4)
 
 sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
     my ( $self, $c ) = @_;
+    my $logger = $c->log;
 
     my $pf_model = $c->model('Config::Pf');
     if ($c->request->method eq 'GET') {
@@ -305,6 +316,7 @@ sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
                                   general.hostname
                                   general.dhcpservers
                                   alerting.emailaddr
+                                  alerting.smtpserver
                                   advanced.hash_passwords
                              )} = (
                                    @$general_ref{qw(
@@ -312,7 +324,10 @@ sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
                                                        hostname
                                                        dhcpservers
                                                   )},
-                                   @$alerting_ref{emailaddr},
+                                   @$alerting_ref{qw(
+                                                       emailaddr
+                                                       smtpserver
+                                                  )},
                                    @$advanced_ref{hash_passwords}
                                   );
                     $c->stash->{'config'} = \%config;
@@ -327,6 +342,7 @@ sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
         my $general_hostname        = $c->request->params->{'general.hostname'};
         my $general_dhcpservers     = $c->request->params->{'general.dhcpservers'};
         my $alerting_emailaddr      = $c->request->params->{'alerting.emailaddr'};
+        my $alerting_smtpserver     = $c->request->params->{'alerting.smtpserver'};
         my $advanced_hash_passwords = $c->request->params->{'advanced.hash_passwords'};
 
         unless ($general_domain && $general_hostname && $general_dhcpservers &&
@@ -341,18 +357,30 @@ sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
                 'dhcpservers' => $general_dhcpservers,
             });
             if (is_error($status)) {
+                $logger->error($message);
                 delete $c->session->{completed}->{$c->action->name};
             }
             ( $status, $message ) = $pf_model->update('alerting' => {
-                'emailaddr'  => $alerting_emailaddr
+                'emailaddr'  => $alerting_emailaddr,
             });
             if (is_error($status)) {
+                $logger->error($message);
                 delete $c->session->{completed}->{$c->action->name};
             }
+            if($alerting_smtpserver) {
+                ( $status, $message ) = $pf_model->update('alerting' => {
+                    'smtpserver'  => $alerting_smtpserver,
+                });
+                if (is_error($status)) {
+                    $logger->error($message);
+                    delete $c->session->{completed}->{$c->action->name};
+                }
+            }
             ( $status, $message ) = $pf_model->update('advanced' => {
                 'hash_passwords'  => $advanced_hash_passwords
             });
             if (is_error($status)) {
+                $logger->error($message);
                 delete $c->session->{completed}->{$c->action->name};
             } else {
                 $pf_model->commit();
@@ -370,6 +398,7 @@ sub configuration :Chained('object') :PathPart('configuration') :Args(0) {
 
         }
         if (is_error($status)) {
+            $logger->error($message);
             $c->response->status($status);
             $c->stash->{status_msg} = $message;
         }
@@ -414,6 +443,19 @@ sub admin :Chained('object') :PathPart('admin') :Args(0) {
     }
 }
 
+=head2 fingerbank
+
+Fingerbank setup (step 6)
+
+=cut
+
+sub fingerbank :Chained('object') :PathPart('fingerbank') :Args(0) {
+    my ($self, $c) = @_;
+    $c->session->{completed}->{$c->action->name} = 1;
+    my $config = fingerbank::Config::get_config;
+    $c->stash->{fingerbank_api_key} = $config->{'upstream'}{'api_key'};
+}
+
 =head2 services
 
 Confirmation and services launch (step 6)
@@ -447,29 +489,30 @@ sub services :Chained('object') :PathPart('services') :Args(0) {
             $c->stash->{'admin_port'} = $c->model('PfConfigAdapter')->getWebAdminPort();
         }
 
-        my ($status, $services_status) = $c->model('Services')->status();
+        my ($status, $services) = $c->model('Services')->status(1);
         if ( is_success($status) ) {
             $c->log->info("successfully listed services");
-            $c->stash->{'services_status'} = $services_status->{services};
+            $c->stash($services);
         }
-        if ( is_error($status) ) {
+        else {
             $c->log->error("an error trying to list the services");
             $c->response->status($status);
-            $c->stash->{'error'} = $services_status;
+            $c->stash->{'error'} = $services;
         }
     } elsif ($c->request->method eq 'POST') {
         # Start the services
         if (!$c->session->{started}) {
             $c->session->{started} = 1;
+            system("sudo /usr/local/pf/bin/pfcmd service pf updatesystemd");
             # restart pfconfig
             $c->model("Config::System")->restart_pfconfig();
-            $c->detach(Service => 'pf_start'); 
-        } else { 
-            my ($HTTP_CODE, $services) = $c->model('Services')->status;
-            if( all { $_ ne '0' } values %{ $services->{services} } ) {
+            $c->detach(Service => 'pf_start');
+        } else {
+            my ($HTTP_CODE, $services) = $c->model('Services')->status(1);
+            if( all { $_->{status} ne '0' } @{ $services->{services} } ) {
                 $c->model('Configurator')->update_currently_at();
             }
-            $c->controller('Service')->_process_model_results_as_json($c, $HTTP_CODE, $services);    
+            $c->controller('Service')->_process_model_results_as_json($c, $HTTP_CODE, $services);
         }
     }
 }
@@ -480,7 +523,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -501,6 +544,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
