@@ -18,6 +18,7 @@ use Moose;
 use Readonly;
 use URI::Escape::XS qw(uri_escape uri_unescape);
 use namespace::autoclean;
+use pf::cluster;
 
 BEGIN { extends 'pfappserver::Base::Controller'; }
 
@@ -29,25 +30,32 @@ sub index :Path : Args(0) {
     my ($self, $c) = @_;
     my $model = $c->model('Pfqueue');
     $c->stash({
-        counters => $model->counters,
-        miss_counters => $model->miss_counters,
-        queue_counts => $model->queue_counts,
+        stats => $model->stats,
+        hostname => $pf::cluster::host_id
     });
 }
 
 sub counters :Args {
     my ($self, $c) = @_;
     my $model = $c->model('Pfqueue');
+    my $counters = [ map { $_->{count} > 0 } @{$model->counters} ];
     $c->stash({
         current_view => 'JSON',
-        counters => $model->counters,
+        counters => $counters,
         miss_counters => $model->miss_counters,
     });
 }
 
+sub cluster :Local : Args(0) {
+    my ($self, $c) = @_;
+    $c->stash({
+        servers => pf::cluster::queue_stats(),
+    });
+}
+
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -68,6 +76,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
