@@ -15,7 +15,9 @@ use warnings;
 
 use Moose;
 use namespace::autoclean;
-
+use pf::db;
+use pf::config qw(%Config);
+use pf::util;
 BEGIN { extends 'Catalyst::Controller' }
 
 #
@@ -29,6 +31,19 @@ __PACKAGE__->config(namespace => '');
 
 =over
 
+
+=head2 auto
+
+auto
+
+=cut
+
+sub auto :Private {
+    my ( $self, $c ) = @_;
+    $c->stash->{readonly_mode} = db_check_readonly();
+    return 1;
+}
+
 =item index
 
 The root page (/)
@@ -70,19 +85,37 @@ Attempt to render a view, if needed.
 
 sub end : ActionClass('RenderView') {
     my ( $self, $c ) = @_;
-    if (defined($c->req->header('accept')) && $c->req->header('accept') eq 'application/json'){
+    $self->updateResponseHeaders($c);
+    if (defined($c->req->header('accept')) && $c->req->header('accept') eq 'application/json') {
         $c->stash->{current_view} = 'JSON';
     }
+
     if (scalar @{$c->error}) {
-        for my $error ( @{ $c->error } ) {
+        for my $error (@{$c->error}) {
             $c->log->error($error);
         }
         $c->stash->{status_msg} = $c->pf_localize('An error condition has occured. See server side logs for details.');
         $c->response->status(500);
         $c->clear_errors;
     }
-    elsif (exists $c->stash->{status_msg} && defined $c->stash->{status_msg} ) {
-        $c->stash->{status_msg} = $c->pf_localize($c->stash->{status_msg});
+    elsif (defined (my $status_msg = $c->stash->{status_msg})) {
+        $c->stash->{status_msg} = $c->pf_localize($status_msg);
+    }
+}
+
+=head2 updateResponseHeaders
+
+updateResponseHeaders
+
+=cut
+
+sub updateResponseHeaders {
+    my ($self, $c) = @_;
+    my $response = $c->response;
+    $response->header('Cache-Control' => 'no-cache, no-store');
+    $response->header('X-Frame-Options' => 'SAMEORIGIN');
+    if (isenabled($Config{'advanced'}{'admin_csp_security_headers'})){
+        $c->csp_server_headers();
     }
 }
 
@@ -94,7 +127,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -115,6 +148,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
