@@ -17,13 +17,17 @@ use HTTP::Status qw(:constants is_error is_success);
 use Moose;
 use namespace::autoclean;
 use POSIX;
-
+use SQL::Abstract::More;
+use JSON::MaybeXS;
 use pfappserver::Form::User;
 use pfappserver::Form::User::Create;
 use pfappserver::Form::User::Create::Single;
 use pfappserver::Form::User::Create::Multiple;
 use pfappserver::Form::User::Create::Import;
 use pf::admin_roles;
+use pf::authentication qw(getAuthenticationSource);
+use pf::config qw(%Config);
+use pf::sms_carrier qw(sms_carrier_view_all);
 
 BEGIN { extends 'pfappserver::Base::Controller'; }
 with 'pfappserver::Role::Controller::BulkActions';
@@ -35,10 +39,12 @@ __PACKAGE__->config(
         bulk_deregister      => { AdminRole => 'USERS_UPDATE' },
         bulk_apply_role      => { AdminRole => 'USERS_UPDATE' },
         bulk_apply_violation => { AdminRole => 'USERS_UPDATE' },
+        bulk_delete          => { AdminRole => 'USERS_DELETE' },
     },
     action_args => {
         '*' => { model => 'User'},
-        advanced_search => { model => 'Search::User', form => 'AdvancedSearch' },
+        advanced_search => { model => 'Search::User', form => 'UserSearch' },
+        simple_search => { model => 'Search::User', form => 'UserSearch' },
     },
 );
 
@@ -48,7 +54,7 @@ __PACKAGE__->config(
 
 =cut
 
-sub index :Path :Args(0) :AdminRole('USERS_READ') {
+sub index :Path :Args(0) :AdminRoleAny(USERS_READ) :AdminRoleAny(USERS_READ_SPONSORED) {
     my ( $self, $c ) = @_;
 
     $c->go('simple_search');
@@ -58,27 +64,11 @@ sub index :Path :Args(0) :AdminRole('USERS_READ') {
 
 =cut
 
-sub simple_search :Local :Args() :AdminRole('USERS_READ') {
+sub simple_search :Local :Args() :AdminRoleAny(USERS_READ): AdminRoleAny(USERS_READ_SPONSORED) {
     my ( $self, $c ) = @_;
-    $c->stash($c->request->params);
-    $self->_list_items( $c, 'User' );
+    $c->forward('advanced_search');
 }
 
-=head2 after _list_items
-
-The method _list_items comes from pfappserver::Base::Controller and is called from Base::Action::SimpleSearch.
-
-=cut
-
-after _list_items => sub {
-    my ( $self, $c ) = @_;
-    my ( $status, $roles, $violations );
-    ( $status, $roles ) = $c->model('Roles')->list();
-    $c->stash( roles => $roles );
-    ( $status, $violations ) = $c->model('Config::Violations')->readAll();
-    $c->stash( violations => $violations );
-
-};
 
 =head2 object
 
@@ -108,19 +98,20 @@ sub object :Chained('/') :PathPart('user') :CaptureArgs(1) {
 
 =cut
 
-sub view :Chained('object') :PathPart('read') :Args(0) :AdminRole('USERS_READ') {
+sub view :Chained('object') :PathPart('read') :Args(0) :AdminRoleAny(USERS_READ) :AdminRoleAny(USERS_READ_SPONSORED) {
     my ($self, $c) = @_;
-
     my ($form);
+    my $user = $c->stash->{user};
 
-    $form = pfappserver::Form::User->new(ctx => $c, init_object => $c->stash->{user});
+    $form = pfappserver::Form::User->new(ctx => $c, init_object => $user);
     $form->process();
-    $form->field('actions')->add_extra unless @{$c->stash->{user}{actions}}; # an action must be chosen
+    $form->field('actions')->add_extra unless @{$user->{actions}}; # an action must be chosen
     $c->stash->{form} = $form;
-    my $password = $c->stash->{user}{password};
+    my $password = $user->{password};
     if(defined $password) {
         $c->stash->{password_hash_type} = pf::password::password_get_hash_type($password);
     }
+    $self->_add_sms_source($c, $user);
 }
 
 =head2 delete
@@ -131,6 +122,7 @@ sub delete :Chained('object') :PathPart('delete') :Args(0) :AdminRole('USERS_DEL
     my ($self, $c) = @_;
 
     my ($status, $result) = $self->getModel($c)->delete($c->stash->{user}->{pid});
+    $self->audit_current_action($c, status => $status, pid => $c->stash->{user}->{pid});
     if (is_error($status)) {
         $c->response->status($status);
         $c->stash->{status_msg} = $result;
@@ -139,6 +131,23 @@ sub delete :Chained('object') :PathPart('delete') :Args(0) :AdminRole('USERS_DEL
     $c->stash->{current_view} = 'JSON';
 }
 
+=head2 unassignNodes
+
+=cut
+
+sub unassignNodes :Chained('object') :PathPart('unassignNodes') :Args(0) :AdminRole('USERS_UPDATE') {
+    my ($self, $c) = @_;
+
+    my ($status, $result) = $self->getModel($c)->unassignNodes($c->stash->{user}->{pid});
+    $self->audit_current_action($c, status => $status, pid => $c->stash->{user}->{pid});
+    if (is_error($status)) {
+        $c->response->status($status);
+    }
+    $c->stash->{status_msg} = $result;
+
+    $c->stash->{current_view} = 'JSON';
+}
+
 =head2 update
 
 =cut
@@ -156,6 +165,7 @@ sub update :Chained('object') :PathPart('update') :Args(0) :AdminRole('USERS_UPD
     }
     else {
         ($status, $message) = $self->getModel($c)->update($c->stash->{user}->{pid}, $form->value, $c->user);
+        $self->audit_current_action($c, status => $status, pid => $c->stash->{user}->{pid});
     }
     if (is_error($status)) {
         $c->response->status($status);
@@ -195,8 +205,11 @@ sub nodes :Chained('object') :PathPart :Args(0) :AdminRole('NODES_READ') {
         $c->stash->{nodes} = $result;
     } else {
         $c->response->status($status);
-        $c->stash->{status_msg} = $result;
-        $c->stash->{current_view} = 'JSON';
+        $c->stash(
+            status_msg => $result,
+            current_view => 'JSON',
+            nodes => [],
+        )
     }
     return ;
 }
@@ -214,6 +227,7 @@ sub reset :Chained('object') :PathPart('reset') :Args(0) :AdminRole('USERS_UPDAT
         my $password = $c->request->params->{password};
         if ($password) {
             ( $status, $message ) = $c->model('DB')->resetUserPassword( $c->stash->{user}->{pid}, $password );
+            $self->audit_current_action($c, status => $status, pid => $c->stash->{user}->{pid});
             $c->session->{'users_passwords'} = [ { pid => $c->stash->{user}->{pid}, password => $password } ];
         }
     }
@@ -236,9 +250,9 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
     my ($type, %data, @options);
     my ($status, $result, $message);
 
-    ($status, $result) = $c->model('Roles')->list();
+    ($status, $result) = $c->model('Config::Roles')->listFromDB();
     if (is_success($status)) {
-        @roles = map { $_->{name} => $_->{name} } @$result;
+        @roles = @$result;
     }
 
     $form = pfappserver::Form::User::Create->new(ctx => $c, roles => \@roles);
@@ -257,6 +271,7 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
     $form_single->process(params => $params);
     $form_multiple->process(params => $params);
 
+    my $skipped;
     if ($c->request->method eq 'POST') {
         $type = $c->request->param('type');
         #check if they can do multiple actions
@@ -280,6 +295,9 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
                 %data = (%{$form->value}, %{$form_single->value});
                 ($status, $message) = $self->getModel($c)->createSingle(\%data, $c->user);
                 @options = ('mail');
+                if ($self->_add_sms_source($c, \%data)) {
+                    push @options, 'sms';
+                }
                 $c->session->{'users_passwords'} = $message;
             }
         }
@@ -290,7 +308,7 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
             }
             else {
                 %data = (%{$form->value}, %{$form_multiple->value});
-                ($status, $message) = $self->getModel($c)->createMultiple(\%data, $c->user);
+                ($status, $message, $skipped) = $self->getModel($c)->createMultiple(\%data, $c->user);
                 $c->session->{'users_passwords'} = $message;
             }
         }
@@ -304,7 +322,7 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
             }
             else {
                 %data = (%{$form->value}, %{$form_import->value});
-                ($status, $message) = $self->getModel($c)->importCSV(\%data, $c->user);
+                ($status, $message, $skipped) = $self->getModel($c)->importCSV(\%data, $c->user);
                 @options = ('mail');
                 $c->session->{'users_passwords'} = $message;
             }
@@ -312,6 +330,7 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
         else {
             $status = $STATUS::INTERNAL_SERVER_ERROR;
         }
+        $self->audit_current_action($c, status => $status, create_type => $type);
 
         $c->response->status($status);
         $c->stash->{status} = $status;
@@ -320,13 +339,15 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
             # List the created accounts
             my @pids = map { $_->{pid} } @{$message};
             $c->stash->{users} = $message;
+            $c->stash->{skipped} = $skipped if defined($skipped);
             $c->stash->{pids} = \@pids;
             $c->stash->{options} = \@options;
             $c->stash->{template} = 'user/list_password.tt';
         }
         else {
             $c->stash->{status_msg} = $message; # TODO: localize error message
-            $c->stash->{current_view} = 'JSON';
+            $c->stash->{template} = 'user/create_error.tt';
+            $c->stash->{error_information} = encode_json({status_msg => $message, status => $status});
         }
     }
     else {
@@ -341,6 +362,30 @@ sub create :Local :AdminRoleAny('USERS_CREATE') :AdminRoleAny('USERS_CREATE_MULI
     }
 }
 
+=head2 _add_sms_source
+
+Add SMS source information if advanced.source_to_send_sms_when_creating_users is configured
+
+=cut
+
+sub _add_sms_source {
+    my ($self, $c, $user) = @_;
+    my $sms_source_id = $Config{advanced}{source_to_send_sms_when_creating_users};
+    unless ($sms_source_id && $user->{telephone}) {
+        return;
+    }
+    my $sms_source = getAuthenticationSource($sms_source_id);
+    unless ($sms_source) {
+        return;
+    }
+    $c->stash->{sms_source} = $sms_source;
+    if ($sms_source->can("sms_carriers")) {
+        $c->stash->{sms_carriers} = sms_carrier_view_all($sms_source);
+    }
+    return 1;
+}
+
+
 =head2 advanced_search
 
 Perform advanced search for user
@@ -348,7 +393,7 @@ Perform advanced search for user
 
 =cut
 
-sub advanced_search :Local :Args() :AdminRole('USERS_READ') {
+sub advanced_search :Local :Args() :AdminRoleAny(USERS_READ) :AdminRoleAny(USERS_READ_SPONSORED) {
     my ($self, $c, @args) = @_;
     my ($status, $status_msg, $result);
     my %search_results;
@@ -362,7 +407,7 @@ sub advanced_search :Local :Args() :AdminRole('USERS_READ') {
     }
     else {
         my $query = $form->value;
-        ($status, $result) = $model->search($query);
+        ($status, $result) = $model->search($c, $query);
         if (is_success($status)) {
             $c->stash(form => $form);
             $c->stash($result);
@@ -370,13 +415,18 @@ sub advanced_search :Local :Args() :AdminRole('USERS_READ') {
         $c->stash(current_view => 'JSON') if ($c->request->params->{'json'});
     }
     my ( $roles, $violations );
-    (undef, $roles) = $c->model('Roles')->list();
+    (undef, $roles) = $c->model('Config::Roles')->listFromDB();
     (undef, $violations) = $c->model('Config::Violations')->readAll();
     $c->stash(
         status_msg => $status_msg,
         roles => $roles,
         violations => $violations,
     );
+
+    if($c->request->param('export')) { 
+        $c->stash->{current_view} = "CSV";
+    }
+
     $c->response->status($status);
 }
 
@@ -397,6 +447,7 @@ sub print :Local :AdminRole('USERS_UPDATE') {
     my %users_passwords_by_pid = map { $_->{'pid'}, $_ } @{ $c->session->{'users_passwords'} };
 
     ( $status, $result ) = $self->getModel($c)->read( $c, \@pids );
+    $self->audit_current_action($c, status => $status, pids => \@pids);
 
     # we overwrite the password found in the database with the one in the session for the same user
     for my $user (@$result) {
@@ -429,6 +480,7 @@ sub mail :Local :AdminRole('USERS_UPDATE') {
     my @pids = split(/,/, $c->request->params->{pids});
 
     ($status, $result) = $self->getModel($c)->mail($c, \@pids);
+    $self->audit_current_action($c, status => $status, pids => \@pids);
 
     if (is_success($status)) {
         $c->stash->{status_msg} = $c->loc('An email was sent to [_1] out of [_2] users.',
@@ -442,9 +494,38 @@ sub mail :Local :AdminRole('USERS_UPDATE') {
     $c->stash->{current_view} = 'JSON';
 }
 
+=head2 sms
+
+Send users credentials by sms
+
+/user/sms
+
+=cut
+
+sub sms :Local :AdminRole('USERS_UPDATE') {
+    my ($self, $c) = @_;
+
+    $c->stash->{current_view} = 'JSON';
+    my ($status, $result);
+    my @pids = split(/,/, $c->request->params->{pids});
+
+    ($status, $result) = $self->getModel($c)->sms($c, \@pids);
+    $self->audit_current_action($c, status => $status, pids => \@pids);
+
+    if (is_success($status)) {
+        $c->stash->{status_msg} = $c->loc('An sms was sent to [_1] out of [_2] users.',
+                                          scalar @pids, scalar @$result);
+    }
+    else {
+        $c->stash->{status_msg} = $result;
+    }
+
+    $c->response->status($status);
+}
+
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -465,6 +546,6 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 1;
