@@ -2,7 +2,6 @@ package pfappserver::View::HTML;
 
 use strict;
 use warnings;
-use pf::file_paths;
 use pf::admin_roles;
 
 use base 'Catalyst::View::TT';
@@ -14,6 +13,7 @@ __PACKAGE__->config(
     PRE_PROCESS => 'macros.inc',
     FILTERS => {
         css => \&css_filter,
+        css_escape => \&css_escape_filter,
         js => \&js_filter,
         none => sub { $_[0] },
     },
@@ -47,6 +47,19 @@ sub css_filter {
     return $string;
 }
 
+=head2 css_escape_filter
+
+css_escape_filter
+
+=cut
+
+sub css_escape_filter {
+    my ($string) = @_;
+    $string =~ s/\\/\\\\/g;
+    $string =~ s/([!"#\$\%\&'\(\)\*\+,\.\/:;<=>?@\[\]^`\{\|\}\\~-])/\\$1/g;
+    return $string;
+}
+
 =head2 js_filter
 
 =cut
@@ -93,7 +106,7 @@ sub can_access_group_any {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
