@@ -1,3 +1,5 @@
+/* -*- Mode: js; indent-tabs-mode: nil; js-indent-level: 4 -*- */
+
 "use strict";
 
 /*
@@ -11,8 +13,10 @@ Nodes.prototype.doAjax = function(url_data, options) {
         .always(options.always)
         .done(options.success)
         .fail(function(jqXHR) {
-            var status_msg = getStatusMsg(jqXHR);
-            showError(options.errorSibling, status_msg);
+            if (options.errorSibling) {
+                var status_msg = getStatusMsg(jqXHR);
+                showError(options.errorSibling, status_msg);
+            }
         });
 };
 
@@ -36,47 +40,71 @@ Nodes.prototype.post = function(options) {
  * The NodeView class defines the DOM operations from the Web interface.
  */
 var NodeView = function(options) {
+    var that = this;
     this.nodes = options.nodes;
 
     var read = $.proxy(this.readNode, this);
-    options.parent.on('click', '#nodes [href*="node"][href$="/read"]', read);
+    var body = $('body');
+    options.parent.on('click', '[href*="node"][href*="/read"]', read);
 
-    this.proxyClick($('body'), '.node [href*="node"][href$="/read"]', this.readNode);
+    this.proxyClick(body, '.node [href*="node"][href*="/read"]', this.readNode);
 
-    this.proxyFor($('body'), 'show', '#modalNode', this.showNode);
+    this.proxyFor(body, 'show', '#modalNode', this.showNode);
 
-    this.proxyFor($('body'), 'submit', 'form[name="nodes"]', this.createNode);
+    this.proxyFor(body, 'submit', 'form[name="nodes"]', this.createNode);
 
-    this.proxyFor($('body'), 'submit', 'form[name="simpleNodeSearch"]', this.submitSearch);
+    this.proxyFor(body, 'submit', 'form[name="simpleNodeSearch"]', this.submitSearch);
 
-    this.proxyFor($('body'), 'submit', 'form[name="advancedNodeSearch"]', this.submitSearch);
+    this.proxyFor(body, 'change', 'form[name="simpleNodeSearch"] [name$=".name"]', this.changeSearchField);
 
-    this.proxyFor($('body'), 'submit', '#modalNode form[name="modalNode"]', this.updateNode);
+    this.proxyFor(body, 'change', 'form[name="simpleNodeSearch"] [name$=".op"]', this.changeOpField);
 
-    this.proxyClick($('body'), '#modalNode [href$="/delete"]', this.deleteNode);
+    this.proxyFor(body, 'click', '#simpleNodeSearchResetBtn', this.resetSimpleSearch);
 
-    this.proxyFor($('body'), 'show', 'a[data-toggle="tab"][href="#nodeViolations"]', this.readViolations);
+    this.proxyFor(body, 'submit', 'form[name="advancedNodeSearch"]', this.submitSearch);
 
-    this.proxyClick($('body'), '#modalNode [href*="/close/"]', this.closeViolation);
+    this.proxyFor(body, 'click', '#advancedNodeSearchResetBtn', this.resetAdvancedSearch);
 
-    this.proxyClick($('body'), '#modalNode [href*="/run/"]', this.runViolation);
+    this.proxyFor(body, 'change', 'form[name="advancedNodeSearch"] [name$=".name"]', this.changeSearchField);
 
-    this.proxyClick($('body'), '#modalNode #reevaluateNode', this.reevaluateAccess);
+    this.proxyFor(body, 'change', 'form[name="advancedNodeSearch"] [name$=".op"]', this.changeOpField);
 
-    this.proxyClick($('body'), '#modalNode #addViolation', this.triggerViolation);
+    this.proxyFor(body, 'submit', '#modalNode form[name="modalNode"]', this.updateNode);
+
+    this.proxyClick(body, '#modalNode [href*="node"][href8="/delete"]', this.deleteNode);
+
+    this.proxyFor(body, 'show', 'a[data-toggle="tab"][href="#nodeViolations"]', this.loadTab);
+
+    this.proxyFor(body, 'show', 'a[data-toggle="tab"][href="#nodeAdditionalTabView"]', this.loadTab);
+
+    this.proxyFor(body, 'click', '[data-href*="/node"][data-href*="/tab_process"]', this.tabProcess);
+
+    this.proxyClick(body, '#modalNode [href*="/close/"]', this.closeViolation);
+
+    this.proxyClick(body, '#modalNode [href*="/run/"]', this.runViolation);
+
+    this.proxyClick(body, '#modalNode #reevaluateNode', this.reevaluateAccess);
+    
+    this.proxyClick(body, '#modalNode #refreshFingerbankDeviceNode', this.refreshFingerbankDevice);
+    
+    this.proxyClick(body, '#modalNode #restartSwitchport', this.restartSwitchport);
+
+    this.proxyClick(body, '#modalNode #addViolation', this.triggerViolation);
+    
+    this.proxyClick(body, '#modalNode #runRapid7Scan', this.runRapid7Scan);
 
     /* Update the advanced search form to the next page or sort the query */
-    this.proxyClick($('body'), '.nodes .pagination a', this.searchPagination);
+    this.proxyClick(body, '.nodes .pagination a', this.searchPagination);
 
-    this.proxyClick($('body'), '#nodes thead a', this.reorderSearch);
+    this.proxyClick(body, '#nodes thead a', this.reorderSearch);
 
-    this.proxyClick($('body'), '#toggle_all_items', this.toggleAllItems);
+    this.proxyClick(body, '#toggle_all_items', this.toggleAllItems);
 
-    this.proxyClick($('body'), '[name="items"]', this.toggleActionsButton);
+    this.proxyClick(body, '[name="items"]', this.toggleActionsButton);
 
-    this.proxyClick($('body'), '#node_bulk_actions .bulk_action', this.submitItems);
+    this.proxyClick(body, '#node_bulk_actions .bulk_action', this.submitItems);
 
-    this.proxyClick($('body'), '[id$="Empty"] [href="#add"]', function(e) {
+    this.proxyClick(body, '[id$="Empty"] [href="#add"]', function(e) {
         var emptyDiv = $(e.currentTarget).closest('[id$="Empty"]');
         var match = /(.+)Empty/.exec(emptyDiv.attr('id'));
         var id = match[1];
@@ -86,17 +114,17 @@ var NodeView = function(options) {
         return false;
     });
 
-    this.proxyFor($('body'), 'section.loaded', '#section', function(e) {
-        /* Enable autocompletion of owner on tab of single node creation */
-        $('[data-provide="typeahead"]').typeahead({
-            source: $.proxy(this.searchUser, this),
-            minLength: 2,
-            items: 11,
-            matcher: function(item) { return true; }
-        });
+    this.proxyFor(body, 'section.loaded', '#section', function(e) {
         /* Disable checked columns from import tab since they are required */
-        $('form["nodes"] .columns :checked').attr('disabled', 'disabled');
+        $('form[name="nodes"] .columns :checked').attr('disabled', 'disabled');
     });
+    this.proxyFor(body, 'saved_search.loaded', 'form[name="advancedNodeSearch"] [name$=".name"]', this.changeSearchFieldKeep);
+
+    this.proxyFor(body, 'saved_search.loaded', 'form[name="advancedNodeSearch"] [name$=".op"]', this.changeOpFieldKeep);
+
+    this.proxyFor(body, 'saved_search.loaded', 'form[name="simpleNodeSearch"] [name$=".name"]', this.changeSearchFieldKeep);
+
+    this.proxyFor(body, 'saved_search.loaded', 'form[name="simpleNodeSearch"] [name$=".op"]', this.changeOpFieldKeep);
 };
 
 NodeView.prototype.proxyFor = function(obj, action, target, method) {
@@ -112,19 +140,28 @@ NodeView.prototype.readNode = function(e) {
 
     var that = this;
     var section = $('#section');
-    var loader = section.prev('.loader');
-    loader.show();
+    section.loader();
     section.fadeTo('fast', 0.5);
     this.nodes.get({
         url: $(e.target).attr('href'),
         always: function() {
-            loader.hide();
             section.stop();
-            section.fadeTo('fast', 1.0);
+            section.fadeTo('fast', 1.0, function() {
+                section.loader('hide');
+            });
         },
         success: function(data) {
             $('body').append(data);
             var modal = $("#modalNode");
+            /* Ability to track submitted button (multihost feature) */
+            modal.find("form button[type=submit]").click(function() {
+                $(this, $(this).parents("form")).removeAttr("clicked");
+                $(this).attr("clicked", "true");
+            });
+            modal.on('hidden', function () {
+                modal.remove();
+                $("#modalNode").remove();
+            });
             modal.modal({ show: true });
         },
         errorSibling: section.find('h2').first()
@@ -134,8 +171,8 @@ NodeView.prototype.readNode = function(e) {
 NodeView.prototype.showNode = function(e) {
     var that = this;
     var modal = $("#modalNode");
-    modal.find('.chzn-select').chosen();
-    modal.find('.chzn-deselect').chosen({allow_single_deselect: true});
+    modal.find('.chzn-select').chosen({width: ''});
+    modal.find('.chzn-deselect').chosen({allow_single_deselect: true, width: ''});
     modal.find('.timepicker-default').each(function() {
         // Keep the placeholder visible if the input has no value
         var $this = $(this);
@@ -146,7 +183,8 @@ NodeView.prototype.showNode = function(e) {
             e.stopPropagation();
         });
     });
-    modal.find('.datepicker').datepicker({ autoclose: true });
+    modal.find('.input-date').datepicker({ autoclose: true });
+
     modal.find('[data-toggle="tooltip"]').tooltip({placement: 'right'}).click(function(e) {
         e.preventDefault();
         return false;
@@ -192,15 +230,33 @@ NodeView.prototype.searchUser = function(query, process) {
     });
 };
 
-NodeView.prototype.readViolations = function(e) {
+NodeView.prototype.loadTab = function(e) {
     var btn = $(e.target);
     var name = btn.attr("href");
-    var target = $(name.substr(name.indexOf('#')));
+    var target = $(name);
     var url = btn.attr("data-href");
-    target.load(btn.attr("data-href"), function() {
+    target.load(url, function() {
         target.find('.switch').bootstrapSwitch();
     });
     return true;
+}
+
+NodeView.prototype.tabProcess = function(e) {
+    var a = $(e.target);
+    var name = a.attr("href");
+    var target = $(name);
+    var url = a.attr("data-href");
+    this.nodes.get({
+        url: url,
+        always: function(data) {
+            if (typeof data === 'object') {
+                target.html(data.responseText);
+            } else {
+                target.html(data);
+            }
+        }
+    });
+    return false;
 };
 
 NodeView.prototype.createNode = function(e) {
@@ -262,6 +318,14 @@ NodeView.prototype.updateNode = function(e) {
     var form = modal.find('form').first();
     var btn = form.find('[type="submit"]').first();
     var valid = isFormValid(form);
+
+    var submitted_button = form.find("button[type=submit][clicked=true]");
+    if (submitted_button.attr("data-multihost")) {
+        form.find('[name="multihost"]').val("yes");
+    } else {
+        form.find('[name="multihost"]').val("no");
+    }
+
     if (valid) {
         resetAlert(modal_body);
         btn.button('loading');
@@ -347,12 +411,12 @@ NodeView.prototype.triggerViolation = function(e) {
     var modal = $('#modalNode');
     var modal_body = modal.find('.modal-body');
     var btn = $(e.target);
-    var href = btn.attr('href');
-    var vid = modal.find('#vid').val();
+    var option = modal.find('#vid').find(':selected');
+    var href = option.attr("trigger_url");
     var pane = $('#nodeViolations');
     resetAlert(pane);
     this.nodes.get({
-        url: [href, vid].join('/'),
+        url: href,
         success: function(data) {
             pane.html(data);
             pane.find('.switch').bootstrapSwitch();
@@ -361,6 +425,25 @@ NodeView.prototype.triggerViolation = function(e) {
     });
 };
 
+NodeView.prototype.runRapid7Scan = function(e) {
+    e.preventDefault();
+
+    var modal = $('#modalNode');
+    var modal_body = modal.find('.modal-body');
+    var btn = $(e.target);
+    var option = modal.find('#rapid7ScanTemplateSelection').find(':selected');
+    var href = option.attr("trigger_url");
+    var pane = $('#runRapid7Scan').closest('div');
+    resetAlert(pane);
+    this.nodes.get({
+        url: href,
+        success: function(data) {
+            showSuccess(pane, data.status_msg);
+        },
+        errorSibling: pane.children().first()
+    });
+};
+
 NodeView.prototype.reevaluateAccess = function(e){
     e.preventDefault();
     
@@ -377,6 +460,38 @@ NodeView.prototype.reevaluateAccess = function(e){
     });
 }
 
+NodeView.prototype.refreshFingerbankDevice = function(e){
+    e.preventDefault();
+    
+    var modal = $('#modalNode');
+    var modal_body = modal.find('.modal-body');
+    var link = $(e.target);
+    var url = link.attr('href');
+    this.nodes.get({
+        url: url,
+        success: function(data) {
+            showSuccess(modal_body.children().first(), data.status_msg);
+        },
+        errorSibling: modal_body.children().first()
+    });
+}
+
+NodeView.prototype.restartSwitchport = function(e){
+    e.preventDefault();
+    
+    var modal = $('#modalNode');
+    var modal_body = modal.find('.modal-body');
+    var link = $(e.target);
+    var url = link.attr('href');
+    this.nodes.get({
+        url: url,
+        success: function(data) {
+            showSuccess(modal_body.children().first(), data.status_msg);
+        },
+        errorSibling: modal_body.children().first()
+    });
+}
+
 NodeView.prototype.reorderSearch = function(e) {
     e.preventDefault();
     var that = this;
@@ -384,23 +499,23 @@ NodeView.prototype.reorderSearch = function(e) {
     var pagination = $('.pagination').first();
     var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
-    if(form.length == 0) {
+    if (form.length == 0) {
         form = $('#search');
     }
     var columns = $('#columns');
     var href = link.attr("href");
     var section = $('#section');
     var status_container = $("#section").find('h2').first();
-    var loader = section.prev('.loader');
-    loader.show();
+    section.loader();
     section.fadeTo('fast', 0.5);
     section.fadeTo('fast', 0.5, function() {
         that.nodes.post({
             url: href,
             data: form.serialize() + "&" + columns.serialize(),
             always: function() {
-                loader.hide();
-                section.fadeTo('fast', 1.0);
+                section.fadeTo('fast', 1.0, function() {
+                    section.loader('hide');
+                });
             },
             success: function(data) {
                 section.html(data);
@@ -420,23 +535,22 @@ NodeView.prototype.searchPagination = function(e) {
     var pagination = link.closest('.pagination');
     var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
-    if(form.length == 0) {
+    if (form.length == 0) {
         form = $('#search');
     }
     var columns = $('#columns');
     var href = link.attr("href");
     var section = $('#section');
     var status_container = $("#section").find('h2').first();
-    var loader = section.prev('.loader');
-    loader.show();
-    section.fadeTo('fast', 0.5);
+    section.loader();
     section.fadeTo('fast', 0.5, function() {
         that.nodes.post({
             url: href,
             data: form.serialize() + "&" + columns.serialize(),
             always: function() {
-                loader.hide();
-                section.fadeTo('fast', 1.0);
+                section.fadeTo('fast', 1.0, function() {
+                    section.loader('hide');
+                });
             },
             success: function(data) {
                 section.html(data);
@@ -451,29 +565,38 @@ NodeView.prototype.searchPagination = function(e) {
 NodeView.prototype.refreshPage = function() {
     var that = this;
     var pagination = $('.pagination').first();
+    if (pagination.attr('data-no-refresh') == "yes") {
+        return;
+    }
     var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
     var link = pagination.find('li.disabled a').first();
-    if(form.length == 0) {
+    if (form.length == 0) {
         form = $('#search');
     }
     var columns = $('#columns');
     var href = link.attr("href");
+    var section_id = pagination.attr('data-section') || "#section";
+    var refresh_section = $(section_id);
     var section = $('#section');
-    var status_container = $("#section").find('h2').first();
-    var loader = section.prev('.loader');
-    loader.show();
+    var status_container = section.find('h2').first();
+    var form_data = form.serialize();
+    if (columns.length == 0) {
+        form_data += "&" + columns.serialize();
+    }
+    section.loader();
     section.fadeTo('fast', 0.5);
     section.fadeTo('fast', 0.5, function() {
         that.nodes.post({
             url: href,
-            data: form.serialize() + "&" + columns.serialize(),
+            data: form_data,
             always: function() {
-                loader.hide();
-                section.fadeTo('fast', 1.0);
+                section.fadeTo('fast', 1.0, function() {
+                    section.loader('hide');
+                });
             },
             success: function(data) {
-                section.html(data);
+                refresh_section.html(data);
                 section.trigger('section.loaded');
             },
             errorSibling: status_container
@@ -491,15 +614,15 @@ NodeView.prototype.submitSearch = function(e) {
     var columns = $('#columns');
     $("body,html").animate({scrollTop:0}, 'fast');
     var status_container = $("#section").find('h2').first();
-    var loader = section.prev('.loader');
-    loader.show();
+    section.loader();
     section.fadeTo('fast', 0.5, function() {
         that.nodes.post({
             url: href,
             data: form.serialize() + "&" + columns.serialize(),
             always: function() {
-                loader.hide();
-                section.fadeTo('fast', 1.0);
+                section.fadeTo('fast', 1.0, function() {
+                    section.loader('hide');
+                });
             },
             success: function(data) {
                 section.html(data);
@@ -531,15 +654,19 @@ NodeView.prototype.submitItems = function(e) {
     var that = this;
     var target = $(e.currentTarget);
     var section = $('#section');
-    var loader = section.prev('.loader');
     var status_container = section.find('h2').first();
     var items = $("#items").serialize();
     if (items.length) {
-        loader.show();
+        section.loader();
         section.fadeTo('fast', 0.5, function() {
             that.nodes.post({
                 url: target.attr("data-target"),
                 data: items,
+                always: function() {
+                    section.fadeTo('fast', 1.0, function() {
+                        section.loader('hide');
+                    });
+                },
                 success: function(data) {
                     $("#section").one('section.loaded', function() {
                         showSuccess($("#section").find('h2').first(), data.status_msg);
@@ -551,3 +678,117 @@ NodeView.prototype.submitItems = function(e) {
         });
     }
 };
+
+NodeView.prototype.changeSearchFieldKeep = function(e) {
+    this.handleChangeSearchField(e, true);
+};
+
+NodeView.prototype.changeSearchField = function(e) {
+    this.handleChangeSearchField(e, false);
+};
+
+NodeView.prototype.handleChangeSearchField = function(e, keep) {
+    var search_input = $(e.currentTarget);
+    var op_input = search_input.next();
+    var search_type = search_input.val();
+    var value_input = op_input.next();
+    var op_input_template_id = '#' + search_type + "_op";
+    var op_input_template = $(op_input_template_id);
+    if (op_input_template.length == 0 ) {
+        op_input_template = $('#default_op');
+    }
+    if (op_input_template.length) {
+        changeInputFromTemplate(op_input, op_input_template, keep);
+    }
+    var value_template_id = '#' + search_type + "_value";
+    var value_template = $(value_template_id);
+    if (value_template.length == 0 ) {
+        value_template = $('#default_value');
+    }
+    if (value_template.length) {
+        changeInputFromTemplate(value_input, value_template, keep);
+    }
+    this.setupTypeAhead(search_input);
+};
+
+NodeView.prototype.changeOpFieldKeep = function(e) {
+    this.handleChangeOpField(e, true);
+};
+
+NodeView.prototype.changeOpField = function(e) {
+    this.handleChangeOpField(e, false);
+};
+
+NodeView.prototype.handleChangeOpField = function(e, keep) {
+    var op_input = $(e.currentTarget);
+    var search_input = op_input.prev();
+    var value_input = op_input.next();
+    var search_type = search_input.val();
+    var op_type = op_input.val();
+    var value_template_id = '#' +  search_type + "_value_" + op_type + "_op" ;
+    var value_template = $(value_template_id);
+    var value_input_id = value_input.attr("id");
+    if (value_template.length) {
+        changeInputFromTemplate(value_input, value_template, keep);
+    }
+    this.setupTypeAhead(search_input);
+};
+
+NodeView.prototype.setupTypeAhead = function(search_input) {
+    var search_type = search_input.val();
+    var op_input = search_input.next();
+    var value_input = op_input.next();
+    var op_input_value = op_input.val();
+    if(op_input_value != "equal" && op_input_value != "not_equal") {
+        return;
+    }
+    if(search_type == "switch_id") {
+        value_input.typeahead({
+            source: $.proxy(this.searchSwitch, this),
+            minLength: 2,
+            items: 11,
+            matcher: function(item) { return true; }
+        });
+    }
+    if(search_type == "person_name") {
+        value_input.typeahead({
+            source: $.proxy(this.searchUser, this),
+            minLength: 2,
+            items: 11,
+            matcher: function(item) { return true; }
+        });
+    }
+};
+
+NodeView.prototype.searchSwitch = function(query, process) {
+    this.nodes.post({
+        url: '/config/switch/search',
+        data: {
+            'json': 1,
+            'all_or_any': 'any',
+            'searches.0.name': 'id',
+            'searches.0.op': 'like',
+            'searches.0.value': query,
+        },
+        success: function(data) {
+            var results = $.map(data.items, function(i) {
+                return i.id;
+            });
+            process(results);
+        }
+    });
+}
+
+NodeView.prototype.resetAdvancedSearch = function(e) {
+    var form = $('form[name="advancedNodeSearch"]');
+    form.find('#advancedSearchConditions').find('tbody').children(':not(.hidden)').find('[href="#delete"]').click();
+    form.find('#advancedSearchConditionsEmpty [href="#add"]').click();
+    form[0].reset();
+    form.submit();
+};
+
+NodeView.prototype.resetSimpleSearch = function(e) {
+    var form = $('#simpleNodeSearch');
+    form[0].reset();
+    form.submit();
+};
