@@ -1,4 +1,5 @@
 package pf::Authentication::Source::BlackholeSource;
+
 =head1 NAME
 
 pf::Authentication::Source::BlackholeSource add documentation
@@ -19,6 +20,7 @@ use pf::config;
 use pf::Authentication::constants;
 use pf::constants::authentication::messages;
 use pf::util;
+use pf::constants::role qw($REJECT_ROLE);
 
 extends 'pf::Authentication::Source';
 
@@ -32,6 +34,14 @@ has '+class' => (default => 'exclusive');
 
 has '+type' => (default => 'Blackhole');
 
+=head2 dynamic_routing_module
+
+Which module to use for DynamicRouting
+
+=cut
+
+sub dynamic_routing_module { 'Authentication::Blackhole' }
+
 =head2 available_attributes
 
 Allow to make a condition on the user's email address.
@@ -72,17 +82,16 @@ sub available_actions {
 
 =cut
 
-sub match_in_subclass {
-    my ($self, $params, $rule, $own_conditions, $matching_conditions) = @_;
-    my $username =  $params->{'username'};
-    foreach my $condition (@{ $own_conditions }) {
-        if ($condition->{'attribute'} eq "username") {
-            if ( $condition->matches("username", $username) ) {
-                push(@{ $matching_conditions }, $condition);
-            }
-        }
-    }
-    return $username;
+sub match {
+    my ($self, $params) = @_;
+    return [ 
+        pf::Authentication::Action->new({
+            type    => $Actions::SET_ROLE,
+            value   => $REJECT_ROLE,
+            class   => pf::Authentication::Action->getRuleClassForAction($Actions::SET_ROLE),
+        }) 
+    ];
+       
 }
 
 =head2 authenticate
@@ -96,13 +105,21 @@ sub authenticate {
     return ($FALSE, 'Not allowed');
 }
 
+=head2 has_authentication_rules
+
+Whether or not the source should have authentication rules
+
+=cut
+
+sub has_authentication_rules { $FALSE }
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -124,4 +141,3 @@ USA.
 =cut
 
 1;
-
