@@ -9,19 +9,30 @@ pf::Authentication::Source::EmailSource
 =cut
 
 use pf::Authentication::constants;
+use pf::constants qw($TRUE $FALSE);
 use pf::constants::authentication::messages;
+use pf::log;
 
 use Moose;
 extends 'pf::Authentication::Source';
+with qw(
+    pf::Authentication::CreateLocalAccountRole
+    pf::Authentication::EmailFilteringRole
+);
 
 has '+class' => (default => 'external');
 has '+type' => (default => 'Email');
-has '+unique' => (default => 1);
-has 'allow_localdomain' => (isa => 'Str', is => 'rw', default => 'yes');
 has 'email_activation_timeout' => (isa => 'Str', is => 'rw', default => '10m');
-has 'create_local_account' => (isa => 'Str', is => 'rw', default => 'no');
 has 'activation_domain' => (isa => 'Maybe[Str]', is => 'rw');
 
+=head2 dynamic_routing_module
+
+Which module to use for DynamicRouting
+
+=cut
+
+sub dynamic_routing_module { 'Authentication::Email' }
+
 =head2 available_attributes
 
 Allow to make a condition on the user's email address.
@@ -29,12 +40,11 @@ Allow to make a condition on the user's email address.
 =cut
 
 sub available_attributes {
-  my $self = shift;
-
-  my $super_attributes = $self->SUPER::available_attributes;
-  my $own_attributes = [{ value => "user_email", type => $Conditions::SUBSTRING }];
-
-  return [@$super_attributes, @$own_attributes];
+    my $self = shift;
+    return [
+        @{ $self->SUPER::available_attributes },
+        { value => "user_email", type => $Conditions::SUBSTRING }
+    ];
 }
 
 =head2 available_rule_classes
@@ -85,13 +95,30 @@ sub mandatoryFields {
     return qw(email);
 }
 
+
+=head2 authenticate
+
+=cut
+
+sub authenticate {
+    my ( $self, $username, $password ) = @_;
+    if (!$self->isEmailAllowed($username)) {
+        my $logger = get_logger();
+        $logger->warn("EmailSource ($self->{id}) failed to authenticate PID '$username' is banned");
+        return ($FALSE, $pf::constants::authentication::messages::EMAIL_UNAUTHORIZED);
+    }
+
+    return $TRUE;
+}
+
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -112,7 +139,7 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
 
 # vim: set shiftwidth=4:
