@@ -11,23 +11,23 @@ pf::Authentication::Source::LDAPSource
 use pf::log;
 use pf::constants qw($TRUE $FALSE);
 use pf::constants::authentication::messages;
-use pf::Authentication::constants;
+use pf::Authentication::constants qw($DEFAULT_LDAP_READ_TIMEOUT $DEFAULT_LDAP_WRITE_TIMEOUT $DEFAULT_LDAP_CONNECTION_TIMEOUT);
 use pf::Authentication::Condition;
 use pf::CHI;
 use pf::util;
 use Readonly;
 
-use Net::LDAP;
-use Net::LDAPS;
+use pf::LDAP;
 use List::Util;
 use Net::LDAP::Util qw(escape_filter_value);
-use pf::config;
-use List::MoreUtils qw(uniq);
+use pf::config qw(%Config);
+use List::MoreUtils qw(uniq any);
 use pf::StatsD::Timer;
 use pf::util::statsd qw(called);
 
 use Moose;
 extends 'pf::Authentication::Source';
+with qw(pf::Authentication::InternalRole);
 
 # available encryption
 use constant {
@@ -49,23 +49,37 @@ Readonly our %ATTRIBUTES_MAP => (
 );
 
 has '+type' => (default => 'LDAP');
-has 'host' => (isa => 'Maybe[Str]', is => 'rw', default => '127.0.0.1');
+has 'host' => (isa => 'Maybe[Str]', is => 'rw', default => '');
 has 'port' => (isa => 'Maybe[Int]', is => 'rw', default => 389);
-has 'connection_timeout' => ( isa     => 'Int', is => 'rw', default => 5 );
+has 'connection_timeout' => ( isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_CONNECTION_TIMEOUT );
+has 'write_timeout' => (isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_WRITE_TIMEOUT);
+has 'read_timeout' => (isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_READ_TIMEOUT);
 has 'basedn' => (isa => 'Str', is => 'rw', required => 1);
 has 'binddn' => (isa => 'Maybe[Str]', is => 'rw');
 has 'password' => (isa => 'Maybe[Str]', is => 'rw');
 has 'encryption' => (isa => 'Str', is => 'rw', required => 1);
 has 'scope' => (isa => 'Str', is => 'rw', required => 1);
 has 'usernameattribute' => (isa => 'Str', is => 'rw', required => 1);
-has 'stripped_user_name' => (isa => 'Str', is => 'rw', default => 'yes');
+has 'searchattributes' => (isa => 'ArrayRef[Str]', is => 'rw', required => 0);
 has '_cached_connection' => (is => 'rw');
 has 'cache_match' => ( isa => 'Bool', is => 'rw', default => 0 );
+has 'email_attribute' => (isa => 'Maybe[Str]', is => 'rw', default => 'mail');
+has 'monitor' => ( isa => 'Bool', is => 'rw', default => 1 );
+has 'shuffle' => ( isa => 'Bool', is => 'rw', default => 0 );
 
 our $logger = get_logger();
 
 =head1 METHODS
 
+=head2 dynamic_routing_module
+
+Which module to use for DynamicRouting
+
+=cut
+
+sub dynamic_routing_module { 'Authentication::Login' }
+
+
 =head2 available_attributes
 
 =cut
@@ -74,17 +88,28 @@ sub available_attributes {
   my $self = shift;
 
   my $super_attributes = $self->SUPER::available_attributes;
-  my @attributes = @{$Config{advanced}->{ldap_attributes}};
-  my @ldap_attributes = map { { value => $_, type => $Conditions::LDAP_ATTRIBUTE } } @attributes;
+  my @ldap_attributes = $self->ldap_attributes;
 
   # We check if our username attribute is present, if not we add it.
-  if (not grep {$_->{value} eq $self->{'usernameattribute'} } @ldap_attributes ) {
-    push (@ldap_attributes, { value => $self->{'usernameattribute'}, type => $Conditions::LDAP_ATTRIBUTE });
+  my $usernameattribute = $self->{'usernameattribute'};
+  if ( length ($usernameattribute) && !grep {$_->{value} eq $usernameattribute } @ldap_attributes ) {
+    push (@ldap_attributes, { value => $usernameattribute, type => $Conditions::LDAP_ATTRIBUTE });
   }
 
   return [@$super_attributes, sort { $a->{value} cmp $b->{value} } @ldap_attributes];
 }
 
+=head2 ldap_attributes
+
+get the ldap attributes
+
+=cut
+
+sub ldap_attributes {
+    my ($self) = @_;
+    return map { { value => $_, type => $Conditions::LDAP_ATTRIBUTE } } @{$Config{advanced}->{ldap_attributes}};
+}
+
 =head2 authenticate
 
 =cut
@@ -92,7 +117,7 @@ sub available_attributes {
 sub authenticate {
   my ( $self, $username, $password ) = @_;
   my $timer_stat_prefix = called() . "." .  $self->{'id'};
-  my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}"});
+  my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}", level => 6});
   my $before; # will hold time before StatsD calls
 
   my ($connection, $LDAPServer, $LDAPServerPort ) = $self->_connect();
@@ -100,17 +125,11 @@ sub authenticate {
   if (!defined($connection)) {
     return ($FALSE, $COMMUNICATION_ERROR_MSG);
   }
-  my $result = $self->bind_with_credentials($connection);
 
-  if ($result->is_error) {
-    $logger->error("[$self->{'id'}] Unable to bind with $self->{'binddn'} on $LDAPServer:$LDAPServerPort");
-    return ($FALSE, $COMMUNICATION_ERROR_MSG);
-  }
+  my $filter = $self->_makefilter(escape_filter_value($username));
 
-  my $filter = "($self->{'usernameattribute'}=$username)";
-
-  $result = do {
-    my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}.search"});
+  my $result = do {
+    my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}.search", level => 7});
     $connection->search(
       base => $self->{'basedn'},
       filter => $filter,
@@ -138,7 +157,7 @@ sub authenticate {
   my $user = $result->entry(0);
 
   $result = do {
-    my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}.bind"});
+    my $timer = pf::StatsD::Timer->new({'stat' => "${timer_stat_prefix}.bind", level => 7});
     $connection->bind($user->dn, password => $password)
   };
 
@@ -164,43 +183,43 @@ if all connections fail
 sub _connect {
   my $self = shift;
   my $timer_stat_prefix = called() . "." .  $self->{'id'};
-  my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}"});
+  my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}", level => 7});
   my $connection;
   my $logger = Log::Log4perl::get_logger(__PACKAGE__);
-
+  my ($LDAPServer, $LDAPServerPort);
   my @LDAPServers = split(/\s*,\s*/, $self->{'host'});
-  # uncomment the next line if you want the servers to be tried in random order
-  # to spread out the connections amongst a set of servers
-  #@LDAPServers = List::Util::shuffle @LDAPServers;
+  if ($self->shuffle) {
+      @LDAPServers = List::Util::shuffle @LDAPServers;
+  }
+  my @credentials;
+  if ($self->{'binddn'} && $self->{'password'}) {
+    @credentials = ($self->{'binddn'}, password => $self->{'password'})
+  }
 
   TRYSERVER:
-  foreach my $LDAPServer ( @LDAPServers ) {
+  foreach my $s (@LDAPServers) {
+    $LDAPServer = $s;
+    $LDAPServerPort = undef;
     # check to see if the hostname includes a port (e.g. server:port)
-    my $LDAPServerPort;
-    if ( $LDAPServer =~ /:/ ) {
-        $LDAPServerPort = ( split(/:/,$LDAPServer) )[-1];
+    if ($LDAPServer =~ /:/) {
+        $LDAPServerPort = (split(/:/, $LDAPServer))[-1];
     }
     $LDAPServerPort //=  $self->{'port'} ;
+    $connection = pf::LDAP->new(
+        $LDAPServer,
+        port       => $LDAPServerPort,
+        timeout    => $self->{'connection_timeout'},
+        write_timeout  => $self->{'write_timeout'},
+        read_timeout  => $self->{'read_timeout'},
+        encryption => $self->{encryption},
+        credentials => \@credentials,
+    );
 
-    if ( $self->{'encryption'} eq SSL ) {
-        $connection = Net::LDAPS->new($LDAPServer, port =>  $LDAPServerPort, timeout => $self->{'connection_timeout'} );
-    } else {
-        $connection = Net::LDAP->new($LDAPServer, port =>  $LDAPServerPort, timeout => $self->{'connection_timeout'} );
-    }
     if (! defined($connection)) {
       $logger->warn("[$self->{'id'}] Unable to connect to $LDAPServer");
       next TRYSERVER;
     }
 
-    # try TLS if required, return undef if it fails
-    if ( $self->{'encryption'} eq TLS ) {
-      my $mesg = $connection->start_tls();
-      if ( $mesg->code() ) {
-          $logger->error("[$self->{'id'}] ".$mesg->error());
-          $pf::StatsD::statsd->increment("${timer_stat_prefix}.error.count" );
-          return undef;
-      }
-    }
 
     $logger->debug("[$self->{'id'}] Using LDAP connection to $LDAPServer");
     return ( $connection, $LDAPServer, $LDAPServerPort );
@@ -210,32 +229,10 @@ sub _connect {
     $logger->error("[$self->{'id'}] Unable to connect to any LDAP server");
     $pf::StatsD::statsd->increment("${timer_stat_prefix}.error.count" );
   }
-  return undef;
+  return (undef, $LDAPServer, $LDAPServerPort);
 }
 
 
-=head2 match
-
-    Overrided to add caching to avoid a hit to the database
-
-=cut
-
-sub match {
-    my ($self, $params) = @_;
-    my $timer_stat_prefix = called() . "." .  $self->{'id'};
-    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}"});
-    if($self->is_match_cacheable) {
-        my $result = $self->cache->compute_with_undef([$self->id, $params], sub {
-                $pf::StatsD::statsd->increment(called() . "." . $self->id. ".cache_miss.count" );
-                my $result =   $self->SUPER::match($params);
-                return $result;
-            });
-        return $result;
-    }
-    my $result = $self->SUPER::match($params);
-    return $result;
-}
-
 =head2 cache
 
     get the cache object
@@ -246,29 +243,80 @@ sub cache {
     return pf::CHI->new( namespace => 'ldap_auth');
 }
 
-=head2 is_match_cacheable
+=head2 match_rule
 
-Checks to see if the match can be cached
+match_rule
 
 =cut
 
-sub is_match_cacheable {
-    my ($self) = @_;
-    #First check to see caching is disabled to see if we can exit quickly
-    return 0 unless $self->cache_match;
-    #Check rules for timed based operations return false first one found
-    foreach my $rule (@{$self->{rules}}) {
-        foreach my $condition (@{$rule->{conditions}}) {
-            my $op = $condition->{operator};
-            return 0 if $op eq $Conditions::IS_BEFORE || $op eq $Conditions::IS_AFTER;
-        }
+sub match_rule {
+    my ($self, $rule, $params, $extra) = @_;
+    if ($self->is_rule_cacheable($rule)) {
+        return $self->cache->compute_with_undef($self->rule_cache_key($rule, $params, $extra), sub {
+            $pf::StatsD::statsd->increment("pf::Authentication::Source::LDAPSource::match_rule.$self->{id}.cache_miss.count" );
+            return $self->SUPER::match_rule($rule, $params, $extra);
+        });
     }
-    return $self->cache_match;
+    return $self->SUPER::match_rule($rule, $params, $extra);
+}
+
+our %NON_CACHEABLE_OPS = (
+   $Conditions::IS_BEFORE => 1, 
+   $Conditions::IS_AFTER => 1, 
+   $Conditions::IN_TIME_PERIOD => 1, 
+);
+
+
+=head2 is_rule_cacheable
+
+is_rule_cacheable
+
+=cut
+
+sub is_rule_cacheable {
+    my ($self, $rule) = @_;
+    if (!defined ($rule) || !$self->cache_match) {
+        return $FALSE;
+    }
+    return (any { exists $NON_CACHEABLE_OPS{$_->{operator} // ''}  } @{$rule->{'conditions'} // []}) ? $FALSE : $TRUE;
 }
 
 
+=head2 rule_cache_key
+
+rule_cache_key
+
+=cut
+
+sub rule_cache_key {
+    my ($self, $rule, $params, $extra) = @_;
+    my %temp = %{$params // {}};
+    delete @temp{qw(current_date current_time current_time_period radius_request)};
+    return [$self->{id}, $rule->{id}, \%temp ];
+}
+
 =head2 match_in_subclass
 
+match_in_subclass
+
+=cut
+
+sub match_in_subclass {
+    my ($self, $params, $rule, $own_conditions, $matching_conditions) = @_;
+    my $filter = $self->ldap_filter_for_conditions($own_conditions, $rule->match, $self->{'usernameattribute'}, $params);
+    my $id = $self->id;
+    if (! defined($filter)) {
+        $logger->error("[$id] Missing parameters to construct LDAP filter");
+        $pf::StatsD::statsd->increment(called() . "." . $id . ".error.count" );
+        return undef;
+    }
+    my $rule_id = $rule->id;
+    $logger->debug("[$id $rule_id] Searching for $filter, from $self->{'basedn'}, with scope $self->{'scope'}");
+    return $self->_match_in_subclass($filter, $params, $rule, $own_conditions, $matching_conditions);
+}
+
+=head2 _match_in_subclass
+
 C<$params> are the parameters gathered at authentication (username, SSID, connection type, etc).
 
 C<$rule> is the rule instance that defines the conditions.
@@ -279,10 +327,10 @@ Conditions that match are added to C<$matching_conditions>.
 
 =cut
 
-sub match_in_subclass {
-    my ($self, $params, $rule, $own_conditions, $matching_conditions) = @_;
+sub _match_in_subclass {
+    my ($self, $filter, $params, $rule, $own_conditions, $matching_conditions) = @_;
     my $timer_stat_prefix = called() . "." .  $self->{'id'};
-    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}", sample_rate => 0.1});
+    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}",  level => 6});
 
     my $cached_connection = $self->_cached_connection;
     unless ( $cached_connection ) {
@@ -291,17 +339,10 @@ sub match_in_subclass {
     my ( $connection, $LDAPServer, $LDAPServerPort ) = @$cached_connection;
 
 
-    my $filter = $self->ldap_filter_for_conditions($own_conditions, $rule->match, $self->{'usernameattribute'}, $params);
-    if (! defined($filter)) {
-        $logger->error("[$self->{'id'}] Missing parameters to construct LDAP filter");
-        $pf::StatsD::statsd->increment(called() . "." . $self->{'id'} . ".error.count" );
-        return undef;
-    }
-    $logger->debug("[$self->{'id'} $rule->{'id'}] Searching for $filter, from $self->{'basedn'}, with scope $self->{'scope'}");
 
     my @attributes = map { $_->{'attribute'} } @{$own_conditions};
     my $result = do {
-        my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}.search", sample_rate => 0.1});
+        my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}.search",  level => 6});
         $connection->search(
           base => $self->{'basedn'},
           filter => $filter,
@@ -344,13 +385,15 @@ sub match_in_subclass {
         # Perform match on a static group condition since they require a second LDAP search
         foreach $condition (grep { $_->{'operator'} eq $Conditions::IS_MEMBER } @{$own_conditions}) {
             $value = escape_filter_value($condition->{'value'});
-            $attribute = $entry->get_value($condition->{'attribute'});
+            $attribute = $entry->get_value($condition->{'attribute'}) // '';
+            $attribute = escape_filter_value($attribute);
             # Search for any type of group definition:
             # - groupOfNames       => member (dn)
             # - groupOfUniqueNames => uniqueMember (dn)
             # - posixGroup         => memberUid (uid)
             my $dn_search = escape_filter_value($dn);
             $filter = "(|(member=${dn_search})(uniqueMember=${dn_search})(memberUid=${attribute}))";
+            $logger->debug("[$self->{'id'} $rule->{'id'}] Searching is_member filter $filter");
             $result = $connection->search
               (
                base => $value,
@@ -386,6 +429,12 @@ sub match_in_subclass {
             return $params->{'username'} || $params->{'email'};
         }
     }
+    elsif($result->count > 1) {
+        $logger->warn("[$self->{'id'} $rule->{'id'}] Found more than 1 match. Ignoring all of them. Make sure your filtering rules (on username and on email) can only return a single result");
+    }
+    else {
+        $logger->debug("[$self->{'id'} $rule->{'id'}] No match found for this LDAP filter");
+    }
 
     return undef;
 }
@@ -401,31 +450,26 @@ sub test {
 
   # Connect
   my ( $connection, $LDAPServer, $LDAPServerPort ) = $self->_connect();
+  my $id = $self->{id};
 
-  if (! defined($connection)) {
-    $logger->warn("[$self->{'id'}] Unable to connect to any LDAP server");
-    return ($FALSE, "Can't connect to server");
+  if (!defined($connection)) {
+    my $binddn = $self->{'binddn'} // '';
+    $logger->warn("[$id] Unable to connect to any LDAP server");
+    return ($FALSE, "Can't connect to server or bind with '$binddn' on $LDAPServer:$LDAPServerPort");
   }
-
-  # Bind
-  my $result = $self->bind_with_credentials($connection);
-  if ($result->is_error) {
-    $logger->warn("[$self->{'id'}] Unable to bind with $self->{'binddn'} on $LDAPServer:$LDAPServerPort");
-    return ($FALSE, ["Unable to bind to [_1] with these settings", $LDAPServer]);
-  }
-
+  my $base = $self->{basedn};
   # Search
   my $filter = "($self->{'usernameattribute'}=packetfence)";
-  $result = $connection->search(
-    base => $self->{'basedn'},
+  my $result = $connection->search(
+    base => $base,
     filter => $filter,
     scope => $self->{'scope'},
     attrs => ['dn'],
-    sizelimit => 1
+    sizelimit => 1,
   );
 
   if ($result->is_error) {
-      $logger->warn("[$self->{'id'}] Unable to execute search $filter from $self->{'basedn'} on $LDAPServer:$LDAPServerPort: ".$result->error);
+      $logger->warn("[$id] Unable to execute search $filter from '$base' on $LDAPServer:$LDAPServerPort: " . ($result->error // '' ));
       return ($FALSE, 'Wrong base DN or username attribute');
   }
 
@@ -445,14 +489,14 @@ for the usernameattribute - to match it in the source.
 sub ldap_filter_for_conditions {
   my ($self, $conditions, $match, $usernameattribute, $params) = @_;
   my $timer_stat_prefix = called() . "." .  $self->{'id'};
-  my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}", sample_rate => 0.1});
+  my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}",  level => 7});
 
   my (@ldap_conditions, $expression);
-  $params->{'username'} = $params->{'stripped_user_name'} if (defined($params->{'stripped_user_name'} ) && $params->{'stripped_user_name'} ne '' && isenabled($self->{'stripped_user_name'}));
+
   if ($params->{'username'}) {
       $expression = '(' . $usernameattribute . '=' . $params->{'username'} . ')';
   } elsif ($params->{'email'}) {
-      $expression = '(|(mail=' . $params->{'email'} . ')(proxyAddresses=smtp:' . $params->{'email'} . ')(mailLocalAddress=' . $params->{'email'} . ')(mailAlternateAddress=' . $params->{'email'} . '))';
+      $expression = '(|(' . $self->{'email_attribute'} . '=' . $params->{'email'} . ')(proxyAddresses=smtp:' . $params->{'email'} . ')(mailLocalAddress=' . $params->{'email'} . ')(mailAlternateAddress=' . $params->{'email'} . '))';
   }
 
   if ($expression) {
@@ -491,26 +535,6 @@ sub ldap_filter_for_conditions {
   return $expression;
 }
 
-=head2 bind_with_credentials
-
-=cut
-
-sub bind_with_credentials {
-    my ($self,$connection) = @_;
-    my $result;
-    my $timer_stat_prefix = called() . "." .  $self->{'id'};
-    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}", sample_rate => 0.1});
-    if ($self->{'binddn'} && $self->{'password'}) {
-        $result = $connection->bind($self->{'binddn'}, password => $self->{'password'});
-    } else {
-        $result = $connection->bind;
-    }
-    if ($result->is_error) {
-        $pf::StatsD::statsd->increment(called() . "." . $self->{'id'} . ".error.count" );
-    }
-    return $result;
-}
-
 =head2 search based on a attribute
 
 =cut
@@ -518,30 +542,27 @@ sub bind_with_credentials {
 sub search_attributes_in_subclass {
     my ($self, $username) = @_;
     my $timer_stat_prefix = called() . "." .  $self->{'id'};
-    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}", sample_rate => 0.1});
+    my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}",  level => 6});
     my ($connection, $LDAPServer, $LDAPServerPort ) = $self->_connect();
     if (!defined($connection)) {
       return ($FALSE, $COMMUNICATION_ERROR_MSG);
     }
-    my $result = $self->bind_with_credentials($connection);
 
-    if ($result->is_error) {
-      $logger->error("[$self->{'id'}] Unable to bind with $self->{'binddn'} on $LDAPServer:$LDAPServerPort");
-      return ($FALSE, $COMMUNICATION_ERROR_MSG);
-    }
     my $searchresult = $connection->search(
                   base => $self->{'basedn'},
                   filter => "($self->{'usernameattribute'}=$username)"
     );
+    if ($searchresult->is_error()) {
+      $logger->error("Unable to locate user '$username'");
+      return ($FALSE, $COMMUNICATION_ERROR_MSG);
+    }
+    if ($searchresult->count == 0) {
+      $logger->error("Unable to locate user '$username'");
+      return ($FALSE, $COMMUNICATION_ERROR_MSG);
+    }
     my $entry = $searchresult->entry();
-    $connection->unbind();
 
-    if (!$entry) {
-        $logger->warn("Unable to locate user '$username'");
-    }
-    else {
-         $logger->info("User: '$username' found in the directory");
-    }
+    $logger->info("User: '$username' found in the directory");
 
     my $info = {};
     foreach my $attrs (keys %ATTRIBUTES_MAP){
@@ -565,7 +586,6 @@ sub postMatchProcessing {
     my $cached_connection = $self->_cached_connection;
     if($cached_connection) {
         my ( $connection, $LDAPServer, $LDAPServerPort ) = @$cached_connection;
-        $connection->unbind;
         $self->_cached_connection(undef);
     }
 }
@@ -583,22 +603,32 @@ sub preMatchProcessing {
         return undef;
     }
 
-    my $result = $self->bind_with_credentials($connection);
-
-    if ($result->is_error) {
-        $logger->error("[$self->{'id'}] Unable to bind with $self->{'binddn'} on $LDAPServer:$LDAPServerPort");
-        return undef;
-    }
     $self->_cached_connection([$connection, $LDAPServer, $LDAPServerPort]);
 }
 
+=head2 _makefilter
+
+Create the filter to search for the dn
+
+=cut
+
+sub _makefilter {
+    my ($self,$username) = @_;
+    if (@{$self->{'searchattributes'}}) {
+        my $search = join ("", map { "($_=$username)" } @{$self->{'searchattributes'}});
+        return "(|$search)";
+    } else {
+        return "$self->{'usernameattribute'}=$username";
+    }
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -619,7 +649,7 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
 
 # vim: set shiftwidth=4:
