@@ -22,11 +22,27 @@ use pf::util;
 
 extends 'pf::Authentication::Source';
 
-has '+class' => (default => 'exclusive');
+has '+class' => (default => 'external');
 has '+type' => (default => 'Null');
-has '+unique' => (default => 1);
 has 'email_required' => (isa => 'Str', is => 'rw', default => 'no');
 
+=head2 authenticate
+
+=cut
+
+sub authenticate {
+  my $self = shift;
+  return $TRUE;
+}
+
+=head2 dynamic_routing_module
+
+Which module to use for DynamicRouting
+
+=cut
+
+sub dynamic_routing_module { 'Authentication::Null' }
+
 =head2 available_attributes
 
 Allow to make a condition on the user's email address.
@@ -80,16 +96,16 @@ sub match_in_subclass {
     return $username;
 }
 
-=head2 authenticate
+=head2 mandatoryFields
 
 =cut
 
-sub authenticate {
-    my ($self, $username, $password) = @_;
-    if (isdisabled($self->email_required) || Email::Valid->address($username) ) {
-        return ($TRUE, $AUTH_SUCCESS_MSG);
+sub mandatoryFields {
+    my ($self) = @_;
+    if (isenabled($self->email_required)) {
+        return (qw(email));
     }
-    return ($FALSE, $INVALID_EMAIL_MSG);
+    return ();
 }
 
 =head1 AUTHOR
@@ -98,7 +114,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
