@@ -17,11 +17,20 @@ use pf::Authentication::Source;
 
 use Moose;
 extends 'pf::Authentication::Source';
+with qw(pf::Authentication::InternalRole);
 
 has '+type' => ( default => 'SQL' );
 
 =head1 METHODS
 
+=head2 dynamic_routing_module
+
+Which module to use for DynamicRouting
+
+=cut
+
+sub dynamic_routing_module { 'Authentication::Login' }
+
 =head2 available_attributes
 
 =cut
@@ -130,6 +139,21 @@ sub match {
             push(@actions, $action);
         }
 
+        my $time_balance = $result->{'time_balance'};
+        if (defined $time_balance) {
+            $action =  pf::Authentication::Action->new({type => $Actions::SET_TIME_BALANCE,
+                                                        value => $time_balance});
+            push(@actions, $action);
+        }
+
+        my $bandwidth_balance = $result->{'bandwidth_balance'};
+        if (defined $bandwidth_balance) {
+            $action =  pf::Authentication::Action->new({type => $Actions::SET_BANDWIDTH_BALANCE,
+                                                        value => $bandwidth_balance});
+            push(@actions, $action);
+        }
+
+
         return \@actions;
     }
 
@@ -142,7 +166,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -163,7 +187,7 @@ USA.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 1;
 
 # vim: set shiftwidth=4:
