@@ -15,10 +15,10 @@ pf::ConfigStore::AdminRoles
 use HTTP::Status qw(:constants is_error is_success);
 use Moo;
 use namespace::autoclean;
-use pf::file_paths;
+use pf::file_paths qw($admin_roles_config_file);
 extends 'pf::ConfigStore';
 
-sub expandableParams { return (qw(actions allowed_roles allowed_access_levels)); }
+sub expandableParams { return (qw(actions allowed_roles allowed_access_levels allowed_node_roles allowed_actions)); }
 
 sub configFile { $admin_roles_config_file }
 
@@ -48,11 +48,11 @@ sub cleanupBeforeCommit {
 
 
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
