@@ -1,4 +1,5 @@
 package pf::ConfigStore::Cluster;
+
 =head1 NAME
 
 pf::ConfigStore::Realm
@@ -15,14 +16,14 @@ pf::ConfigStore::Realm
 use strict;
 use warnings;
 use Moo;
-use pf::file_paths;
+use pf::file_paths qw($cluster_config_file);;
 extends 'pf::ConfigStore';
 
 sub configFile { $cluster_config_file };
 
 sub pfconfigNamespace {'config::Cluster'}
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 AUTHOR
 
@@ -30,7 +31,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -52,4 +53,3 @@ USA.
 =cut
 
 1;
-
