@@ -14,7 +14,7 @@ pf::ConfigStore::FirewallSSO
 use strict;
 use warnings;
 use Moo;
-use pf::file_paths;
+use pf::file_paths qw($firewall_sso_config_file);
 extends 'pf::ConfigStore';
 
 sub configFile { $firewall_sso_config_file };
@@ -51,7 +51,7 @@ sub _fields_expanded {
     return qw(categories);
 }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 AUTHOR
 
@@ -59,7 +59,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
