@@ -1,13 +1,12 @@
 package pf::ConfigStore::Interface;
+
 =head1 NAME
 
-pf::ConfigStore::Profile add documentation
-
-=cut
+pf::ConfigStore::Profile
 
 =head1 DESCRIPTION
 
-pf::ConfigStore::Switch;
+pf::ConfigStore::Switch
 
 =cut
 
@@ -15,6 +14,7 @@ use Moo;
 use namespace::autoclean;
 use pf::ConfigStore::Pf;
 use pf::ConfigStore::Group;
+use pf::file_paths qw($pf_config_file);
 
 extends 'pf::ConfigStore';
 with 'pf::ConfigStore::Group';
@@ -23,23 +23,23 @@ sub group { 'interface' };
 
 sub pfconfigNamespace {'config::Pf'};
 
-=head2 Methods
+sub configFile {$pf_config_file};
 
-=over
+=head1 METHODS
 
-=item _buildCachedConfig
+=head2 _buildCachedConfig
+
+  Build the cached config
 
 =cut
 
 sub _buildCachedConfig { pf::ConfigStore::Pf->new->cachedConfig() }
 
-__PACKAGE__->meta->make_immutable;
-
-=back
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -61,4 +61,3 @@ USA.
 =cut
 
 1;
-
