@@ -15,19 +15,30 @@ pf::ConfigStore::PKI_Provider
 use HTTP::Status qw(:constants is_error is_success);
 use Moo;
 use namespace::autoclean;
-use pf::file_paths;
+use pf::file_paths qw($pki_provider_config_file);
 extends 'pf::ConfigStore';
+with 'pf::ConfigStore::Role::ReverseLookup';
 
 sub configFile { $pki_provider_config_file }
 
 sub pfconfigNamespace { 'config::PKI_Provider' }
 
+=head2 canDelete
 
-__PACKAGE__->meta->make_immutable;
+canDelete
+
+=cut
+
+sub canDelete {
+    my ($self, $id) = @_;
+    return !$self->isInProvisioning('pki_provider', $id) && $self->SUPER::canDelete($id);
+}
+
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
