@@ -14,7 +14,7 @@ pf::ConfigStore::Profile
 
 use Moo;
 use namespace::autoclean;
-use pf::file_paths;
+use pf::file_paths qw($profiles_config_file $profiles_default_config_file);
 
 use pf::ConfigStore;
 
@@ -27,6 +27,8 @@ with 'pf::ConfigStore::Role::ValidGenericID';
 
 sub configFile { $profiles_config_file }
 
+sub importConfigFile { $profiles_default_config_file }
+
 sub pfconfigNamespace {'config::Profiles'}
 
 sub default_section { 'default' }
@@ -54,6 +56,7 @@ Clean up switch data
 sub cleanupAfterRead {
     my ($self, $id, $profile) = @_;
     $self->expand_list($profile, $self->_fields_expanded);
+    $profile->{filter} = [ map {s/,,/,/g;$_} split( /\s*(?<!,),(?!,)\s*/, $profile->{filter} || '' ) ];
 }
 
 =head2 cleanupBeforeCommit
@@ -65,6 +68,9 @@ Clean data before update or creating
 sub cleanupBeforeCommit {
     my ($self, $id, $profile) = @_;
     $self->flatten_list($profile, $self->_fields_expanded);
+    if (exists $profile->{filter}) {
+        $profile->{filter} = join(",", map { s/,/,,/g;$_ } @{$profile->{filter} // []});
+    }
 }
 
 =head2 _fields_expanded
@@ -72,14 +78,14 @@ sub cleanupBeforeCommit {
 =cut
 
 sub _fields_expanded {
-    return qw(sources filter locale mandatory_fields custom_fields_authentication_sources allowed_devices provisioners billing_tiers scans);
+    return qw(sources locale allowed_devices provisioners billing_tiers scans);
 }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
