@@ -15,14 +15,14 @@ pf::ConfigStore::RadiusFilters
 use strict;
 use warnings;
 use Moo;
-use pf::file_paths;
+use pf::file_paths qw($radius_filters_config_file);
 extends 'pf::ConfigStore';
 
 sub configFile { $radius_filters_config_file };
 
 sub pfconfigNamespace {'config::RadiusFilters'}
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 AUTHOR
 
@@ -30,7 +30,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
