@@ -15,7 +15,7 @@ pf::ConfigStore::Switch;
 use Moo;
 use namespace::autoclean;
 use pf::log;
-use pf::file_paths;
+use pf::file_paths qw($switches_config_file $switches_default_config_file);
 use pf::util;
 use HTTP::Status qw(:constants is_error is_success);
 use List::MoreUtils qw(part any);
@@ -27,6 +27,8 @@ with 'pf::ConfigStore::Hierarchy';
 
 sub configFile { $switches_config_file }
 
+sub importConfigFile { $switches_default_config_file }
+
 sub pfconfigNamespace {'config::Switch'}
 
 =head2 Methods
@@ -101,11 +103,33 @@ Clean data before update or creating
 
 sub cleanupBeforeCommit {
     my ( $self, $id, $switch ) = @_;
+    $self->_normalizeUplink($switch);
+    $self->_normalizeInlineTrigger($switch);
+    $self->_removeParentValues($id, $switch);
+}
 
+=head2 _normalizeUplink
+
+_normalizeUplink
+
+=cut
+
+sub _normalizeUplink {
+    my ($self, $switch) = @_;
     if ( $switch->{uplink_dynamic} ) {
         $switch->{uplink}         = 'dynamic';
         $switch->{uplink_dynamic} = undef;
     }
+}
+
+=head2 _normalizeInlineTrigger
+
+_normalizeInlineTrigger
+
+=cut
+
+sub _normalizeInlineTrigger {
+    my ($self, $switch) = @_;
     if ( exists $switch->{inlineTrigger} ) {
 
         # Build string definition for inline triggers (see pf::role::isInlineTrigger)
@@ -117,9 +141,21 @@ sub cleanupBeforeCommit {
         @triggers = ('always::1') if $has_always;
         $switch->{inlineTrigger} = join( ',', @triggers );
     }
+    return ;
+}
 
-    my $parent_config = $self->parentConfigRaw($id);
-    if($id ne $self->topLevelGroup) {
+=head2 _removeParentValues
+
+_removeParentValues
+
+=cut
+
+sub _removeParentValues {
+    my ($self, $id, $switch) = @_;
+    my $parentAttribute = $self->parentAttribute;
+    my $topLevelGroup = $self->topLevelGroup;
+    my $parent_config = $self->fullConfigRaw($switch->{$parentAttribute} ? $self->_formatGroup($switch->{$parentAttribute}) : $topLevelGroup);
+    if($id ne $topLevelGroup) {
         # Put the elements to undef if they are the same as in the inheritance
         while (my ($key, $value) = each %$switch){
             if(defined($value) && defined($parent_config->{$key}) && $value eq $parent_config->{$key}){
@@ -127,7 +163,6 @@ sub cleanupBeforeCommit {
             }
         }
     }
-
 }
 
 
@@ -161,13 +196,13 @@ before rewriteConfig => sub {
 };
 
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
