@@ -19,18 +19,27 @@ use pf::ConfigStore::Group;
 extends 'pf::ConfigStore::Switch';
 with 'pf::ConfigStore::Group';
 with 'pf::ConfigStore::Hierarchy';
+with 'pf::ConfigStore::Role::ReverseLookup';
 
 sub group { 'group' };
 
 sub globalConfigStore { pf::ConfigStore::Switch->new }
+=head2 canDelete
 
-__PACKAGE__->meta->make_immutable;
+canDelete
 
-=back
+=cut
+
+sub canDelete {
+    my ($self, $id) = @_;
+    return !$self->isInSwitch('group', $id) && $self->SUPER::canDelete($id);
+}
+
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -52,5 +61,3 @@ USA.
 =cut
 
 1;
-
-
