@@ -15,7 +15,7 @@ pf::ConfigStore::WMI
 use strict;
 use warnings;
 use Moo;
-use pf::file_paths;
+use pf::file_paths qw($wmi_config_file);
 extends 'pf::ConfigStore';
 
 sub configFile { $wmi_config_file };
@@ -52,7 +52,7 @@ sub _fields_expanded {
     return qw(actions);
 }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 AUTHOR
 
@@ -60,7 +60,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
