@@ -16,6 +16,7 @@ use strict;
 use warnings;
 use Moose::Util::TypeConstraints;
 use NetAddr::IP;
+use pf::util qw(normalize_time);
 
 subtype 'NetAddrIpStr', as 'NetAddr::IP';
 
@@ -25,7 +26,11 @@ subtype 'RegexpRefStr', as 'RegexpRef';
 
 coerce 'RegexpRefStr', from 'Str', via {qr/$_/};
 
-#no Moose::Util::TypeConstraints;
+subtype 'PfInterval', as 'Int';
+
+coerce 'PfInterval', from 'Str', via { return normalize_time($_) };
+
+no Moose::Util::TypeConstraints;
 
 =head1 AUTHOR
 
@@ -33,7 +38,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
