@@ -49,7 +49,6 @@ use strict;
 use warnings;
 
 use pf::log;
-use Net::Appliance::Session;
 use Net::SNMP;
 use Try::Tiny;
 
@@ -124,6 +123,7 @@ sub getCurrentApFromMac {
 
     my $session;
     try {
+        require Net::Appliance::Session;
         $session = Net::Appliance::Session->new(
             Host => $self->{_ip},
             Timeout => 25, # apparently these things are very slow
@@ -259,7 +259,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
