@@ -29,10 +29,10 @@ The hardware should support it.
 
 =head1 BUGS AND LIMITATIONS
 
-Because a lot of code is shared with the 2950 make sure to check the BUGS AND LIMITATIONS section of 
+Because a lot of code is shared with the 2950 make sure to check the BUGS AND LIMITATIONS section of
 L<pf::Switch::Cisco::Catalyst_2950> also.
 
-=over 
+=over
 
 =item port-security + Voice over IP (VoIP)
 
@@ -63,8 +63,6 @@ use warnings;
 
 use Net::SNMP;
 
-use pf::config;
-
 use base ('pf::Switch::Cisco::Catalyst_3560');
 
 sub description { 'Cisco Catalyst 3560G' }
@@ -100,7 +98,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
