@@ -44,7 +44,6 @@ use warnings;
 use base ('pf::Switch::Cisco');
 use Carp;
 use Net::SNMP;
-use Net::Appliance::Session;
 
 sub description { 'Cisco ISR 1800 Series' }
 
@@ -139,6 +138,7 @@ sub getMacBridgePortHash {
 
     my $session;
     eval {
+        require Net::Appliance::Session;
         $session = Net::Appliance::Session->new(
             Host      => $self->{_ip},
             Timeout   => 5,
@@ -246,7 +246,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
