@@ -19,7 +19,6 @@ F<conf/switches.conf>
 use strict;
 use warnings;
 use Data::Dumper;
-use Net::Telnet;
 
 use base ('pf::Switch::Dell');
 
@@ -37,6 +36,7 @@ sub _setVlan {
     my $session;
 
     eval {
+        require Net::Telnet;
         $session = new Net::Telnet( Host => $self->{_ip}, Timeout => 20 );
 
         #$session->dump_log();
@@ -74,7 +74,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
