@@ -11,7 +11,7 @@ to access SNMP enabled Dlink DGS 3200 switches.
 
 =head1 STATUS
 
-=over 
+=over
 
 =item Supports
 
@@ -44,7 +44,10 @@ sub description { 'D-Link DGS 3200' }
 use pf::Switch::constants;
 use pf::util;
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $MAC
+    $PORT
+);
 
 =head1 SUBROUTINES
 
@@ -88,7 +91,7 @@ Translate RADIUS NAS-Port into the physical port ifIndex
 sub NasPortToIfIndex {
     my ($self, $NAS_port) = @_;
     my $logger = $self->logger;
-    
+
     #NAS-Port is ifIndex (Stacked switch not tested!!)
     return $NAS_port;
 }
@@ -101,7 +104,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
