@@ -25,7 +25,11 @@ use POSIX;
 use base ('pf::Switch');
 
 use pf::constants;
-use pf::config;
+use pf::constants::role qw($VOICE_ROLE);
+use pf::config qw(
+    $MAC
+    $PORT
+);
 use pf::radius::constants;
 use pf::Switch::constants;
 use pf::util;
@@ -154,7 +158,7 @@ sub getVoipVsa {
     return (
         'Tunnel-Type'               => $RADIUS::VLAN,
         'Tunnel-Medium-Type'        => $RADIUS::ETHERNET,
-        'Tunnel-Private-Group-ID'   => $self->getVlanByName('voice'),
+        'Tunnel-Private-Group-ID'   => $self->getVlanByName($VOICE_ROLE),
     );
 }
 
@@ -180,7 +184,7 @@ sub NasPortToIfIndex {
     my ($self, $nas_port) = @_;
     my $logger = $self->logger;
 
-    # 4096 NAS-Port slots are reserved per physical ports, 
+    # 4096 NAS-Port slots are reserved per physical ports,
     # I'm assuming that each client will get a +1 so I translate all of them into the same ifIndex
     # Also there's a large offset (16781312), couldn't find where it is coming from...
     my $port = ceil(($nas_port - $THREECOM::NAS_PORT_OFFSET) / $THREECOM::NAS_PORTS_PER_PORT_RANGE);
@@ -201,24 +205,44 @@ sub NasPortToIfIndex {
     return $nas_port;
 }
 
-=item parseTrap
+=item returnAuthorizeWrite
 
-All traps ignored
+    Return a generic accept without any attributes for this module
 
 =cut
 
-sub parseTrap {
-    my ( $self, $trapString ) = @_;
+sub returnAuthorizeWrite {
+    my ($self, $args) = @_;
     my $logger = $self->logger;
+    my $radius_reply_ref;
+    my $status;
+    $radius_reply_ref->{'Reply-Message'} = "Switch enable access granted by PacketFence";
+    $logger->info("User $args->{'user_name'} logged in $args->{'switch'}{'_id'} with write access");
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test('returnAuthorizeWrite', $args);
+    ($radius_reply_ref, $status) = $filter->handleAnswerInRule($rule,$args,$radius_reply_ref);
+    return [$status, %$radius_reply_ref];
 
-    my $trapHashRef;
-
-    $logger->debug("trap ignored, since we're using 802.1x/mac-auth");
-    $trapHashRef->{'trapType'} = 'unknown';
-
-    return $trapHashRef;
 }
 
+=item returnAuthorizeRead
+
+    Return a generic accept without any attributes for this module
+
+=cut
+
+sub returnAuthorizeRead {
+    my ($self, $args) = @_;
+    my $logger = $self->logger;
+    my $radius_reply_ref;
+    my $status;
+    $radius_reply_ref->{'Reply-Message'} = "Switch read access granted by PacketFence";
+    $logger->info("User $args->{'user_name'} logged in $args->{'switch'}{'_id'} with read access");
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test('returnAuthorizeRead', $args);
+    ($radius_reply_ref, $status) = $filter->handleAnswerInRule($rule,$args,$radius_reply_ref);
+    return [$status, %$radius_reply_ref];
+}
 
 =back
 
@@ -228,7 +252,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
