@@ -12,7 +12,7 @@ A copy of the 3COM E5500G Switch module because HP bought 3Com and is selling re
 
 =over
 
-=item Supports 
+=item Supports
 
 =over
 
@@ -31,7 +31,7 @@ Although current limitation regarding 802.1X re-authentication could imply lost
 
 =back
 
-802.1X and MAC-Authentication confirmed to work with firmware V3.03.02s168p07. 
+802.1X and MAC-Authentication confirmed to work with firmware V3.03.02s168p07.
 
 Tested by the community.
 
@@ -46,23 +46,23 @@ It might work out of the box or the module might need adjustments.
 
 =item Unclear NAS-Port to ifIndex translation
 
-This switch's NAS-Port usage is not well documented or easy to guess 
+This switch's NAS-Port usage is not well documented or easy to guess
 so we reversed engineered the translation for the 4200G but it might not apply well to other switches.
 If it's your case, please let us know the NAS-Port you obtain in a RADIUS Request and the physical port you are on.
 The consequence of a bad translation are that VLAN re-assignment (ie after registration) won't work.
 
 =item Port-Security: security traps not sent under some circumstances
 
-The 4200G exhibit a behavior where secureViolation traps are not sent 
-if the MAC has already been authorized on another port on the same VLAN. 
-This tend to happen a lot (when users move on the same switch) for this 
+The 4200G exhibit a behavior where secureViolation traps are not sent
+if the MAC has already been authorized on another port on the same VLAN.
+This tend to happen a lot (when users move on the same switch) for this
 reason we recommend not to use this switch in port-security mode.
 
 This behavior has not been confirmed or denied for this model.
 
 =item 802.1X Re-Authentication doesn't trigger a DHCP Request from the endpoint
 
-Since this is critical for PacketFence's operation, as a work-around, 
+Since this is critical for PacketFence's operation, as a work-around,
 we decided to bounce the port which will force the client to re-authenticate and do DHCP.
 Because of the port bounce PCs behind IP phones aren't recommended.
 This behavior was experienced on a Windows 7 client on the 4200G with the latest firmware.
@@ -73,7 +73,7 @@ This behavior has not been confirmed or denied for this model.
 
 =head1 NOTES
 
-=over 
+=over
 
 =item MAC Authentication and 802.1X behavior
 
@@ -89,14 +89,8 @@ It's really a matter of choice.
 use strict;
 use warnings;
 
-use Net::SNMP;
-use POSIX;
-
 use base ('pf::Switch::ThreeCom::Switch_4200G');
 
-use pf::config;
-use pf::Switch::constants;
-
 sub description { 'HP E5500G (3Com)' }
 
 =head1 SUBROUTINES
@@ -111,7 +105,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
