@@ -6,7 +6,7 @@ pf::SNMP::Juniper::EX2200 - Object oriented module to manage Juniper's EX Series
 
 =head1 STATUS
 
-Supports 
+Supports
  MAC Authentication (MAC RADIUS in Juniper's terms)
  802.1X
 
@@ -30,10 +30,12 @@ use strict;
 use warnings;
 
 use base ('pf::Switch::Juniper');
-use Net::Appliance::Session;
 
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $WIRED_802_1X
+    $WIRED_MAC_AUTH
+);
 sub description { 'Juniper EX 2200 Series' }
 
 # importing switch constants
@@ -66,18 +68,18 @@ For now it returns the voiceVlan untagged since Juniper supports multiple untagg
 =cut
 
 sub getVoipVsa{
-    my ($self) = @_; 
-    my $logger = $self->logger; 
+    my ($self) = @_;
+    my $logger = $self->logger;
     my $voiceVlan = $self->{'_voiceVlan'};
     $logger->info("Accepting phone with untagged Access-Accept on voiceVlan $voiceVlan");
-    
+
     # Return the normal response except we force the voiceVlan to be sent
     return (
         'Tunnel-Medium-Type' => $RADIUS::ETHERNET,
         'Tunnel-Type' => $RADIUS::VLAN,
-        'Tunnel-Private-Group-ID' => $voiceVlan, 
+        'Tunnel-Private-Group-ID' => $voiceVlan,
     );
- 
+
 }
 
 
@@ -124,9 +126,9 @@ sub radiusDisconnect {
         my $connection_info = {
             nas_ip => $send_disconnect_to,
             secret => $self->{'_radiusSecret'},
-            LocalAddr => $self->deauth_source_ip(),
+            LocalAddr => $self->deauth_source_ip($send_disconnect_to),
         };
-       
+
         my $acctsessionid = node_accounting_current_sessionid($mac);
         # Standard Attributes
         my $attributes_ref = {
@@ -148,7 +150,7 @@ sub radiusDisconnect {
     };
     return if (!defined($response));
 
-    return $TRUE if ($response->{'Code'} eq 'Disconnect-ACK');
+    return $TRUE if ( ($response->{'Code'} eq 'Disconnect-ACK') || ($response->{'Code'} eq 'CoA-ACK') );
 
     $logger->warn(
         "Unable to perform RADIUS Disconnect-Request."
@@ -164,7 +166,7 @@ Return the reference to the deauth technique or the default deauth technique.
 
 =cut
 
-sub wiredeauthTechniques { 
+sub wiredeauthTechniques {
    my ($self, $method, $connection_type) = @_;
    my $logger = $self->logger;
 
@@ -183,7 +185,7 @@ sub wiredeauthTechniques {
         my $default = $SNMP::RADIUS;
         my %tech = (
             $SNMP::RADIUS => 'deauthenticateMacRadius',
-        ); 
+        );
         if (!defined($method) || !defined($tech{$method})) {
             $method = $default;
         }
@@ -195,119 +197,113 @@ sub wiredeauthTechniques {
 
 }
 
+=head2 _commandSSH
+
+Execute a command on an SSH channel with a timeout
+
+HACK Alert: This is necessary (mandatory even) for the Juniper Switches as Net::SSH2 and the Juniper switches don't seem to understand themselves as the return data channel from the Juniper never closes (even after it prints its output) so all commands will last the specified timeout.
+
+=cut
+
+sub _commandSSH{
+    my ($self, $chan, $command, $timeout) = @_;
+    my $logger = $self->logger;
+    $timeout //= 5;
+    eval {
+        local $SIG{ALRM} = sub { die "timeout\n" };
+        alarm $timeout;
+        print $chan "$command\n";
+        $logger->debug("SSH output : $_") while <$chan>;
+        alarm 0;
+    };
+}
+
+=head2 _connectSSH
+
+Connect to the switch using SSH
+
+=cut
+
+sub _connectSSH {
+    my ($self) = @_;
+    
+    my $ssh;
+    eval {
+        require Net::SSH2;
+        $ssh = Net::SSH2->new();
+        $ssh->connect($self->{_ip}, 22 ) or die "Cannot connect $!"  ;
+        $ssh->auth_password($self->{_cliUser},$self->{_cliPwd}) or die "Cannot authenticate" ;
+    };
+
+    if($@) {
+        $self->logger->error("Error connecting through SSH: $@");
+    }
+    return $ssh;
+
+}
+
 =head2 enableMABFloatingDevice
 
-Connects to the switch and configures the specified port to be RADIUS floating device ready
+Enable the MAB floating device mode on a switch port
 
 =cut
 
 sub enableMABFloatingDevice{
-    my ($self, $ifIndex) = @_; 
+    my ($self, $ifIndex) = @_;
     my $logger = $self->logger;
-    
-    my $session;
-    eval {
-        $session = Net::Appliance::Session->new(
-            Host      => $self->{_ip},
-            Timeout   => 20,
-            Transport => $self->{_cliTransport},        
-            Platform  => "JUNOS",    
-        );
-        
-        $session->connect(
-            Name     => $self->{_cliUser},
-            Password => $self->{_cliPwd}
-        );  
-    };  
-    
-    if ($@) {
-        $logger->error("Unable to connect to ".$self->{'_ip'}." using ".$self->{_cliTransport}.". Failed with $@");
-        return;
-    }   
 
-    my $port = $self->getIfName($ifIndex);
+    my $ssh = $self->_connectSSH();
+
+    return unless($ssh);
+
+    my $port = $ifIndex;
 
     my $command_mac_limit = "set ethernet-switching-options secure-access-port interface $port mac-limit 16383";
     my $command_disconnect_flap = "delete protocols dot1x authenticator interface $port mac-radius flap-on-disconnect";
 
-    my @output;
-    eval {
-        # fake priviledged mode
-        $session->in_privileged_mode(1);
-        $session->begin_configure();
+    my $chan = $ssh->channel();
+    $chan->shell();
+    $self->_commandSSH($chan, "configure");
+    $self->_commandSSH($chan, $command_mac_limit);
+    $self->_commandSSH($chan, $command_disconnect_flap);
+    $self->_commandSSH($chan, 'commit comment "configured floating device on '.$port.'"', 30);
 
-    
-        @output = $session->cmd(String => $command_mac_limit, Timeout => '5');
-        @output = $session->cmd(String => $command_disconnect_flap, Timeout => '5');
-        @output = $session->cmd(String => 'commit comment "configured floating device"', Timeout => '30');
+    $ssh->disconnect();
 
-        $session->in_privileged_mode(0);
-    };
+    $logger->info("Completed configuration of floating device on $port");
 
-    if ($@) {
-        $logger->error("Unable to set mac limit for port $port: $@");
-        $session->close();
-        return;
-    }
-    $session->close();
     return 1;
-
 }
 
 =head2 disableMABFloatingDevice
 
-Connects to the switch and removes the RADIUS floating device configuration
+Disable the MAB floating device mode on a switch port
 
 =cut
 
 sub disableMABFloatingDevice{
-    my ($self, $ifIndex) = @_; 
+    my ($self, $ifIndex) = @_;
     my $logger = $self->logger;
-    
-    my $session;
-    eval {
-        $session = Net::Appliance::Session->new(
-            Host      => $self->{_ip},
-            Timeout   => 20,
-            Transport => $self->{_cliTransport},        
-            Platform  => "JUNOS",    
-        );
-        
-        $session->connect(
-            Name     => $self->{_cliUser},
-            Password => $self->{_cliPwd}
-        );  
-    };  
-    
-    if ($@) {
-        $logger->error("Unable to connect to ".$self->{'_ip'}." using ".$self->{_cliTransport}.". Failed with $@");
-        return;
-    }   
 
-    my $port = $self->getIfName($ifIndex);
+    my $ssh = $self->_connectSSH();
+
+    return unless($ssh);
+
+    my $port = $ifIndex;
 
     my $command_mac_limit = "delete ethernet-switching-options secure-access-port interface $port mac-limit";
     my $command_disconnect_flap = "set protocols dot1x authenticator interface $port mac-radius flap-on-disconnect";
-    my @output;
-    eval {
-        # fake priviledged mode
-        $session->in_privileged_mode(1);
-        $session->begin_configure();
 
+    my $chan = $ssh->channel();
+    $chan->shell();
+    $self->_commandSSH($chan, "configure");
+    $self->_commandSSH($chan, $command_mac_limit);
+    $self->_commandSSH($chan, $command_disconnect_flap);
+    $self->_commandSSH($chan, 'commit comment "de-configured floating device on '.$port.'"', 30);
+
+    $ssh->disconnect();
     
-        @output = $session->cmd(String => $command_mac_limit, Timeout => '5');
-        @output = $session->cmd(String => $command_disconnect_flap, Timeout => '5');
-        @output = $session->cmd(String => 'commit comment "deconfigured floating device"', Timeout => '30');
-
-        $session->in_privileged_mode(0);
-    };
-
-    if ($@) {
-        $logger->error("Unable to set mac limit for port $port: $@");
-        $session->close();
-        return;
-    }
-    $session->close();
+    $logger->info("Completed de-configuration of floating device on $port");
 
     return 1;
 }
@@ -323,7 +319,7 @@ sub disableMABFloatingDevice{
 #
 #    # if can't SNMP read abort
 #    return if ( !$self->connectRead() );
-#    
+#
 #    # LLDP info takes a few seconds to appear in the SNMP table after the switch makes the radius request
 #    # Sleep for 2 seconds to make sure the info is there
 #    sleep(2);
@@ -334,7 +330,7 @@ sub disableMABFloatingDevice{
 #
 #    my $oid_lldpRemPortId = '1.0.8802.1.1.2.1.4.1.1.7';
 #    my $oid_lldpRemSysCapEnabled = '1.0.8802.1.1.2.1.4.1.1.12';
-#    
+#
 #    $logger->trace(
 #        "SNMP get_next_request for lldpRemSysCapEnabled: "
 #        . "$oid_lldpRemSysCapEnabled"
@@ -345,7 +341,7 @@ sub disableMABFloatingDevice{
 #    # Cap entries look like this:
 #    # iso.0.8802.1.1.2.1.4.1.1.12.0.10.29 = Hex-STRING: 24 00
 #    # We want to validate that the telephone capability bit is turned on.
-#    my @phones = (); 
+#    my @phones = ();
 #    foreach my $oid ( keys %{$result} ) {
 #
 #        # grab the lldpRemIndex
@@ -386,7 +382,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
