@@ -146,7 +146,7 @@ sub _setVlan {
             . $self->{_ip}
             . "} in _setVlan" );
     {
-        lock %{ $switch_locker_ref->{ $self->{_ip} } };
+        my $lock = $self->getExclusiveLock();
         $logger->trace( "locking - \$switch_locker{"
                 . $self->{_ip}
                 . "} locked in _setVlan" );
@@ -578,7 +578,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
