@@ -68,12 +68,14 @@ ethernet interface.
 use strict;
 use warnings;
 
-use Net::Appliance::Session;
-
 use base ('pf::Switch');
 
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $MAC
+    $SSID
+);
+use pf::file_paths qw($lib_dir);
 # importing switch constants
 use pf::Switch::constants;
 use pf::util;
@@ -127,23 +129,6 @@ sub getVersion {
     $logger->warn("unable to fetch version information");
 }
 
-=item parseTrap
-
-This is called when we receive an SNMP-Trap for this device
-
-=cut
-
-sub parseTrap {
-    my ( $self, $trapString ) = @_;
-    my $trapHashRef;
-    my $logger = $self->logger;
-
-    $logger->debug("trap currently not handled");
-    $trapHashRef->{'trapType'} = 'unknown';
-
-    return $trapHashRef;
-}
-
 =item deauthenticateMacDefault
 
 deauthenticate a MAC address from wireless network
@@ -170,6 +155,7 @@ sub deauthenticateMacDefault {
 
     my $session;
     eval {
+        require Net::Appliance::Session;
         $session = Net::Appliance::Session->new(
             Host      => $self->{_ip},
             Timeout   => 5,
@@ -262,7 +248,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
