@@ -42,7 +42,11 @@ use base ('pf::Switch');
 
 use pf::accounting qw(node_accounting_dynauth_attr);
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $MAC
+    $SSID
+    $WEBAUTH_WIRELESS
+);
 use pf::util;
 
 sub description { 'Ruckus Wireless Controllers' }
@@ -67,7 +71,7 @@ Will be activated only if HTTP is selected as a deauth method
 
 =cut
 
-sub supportsWebFormRegistration { 
+sub supportsWebFormRegistration {
     my ($self) = @_;
     return $self->{_deauthMethod} eq $SNMP::HTTP;
 }
@@ -110,14 +114,9 @@ sub parseTrap {
     my $trapHashRef;
     my $logger = $self->logger;
 
-    # Handle WIPS Trap
-    if ( $trapString =~ /\.1\.3\.6\.1\.4\.1\.25053\.2\.2\.2\.20 = STRING: \"([a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2})/ ) {
-        $trapHashRef->{'trapType'}    = 'wirelessIPS';
-        $trapHashRef->{'trapMac'} = clean_mac($1);
-    } else {
-        $logger->debug("trap currently not handled.  TrapString was: $trapString");
-        $trapHashRef->{'trapType'} = 'unknown';
-    }
+    $logger->debug("trap currently not handled.  TrapString was: $trapString");
+    $trapHashRef->{'trapType'} = 'unknown';
+
     return $trapHashRef;
 }
 
@@ -143,7 +142,7 @@ sub deauthenticateMacDefault {
 
     $logger->debug("deauthenticate $mac using RADIUS Disconnect-Request deauth method");
     return $self->radiusDisconnect(
-        $mac, { 'Acct-Session-Id' => $dynauth->{'acctsessionid'}, 'User-Name' => $dynauth->{'username'} },
+        $mac, { 'User-Name' => $dynauth->{'username'} },
     );
 }
 
@@ -167,25 +166,36 @@ sub deauthTechniques {
     return $method,$tech{$method};
 }
 
-=item parseUrl
 
-This is called when we receive a http request from the device and return specific attributes:
+=item parseExternalPortalRequest
 
-client mac address
-SSID
-client ip address
-redirect url
-grant url
-status code
+Parse external portal request using URI and it's parameters then return an hash reference with the appropriate parameters
+
+See L<pf::web::externalportal::handle>
 
 =cut
 
-sub parseUrl {
-    my($self, $req) = @_;
+sub parseExternalPortalRequest {
+    my ( $self, $r, $req ) = @_;
     my $logger = $self->logger;
-    return (clean_mac($$req->param('client_mac')),$$req->param('ssid'),defined($$req->param('uip')) ? $$req->param('uip') : undef,$$req->param('url'),undef,undef);
+
+    # Using a hash to contain external portal parameters
+    my %params = ();
+
+    %params = (
+        switch_id               => $req->param('sip'),
+        client_mac              => clean_mac($req->param('client_mac')),
+        client_ip               => defined($req->param('uip')) ? $req->param('uip') : undef,
+        ssid                    => $req->param('ssid'),
+        redirect_url            => $req->param('url'),
+        synchronize_locationlog => $FALSE,
+        connection_type         => $WEBAUTH_WIRELESS,
+    );
+
+    return \%params;
 }
 
+
 =item getAcceptForm
 
 Creates the form that should be given to the client device to trigger a reauthentication.
@@ -193,24 +203,21 @@ Creates the form that should be given to the client device to trigger a reauthen
 =cut
 
 sub getAcceptForm {
-    my ( $self, $mac , $destination_url, $cgi_session) = @_;
+    my ( $self, $mac, $destination_url, $portalSession ) = @_;
     my $logger = $self->logger;
     $logger->debug("Creating web release form");
 
-    my $client_ip = $cgi_session->param("ecwp-original-param-uip");
+    my $client_ip = $portalSession->param("ecwp-original-param-uip");
     my $controller_ip = $self->{_ip};
 
     my $html_form = qq[
-        <form name="weblogin_form" action="http://$controller_ip:9997/login" method="POST" style="display:none">
+        <form name="weblogin_form" data-autosubmit="1000" method="POST" action="http://$controller_ip:9997/login" style="display:none">
           <input type="text" name="ip" value="$client_ip" />
           <input type="text" name="username" value="$mac" />
           <input type="text" name="password" value="$mac"/>
           <input type="submit">
         </form>
-
-        <script language="JavaScript" type="text/javascript">
-        window.setTimeout('document.weblogin_form.submit();', 1000);
-        </script>
+        <script src="/content/autosubmit.js" type="text/javascript"></script>
     ];
 
     $logger->debug("Generated the following html form : ".$html_form);
@@ -225,7 +232,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
