@@ -17,6 +17,7 @@ use warnings;
 use JSON::MaybeXS;
 use pf::log;
 use pf::util::webapi;
+use pf::dal;
 use Apache2::RequestIO;
 use Apache2::RequestRec;
 use Apache2::Response;
@@ -33,7 +34,6 @@ our $JSONRPC_ERROR_CODE_PARSE_ERROR     = -32700;
 
 our %ALLOW_CONTENT_TYPE = (
     'application/json-rpc'    => undef,
-    'application/json'        => undef,
     'application/jsonrequest' => undef,
 );
 
@@ -47,15 +47,19 @@ sub handler {
     use bytes;
     my ($self, $r) = @_;
     my $content = $self->get_all_content($r);
+    my $content_type = $r->headers_in->{'Content-Type'} || $CONTENT_TYPE;
     my $data = eval {decode_json $content };
     if ($@) {
-        get_logger->error($@);
+        my $error = $@;
+        get_logger->error($error);
         return $self->send_response(
             $r,
             Apache2::Const::HTTP_UNSUPPORTED_MEDIA_TYPE,
-            $self->make_error_object(undef, $JSONRPC_ERROR_CODE_PARSE_ERROR, "Cannot parse request\n", $@),
+            $self->make_error_object(undef, $JSONRPC_ERROR_CODE_PARSE_ERROR, "Cannot parse request\n", $error),
+            $content_type,
         );
     }
+    pf::dal->reset_tenant();
     my $ref_type = ref $data;
     unless ($ref_type && $ref_type eq 'HASH') {
         get_logger->error("Invalid request");
@@ -63,18 +67,24 @@ sub handler {
             $r,
             Apache2::Const::HTTP_UNSUPPORTED_MEDIA_TYPE,
             $self->make_error_object(undef, $JSONRPC_ERROR_CODE_INVALID_REQUEST, "Invalid request\n"),
+            $content_type,
         );
     }
 
-    my ($method, $id, $jsonrpc) = @{$data}{qw(method id jsonrpc)};
+    my ($method, $id, $jsonrpc, $tenant_id) = @{$data}{qw(method id jsonrpc tenant_id)};
     unless (defined $method) {
         get_logger->error("Invalid request, no method defined");
         return $self->send_response(
             $r,
             Apache2::Const::HTTP_UNSUPPORTED_MEDIA_TYPE,
             $self->make_error_object(undef, $JSONRPC_ERROR_CODE_INVALID_REQUEST, "Invalid request, no method defined\n"),
+            $content_type,
         );
     }
+    if (defined $tenant_id) {
+        pf::dal->set_tenant($tenant_id);
+    }
+
     my $dispatch_to = $self->dispatch_to;
     my $response_content = '';
     my $method_sub;
@@ -84,6 +94,7 @@ sub handler {
             $r,
             Apache2::Const::HTTP_NOT_FOUND,
             $self->make_error_object(undef, $JSONRPC_ERROR_CODE_NOT_FOUND, "Method '$method' not found\n"),
+            $content_type,
         );
     }
     my @args;
@@ -106,14 +117,16 @@ sub handler {
             }
         };
         if ($@) {
-            get_logger->error($@);
+            my $error = $@;
+            get_logger->error($error);
             return $self->send_response(
                 $r,
                 Apache2::Const::HTTP_INTERNAL_SERVER_ERROR,
-                $self->make_error_object($id, $JSONRPC_ERROR_CODE_GENERIC_ERROR, $@)
+                $self->make_error_object($id, $JSONRPC_ERROR_CODE_GENERIC_ERROR, $error),
+                $content_type,
             );
         }
-        return $self->send_response($r, Apache2::Const::HTTP_OK, $object);
+        return $self->send_response($r, Apache2::Const::HTTP_OK, $object, $content_type);
     }
     # Notify message defer until later
     $r->push_handlers(
@@ -122,14 +135,14 @@ sub handler {
             $logger->error($@) if $@;
         }
     );
-    $r->content_type($CONTENT_TYPE);
+    $r->content_type($content_type);
     return Apache2::Const::HTTP_NO_CONTENT;
 }
 
 sub send_response {
-    my ($self, $r, $status, $object) = @_;
+    my ($self, $r, $status, $object, $content_type) = @_;
     $r->custom_response($status, '');
-    $r->content_type($CONTENT_TYPE);
+    $r->content_type($content_type // $CONTENT_TYPE);
     $r->status($status);
     my $response_content = encode_json($object);
     $r->print($response_content);
@@ -160,7 +173,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
