@@ -66,8 +66,9 @@ sub handler {
             $response = [$MSGPACKRPC_RESPONSE,$msgid,undef,\@results];
         };
         if($@) {
-            $logger->error($@);
-            $self->_set_error($r,$msgid,Apache2::Const::SERVER_ERROR,$@);
+            my $error = $@;
+            $logger->error($error);
+            $self->_set_error($r,$msgid,Apache2::Const::SERVER_ERROR,$error);
             return Apache2::Const::OK;
         }
         my $content = Data::MessagePack->pack($response);
@@ -112,7 +113,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
