@@ -15,7 +15,7 @@ use warnings;
 
 use pf::log;
 use pf::api::jsonrpcclient;
-use pf::config qw(%connection_type_to_str);
+use pf::constants::config qw(%connection_type_to_str);
 use pf::person qw(person_view);
 use pf::factory::condition::access_filter;
 use pf::filter_engine;
@@ -61,7 +61,7 @@ sub test {
 
 =head2 filter
 
- Filter the arguements passed
+ Filter the arguments passed
 
 =cut
 
@@ -100,7 +100,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
