@@ -21,6 +21,7 @@ use pf::util qw(isenabled generate_session_id);
 use pf::CHI;
 use pf::radius::constants;
 use Scalar::Util qw(reftype);
+use Number::Range;
 
 use base qw(pf::access_filter);
 tie our %ConfigRadiusFilters, 'pfconfig::cached_hash', 'config::RadiusFilters';
@@ -64,7 +65,7 @@ sub handleAnswerInRule {
         $logger->info(evalParam($rule->{'log'},$args)) if defined($rule->{'log'});
         while (1) {
             if (defined($rule->{"answer$i"}) && $rule->{"answer$i"} ne '') {
-                my @answer = $rule->{"answer$i"} =~ /([a-zA-Z_-]*)\s*=>\s*(.*)/;
+                my @answer = $rule->{"answer$i"} =~ /([.0-9a-zA-Z_:-]*)\s*=>\s*(.*)/;
                 $args->{'session_id'} = setSession($args) if ($answer[1] =~ /\$session_id/);
                 evalAnswer(\@answer,$args,\$radius_reply);
             } else {
@@ -79,6 +80,18 @@ sub handleAnswerInRule {
         if (defined($rule->{'merge_answer'}) && !(isenabled($rule->{'merge_answer'}))) {
             return ($radius_reply,$status);
         } else {
+            foreach my $key (keys %$radius_reply_ref) {
+                if (exists($radius_reply->{$key})) {
+                    my $type = reftype($radius_reply->{$key});
+                    if (defined($type) && $type eq 'ARRAY') {
+                        my @attribute;
+                        push(@attribute,@{$radius_reply_ref->{$key}});
+                        push(@attribute,@{$radius_reply->{$key}});
+                        $radius_reply_ref->{$key} = \@attribute;
+                        delete $radius_reply->{$key};
+                    }
+                }
+            }
             $radius_reply_ref = {%$radius_reply_ref, %$radius_reply} if (keys %$radius_reply);
             return ($radius_reply_ref,$status);
         }
@@ -87,6 +100,7 @@ sub handleAnswerInRule {
     }
 }
 
+
 sub setSession {
     my($args) = @_;
     my $mac = $args->{'mac'};
@@ -129,11 +143,52 @@ evaluate all the variables
 
 sub evalParam {
     my ($answer, $args) = @_;
+    $answer = _random($answer) if rangeValidator($answer);
     $answer =~ s/\$([a-zA-Z_0-9]+)/$args->{$1} \/\/ ''/ge;
-    $answer =~ s/\${([a-zA-Z0-9_\-]+(?:\.[a-zA-Z0-9_\-]+)*)}/&_replaceParamsDeep($1,$args)/ge;
+    $answer =~ s/\$\{([a-zA-Z0-9_\-]+(?:\.[a-zA-Z0-9_\-]+)*)\}/&_replaceParamsDeep($1,$args)/ge;
     return $answer;
 }
 
+=head2 rangeValidator
+
+Validate the range definition
+Should be something like that 20..23 or 20..23,27..30
+
+=cut
+
+sub rangeValidator {
+    my ($range) =@_;
+    my $rangesep = qr/(?:\.\.)/;
+    my $sectsep  = qr/(?:\s|,)/;
+    my $validation = qr/(?:
+         [^0-9,. -]|
+         $rangesep$sectsep|
+         $sectsep$rangesep|
+         \d-\d|
+         ^$sectsep|
+         ^$rangesep|
+         $sectsep$|
+         $rangesep$|
+         ^\d+$
+         )/x;
+    return 0 if ($range =~ m/$validation/g);
+    return 1;
+}
+
+=head2 _random
+
+return random int in a range
+
+=cut
+
+sub _random {
+    my ($value) = @_;
+    my $range = Number::Range->new($value);
+    my $count = $range->size;
+    my @array = $range->range;
+    return $array[rand($count)];
+}
+
 =head2 _replaceParamsDeep
 
 evaluate all the variables deeply
@@ -175,7 +230,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
