@@ -13,6 +13,7 @@ pf::access_filter::vlan
 use strict;
 use warnings;
 use pf::api::jsonrpcclient;
+use Scalar::Util qw(reftype);
 
 use base qw(pf::access_filter);
 tie our %ConfigVlanFilters, 'pfconfig::cached_hash', 'config::VlanFilters';
@@ -33,7 +34,7 @@ sub filterRule {
         my $scope = $rule->{scope};
         if (defined($rule->{'role'}) && $rule->{'role'} ne '') {
             my $role = $rule->{'role'};
-            $role =~ s/\$([a-zA-Z_]+)/$args->{$1} \/\/ ''/ge;
+            $role = evalAnswer($role,$args);
             return $role;
         }
     }
@@ -63,7 +64,7 @@ Return the reference to the function that call the api.
 sub dispatchAction {
     my ($self, $rule, $args) = @_;
 
-    my $param = $self->evalParam($rule->{'action_param'}, $args);
+    my $param = $self->evalParamAction($rule->{'action_param'}, $args);
     my $apiclient = pf::api::jsonrpcclient->new;
     $apiclient->notify($rule->{'action'}, %{$param});
 }
@@ -74,7 +75,7 @@ evaluate action parameters
 
 =cut
 
-sub evalParam {
+sub evalParamAction {
     my ($self, $action_param, $args) = @_;
     my @params = split(/\s*,\s*/, $action_param);
     my $return = {};
@@ -87,13 +88,63 @@ sub evalParam {
     return $return;
 }
 
+
+=head2 evalAnswer
+
+evaluate the radius answer
+
+=cut
+
+sub evalAnswer {
+    my ($answer,$args) = @_;
+
+    my $return = evalParam($answer,$args);
+    return $return;
+
+}
+
+=head2 evalParam
+
+evaluate all the variables
+
+=cut
+
+sub evalParam {
+    my ($answer, $args) = @_;
+    $answer =~ s/\$([a-zA-Z_0-9]+)/$args->{$1} \/\/ ''/ge;
+    $answer =~ s/\$\{([a-zA-Z0-9_\-]+(?:\.[a-zA-Z0-9_\-]+)*)\}/&_replaceParamsDeep($1,$args)/ge;
+    return $answer;
+}
+
+
+=head2 _replaceParamsDeep
+
+evaluate all the variables deeply
+
+=cut
+
+sub _replaceParamsDeep {
+    my ($param_string, $args) = @_;
+    my @params = split /\./, $param_string;
+    my $param  = pop @params;
+    my $hash   = $args;
+    foreach my $key (@params) {
+        if (exists $hash->{$key} && reftype($hash->{$key}) eq 'HASH') {
+            $hash = $hash->{$key};
+            next;
+        }
+        return '';
+    }
+    return $hash->{$param} // '';
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
