@@ -15,36 +15,78 @@ pf::api::attributes
 use strict;
 use warnings;
 use Scalar::Util( );
+use Sub::Util();
+use List::MoreUtils qw(any);
 
 our %ALLOWED_ATTRIBUTES = (
     Public => 1,
     Fork => 1,
+    AllowedAsAction => 1,
+    ActionParams => 1,
+    RestPath => 1,
 );
 
+our $ATTRIBUTE_WITH_PARAMS = qr/([a-zA-Z0-9_]+)\((.*)\)/;
+
+
 our %TAGS;
+our %ALLOWED_ACTIONS;
+our %REST_PATHS;
 
 sub MODIFY_CODE_ATTRIBUTES {
     my ($class, $code, @attrs) = @_;
-    my (@bad, @good);
+    my (@bad, %extra);
     foreach my $attr (@attrs) {
         if (exists $ALLOWED_ATTRIBUTES{$attr} ) {
-            push @good, $attr;
-        } else {
+            $extra{$attr} = 1;
+        }
+        elsif ( $attr =~ $ATTRIBUTE_WITH_PARAMS ) {
+            if (exists $ALLOWED_ATTRIBUTES{$1} ) {
+               $extra{$1} = $2;
+            }
+            else {
+                push @bad, $attr;
+            }
+        }
+        else {
             push @bad, $attr;
         }
     }
-    _updateTags($code,@good) unless @bad;
+    unless(@bad){
+        _updateTags($code, \%extra);
+    }
     return @bad;
 }
 
+sub restPath {
+    my ($class, $path) = @_;
+    return undef unless exists $REST_PATHS{$path};
+    return $REST_PATHS{$path};
+}
+
+sub _updateRestPath {
+    my ($code, $rest_path) = @_;
+    $REST_PATHS{$rest_path} = $code;
+    Scalar::Util::weaken($REST_PATHS{$rest_path});
+}
+
 sub _updateTags {
-    my ($code, @attrs) = @_;
-    my %attrs;
+    my ($code, $attrs) = @_;
     my $ref_add = Scalar::Util::refaddr($code);
-    @attrs{@attrs} = ();
-    $attrs{code} = $code;
-    Scalar::Util::weaken($attrs{code});
-    $TAGS{$ref_add} = \%attrs;
+    $attrs->{code} = $code;
+    Scalar::Util::weaken($attrs->{code});
+    if (exists $attrs->{RestPath}) {
+       _updateRestPath($code, $attrs->{RestPath});
+    }
+    $TAGS{$ref_add} = $attrs;
+}
+
+sub updateAllowedAsActions {
+    for my $info (values %TAGS) {
+        if (exists $info->{AllowedAsAction}) {
+            $ALLOWED_ACTIONS{Sub::Util::subname($info->{code})} = $info->{AllowedAsAction};
+        }
+    }
 }
 
 sub isPublic {
@@ -53,7 +95,7 @@ sub isPublic {
 }
 
 sub _hasTag {
-    my ($class,$method, $tag) = @_;
+    my ($class, $method, $tag) = @_;
     my $code = $class->can($method);
     return unless $code;
     my $ref_addr = Scalar::Util::refaddr($code);
@@ -70,9 +112,10 @@ sub CLONE {
     # fix-up all object ids in the new thread
     my @tags = grep {defined} values %TAGS;
     %TAGS = ();
+    %REST_PATHS = ();
     foreach my $tag_data (@tags) {
         my $code = delete $tag_data->{code};
-        _updateTags($code, keys %$tag_data);
+        _updateTags($code, $tag_data);
     }
     return;
 }
@@ -83,7 +126,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
