@@ -1,4 +1,5 @@
 package pf::api::can_fork;
+
 =head1 NAME
 
 pf::api::can_fork local client for pf::api
@@ -10,14 +11,13 @@ pf::api::can_fork local client for pf::api
 pf::api::can_fork
 
 can_fork client for pf::api which calls the api directly and fork on notify for api calls that are marked for forking
+To avoid circular dependencies pf::api needs to be included before consuming this module
 
 =cut
 
 use strict;
 use warnings;
 use pf::log;
-use pf::api;
-use pf::db;
 use pf::util::webapi;
 use POSIX;
 use Moo;
@@ -46,7 +46,6 @@ sub notify {
     my ($self, $method, @args) = @_;
     my $pid;
     if (pf::api->shouldFork($method)) {
-        pf::db::db_disconnect();
         $pid = fork;
         unless (defined $pid) {
             $logger->error("Error fork $!");
@@ -61,7 +60,7 @@ sub notify {
     pf::util::webapi::add_mac_to_log_context(\@args);
     eval {pf::api->$method(@args);};
     if ($@) {
-        $logger->error($@);
+        $logger->error("Error handling $method : $@");
     }
     if (defined $pid && $pid == 0 ) {
         POSIX::_exit(0);
@@ -75,7 +74,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
