@@ -22,7 +22,7 @@ pf::api::msgpackclient
 use strict;
 use warnings;
 
-use pf::config;
+use pf::config qw(%Config);
 use pf::log;
 use WWW::Curl::Easy;
 use Data::MessagePack;
@@ -233,7 +233,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
