@@ -1,4 +1,5 @@
 package pf::cmd::pf;
+
 =head1 NAME
 
 pf::cmd::pf
@@ -15,13 +16,15 @@ pfcmd <command> [options]
   cache                       | manage the cache subsystem
   checkup                     | perform a sanity checkup and report any problems
   class                       | view violation classes
-  configfiles                 | push or pull configfiles into/from database
   configreload                | reload the configution
+  connectionprofileconfig     | query/modify connection profile configuration parameters
+  fingerbank                  | Fingerbank related commands
+  fixpermissions              | fix permissions on pf tree
   floatingnetworkdeviceconfig | query/modify floating network devices configuration parameters
+  generatedomainconfig        | generate the domain configuration
+  generatemariadbconfig       | generate the MariaDB configuration
+  generatesyslogconfig        | generate the syslog configuration
   help                        | show help for pfcmd commands
-  ifoctetshistorymac          | accounting history
-  ifoctetshistoryswitch       | accounting history
-  ifoctetshistoryuser         | accounting history
   import                      | bulk import of information into the database
   ipmachistory                | IP/MAC history
   locationhistorymac          | Switch/Port history
@@ -29,12 +32,13 @@ pfcmd <command> [options]
   networkconfig               | query/modify network configuration parameters
   node                        | manipulate node entries
   pfconfig                    | interact with pfconfig
-  portalprofileconfig         | query/modify portal profile configuration parameters
+  pfqueue                     | query/modify pfqueue tasks and counters
   reload                      | rebuild fingerprint or violations tables without restart
   service                     | start/stop/restart and get PF daemon status
   schedule                    | Nessus scan scheduling
   switchconfig                | query/modify switches.conf configuration parameters
   version                     | output version information
+  violation                   | manipulate violations
   violationconfig             | query/modify violations.conf configuration parameters
 
 Please view "pfcmd help <command>" for details on each option
@@ -61,7 +65,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
