@@ -6,16 +6,25 @@ pf::cmd::pf::cache add documentation
 =head1 SYNOPSIS
 
  pfcmd cache <namespace> <options>
+ pfcmd cache all clear
 
 Namespaces:
 
-  configfilesdata
+  accounting
+  clustering
   configfiles
+  configfilesdata
+  fingerbank
+  firewall_sso
   httpd.admin
   httpd.portal
+  ldap_auth
+  person_lookup
   pfdns
-  switch.overlay
+  provisioning
+  route_int
   switch
+  switch.overlay
 
 Options:
 
@@ -42,7 +51,7 @@ use List::MoreUtils qw(any);
 
 =head2 parseArgs
 
-parsing the arguements for the cache command
+parsing the arguments for the cache command
 
 =cut
 
@@ -50,23 +59,32 @@ sub parseArgs {
     my ($self) = @_;
     my @args = $self->args;
     if (@args <= 1 || @args > 3 ) {
-        print STDERR  "invalid arguements\n";
+        print STDERR  "invalid arguments\n";
         return 0;
     }
+
     my $namespace = shift @args;
-    unless ( any { $namespace eq $_ } @pf::CHI::CACHE_NAMESPACES ) {
+    my $action = shift @args;
+    if ( ($namespace eq 'all' && $action ne 'clear') && !any { $namespace eq $_ } @pf::CHI::CACHE_NAMESPACES ) {
         print STDERR "the namespace '$namespace' does not exist\n";
         return 0;
     }
+
     $namespace =~ /^(.*)$/;
     $namespace = $1;
-    my $action = shift @args;
+
     my $action_method = "action_$action";
     unless ($self->can($action_method)) {
         print STDERR "invalid option '$action'\n";
         return 0;
     }
-    $self->{cache} = pf::CHI->new( namespace => $namespace);
+
+    if ($action eq 'clear') {
+        $self->{caches} = [ map { pf::CHI->new( namespace => $_) } ( $namespace eq 'all'   ? @pf::CHI::CACHE_NAMESPACES  : ($namespace))];
+    } else {
+        $self->{cache} = pf::CHI->new( namespace => $namespace);
+    }
+
     $self->{action_method} = $action_method;
     $self->{key} = shift @args if $action eq 'remove' || $action eq 'dump' ;
     return 1;
@@ -93,8 +111,12 @@ Handles the clear action
 
 sub action_clear {
     my ($self) = @_;
-    my $cache = $self->{cache};
-    $cache->remove($_) for map { /^(.*)$/;$1  } $cache->get_keys;
+    for my $cache (@{$self->{caches}}) {
+        print "clearing " . $cache->namespace . "\n";
+        for my $key (map { /^(.*)$/;$1  } $cache->get_keys) {
+            $cache->remove($key);
+        }
+    }
 }
 
 =head2 action_expire
@@ -158,7 +180,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
