@@ -5,50 +5,51 @@ pf::cmd::pf::service add documentation
 
 =head1 SYNOPSIS
 
-pfcmd service <service> [start|stop|restart|status|watch] [--ignore-checkup]
+pfcmd service <service> [start|stop|restart|status|generateconfig|updatesystemd] [--ignore-checkup]
 
   stop/stop/restart specified service
-  status returns PID of specified PF daemon or 0 if not running
-  watch acts as a service watcher which can send email/restart the services
+  status returns PID of specified PF daemon or 0 if not running.
 
   --ignore-checkup will start the requested services even if the checkup fails
 
 Services managed by PacketFence:
 
-  carbon-cache     | carbon-cache daemon
-  carbon-relay     | carbon-relay daemon
-  collectd         | collectd daemon
-  dhcpd            | dhcpd daemon
-  haproxy          | haproxy daemon
-  httpd.aaa        | Apache AAA webservice
-  httpd.admin      | Apache Web admin
-  httpd.portal     | Apache Captive Portal
-  httpd.proxy      | Apache Proxy Interception
-  httpd.webservices| Apache Webservices
-  iptables         | PacketFence firewall rules
-  keepalived       | Virtual IP management
-  pf               | all services that should be running based on your config
-  pfbandwidthd     | A pf service to monitor bandwidth usages
-  pfdetect         | PF snort alert parser
-  pfdhcplistener   | PF DHCP monitoring daemon
-  pfdns            | DNS daemon
-  pfmon            | PF ARP monitoring daemon
-  pfsetvlan        | PF VLAN isolation daemon
-  radiusd          | FreeRADIUS daemon
-  radsniff3        | radsniff3 daemo
-  redis_queue      | Redis for pfqueue
-  snmptrapd        | SNMP trap receiver daemon
-  snort            | Sourcefire Snort IDS
-  statsd           | statsd service
-  suricata         | Suricata IDS
-  winbindd         | Winbind daemon
-
-watch
-
- Watch performs services checks to make sure that everything is fine. It's
- behavior is controlled by servicewatch configuration parameters. watch is
- typically best called from cron with something like:
- */5 * * * * /usr/local/pf/bin/pfcmd service pf watch
+  api-frontend         | Golang daemon providing API
+  fingerbank-collector | Fingerprinting data collection daemon
+  haproxy-portal       | haproxy portal daemon
+  haproxy-db           | haproxy database daemon
+  httpd.aaa            | Apache AAA webservice
+  httpd.admin          | Apache Web admin
+  httpd.collector      | Apache Collector daemon
+  httpd.dispatcher     | Captive portal dispatcher
+  httpd.parking        | Apache Parking Portal
+  httpd.portal         | Apache Captive Portal
+  httpd.proxy          | Apache Proxy Interception
+  httpd.webservices    | Apache Webservices
+  iptables             | PacketFence firewall rules
+  keepalived           | Virtual IP management
+  netdata              | Monitoring service
+  pf                   | all services that should be running based on your config
+  pfbandwidthd         | A pf service to monitor bandwidth usages
+  pfdetect             | PF snort alert parser
+  pfdhcp               | dhcpd daemon
+  pfdhcplistener       | PF DHCP monitoring daemon
+  pfdns                | DNS daemon
+  pfipset              | IPSET daemon
+  pffilter             | PF conditions filtering daemon
+  pfmon                | PF monitoring daemon
+  pfperl-api           | Perl daemon providing API
+  pfqueue              | PF queueing service
+  pfsso                | Firewall SSO daemon
+  pfstats              | PF statistics daemon
+  radiusd              | FreeRADIUS daemon
+  radsniff             | radsniff daemon
+  redis_ntlm_cache     | Redis for the NTLM cache
+  redis_queue          | Redis for pfqueue
+  routes               | manage static routes
+  snmptrapd            | SNMP trap receiver daemon
+  tc                   | Traffic shaping service
+  winbindd             | Winbind daemon
 
 =head1 DESCRIPTION
 
@@ -61,37 +62,34 @@ use warnings;
 use base qw(pf::cmd);
 use IO::Interactive qw(is_interactive);
 use Term::ANSIColor;
-our ($SERVICE_HEADER, $IS_INTERACTIVE);
-our ($RESET_COLOR, $WARNING_COLOR, $ERROR_COLOR, $SUCCESS_COLOR);
+our ($SERVICE_HEADER);
+our $COLORS;
 use pf::log;
-use pf::file_paths;
-use pf::config;
+use pf::file_paths qw($install_dir);
+use pf::config qw(%Config);
 use pf::config::util;
 use pf::util;
+use pf::util::console;
 use pf::constants;
 use pf::constants::exit_code qw($EXIT_SUCCESS $EXIT_FAILURE $EXIT_SERVICES_NOT_STARTED $EXIT_FATAL);
 use pf::services;
 use List::MoreUtils qw(part any true all);
-use constant {
-    JUST_MANAGED       => 1,
-    INCLUDE_DEPENDS_ON => 2,
-};
+use pf::constants::services qw(JUST_MANAGED);
+use pf::cluster;
+
 my $logger = get_logger();
 
 our %ACTION_MAP = (
     status  => \&statusOfService,
     start   => \&startService,
     stop    => \&stopService,
-    watch   => \&watchService,
     restart => \&restartService,
+    generateconfig => \&generateConfig,
+    updatesystemd    => \&updateSystemd,
 );
 
 our $ignore_checkup = $FALSE;
 
-sub _byIndexOrder {
-    $a->orderIndex <=> $b->orderIndex;
-}
-
 sub parseArgs {
     my ($self) = @_;
     my ($service, $action, $option) = $self->args;
@@ -99,11 +97,19 @@ sub parseArgs {
     return 0 unless $service eq 'pf' || any { $_ eq $service} @pf::services::ALL_SERVICES;
 
     my ( @services, @managers );
-    if ($service eq 'pf' ) {
-        @services = @pf::services::ALL_SERVICES;
-    }
-    else {
-        @services = ($service);
+    if (($action eq 'updatesystemd' || $action eq 'generateconfig') && $service eq 'pf') {
+        @services = grep {$_ ne 'pf'} @pf::services::ALL_SERVICES;
+    } else {
+        if($cluster_enabled && $service eq 'pf') {
+            if ($action eq 'status') {
+                @services = ($service);
+            } else {
+                @services = ('haproxy-db','pf');
+            }
+        }
+        else {
+            @services = ($service);
+        }
     }
     $self->{service}  = $service;
     $self->{services} = \@services;
@@ -118,17 +124,21 @@ sub _run {
     my $services = $self->{services};
     my $action = $self->{action};
     $SERVICE_HEADER ="service|command\n";
-    $IS_INTERACTIVE = is_interactive();
-    $RESET_COLOR =  $IS_INTERACTIVE ? color 'reset' : '';
-    $WARNING_COLOR =  $IS_INTERACTIVE ? color $Config{advanced}{pfcmd_warning_color} : '';
-    $ERROR_COLOR =  $IS_INTERACTIVE ? color $Config{advanced}{pfcmd_error_color} : '';
-    $SUCCESS_COLOR =  $IS_INTERACTIVE ? color $Config{advanced}{pfcmd_success_color} : '';
+    $COLORS = pf::util::console::colors();
     my $actionHandler;
     $action =~ /^(.*)$/;
     $action = $1;
     $actionHandler = $ACTION_MAP{$action};
     $service =~ /^(.*)$/;
     $service = $1;
+    # On pfcmd pf status we don't want to run updatesystemd
+    # On pfcmd pf updatesystemd we don't want to run it twice
+    if ($service eq 'pf' && ($action ne 'status' && $action ne 'updatesystemd')) {
+        updateSystemd->($service, grep {$_ ne 'pf'} @pf::services::ALL_SERVICES);
+    }
+    my $output = "Service";
+    $output .= (" " x 49);
+    print "$COLORS->{status}${output}Status    PID$COLORS->{reset}\n" if  ($action ne 'updatesystemd' && $action ne 'generateconfig');
     return $actionHandler->($service,@$services);
 }
 
@@ -142,8 +152,13 @@ sub postPfStartService {
 sub startService {
     my ($service,@services) = @_;
     use sort qw(stable);
-    my @managers = sort _byIndexOrder getManagers(\@services,INCLUDE_DEPENDS_ON | JUST_MANAGED);
-    print $SERVICE_HEADER;
+    my @managers = pf::services::getManagers(\@services,JUST_MANAGED);
+
+    if ( !@managers ) {
+        print "Service '$service' is not managed by PacketFence. Therefore, no action will be performed\n";
+        return $EXIT_SUCCESS;
+    }
+
     my $count = 0;
     postPfStartService(\@managers) if $service eq 'pf';
 
@@ -154,6 +169,12 @@ sub startService {
             _doStart($manager);
         }
     }
+    # Just before the checkup we make sure that the configuration is correct in the cluster if applicable
+    
+    if($cluster_enabled && $service eq 'pf') {
+        pf::cluster::handle_config_conflict();
+    }
+
     if($checkupManagers && @$checkupManagers) {
         checkup( map {$_->name} @$checkupManagers);
         foreach my $manager (@$checkupManagers) {
@@ -163,6 +184,33 @@ sub startService {
     return $EXIT_SUCCESS;
 }
 
+sub generateConfig {
+    my ($service, @services) = @_;
+    use sort qw(stable);
+    my @managers = pf::services::getManagers(\@services);
+    print $SERVICE_HEADER;
+    for my $manager (@managers) {
+        _doGenerateConfig($manager);
+    }
+    return $EXIT_SUCCESS;
+}
+
+sub updateSystemd {
+    my ( $service, @services ) = @_;
+    my @managers = pf::services::getManagers( \@services );
+    my $show = $FALSE;
+    if ($service ne 'pf') {
+        print $SERVICE_HEADER;
+        $show = $TRUE;
+    }
+    for my $manager (@managers) {
+        _doUpdateSystemd($manager, $show);
+    }
+    system("sudo systemctl daemon-reload");
+    return $EXIT_SUCCESS;
+}
+
+
 sub checkup {
     require pf::services;
     require pf::pfcmd::checkup;
@@ -196,49 +244,54 @@ sub checkup {
 
 sub _doStart {
     my ($manager) = @_;
-    my $command;
-    my $color = '';
-    if($manager->status ne '0') {
-        $color =  $WARNING_COLOR;
-        $command = 'already started';
+    if($manager->status ne '0' && $manager->name ne 'pf') {
+        $manager->print_status;
     } else {
-        if($manager->start) {
-            $command = 'start';
-            $color =  $SUCCESS_COLOR;
-        } else {
-            $command = 'not started';
-            $color =  $ERROR_COLOR;
-        }
+        $manager->start;
+        $manager->print_status;
     }
-    print $manager->name,"|${color}${command}${RESET_COLOR}\n";
 }
 
-sub getManagers {
-    my ($services,$flags) = @_;
-    $flags = 0 unless defined $flags;
-    my %seen;
-    my $includeDependsOn = $flags & INCLUDE_DEPENDS_ON;
-    my $justManaged      = $flags & JUST_MANAGED;
-    my @temp = grep { defined $_ } map { pf::services::get_service_manager($_) } @$services;
-    my @serviceManagers;
-    foreach my $m (@temp) {
-        next if $seen{$m->name} || ( $justManaged && !$m->isManaged );
-        my @managers;
-        #Get dependencies
-        if ($includeDependsOn) {
-            @managers = grep { defined $_ } map { pf::services::get_service_manager($_) } @{$m->dependsOnServices}
-        }
-        if($m->isa("pf::services::manager::submanager")) {
-            push @managers,$m->managers;
-        } else {
-            push @managers,$m;
-        }
-        #filter out managers already seen
-        @managers = grep { !$seen{$_->name}++ } @managers;
-        $seen{$m->name}++;
-        push @serviceManagers,@managers;
+sub _doGenerateConfig {
+    my ($manager) = @_;
+    my $command;
+    my $color = '';
+    if($manager->generateConfig()) {
+        $command = 'config generated';
+        $color =  $COLORS->{success};
+    } else {
+        $command = 'config not generated';
+        $color =  $COLORS->{error};
     }
-    return @serviceManagers;
+    print $manager->name,"|${color}${command}$COLORS->{reset}\n";
+}
+
+sub _doUpdateSystemd {
+    my ($manager, $show) = @_;
+    my $command;
+    my $color = '';
+    if ( $manager->isManaged ) {
+        if ( $manager->sysdEnable() ) {
+            $command = 'Service enabled';
+            $color =  $COLORS->{success};
+        }
+        else {
+            $command = 'Service not enabled';
+            $color =  $COLORS->{error};
+        }
+    }
+    else {
+        if ( $manager->sysdDisable() ) {
+            $command = 'Service disabled';
+            $color =  $COLORS->{success};
+        }
+        else {
+            $command = 'Service not disabled';
+            $color =  $COLORS->{error};
+        }
+    }
+
+    print $manager->name, "|${color}${command}$COLORS->{reset}\n" if $show;
 }
 
 sub getIptablesTechnique {
@@ -249,25 +302,15 @@ sub getIptablesTechnique {
 
 sub stopService {
     my ($service,@services) = @_;
-    my @managers = reverse sort _byIndexOrder getManagers(\@services);
+    my @managers = pf::services::getManagers(\@services);
 
-    print $SERVICE_HEADER;
     foreach my $manager (@managers) {
-        my $command;
-        my $color = '';
         if($manager->status eq '0') {
-            $command = 'already stopped';
-            $color =  $WARNING_COLOR;
+            $manager->print_status;
         } else {
-            if($manager->stop) {
-                $color =  $SUCCESS_COLOR;
-                $command = 'stop';
-            } else {
-                $color =  $ERROR_COLOR;
-                $command = 'not stopped';
-            }
+            $manager->stop;
+            $manager->print_status;
         }
-        print $manager->name,"|${color}${command}${RESET_COLOR}\n";
     }
     if(isIptablesManaged($service)) {
         my $count = true { $_->status eq '0'  } @managers;
@@ -293,57 +336,12 @@ sub restartService {
     return startService(@_);
 }
 
-sub watchService {
-    my ($service,@services) = @_;
-    my @stoppedServiceManagers =
-        grep { $_->status eq '0'  }
-        getManagers(\@services, JUST_MANAGED | INCLUDE_DEPENDS_ON);
-    if(@stoppedServiceManagers) {
-        my @stoppedServices = map { $_->name } @stoppedServiceManagers;
-        $logger->info("watch found incorrectly stopped services: " . join(", ", @stoppedServices));
-        print "The following processes are not running:\n" . " - "
-            . join( "\n - ", @stoppedServices ) . "\n";
-        if ( isenabled( $Config{'servicewatch'}{'email'} ) ) {
-            my %message;
-            $message{'subject'} = "PF WATCHER ALERT";
-            $message{'message'}
-                = "The following processes are not running:\n" . " - "
-                . join( "\n - ", @stoppedServices ) . "\n";
-            pfmailer(%message);
-        }
-        if ( isenabled( $Config{'servicewatch'}{'restart'} ) ) {
-            print $SERVICE_HEADER;
-            foreach my $manager (@stoppedServiceManagers) {
-                $manager->watch;
-                print join('|',$manager->name,"watch"),"\n";
-            }
-        }
-    }
-    return $EXIT_SUCCESS;
-}
-
 sub statusOfService {
     my ($service,@services) = @_;
-    my @managers = getManagers(\@services);
-    print "service|shouldBeStarted|pid\n";
-    my $notStarted = 0;
+    my @managers = pf::services::getManagers(\@services);
     foreach my $manager (@managers) {
-        my $color = '';
-        my $isManaged = $manager->isManaged;
-        my $status = $manager->status;
-        if($status eq '0' ) {
-            if ($isManaged && !$manager->optional) {
-                $color =  $ERROR_COLOR;
-                $notStarted++;
-            } else {
-                $color =  $WARNING_COLOR;
-            }
-        } else {
-            $color =  $SUCCESS_COLOR;
-        }
-        print $manager->name,"|${color}$isManaged|$status${RESET_COLOR}\n";
+        $manager->print_status;
     }
-    return ( $notStarted ? $EXIT_SERVICES_NOT_STARTED : $EXIT_SUCCESS)
 }
 
 =head1 AUTHOR
@@ -354,7 +352,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
