@@ -14,12 +14,16 @@ Parses the following BNF
 
 EXPR = OR || OR
 EXPR = OR
-OR   = FACT && FACT
-OR   = FACT
+OR   = CMP && CMP
+OR   = CMP
+CMP  = ID OP ID
+CMP  = ID OP STRING
+CMP  = FACT
+OP   = '==' | '!=' | '=~' | '!~'
 FACT = ! FACT
 FACT = '(' EXPR ')'
 FACT = ID
-ID   = /a-zA-Z0-9_/+
+ID   = /a-zA-Z0-9_\./+
 
 =cut
 
@@ -37,7 +41,7 @@ BEGIN {
 
 Parses a string to a structure for building filters and conditions
 
-    my ($array,$msg) = parse_condition_string('(a || b) && (c || d)');
+    my ($array, $msg) = parse_condition_string('(a || b) && (c || d)');
 
 On success
 
@@ -115,12 +119,12 @@ Handle an 'or' expression
 =cut
 
 sub _parse_or {
-    # OR   = FACT && FACT
-    # OR   = FACT
+    # OR   = CMP && CMP
+    # OR   = CMP
     my @expr;
-    push @expr, _parse_fact();
+    push @expr, _parse_cmp();
     while (/\G\s*\&{1,2}/gc) {
-        push @expr, _parse_fact();
+        push @expr, _parse_cmp();
     }
 
     #collapse into a single element if there is only one
@@ -128,6 +132,36 @@ sub _parse_or {
     return ['AND', @expr];
 }
 
+=head2 _parse_cmp
+
+=cut
+
+sub _parse_cmp {
+    # CMP  = ID OP ID
+    # CMP  = ID OP STRING
+    # CMP  = FACT
+    my $old_pos = pos();
+    if (/\G\s*([a-zA-Z0-9_\.]+)/gc) {
+        my $a = $1;
+        if (/\G\s*(==|!=|=~|!~)/gc) {
+            my $op = $1;
+            my $b;
+            if (/\G\s*([a-zA-Z0-9_\.]+)/gc) {
+                $b = $1;
+            } elsif (/\G\s*"((?:[^"\\]|\\"|\\\\)*?)"/gc) {
+                $b = $1;
+                $b =~ s/\\"/"/g;
+                $b =~ s/\\\\/\\/g;
+            } else {
+                die format_parse_error("Invalid format", $_, pos);
+            }
+            return [$op,$a,$b];
+        }
+    }
+    pos() = $old_pos;
+    return _parse_fact();
+}
+
 =head2 _parse_fact
 
 Handle a 'fact' expression
@@ -157,7 +191,7 @@ sub _parse_fact {
     }
 
     #It is a simple id
-    return $1 if (/\G\s*([a-zA-Z0-9_]+)/gc);
+    return $1 if (/\G\s*([a-zA-Z0-9_\.]+)/gc);
     #Reduce whitespace
     /\G\s*/gc;
     die format_parse_error("Invalid character(s)", $_, pos() );
@@ -191,7 +225,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
