@@ -16,14 +16,21 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(@ADMIN_ACTIONS);
+our @EXPORT_OK = qw(@ADMIN_ACTIONS %ADMIN_NOT_IN_READONLY);
 
 our @ADMIN_ACTIONS = qw(
+    SYSTEM_READ
+    SYSTEM_CREATE
+    SYSTEM_UPDATE
+    SYSTEM_DELETE
+
     ADMIN_ROLES_CREATE
     ADMIN_ROLES_DELETE
     ADMIN_ROLES_READ
     ADMIN_ROLES_UPDATE
 
+    AUDITING_READ
+
     CONFIGURATION_MAIN_READ
     CONFIGURATION_MAIN_UPDATE
 
@@ -32,9 +39,6 @@ our @ADMIN_ACTIONS = qw(
     FINGERBANK_UPDATE
     FINGERBANK_DELETE
 
-    FINGERPRINTS_READ
-    FINGERPRINTS_UPDATE
-
     FIREWALL_SSO_READ
     FIREWALL_SSO_CREATE
     FIREWALL_SSO_UPDATE
@@ -58,10 +62,12 @@ our @ADMIN_ACTIONS = qw(
     NODES_READ
     NODES_UPDATE
 
-    PORTAL_PROFILES_CREATE
-    PORTAL_PROFILES_DELETE
-    PORTAL_PROFILES_READ
-    PORTAL_PROFILES_UPDATE
+    MSE_READ
+
+    CONNECTION_PROFILES_CREATE
+    CONNECTION_PROFILES_DELETE
+    CONNECTION_PROFILES_READ
+    CONNECTION_PROFILES_UPDATE
 
     PROVISIONING_CREATE
     PROVISIONING_DELETE
@@ -71,21 +77,16 @@ our @ADMIN_ACTIONS = qw(
     REPORTS
     SERVICES
 
-    SOH_CREATE
-    SOH_DELETE
-    SOH_READ
-    SOH_UPDATE
-
     SWITCHES_CREATE
     SWITCHES_DELETE
     SWITCHES_READ
     SWITCHES_UPDATE
 
-    USERAGENTS_READ
-
     USERS_READ
+    USERS_READ_SPONSORED
     USERS_CREATE
     USERS_CREATE_MULTIPLE
+    USERS_CREATE_OVERWRITE
     USERS_UPDATE
     USERS_DELETE
 
@@ -93,7 +94,10 @@ our @ADMIN_ACTIONS = qw(
     USERS_SET_ACCESS_DURATION
     USERS_SET_UNREG_DATE
     USERS_SET_ACCESS_LEVEL
+    USERS_SET_TENANT_ID
     USERS_MARK_AS_SPONSOR
+    USERS_SET_TIME_BALANCE
+    USERS_SET_BANDWIDTH_BALANCE
 
     USERS_ROLES_CREATE
     USERS_ROLES_DELETE
@@ -110,24 +114,6 @@ our @ADMIN_ACTIONS = qw(
     VIOLATIONS_READ
     VIOLATIONS_UPDATE
 
-    SOH_READ
-    SOH_CREATE
-    SOH_UPDATE
-    SOH_DELETE
-
-    FINGERPRINTS_READ
-    FINGERPRINTS_UPDATE
-
-    USERAGENTS_READ
-
-    MAC_READ
-    MAC_UPDATE
-
-    FIREWALL_SSO_READ
-    FIREWALL_SSO_CREATE
-    FIREWALL_SSO_UPDATE
-    FIREWALL_SSO_DELETE
-
     RADIUS_LOG_READ
 
     REALM_READ
@@ -175,15 +161,43 @@ our @ADMIN_ACTIONS = qw(
 
     FILTERS_READ
     FILTERS_UPDATE
+
+    PORTAL_MODULE_CREATE
+    PORTAL_MODULE_DELETE
+    PORTAL_MODULE_READ
+    PORTAL_MODULE_UPDATE
+
+    PFMON_READ
+    PFMON_UPDATE
+
+    DEVICE_REGISTRATION_CREATE
+    DEVICE_REGISTRATION_DELETE
+    DEVICE_REGISTRATION_READ
+    DEVICE_REGISTRATION_UPDATE
+
+    TRAFFIC_SHAPING_CREATE
+    TRAFFIC_SHAPING_DELETE
+    TRAFFIC_SHAPING_READ
+    TRAFFIC_SHAPING_UPDATE
+
+    SYSLOG_CREATE
+    SYSLOG_DELETE
+    SYSLOG_READ
+    SYSLOG_UPDATE
+
 );
 
+# Actions not allowed in readonly mode
+# Any actions that will update the database is not allowed
+our %ADMIN_NOT_IN_READONLY = map { $_ => 1} grep { !/_READ$/ && /^(NODES_|SWITCHES_|VIOLATIONS_|WRIX_|USERS_|USERS_ROLES_)/ && !/^USERS_SOURCES_/ && $_ ne 'USERS_READ_SPONSORED' } @ADMIN_ACTIONS ;
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
