@@ -19,13 +19,19 @@ use Readonly;
 
 Readonly our $DEFAULT_CLIENT => "pf::api::jsonrpcclient";
 
+our $PFSSO_PORT = 8777;
+our $GO_DHCP_PORT = 22222;
+our $GO_IPSET_PORT = 22223;
+
+our $LOGIN_PATH = "/api/v1/login";
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
