@@ -17,13 +17,15 @@ use warnings;
 use Readonly;
 use base qw(Exporter);
 our @EXPORT = qw(
-  $COMMUNICATION_ERROR_MSG $AUTH_FAIL_MSG $AUTH_SUCCESS_MSG $INVALID_EMAIL_MSG
+  $COMMUNICATION_ERROR_MSG $AUTH_FAIL_MSG $AUTH_SUCCESS_MSG $INVALID_EMAIL_MSG $LOCALDOMAIN_EMAIL_UNAUTHORIZED $EMAIL_UNAUTHORIZED
 );
 
 Readonly our $COMMUNICATION_ERROR_MSG => 'Unable to validate credentials at the moment';
 Readonly our $AUTH_FAIL_MSG => 'Invalid login or password';
 Readonly our $AUTH_SUCCESS_MSG => 'Authentication successful.';
 Readonly our $INVALID_EMAIL_MSG => 'Invalid e-mail address';
+Readonly our $LOCALDOMAIN_EMAIL_UNAUTHORIZED => "You can't register as a guest with this corporate email address. Please register as a regular user using your email address instead.";
+Readonly our $EMAIL_UNAUTHORIZED => "Cannot register with this email address: unallowed domain.";
 
 =head1 AUTHOR
 
@@ -31,7 +33,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
