@@ -21,13 +21,17 @@ our @EXPORT_OK = qw($DEFAULT_LEASE_LENGTH);
 
 Readonly our $DEFAULT_LEASE_LENGTH => 86400;
 
+# The default timeouts for calling the DHCP API
+Readonly our $DHCP_API_DEFAULT_TIMEOUT => 500;
+Readonly our $DHCP_API_DEFAULT_CONNECT_TIMEOUT => 500;
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
