@@ -15,10 +15,18 @@ pf::constants::domain
 use strict;
 use warnings;
 use base qw(Exporter);
+use Readonly;
 
-our @EXPORT_OK = qw($SAMBA_CONF_PATH);
+our @EXPORT_OK = qw(
+    $SAMBA_CONF_PATH 
+    $NTLM_REDIS_CACHE_HOST
+    $NTLM_REDIS_CACHE_PORT
+);
 
-our $SAMBA_CONF_PATH = "/etc/samba/smb.conf";
+Readonly::Scalar our $SAMBA_CONF_PATH => "/etc/samba/smb.conf";
+
+Readonly::Scalar our $NTLM_REDIS_CACHE_HOST => "localhost";
+Readonly::Scalar our $NTLM_REDIS_CACHE_PORT => 6383;
  
 =head1 AUTHOR
 
@@ -26,7 +34,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
