@@ -15,12 +15,16 @@ pf::constants::pfdetect
 use strict;
 use warnings;
 
-use Module::Pluggable search_path => 'pf::detect::parser', sub_name => '_modules' , require => 1;
-
-sub modules {
-  my ($class) = @_;
-  return map { (split('::', $_))[-1] } $class->_modules;
-}
+our @TYPES = qw(
+  dhcp
+  fortianalyser
+  nexpose
+  regex
+  security_onion
+  snort
+  suricata
+  suricata_md5
+);
 
 =head1 AUTHOR
 
@@ -28,7 +32,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
