@@ -15,11 +15,19 @@ use strict;
 use warnings;
 use base qw(Exporter);
 use Readonly;
-use pf::file_paths;
+use pf::file_paths qw(
+    $suricata_categories_file
+    $nexpose_categories_file
+);
 use File::Slurp;
+use pf::SwitchFactory;
+use pf::config qw(
+    %ConfigSwitchesGroup
+    %ConfigSwitchesList
+);
 
 our @EXPORT_OK = qw(
-        $TRIGGER_TYPE_ACCOUNTING $TRIGGER_TYPE_DETECT $TRIGGER_TYPE_INTERNAL $TRIGGER_TYPE_MAC $TRIGGER_TYPE_NESSUS $TRIGGER_TYPE_OPENVAS $TRIGGER_TYPE_OS $TRIGGER_TYPE_SOH $TRIGGER_TYPE_USERAGENT $TRIGGER_TYPE_VENDORMAC $TRIGGER_TYPE_PROVISIONER @VALID_TRIGGER_TYPES
+        $TRIGGER_TYPE_ACCOUNTING $TRIGGER_TYPE_DETECT $TRIGGER_TYPE_INTERNAL $TRIGGER_TYPE_MAC $TRIGGER_TYPE_NESSUS $TRIGGER_TYPE_OPENVAS $TRIGGER_TYPE_OS $TRIGGER_TYPE_USERAGENT $TRIGGER_TYPE_VENDORMAC $TRIGGER_TYPE_PROVISIONER $TRIGGER_TYPE_SWITCH $TRIGGER_TYPE_SWITCH_GROUP @VALID_TRIGGER_TYPES
         $TRIGGER_ID_PROVISIONER
         $TRIGGER_MAP
 );
@@ -32,12 +40,14 @@ Readonly::Scalar our $TRIGGER_TYPE_MAC => 'mac';
 Readonly::Scalar our $TRIGGER_TYPE_NESSUS => 'nessus';
 Readonly::Scalar our $TRIGGER_TYPE_OPENVAS => 'openvas';
 Readonly::Scalar our $TRIGGER_TYPE_OS => 'os';
-Readonly::Scalar our $TRIGGER_TYPE_SOH => 'soh';
-Readonly::Scalar our $TRIGGER_TYPE_SURICATA => 'suricata';
+Readonly::Scalar our $TRIGGER_TYPE_SURICATA_EVENT => 'suricata_event';
+Readonly::Scalar our $TRIGGER_TYPE_NEXPOSE_EVENT_STARTS_WITH => 'nexpose_event_starts_with';
 Readonly::Scalar our $TRIGGER_TYPE_USERAGENT => 'useragent';
 Readonly::Scalar our $TRIGGER_TYPE_VENDORMAC => 'vendormac';
 Readonly::Scalar our $TRIGGER_TYPE_PROVISIONER => 'provisioner';
 Readonly::Scalar our $TRIGGER_ID_PROVISIONER => 'check';
+Readonly::Scalar our $TRIGGER_TYPE_SWITCH => 'switch';
+Readonly::Scalar our $TRIGGER_TYPE_SWITCH_GROUP => 'switch_group';
 
 Readonly::Scalar our $SURICATA_CATEGORIES => sub {
     my %map;
@@ -48,16 +58,31 @@ Readonly::Scalar our $SURICATA_CATEGORIES => sub {
     return \%map;
 }->();
 
+Readonly::Scalar our $NEXPOSE_CATEGORIES => sub {
+    my %map;
+    my @categories = split("\n", read_file($nexpose_categories_file));
+    foreach my $category (@categories){
+        $map{$category} = $category;
+    }
+    return \%map;
+}->();
+
 Readonly::Scalar our $TRIGGER_MAP => {
   $TRIGGER_TYPE_INTERNAL => {
     "1100010" => "Rogue DHCP detection",
     "new_dhcp_info" => "DHCP packet received",
     "hostname_change" => "Hostname changed",
+    "connection_type_change" => "Connection transport changed",
+    "parking_detected" => "Parking detected",
+    "node_discovered" => "Node discovered",
   },
   $TRIGGER_TYPE_PROVISIONER => {
     $TRIGGER_ID_PROVISIONER => "Check status",
   },
-  $TRIGGER_TYPE_SURICATA => $SURICATA_CATEGORIES,
+  $TRIGGER_TYPE_SURICATA_EVENT => $SURICATA_CATEGORIES,
+  $TRIGGER_TYPE_NEXPOSE_EVENT_STARTS_WITH => $NEXPOSE_CATEGORIES,
+  $TRIGGER_TYPE_SWITCH => \%ConfigSwitchesList,
+  $TRIGGER_TYPE_SWITCH_GROUP => \%ConfigSwitchesGroup,
 };
 
 =head1 AUTHOR
@@ -66,7 +91,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
