@@ -29,14 +29,22 @@ use pf::log;
 
 BEGIN {
     use Exporter ();
-    our ( @ISA, @EXPORT, @EXPORT_OK );
+    our ( @ISA, @EXPORT_OK );
     @ISA       = qw(Exporter);
-    @EXPORT    = qw();
     @EXPORT_OK = qw(reevaluate_access);
 }
 
 use pf::constants;
-use pf::config;
+use pf::config qw(
+    $INLINE_API_LEVEL
+    $ROLE_API_LEVEL
+    %Config
+    $INLINE
+    %connection_type_explained
+    $WIRED
+    $WIRELESS
+    $WEBAUTH
+);
 use pf::inline::custom $INLINE_API_LEVEL;
 use pf::iptables;
 use pf::locationlog;
@@ -47,6 +55,9 @@ use pf::config::util;
 use pf::role::custom $ROLE_API_LEVEL;
 use pf::client;
 use pf::cluster;
+use pf::constants::dhcp qw($DEFAULT_LEASE_LENGTH);
+use pf::ip4log;
+use pf::Connection::ProfileFactory;
 
 use Readonly;
 
@@ -69,48 +80,52 @@ sub reevaluate_access {
     # Untaint MAC
     $mac = clean_mac($mac);
 
-    # function must be in advanced.reevaluate_access_reasons list otherwise bail out
-    if ( none { $_ eq $function } split( /\s*,\s*/, $Config{'advanced'}{'reevaluate_access_reasons'} ) ) {
-        $logger->info("access re-evaluation requested but denied by configuration");
-        return $FALSE;
-    }
-
     $logger->info("re-evaluating access ($function called)");
     $opts{'force'} = '1' if ($function eq 'admin_modify');
+
+    if(isenabled($Config{advanced}{sso_on_access_reevaluation})){
+        my $node = node_attributes($mac);
+        my $ip = pf::ip4log::mac2ip($mac);
+        if($ip){
+            my $firewallsso_method = ( $node->{status} eq $STATUS_REGISTERED ) ? "Update" : "Stop";
+            my $client = pf::client::getClient();
+            $client->notify( 'firewallsso', (method => $firewallsso_method, mac => $mac, ip => $ip, timeout => $DEFAULT_LEASE_LENGTH) );
+        }
+        else {
+            $logger->error("Can't do SSO for $mac because can't find its IP address");
+        }
+    }
+
     my $locationlog_entry = locationlog_view_open_mac($mac);
     if ( !$locationlog_entry ) {
         $logger->warn("Can't re-evaluate access because no open locationlog entry was found");
         return;
 
     }
-    else {
 
-        my $conn_type = str_to_connection_type( $locationlog_entry->{'connection_type'} );
-        if ( $conn_type == $INLINE ) {
-
-            my $client = pf::client::getClient();
-            my $inline = new pf::inline::custom();
-            my %data = (
-                'switch'           => '127.0.0.1',
-                'mac'              => $mac,
-            );
-            if ( $inline->isInlineEnforcementRequired($mac) ) {
-                $client->notify( 'firewall', %data );
-            }
-            else {
-                $logger->debug("is already properly enforced in firewall, no change required");
-            }
+    my $conn_type = str_to_connection_type( $locationlog_entry->{'connection_type'} );
+    if ( $conn_type == $INLINE ) {
+        my $client = pf::client::getClient();
+        my $inline = new pf::inline::custom();
+        my %data = (
+            'switch' => '127.0.0.1',
+            'mac'    => $mac,
+        );
+        if ( $inline->isInlineEnforcementRequired($mac) ) {
+            $client->notify( 'firewall', %data );
         }
         else {
-            return _vlan_reevaluation( $mac, $locationlog_entry, %opts );
+            $logger->debug("is already properly enforced in firewall, no change required");
         }
-
+        return 1;
     }
+
+    return _vlan_reevaluation( $mac, $locationlog_entry, %opts );
 }
 
 =item _vlan_reevaluation
 
-Sends local SNMP traps to pfsetvlan if we should reevaluate the VLAN of a node.
+reevaluate the VLAN of a node.
 
 =cut
 
@@ -128,11 +143,14 @@ sub _vlan_reevaluation {
                 . $connection_type_explained{$conn_type} );
 
         my $client;
+        my $cluster_deauth;
         if ($cluster_enabled && isenabled($Config{active_active}{centralized_deauth})){
             $client = pf::client::getManagementClient();
+            $cluster_deauth = 1;
         }
         else {
-            $client = pf::client::getClient();
+            $client = pf::api::queue->new(queue => 'priority');
+            $cluster_deauth = 0;
         }
         my %data = (
             'switch'           => $switch_id,
@@ -141,14 +159,20 @@ sub _vlan_reevaluation {
             'ifIndex'          => $ifIndex
         );
         if ( ( $conn_type & $WIRED ) == $WIRED ) {
-            $logger->debug("Calling json WebAPI with ReAssign request on switch (".$switch_id.")");
-            $client->notify( 'ReAssignVlan', %data );
-
+            $logger->debug("Calling API with ReAssign request on switch (".$switch_id.")");
+            if ($cluster_deauth) {
+                $client->notify( 'ReAssignVlan_in_queue', %data );
+            } else {
+                $client->notify( 'ReAssignVlan', %data );
+            }
         }
-        elsif ( ( $conn_type & $WIRELESS ) == $WIRELESS ) {
-            $logger->debug("Calling json WebAPI with desAssociate request on switch (".$switch_id.")");
-            $client->notify( 'desAssociate', %data );
-
+        elsif ( ( ( $conn_type & $WIRELESS ) == $WIRELESS ) || ( ( $conn_type & $WEBAUTH ) == $WEBAUTH ) ) {
+            $logger->debug("Calling API with desAssociate request on switch (".$switch_id.")");
+            if ($cluster_deauth) {
+                $client->notify( 'desAssociate_in_queue', %data );
+            } else {
+                $client->notify( 'desAssociate', %data );
+            }
         }
         else {
             $logger->error("Connection type is neither wired nor wireless. Cannot reevaluate VLAN");
@@ -204,6 +228,7 @@ sub _should_we_reassign_vlan {
         user_name => $user_name,
         ssid => $ssid,
         node_info => pf::node::node_attributes($mac),
+        profile => pf::Connection::ProfileFactory->instantiate($mac),
     };
 
     my $newRole = $role_obj->fetchRoleForNode( $args );
@@ -221,18 +246,24 @@ sub _should_we_reassign_vlan {
                     "VLAN reassignment required (current VLAN = $currentVlan but should be in VLAN $newCorrectVlan)"
                 );
                 return $TRUE;
-            } else {
-                return $FALSE;
             }
         }
-    } elsif (defined($role)) {
-        if ($role ne $newRole->{role}) {
-            $logger->info(
-                "Reassignment required (current Role = $role but should be in Role $newRole->{role})"
-            );
-            return $TRUE;
-        }
     }
+
+    # If the role in the locationlog is not defined and the new one is, then we reevaluate access
+    if (!defined($role) && defined($newRole->{role})) {
+        $logger->info(
+            "Reassignment required (current Role is undefined and should be in Role $newRole->{role})"
+        );
+        return $TRUE;
+    }
+    elsif ($role ne $newRole->{role}) {
+        $logger->info(
+            "Reassignment required (current Role = $role but should be in Role $newRole->{role})"
+        );
+        return $TRUE;
+    }
+
     $logger->debug("No reassignment required.");
     return $FALSE;
 }
@@ -245,7 +276,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
