@@ -111,8 +111,8 @@ Readonly::Scalar our $NOT_FOUND                         => 404;
 #Readonly::Scalar our $METHOD_NOT_ALLOWED               => 405;
 #Readonly::Scalar our $NOT_ACCEPTABLE                   => 406;
 #Readonly::Scalar our $PROXY_AUTHENTICATION_REQUIRED    => 407;
-#Readonly::Scalar our $REQUEST_TIMEOUT                  => 408;
-#Readonly::Scalar our $CONFLICT                         => 409;
+Readonly::Scalar our $REQUEST_TIMEOUT                  => 408;
+Readonly::Scalar our $CONFLICT                         => 409;
 #Readonly::Scalar our $GONE                             => 410;
 #Readonly::Scalar our $LENGTH_REQUIRED                  => 411;
 Readonly::Scalar our $PRECONDITION_FAILED               => 412;
@@ -122,24 +122,24 @@ Readonly::Scalar our $PRECONDITION_FAILED               => 412;
 #Readonly::Scalar our $REQUEST_RANGE_NOT_SATISFIABLE    => 416;
 #Readonly::Scalar our $EXPECTATION_FAILED               => 417;
 #Readonly::Scalar our $I_AM_A_TEAPOT                    => 418;
-#Readonly::Scalar our $UNPROCESSABLE_ENTITY             => 422;
+Readonly::Scalar our $UNPROCESSABLE_ENTITY             => 422;
 #Readonly::Scalar our $LOCKED                           => 423;
 #Readonly::Scalar our $FAILED_DEPENDENCY                => 424;
 #Readonly::Scalar our $NO_CODE                          => 425;
 #Readonly::Scalar our $UPGRADE_REQUIRED                 => 426;
-#Readonly::Scalar our $PRECONDITION_REQUIRED            => 428;
+Readonly::Scalar our $PRECONDITION_REQUIRED            => 428;
 #Readonly::Scalar our $TOO_MANY_REQUESTS                => 429;
 #Readonly::Scalar our $REQUEST_HEADER_FIELDS_TOO_LARGE  => 431;
 #Readonly::Scalar our $RETRY_WITH                       => 449;
 
 Readonly::Scalar our $INTERNAL_SERVER_ERROR            => 500;
-#Readonly::Scalar our $NOT_IMPLEMENTED                  => 501;
+Readonly::Scalar our $NOT_IMPLEMENTED                  => 501;
 #Readonly::Scalar our $BAD_GATEWAY                      => 502;
 #Readonly::Scalar our $SERVICE_UNAVAILABLE              => 503;
 #Readonly::Scalar our $GATEWAY_TIMEOUT                  => 504;
 #Readonly::Scalar our $HTTP_VERSION_NOT_SUPPORTED       => 505;
 #Readonly::Scalar our $VARIANT_ALSO_NEGOTIATES          => 506;
-#Readonly::Scalar our $INSUFFICIENT_STORAGE             => 507;
+Readonly::Scalar our $INSUFFICIENT_STORAGE             => 507;
 #Readonly::Scalar our $BANDWIDTH_LIMIT_EXCEEDED         => 509;
 #Readonly::Scalar our $NOT_EXTENDED                     => 510;
 #Readonly::Scalar our $NETWORK_AUTHENTICATION_REQUIRED  => 511;
@@ -152,7 +152,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
