@@ -14,23 +14,35 @@ pf::factory::condition::access_filter
 
 use strict;
 use warnings;
-use Module::Pluggable search_path => 'pf::condition', sub_name => '_modules', require => 1;
-use pf::config::util qw(str_to_connection_type);
+use Module::Pluggable
+  search_path => 'pf::condition',
+  sub_name    => '_modules',
+  inner       => 0,
+  require     => 1;
+use pf::util qw(str_to_connection_type);
+use pf::constants::eap_type qw(%RADIUS_EAP_TYPE_2_VALUES %RADIUS_EAP_VALUES_2_TYPE);
 
 our @MODULES;
 
 sub factory_for {'pf::condition'}
 
-our %ACCESS_FILTER_OPERATOR_TO_CONDITION_TYPE = (
-    'is'                => 'pf::condition::equals',
-    'is_not'            => 'pf::condition::not_equals',
-    'match'             => 'pf::condition::matches',
-    'regex'             => 'pf::condition::regex',
-    'match_not'         => 'pf::condition::not_matches',
-    'defined'           => 'pf::condition::is_defined',
-    'not_defined'       => 'pf::condition::not_defined',
-    'date_is_before'    => 'pf::condition::date_before',
-    'date_is_after'     => 'pf::condition::date_after',
+our %FILTER_OP_TO_CONDITION = (
+    'is'                        => 'pf::condition::equals',
+    'is_not'                    => 'pf::condition::not_equals',
+    'includes'                  => 'pf::condition::includes',
+    'match'                     => 'pf::condition::matches',
+    'regex'                     => 'pf::condition::regex',
+    'match_not'                 => 'pf::condition::not_matches',
+    'regex_not'                 => 'pf::condition::regex_not',
+    'defined'                   => 'pf::condition::is_defined',
+    'not_defined'               => 'pf::condition::not_defined',
+    'date_is_before'            => 'pf::condition::date_before',
+    'date_is_after'             => 'pf::condition::date_after',
+    'greater'                   => 'pf::condition::greater',
+    'greater_equals'            => 'pf::condition::greater_equals',
+    'lower'                     => 'pf::condition::lower',
+    'lower_equals'              => 'pf::condition::lower_equals',
+    'fingerbank::device_is_a'   => 'pf::condition::fingerbank::device_is_a',
 );
 
 sub modules {
@@ -47,14 +59,18 @@ sub instantiate {
     my ($class, $data) = @_;
     my $filter = $data->{filter};
     return unless defined $filter;
+
     if ($filter eq 'time') {
         my $c = pf::condition::time_period->new({value => $data->{value}});
         if ($data->{operator} eq 'is_not') {
             return pf::condition::not->new({condition => $c});
         }
+
         return $c;
     }
-    $filter .= "." . $data->{attribute} if defined $data->{attribute} && length $data->{attribute};
+
+    my $attribute = $data->{attribute};
+    $filter .= ".$attribute" if defined $attribute && length $attribute;
     my $sub_condition = _build_sub_condition($data);
     return _build_parent_condition($sub_condition, (split /\./, $filter));
 }
@@ -67,16 +83,50 @@ sub _build_parent_condition {
             condition => $child,
         });
     }
+
     return pf::condition::key->new({
         key       => $key,
         condition => _build_parent_condition($child, @parents),
     });
 }
 
+my %VALUE_FILTERS = (
+    'connection_type'     => \&str_to_connection_type,
+    'connection_sub_type' => \&normalize_connection_sub_type,
+    'EAP-Type'            => \&normalize_eap_type,
+);
+
+sub normalize_connection_sub_type {
+    return $RADIUS_EAP_TYPE_2_VALUES{$_[0]};
+}
+
+sub normalize_eap_type {
+    my $v = $_[0];
+    if (exists $RADIUS_EAP_VALUES_2_TYPE{$v}) {
+        return $v;
+    }
+
+    if (exists $RADIUS_EAP_TYPE_2_VALUES{$v}) {
+        return $RADIUS_EAP_TYPE_2_VALUES{$v};
+    }
+
+    return 0;
+}
+
 sub _build_sub_condition {
     my ($data) = @_;
-    my $condition_class = $ACCESS_FILTER_OPERATOR_TO_CONDITION_TYPE{$data->{operator}};
-    my $value = $data->{filter} eq 'connection_type' ? str_to_connection_type($data->{value}) : $data->{value};
+    my $op = $data->{operator};
+    my $condition_class = $FILTER_OP_TO_CONDITION{$op};
+    unless ($condition_class) {
+        die "Invalid operator : $op\n";
+    }
+
+    my $filter = $data->{filter};
+    my $value = $data->{value};
+    if (exists $VALUE_FILTERS{$filter}) {
+        $value = $VALUE_FILTERS{$filter}->($value);
+    }
+
     return $condition_class ? $condition_class->new({value => $value}) : undef;
 }
 
@@ -86,7 +136,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
