@@ -16,9 +16,13 @@ use strict;
 use warnings;
 
 use List::MoreUtils qw(any);
-use Module::Pluggable search_path => 'pf::pki_provider', sub_name => 'modules' , require => 1;
+use Module::Pluggable
+  search_path => 'pf::pki_provider',
+  sub_name    => 'modules',
+  inner       => 0,
+  require     => 1;
 
-use pf::config;
+use pf::config qw(%ConfigPKI_Provider);
 
 sub factory_for { 'pf::pki_provider' }
 
@@ -76,7 +80,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
