@@ -14,7 +14,11 @@ pf::factory::task
 
 use strict;
 use warnings;
-use Module::Pluggable search_path => 'pf::task', sub_name => 'modules' , require => 1;
+use Module::Pluggable
+  search_path => 'pf::task',
+  sub_name    => 'modules',
+  inner       => 0,
+  require     => 1;
 use List::MoreUtils qw(any);
 
 our @MODULES = __PACKAGE__->modules;
@@ -27,7 +31,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
