@@ -22,14 +22,14 @@ use File::Spec::Functions;
 
 our (
     #Directories
-    $install_dir, $bin_dir, $conf_dir, $lib_dir, $html_dir, $users_cert_dir, $log_dir, $generated_conf_dir, $var_dir,
-    $tt_compile_cache_dir, $pfconfig_cache_dir, $domains_chroot_dir,
+    $install_dir, $bin_dir, $sbin_dir, $conf_dir, $lib_dir, $html_dir, $users_cert_dir, $log_dir, $generated_conf_dir, $var_dir,
+    $tt_compile_cache_dir, $pfconfig_cache_dir, $domains_chroot_dir, $domains_ntlm_cache_users_dir, $systemd_unit_dir, 
 
     #Config files
     #pf.conf.default
-    $default_config_file, $pf_default_file,
+    $pf_default_file,
     #pf.conf
-    $config_file, $pf_config_file,
+    $pf_config_file,
     #network.conf
     $network_config_file,
     #oauth2-ips.conf
@@ -42,91 +42,152 @@ our (
     $dhcp_fingerprints_file, $dhcp_fingerprints_url,
     #oui.txt variables
     $oui_file, $oui_url,
-    #DHCP OMAPI key file
-    $pf_omapi_key_file,
+    # Local secret file for RADIUS
+    $local_secret_file,
+    # Unified API system user password
+    $unified_api_system_pass_file,
     #profiles.conf variables
-    $profiles_config_file, %Profiles_Config,
+    $profiles_config_file, $profiles_default_config_file,
     #Other configuraton files variables
-    $switches_config_file, $violations_config_file, $authentication_config_file,
-    $chi_config_file, $ui_config_file, $floating_devices_file, $log_config_file,
-    $chi_defaults_config_file,
+    $switches_config_file, $switches_default_config_file,
+    $violations_config_file, $violations_default_config_file,
+    $authentication_config_file,
+    $chi_config_file, $chi_defaults_config_file,
+    $ui_config_file, $floating_devices_file, $log_config_file,
     @stored_config_files, @log_files,
     $provisioning_config_file,
+    $device_registration_config_file,
     $admin_roles_config_file,
     $wrix_config_file,
     $firewall_sso_config_file,
     $pfdetect_config_file,
-    $pfqueue_config_file,
+    $pfqueue_config_file, $pfqueue_default_config_file,
     $allowed_device_oui_file, $allowed_device_types_file,
     $apache_filters_config_file,
     $cache_control_file,
+    $config_version_file,
     $log_conf_dir,
-    $vlan_filters_config_file,
+    $vlan_filters_config_file, $vlan_filters_config_default_file,
     $pfcmd_binary,
-    $realm_config_file,
+    $report_config_file, $report_default_config_file,
+    $realm_config_file, $realm_default_config_file,
+    $survey_config_file,
     $cluster_config_file,
     $server_cert, $server_key, $server_pem,
+    $radius_server_key, $radius_server_cert, $radius_ca_cert,
     $ssl_configuration_file,
     $domain_config_file,
     $scan_config_file,
     $wmi_config_file,
     $pki_provider_config_file,
     $suricata_categories_file,
+    $nexpose_categories_file,
     $radius_filters_config_file,
     $billing_tiers_config_file,
     $dhcp_filters_config_file,
+    $roles_config_file,
+    $roles_default_config_file,
+    $dns_filters_config_file, $dns_filters_default_config_file,
+    $admin_audit_log,
+    $violation_log,
+    $portal_modules_config_file, $portal_modules_default_config_file,
+    $captiveportal_templates_path,
+    $captiveportal_profile_templates_path,
+    $captiveportal_default_profile_templates_path,
+    $maintenance_file,
+    $pffilter_socket_path,
+    $control_dir,
+    $switch_control_dir,
+    $pfmon_config_file, $pfmon_default_config_file,
+    $switch_filters_config_file,
+    $stats_config_file,
+    $traffic_shaping_config_file,
+    $pf_admin_i18n_dir,
+    $syslog_config_file,
+    $syslog_default_config_file,
+    $rsyslog_packetfence_config_file,
+    $fingerbank_collector_env_defaults_file,
 );
 
 BEGIN {
 
-    *config_file = \$pf_config_file; # TODO: To be deprecated. See $pf_config_file
-    *default_config_file = \$pf_default_file;  # TODO: To be deprecated. See $pf_default_file
     use Exporter ();
-    our ( @ISA, @EXPORT );
+    our ( @ISA, @EXPORT_OK );
     @ISA = qw(Exporter);
     # Categorized by feature, pay attention when modifying
-    @EXPORT = qw(
-        $install_dir $bin_dir $conf_dir $lib_dir $html_dir $users_cert_dir $log_dir $generated_conf_dir $var_dir
-        $tt_compile_cache_dir $pfconfig_cache_dir $domains_chroot_dir
-        $default_config_file $pf_default_file
-        $config_file $pf_config_file
+    @EXPORT_OK = qw(
+        $install_dir $bin_dir $sbin_dir $conf_dir $lib_dir $html_dir $users_cert_dir $log_dir $generated_conf_dir $var_dir
+        $tt_compile_cache_dir $pfconfig_cache_dir $domains_chroot_dir $domains_ntlm_cache_users_dir $systemd_unit_dir
+        $pf_default_file
+        $pf_config_file
         $network_config_file
         $oauth_ip_file
         $pf_doc_file
         $floating_devices_config_file
         $dhcp_fingerprints_file $dhcp_fingerprints_url
         $oui_file $oui_url
-        $pf_omapi_key_file
-        $profiles_config_file %Profiles_Config
-        $switches_config_file $violations_config_file $authentication_config_file
-        $chi_config_file $ui_config_file $floating_devices_file $log_config_file
-        $chi_defaults_config_file
+        $local_secret_file
+        $unified_api_system_pass_file
+        $profiles_config_file $profiles_default_config_file
+        $switches_config_file $switches_default_config_file
+        $violations_config_file $violations_default_config_file
+        $authentication_config_file
+        $chi_config_file $chi_defaults_config_file
+        $ui_config_file $floating_devices_file $log_config_file
         @stored_config_files @log_files
         $provisioning_config_file
+        $device_registration_config_file
         $admin_roles_config_file
         $wrix_config_file
         @stored_config_files
         $firewall_sso_config_file
         $pfdetect_config_file
-        $pfqueue_config_file
+        $pfqueue_config_file $pfqueue_default_config_file
         $allowed_device_oui_file $allowed_device_types_file
         $apache_filters_config_file
         $cache_control_file
+        $config_version_file
         $log_conf_dir
-        $vlan_filters_config_file
+        $vlan_filters_config_file $vlan_filters_config_default_file
         $pfcmd_binary
-        $realm_config_file
+        $report_config_file $report_default_config_file
+        $realm_config_file $realm_default_config_file
+        $survey_config_file
         $cluster_config_file
         $server_cert $server_key $server_pem
+        $radius_server_cert $radius_server_key $radius_ca_cert
         $ssl_configuration_file
         $domain_config_file
         $scan_config_file
         $wmi_config_file
         $pki_provider_config_file
         $suricata_categories_file
+        $nexpose_categories_file
         $radius_filters_config_file
         $billing_tiers_config_file
         $dhcp_filters_config_file
+        $roles_config_file
+        $roles_default_config_file
+        $dns_filters_config_file $dns_filters_default_config_file
+        $admin_audit_log
+        $violation_log
+        $portal_modules_config_file $portal_modules_default_config_file
+        $captiveportal_templates_path
+        $captiveportal_profile_templates_path
+        $captiveportal_default_profile_templates_path
+        $maintenance_file
+        $pffilter_socket_path
+        $control_dir
+        $switch_control_dir
+        $pfmon_config_file $pfmon_default_config_file
+        $switch_filters_config_file
+        $stats_config_file
+        $traffic_shaping_config_file
+        $pf_admin_i18n_dir
+        $syslog_config_file
+        $syslog_default_config_file
+        $rsyslog_packetfence_config_file
+        $fingerbank_collector_env_defaults_file
     );
 }
 
@@ -134,6 +195,7 @@ $install_dir = '/usr/local/pf';
 
 # TODO bug#920 all application config data should use Readonly to avoid accidental post-startup alterration
 $bin_dir  = catdir( $install_dir,"bin" );
+$sbin_dir = catdir( $install_dir,"sbin" );
 $conf_dir = catdir( $install_dir,"conf" );
 $var_dir  = catdir( $install_dir,"var" );
 $lib_dir  = catdir( $install_dir,"lib" );
@@ -143,14 +205,20 @@ $log_conf_dir  = catdir( $conf_dir,"log.conf.d" );
 
 $generated_conf_dir   = catdir( $var_dir,"conf");
 $tt_compile_cache_dir = catdir( $var_dir,"tt_compile_cache");
+$control_dir  = catdir( $var_dir, "control");
+$switch_control_dir  = catdir( $var_dir, "switch_control");
 $pfconfig_cache_dir = catdir( $var_dir,"cache/pfconfig");
 $domains_chroot_dir = catdir( "/chroots");
+$domains_ntlm_cache_users_dir = catdir( $var_dir, "cache/ntlm_cache_users");
+$systemd_unit_dir   = "/usr/lib/systemd/system"; 
 
-$pfcmd_binary   = catfile($bin_dir, "pfcmd");
+$pfcmd_binary = catfile( $bin_dir, "pfcmd" );
 
 $oui_file           = catfile($conf_dir, "oui.txt");
 $suricata_categories_file = catfile($conf_dir, "suricata_categories.txt");
-$pf_omapi_key_file  = catfile($conf_dir, "pf_omapi_key");
+$nexpose_categories_file = catfile($conf_dir, "nexpose-responses.txt");
+$local_secret_file  = catfile($conf_dir, "local_secret");
+$unified_api_system_pass_file  = catfile($conf_dir, "unified_api_system_pass");
 $pf_doc_file        = catfile($conf_dir, "documentation.conf");
 $oauth_ip_file      = catfile($conf_dir, "oauth2-ips.conf");
 $ui_config_file     = catfile($conf_dir, "ui.conf");
@@ -160,13 +228,22 @@ $chi_config_file    = catfile($conf_dir, "chi.conf");
 $chi_defaults_config_file = catfile($conf_dir, "chi.conf.defaults");
 $log_config_file    = catfile($conf_dir, "log.conf");
 $provisioning_config_file = catfile($conf_dir, 'provisioning.conf');
+$device_registration_config_file = catfile($conf_dir,"device_registration.conf");
 $pki_provider_config_file  = catfile($conf_dir,"pki_provider.conf");
+$traffic_shaping_config_file  = catfile($conf_dir,"traffic_shaping.conf");
+$syslog_config_file  = catfile($conf_dir, "syslog.conf");
+$syslog_default_config_file  = catfile($conf_dir, "syslog.conf.defaults");
+$rsyslog_packetfence_config_file  = "/etc/rsyslog.d/packetfence.conf";
+$fingerbank_collector_env_defaults_file = catfile($conf_dir, "fingerbank-collector.env.defaults");
 
 $network_config_file    = catfile($conf_dir, "networks.conf");
 $switches_config_file   = catfile($conf_dir, "switches.conf");
+$switches_default_config_file   = catfile($conf_dir, "switches.conf.defaults");
 $profiles_config_file   = catfile($conf_dir, "profiles.conf");
+$profiles_default_config_file   = catfile($conf_dir, "profiles.conf.defaults");
 $floating_devices_file  = catfile($conf_dir, "floating_network_device.conf");  # TODO: To be deprecated. See $floating_devices_config_file
 $violations_config_file = catfile($conf_dir, "violations.conf");
+$violations_default_config_file = catfile($conf_dir, "violations.conf.defaults");
 $dhcp_fingerprints_file = catfile($conf_dir, "dhcp_fingerprints.conf");
 $admin_roles_config_file = catfile($conf_dir, "adminroles.conf");
 
@@ -178,14 +255,23 @@ $allowed_device_oui_file   = catfile($conf_dir,"allowed_device_oui.txt");
 $allowed_device_types_file = catfile($conf_dir,"allowed_device_types.txt");
 $apache_filters_config_file = catfile($conf_dir, "apache_filters.conf");
 $vlan_filters_config_file = catfile($conf_dir, "vlan_filters.conf");
+$vlan_filters_config_default_file = catfile($conf_dir, "vlan_filters.conf.defaults");
 $firewall_sso_config_file =  catfile($conf_dir,"firewall_sso.conf");
 $pfdetect_config_file =  catfile($conf_dir,"pfdetect.conf");
 $pfqueue_config_file =  catfile($conf_dir,"pfqueue.conf");
+$report_config_file = catfile($conf_dir,"report.conf");
+$report_default_config_file = catfile($conf_dir,"report.conf.defaults");
+$pfqueue_default_config_file =  catfile($conf_dir,"pfqueue.conf.defaults");
 $realm_config_file = catfile($conf_dir,"realm.conf");
+$realm_default_config_file = catfile($conf_dir,"realm.conf.defaults");
+$survey_config_file = catfile($conf_dir,"survey.conf");
 $cluster_config_file = catfile($conf_dir,"cluster.conf");
 $server_key = catfile($conf_dir,"ssl/server.key");
 $server_cert = catfile($conf_dir,"ssl/server.crt");
 $server_pem = catfile($conf_dir,"ssl/server.pem");
+$radius_server_key = catfile($install_dir, "raddb/certs/server.key");
+$radius_server_cert = catfile($install_dir, "raddb/certs/server.crt");
+$radius_ca_cert = catfile($install_dir, "raddb/certs/ca.pem");
 $ssl_configuration_file = catfile($generated_conf_dir, "ssl-certificates.conf");
 $domain_config_file = catfile($conf_dir,"domain.conf");
 $scan_config_file = catfile($conf_dir,"scan.conf");
@@ -193,12 +279,28 @@ $wmi_config_file = catfile($conf_dir,"wmi.conf");
 $radius_filters_config_file = catfile($conf_dir,"radius_filters.conf");
 $billing_tiers_config_file = catfile($conf_dir,"billing_tiers.conf");
 $dhcp_filters_config_file = catfile($conf_dir,"dhcp_filters.conf");
+$roles_config_file = catfile($conf_dir,"roles.conf");
+$roles_default_config_file = catfile($conf_dir,"roles.conf.defaults");
+$dns_filters_config_file = catfile($conf_dir,"dns_filters.conf");
+$dns_filters_default_config_file = catfile($conf_dir,"dns_filters.conf.defaults");
+$admin_audit_log = catfile($log_dir, "httpd.admin.audit.log");
+$violation_log = catfile($log_dir, "violation.log");
+$portal_modules_config_file = catfile($conf_dir,"portal_modules.conf");
+$portal_modules_default_config_file = catfile($conf_dir,"portal_modules.conf.defaults");
+$pfmon_config_file = catfile($conf_dir,"pfmon.conf");
+$pfmon_default_config_file = catfile($conf_dir,"pfmon.conf.defaults");
+$switch_filters_config_file = catfile($conf_dir,"switch_filters.conf"); 
+$stats_config_file = catfile($conf_dir,"stats.conf");
 
 $oui_url               = 'http://standards.ieee.org/regauth/oui/oui.txt';
 $dhcp_fingerprints_url = 'http://www.packetfence.org/dhcp_fingerprints.conf';
 
 $users_cert_dir = catdir( $html_dir, "captive-portal/certs");
 
+$captiveportal_templates_path = catdir ($install_dir,"html/captive-portal/templates");
+$captiveportal_profile_templates_path = catdir ($install_dir,"html/captive-portal/profile-templates");
+$captiveportal_default_profile_templates_path = catdir ($captiveportal_profile_templates_path,"default");
+
 @log_files = map {catfile($log_dir, $_)}
   qw(
   httpd.admin.access httpd.admin.catalyst httpd.admin.error httpd.admin.log
@@ -207,7 +309,7 @@ $users_cert_dir = catdir( $html_dir, "captive-portal/certs");
   httpd.proxy.reverse.access httpd.proxy.reverse.error
   httpd.webservices.access httpd.webservices.error
   packetfence.log pfbandwidthd.log pfdetect.log pfqueue.log
-  pfdhcplistener.log pfdns.log pfmon.log pfconfig.log
+  pfdhcplistener.log pfdns.log pfmon.log pfconfig.log httpd.admin.audit.log
 );
 
 @stored_config_files = (
@@ -219,17 +321,33 @@ $users_cert_dir = catdir( $html_dir, "captive-portal/certs");
     $chi_config_file,$allowed_device_oui_file,$allowed_device_types_file,
     $chi_defaults_config_file,
     $ui_config_file,$provisioning_config_file,$oauth_ip_file,$log_config_file,
+    $device_registration_config_file,
     $admin_roles_config_file,$wrix_config_file,$apache_filters_config_file,
-    $vlan_filters_config_file,$firewall_sso_config_file,$scan_config_file,
+    $vlan_filters_config_file,$vlan_filters_config_default_file,$firewall_sso_config_file,$scan_config_file,
     $wmi_config_file,$pfdetect_config_file,$pfqueue_config_file,
     $pki_provider_config_file,
     $radius_filters_config_file,
     $dhcp_filters_config_file,
+    $roles_config_file,
+    $dns_filters_config_file,
+    $pfmon_config_file,
+    $switch_filters_config_file,
+    $stats_config_file,
+    $traffic_shaping_config_file,
+    $syslog_config_file,
+    $realm_config_file,
+    $fingerbank_collector_env_defaults_file,
 );
 
+$pffilter_socket_path = catfile($var_dir, "run/pffilter.sock");
 
 $cache_control_file = catfile($var_dir, "cache_control");
 
+$config_version_file = catfile($var_dir, "config_version");
+
+$maintenance_file = catfile($var_dir,"maintenance-mode");
+
+$pf_admin_i18n_dir = catfile($html_dir , 'pfappserver/lib/pfappserver/I18N');
 
 =head1 AUTHOR
 
@@ -238,7 +356,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
