@@ -24,6 +24,8 @@ use IO::Interface::Simple;
 use pf::log;
 use Readonly;
 use NetAddr::IP;
+use pf::constants;
+use pf::config::cluster;
 
 BEGIN {
     use Exporter ();
@@ -35,9 +37,24 @@ BEGIN {
     );
 }
 
-use pf::class qw(class_view_all class_trappable);
-use pf::config;
-use pf::node qw(nodes_registered_not_violators);
+use pf::config qw(
+    %ConfigNetworks
+    %Config
+    $IPTABLES_MARK_UNREG
+    $management_network
+    @internal_nets
+    $IF_ENFORCEMENT_VLAN
+    %ConfigProvisioning
+    $IF_ENFORCEMENT_DNS
+    @portal_ints
+    @ha_ints
+    $IPTABLES_MARK_ISOLATION
+    $IPTABLES_MARK_REG
+    is_inline_enforcement_enabled
+    is_type_inline
+    @radius_ints
+);
+use pf::file_paths qw($generated_conf_dir $conf_dir);
 use pf::util;
 use pf::violation qw(violation_view_open_uniq violation_count);
 use pf::authentication;
@@ -49,20 +66,25 @@ use pf::ConfigStore::Domain;
 # to be considered as running
 Readonly our $FW_FILTER_INPUT_MGMT      => 'input-management-if';
 Readonly our $FW_FILTER_INPUT_PORTAL    => 'input-portal-if';
+Readonly our $FW_FILTER_INPUT_RADIUS    => 'input-radius-if';
 
 Readonly my $FW_TABLE_FILTER => 'filter';
 Readonly my $FW_TABLE_MANGLE => 'mangle';
 Readonly my $FW_TABLE_NAT => 'nat';
 Readonly my $FW_FILTER_INPUT_INT_VLAN => 'input-internal-vlan-if';
+Readonly my $FW_FILTER_INPUT_INT_ISOL_VLAN => 'input-internal-isol_vlan-if';
 Readonly my $FW_FILTER_INPUT_INT_INLINE => 'input-internal-inline-if';
 Readonly my $FW_FILTER_INPUT_INT_HA => 'input-highavailability-if';
 Readonly my $FW_FILTER_FORWARD_INT_INLINE => 'forward-internal-inline-if';
 Readonly my $FW_FILTER_FORWARD_INT_VLAN => 'forward-internal-vlan-if';
+Readonly my $FW_FILTER_FORWARD_INT_ISOL_VLAN => 'forward-internal-isolvlan-if';
 Readonly my $FW_PREROUTING_INT_INLINE => 'prerouting-int-inline-if';
 Readonly my $FW_POSTROUTING_INT_INLINE => 'postrouting-int-inline-if';
 Readonly my $FW_POSTROUTING_INT_INLINE_ROUTED => 'postrouting-inline-routed';
 Readonly my $FW_PREROUTING_INT_VLAN => 'prerouting-int-vlan-if';
 
+tie our %NetworkConfig, 'pfconfig::cached_hash', "resource::network_config($host_id)";
+
 =head1 SUBROUTINES
 
 TODO: This list is incomplete
@@ -98,17 +120,34 @@ sub iptables_generate {
         'input_inter_inline_rules' => '', 'nat_prerouting_vlan' => '',
         'routed_postrouting_inline' => '','input_inter_vlan_if' => '',
         'domain_postrouting' => '','mangle_postrouting_inline' => '',
+        'filter_forward_isol_vlan' => '', 'input_inter_isol_vlan_if' => '',
+        'filter_forward' => '',
     );
 
     # global substitution variables
     $tags{'web_admin_port'} = $Config{'ports'}{'admin'};
     $tags{'webservices_port'} = $Config{'ports'}{'soap'};
     $tags{'aaa_port'} = $Config{'ports'}{'aaa'};
-    $tags{'status_port'} = $Config{'ports'}{'pf_status'};
+    $tags{'unifiedapi_port'} = $Config{'ports'}{'unifiedapi'};
     $tags{'httpd_portal_modstatus'} = $Config{'ports'}{'httpd_portal_modstatus'};
+    $tags{'httpd_collector_port'} = $Config{'ports'}{'collector'};
     # FILTER
     # per interface-type pointers to pre-defined chains
-    $tags{'filter_if_src_to_chain'} .= $self->generate_filter_if_src_to_chain();
+    ($tags{'filter_if_src_to_chain'},$tags{'filter_forward'}) = $self->generate_filter_if_src_to_chain();
+
+    # eduroam RADIUS virtual-server
+    if ( @{pf::authentication::getAuthenticationSourcesByType('Eduroam')} ) {
+        my @eduroam_authentication_source = @{pf::authentication::getAuthenticationSourcesByType('Eduroam')};
+        my $eduroam_listening_port = $eduroam_authentication_source[0]{'auth_listening_port'};    # using array index 0 since there can only be one 'eduroam' authentication source ('unique' attribute)
+        $tags{'eduroam_radius_virtualserver'} = "-A input-management-if --protocol tcp --match tcp --dport $eduroam_listening_port --jump ACCEPT\n";
+        $tags{'eduroam_radius_virtualserver'} .= "-A input-management-if --protocol udp --match udp --dport $eduroam_listening_port --jump ACCEPT\n";
+        $tags{'eduroam_radius_listening'} = "-A input-radius-if --protocol tcp --match tcp --dport $eduroam_listening_port --jump ACCEPT\n";
+        $tags{'eduroam_radius_listening'} .= "-A input-radius-if --protocol udp --match udp --dport $eduroam_listening_port --jump ACCEPT\n";
+    }
+    else {
+        $tags{'eduroam_radius_virtualserver'} = "# eduroam integration is not configured\n";
+        $tags{'eduroam_radius_listening'} = "# eduroam integration is not configured\n";
+    }
 
     if (is_inline_enforcement_enabled()) {
         # Note: I'm giving references to this guy here so he can directly mess with the tables
@@ -130,11 +169,11 @@ sub iptables_generate {
     $self->generate_interception_rules(\$tags{'nat_if_src_to_chain'},\$tags{'nat_prerouting_vlan'},\$tags{'input_inter_vlan_if'} );
 
     # OAuth
-    my $passthrough_enabled = isenabled($Config{'trapping'}{'passthrough'});
+    my $passthrough_enabled = (isenabled($Config{'fencing'}{'passthrough'}) || isenabled($Config{'fencing'}{'isolation_passthrough'}));
 
     if ($passthrough_enabled) {
         generate_passthrough_rules(
-            $passthrough_enabled,\$tags{'filter_forward_vlan'},\$tags{'nat_postrouting_vlan'}
+            $passthrough_enabled,\$tags{'filter_forward_vlan'},\$tags{'nat_postrouting_vlan'},\$tags{'filter_forward_isol_vlan'}
         );
     }
 
@@ -146,6 +185,10 @@ sub iptables_generate {
 
     generate_domain_rules(\$tags{'filter_forward_domain'}, \$tags{'domain_postrouting'});
 
+    # HTTP parking related rule
+    $tags{'nat_prerouting_vlan'} .= "-A PREROUTING -p tcp --dport 80 -m set --match-set $pf::constants::parking::PARKING_IPSET_NAME src -j REDIRECT --to-port 5252\n";
+    $tags{'nat_prerouting_vlan'} .= "-A PREROUTING -p tcp --dport 443 -m set --match-set $pf::constants::parking::PARKING_IPSET_NAME src -j REDIRECT --to-port 5252\n";
+
     parse_template( \%tags, "$conf_dir/iptables.conf", "$generated_conf_dir/iptables.conf" );
     $self->iptables_restore("$generated_conf_dir/iptables.conf");
 }
@@ -161,8 +204,9 @@ sub generate_filter_if_src_to_chain {
     my ($self) = @_;
     my $logger = get_logger();
     my $rules = '';
-
-    my $passthrough_enabled = isenabled($Config{'trapping'}{'passthrough'});
+    my $rules_forward = '';
+    my $passthrough_enabled = (isenabled($Config{'fencing'}{'passthrough'}) || isenabled($Config{'fencing'}{'isolation_passthrough'}));
+    my $isolation_passthrough_enabled = isenabled($Config{'fencing'}{'isolation_passthrough'});
 
     # internal interfaces handling
     foreach my $interface (@internal_nets) {
@@ -172,19 +216,40 @@ sub generate_filter_if_src_to_chain {
 
         my $cluster_ip = $ConfigCluster{$CLUSTER}->{"interface $dev"}->{ip};
         # VLAN enforcement
-        if ($enforcement_type eq $IF_ENFORCEMENT_VLAN) {
+        if ($enforcement_type eq $IF_ENFORCEMENT_VLAN || $enforcement_type eq $IF_ENFORCEMENT_DNS) {
             if ($dev =~ m/(\w+):\d+/) {
                 $dev = $1;
             }
+            my $type = $pf::config::NET_TYPE_VLAN_REG;
+            my $chain = $FW_FILTER_INPUT_INT_VLAN;
+            foreach my $network ( keys %ConfigNetworks ) {
+                # We skip non-inline networks/interfaces
+                next if ( pf::config::is_network_type_inline($network) );
+                if ( $ConfigNetworks{$network}{'type'} eq $pf::config::NET_TYPE_VLAN_ISOL ) {
+                    my $net_addr = NetAddr::IP->new($network,$ConfigNetworks{$network}{'netmask'});
+                    my $ip_test = new NetAddr::IP::Lite clean_ip($ip);
+                    if ($net_addr->contains($ip_test)) {
+                        $chain = $FW_FILTER_INPUT_INT_ISOL_VLAN;
+                        $type = $pf::config::NET_TYPE_VLAN_ISOL;
+                    }
+                }
+            }
             $rules .= "-A INPUT --in-interface $dev -d 224.0.0.0/8 -j ACCEPT\n";
             $rules .= "-A INPUT --in-interface $dev -p vrrp -j ACCEPT\n";
-            $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647\n" if ($pf::cluster_enabled);
+            $rules .= "# DHCP Sync\n";
+            $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647 -j ACCEPT\n" if ($pf::cluster_enabled);
+            $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 67 -j ACCEPT\n";
             $rules .= "-A INPUT --in-interface $dev -d ".$cluster_ip." --jump $FW_FILTER_INPUT_INT_VLAN\n" if ($cluster_enabled);
-            $rules .= "-A INPUT --in-interface $dev -d $ip --jump $FW_FILTER_INPUT_INT_VLAN\n";
+            $rules .= "-A INPUT --in-interface $dev -d " . $interface->tag("vip") . " --jump $FW_FILTER_INPUT_INT_VLAN\n" if $interface->tag("vip");
+            $rules .= "-A INPUT --in-interface $dev -d " . $interface->tag("ip") . " --jump $FW_FILTER_INPUT_INT_VLAN\n";
             $rules .= "-A INPUT --in-interface $dev -d 255.255.255.255 --jump $FW_FILTER_INPUT_INT_VLAN\n";
-            if ($passthrough_enabled) {
-                $rules .= "-A FORWARD --in-interface $dev --jump $FW_FILTER_FORWARD_INT_VLAN\n";
-                $rules .= "-A FORWARD --out-interface $dev --jump $FW_FILTER_FORWARD_INT_VLAN\n";
+            if ($passthrough_enabled && ($type eq $pf::config::NET_TYPE_VLAN_REG)) {
+                $rules_forward .= "-A FORWARD --in-interface $dev --jump $FW_FILTER_FORWARD_INT_VLAN\n";
+                $rules_forward .= "-A FORWARD --out-interface $dev --jump $FW_FILTER_FORWARD_INT_VLAN\n";
+            }
+            if ($isolation_passthrough_enabled && ($type eq $pf::config::NET_TYPE_VLAN_ISOL)) { 
+                $rules_forward .= "-A FORWARD --in-interface $dev --jump $FW_FILTER_FORWARD_INT_ISOL_VLAN\n";
+                $rules_forward .= "-A FORWARD --out-interface $dev --jump $FW_FILTER_FORWARD_INT_ISOL_VLAN\n";
             }
 
         # inline enforcement
@@ -192,12 +257,16 @@ sub generate_filter_if_src_to_chain {
             my $mgmt_ip = (defined($management_network->tag('vip'))) ? $management_network->tag('vip') : $management_network->tag('ip');
             $rules .= "-A INPUT --in-interface $dev -d 224.0.0.0/8 -j ACCEPT\n";
             $rules .= "-A INPUT --in-interface $dev -p vrrp -j ACCEPT\n";
-            $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647\n" if ($cluster_enabled);
+            $rules .= "# DHCP Sync\n";
+            $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647 -j ACCEPT\n" if ($cluster_enabled);
+            $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 67 -j ACCEPT\n";
             $rules .= "-A INPUT --in-interface $dev -d ".$cluster_ip." --jump $FW_FILTER_INPUT_INT_INLINE\n" if ($cluster_enabled);
+            $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 53 --jump $FW_FILTER_INPUT_INT_INLINE\n";
+            $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 53 --jump $FW_FILTER_INPUT_INT_INLINE\n";
             $rules .= "-A INPUT --in-interface $dev -d $ip --jump $FW_FILTER_INPUT_INT_INLINE\n";
             $rules .= "-A INPUT --in-interface $dev -d 255.255.255.255 --jump $FW_FILTER_INPUT_INT_INLINE\n";
             $rules .= "-A INPUT --in-interface $dev -d $mgmt_ip --protocol tcp --match tcp --dport 443 --jump ACCEPT\n";
-            $rules .= "-A FORWARD --in-interface $dev --jump $FW_FILTER_FORWARD_INT_INLINE\n";
+            $rules_forward .= "-A FORWARD --in-interface $dev --jump $FW_FILTER_FORWARD_INT_INLINE\n";
 
         # nothing? something is wrong
         } else {
@@ -213,6 +282,14 @@ sub generate_filter_if_src_to_chain {
         $rules .= "-A INPUT --in-interface $dev --jump $FW_FILTER_INPUT_PORTAL\n";
     }
 
+    # 'radius' interfaces handling
+    foreach my $radius_interface ( @radius_ints ) {
+        my $dev = $radius_interface->tag("int");
+        $rules .= "-A INPUT --in-interface $dev -d 224.0.0.0/8 -j ACCEPT\n";
+        $rules .= "-A INPUT --in-interface $dev -p vrrp -j ACCEPT\n";
+        $rules .= "-A INPUT --in-interface $dev --jump $FW_FILTER_INPUT_RADIUS\n";
+    }
+
     # management interface handling
     if($management_network) {
         my $mgmt_int = $management_network->tag("int");
@@ -220,7 +297,7 @@ sub generate_filter_if_src_to_chain {
     }
 
     # high-availability interfaces handling
-    foreach my $interface (@ha_ints) {
+    foreach my $interface (map { $_->{Tint}} @ha_ints) {
         $rules .= "-A INPUT --in-interface $interface --jump $FW_FILTER_INPUT_INT_HA\n";
     }
 
@@ -233,16 +310,16 @@ sub generate_filter_if_src_to_chain {
                 my $inline_obj = new Net::Netmask( $network, $ConfigNetworks{$network}{'netmask'} );
                 my $nat = $ConfigNetworks{$network}{'nat_enabled'};
                 if (defined ($nat) && (isdisabled($nat))) {
-                    $rules .= "-A FORWARD -d $network/$inline_obj->{BITS} --in-interface $val ";
-                    $rules .= "--jump ACCEPT";
-                    $rules .= "\n";
+                    $rules_forward .= "-A FORWARD -d $network/$inline_obj->{BITS} --in-interface $val ";
+                    $rules_forward .= "--jump ACCEPT";
+                    $rules_forward .= "\n";
                 }
             }
-            $rules .= "-A FORWARD --in-interface $val --match state --state ESTABLISHED,RELATED --jump ACCEPT\n";
+            $rules_forward .= "-A FORWARD --in-interface $val --match state --state ESTABLISHED,RELATED --jump ACCEPT\n";
         }
     }
 
-    return $rules;
+    return ($rules,$rules_forward);
 }
 
 
@@ -262,25 +339,27 @@ sub generate_inline_rules {
         # We skip non-inline networks/interfaces
         next if ( !pf::config::is_network_type_inline($network) );
         # Set the correct gateway if it is an inline Layer 3 network
-        my $gateway = $ConfigNetworks{$network}{'gateway'};
-        if ( $ConfigNetworks{$network}{'type'} eq $pf::config::NET_TYPE_INLINE_L3 ) {
-            foreach my $test_network ( keys %ConfigNetworks ) {
-                my $net_addr = NetAddr::IP->new($test_network,$ConfigNetworks{$test_network}{'netmask'});
-                my $ip = new NetAddr::IP::Lite clean_ip($ConfigNetworks{$network}{'next_hop'});
-                if ($net_addr->contains($ip)) {
-                    $gateway = $ConfigNetworks{$test_network}{'gateway'};
-                }
-            }
-        }
+        my $dev = $NetworkConfig{$network}{'interface'}{'int'};
+        my $gateway = $Config{"interface $dev"}{'ip'};
 
         my $rule = "--protocol udp --destination-port 53 -s $network/$ConfigNetworks{$network}{'netmask'}";
         $$nat_prerouting_ref .= "-A $FW_PREROUTING_INT_INLINE $rule --match mark --mark 0x$IPTABLES_MARK_UNREG "
             . "--jump DNAT --to $gateway\n";
         $$nat_prerouting_ref .= "-A $FW_PREROUTING_INT_INLINE $rule --match mark --mark 0x$IPTABLES_MARK_ISOLATION "
             . "--jump DNAT --to $gateway\n";
-        if (defined($Config{'trapping'}{'interception_proxy_port'}) && isenabled($Config{'trapping'}{'interception_proxy'})) {
+
+        if (isenabled($ConfigNetworks{$network}{'split_network'}) && defined($ConfigNetworks{$network}{'reg_network'}) && $ConfigNetworks{$network}{'reg_network'} ne '') {
+            $rule = "--protocol udp --destination-port 53 -s $ConfigNetworks{$network}{'reg_network'}";
+            $$nat_prerouting_ref .= "-A $FW_PREROUTING_INT_INLINE $rule --match mark --mark 0x$IPTABLES_MARK_UNREG "
+                . "--jump DNAT --to $gateway\n";
+            $$nat_prerouting_ref .= "-A $FW_PREROUTING_INT_INLINE $rule --match mark --mark 0x$IPTABLES_MARK_ISOLATION "
+                . "--jump DNAT --to $gateway\n";
+
+        }
+
+        if (defined($Config{'fencing'}{'interception_proxy_port'}) && isenabled($Config{'fencing'}{'interception_proxy'})) {
             $logger->info("Adding Proxy interception rules");
-            foreach my $intercept_port ( split(',', $Config{'trapping'}{'interception_proxy_port'} ) ) {
+            foreach my $intercept_port ( split(',', $Config{'fencing'}{'interception_proxy_port'} ) ) {
                 my $rule = "--protocol tcp --destination-port $intercept_port -s $network/$ConfigNetworks{$network}{'netmask'}";
                 $$nat_prerouting_ref .= "-A $FW_PREROUTING_INT_INLINE $rule --match mark --mark 0x$IPTABLES_MARK_UNREG "
                         . "--jump DNAT --to $gateway\n";
@@ -290,9 +369,9 @@ sub generate_inline_rules {
         }
     }
 
-    if (defined($Config{'trapping'}{'interception_proxy_port'}) && isenabled($Config{'trapping'}{'interception_proxy'})) {
+    if (defined($Config{'fencing'}{'interception_proxy_port'}) && isenabled($Config{'fencing'}{'interception_proxy'})) {
         $logger->info("Adding Proxy interception rules");
-        foreach my $intercept_port ( split(',', $Config{'trapping'}{'interception_proxy_port'} ) ) {
+        foreach my $intercept_port ( split(',', $Config{'fencing'}{'interception_proxy_port'} ) ) {
             $$input_filtering_ref .= "-A $FW_FILTER_INPUT_INT_INLINE --protocol tcp --match tcp --dport $intercept_port "
                     . " --match mark --mark 0x$IPTABLES_MARK_UNREG  --jump ACCEPT\n";
             $$input_filtering_ref .= "-A $FW_FILTER_INPUT_INT_INLINE --protocol tcp --match tcp --dport $intercept_port "
@@ -310,30 +389,16 @@ sub generate_inline_rules {
     $$routed_postrouting_inline .= "-A $FW_POSTROUTING_INT_INLINE_ROUTED --jump ACCEPT\n";
 
     $logger->info("building firewall to accept registered users through inline interface");
-    my $passthrough_enabled = isenabled($Config{'trapping'}{'passthrough'});
-
-    # Allow remote conformity scan server to reach unregistered devices in inline mode
-    if ( defined($Config{'scan'}{'host'}) && $Config{'scan'}{'host'} ne "127.0.0.1" ) {
-        $$filter_rules_ref .= "-A $FW_FILTER_FORWARD_INT_INLINE --source $Config{'scan'}{'host'} --jump ACCEPT\n";
-        $$filter_rules_ref .= "-A $FW_FILTER_FORWARD_INT_INLINE --destination $Config{'scan'}{'host'} --jump ACCEPT\n";
-    }
+    my $passthrough_enabled = (isenabled($Config{'fencing'}{'passthrough'}) || isenabled($Config{'fencing'}{'isolation_passthrough'}));
 
     if ($passthrough_enabled) {
         $$filter_rules_ref .= "-A $FW_FILTER_FORWARD_INT_INLINE --match mark --mark 0x$IPTABLES_MARK_UNREG -m set --match-set pfsession_passthrough dst,dst --jump ACCEPT\n";
+        $$filter_rules_ref .= "-A $FW_FILTER_FORWARD_INT_INLINE --match mark --mark 0x$IPTABLES_MARK_ISOLATION -m set --match-set pfsession_isol_passthrough dst,dst --jump ACCEPT\n";
     }
 
 
     $$filter_rules_ref .= "-A $FW_FILTER_FORWARD_INT_INLINE --match mark --mark 0x$IPTABLES_MARK_REG --jump ACCEPT\n";
-    if (!isenabled($Config{'trapping'}{'registration'})) {
-        $logger->info(
-            "trapping.registration is disabled, adding rule so we accept unregistered users through inline interface"
-        );
-        $$filter_rules_ref .=
-            "-A $FW_FILTER_FORWARD_INT_INLINE "
-            . "--match mark --mark 0x$IPTABLES_MARK_UNREG --jump ACCEPT\n"
-        ;
     }
-}
 
 =item generate_passthrough_rules
 
@@ -342,7 +407,7 @@ Creating the proper firewall rules to allow Google/Facebook OAuth2 and passthrou
 =cut
 
 sub generate_passthrough_rules {
-    my ($passthrough,$forward_rules_ref,$nat_rules_ref) = @_;
+    my ($passthrough,$forward_rules_ref,$nat_rules_ref,$forward_isol_rules_ref) = @_;
     my $logger = get_logger();
 
     $logger->info("Adding Forward rules to allow connections to the OAuth2 Providers and passthrough.");
@@ -351,31 +416,37 @@ sub generate_passthrough_rules {
     if ($passthrough) {
         $$forward_rules_ref .= "-A $FW_FILTER_FORWARD_INT_VLAN -m set --match-set pfsession_passthrough dst,dst --jump ACCEPT\n";
         $$forward_rules_ref .= "-A $FW_FILTER_FORWARD_INT_VLAN -m set --match-set pfsession_passthrough src,src --jump ACCEPT\n";
+        $$forward_isol_rules_ref .= "-A $FW_FILTER_FORWARD_INT_ISOL_VLAN -m set --match-set pfsession_isol_passthrough dst,dst --jump ACCEPT\n";
+        $$forward_isol_rules_ref .= "-A $FW_FILTER_FORWARD_INT_ISOL_VLAN -m set --match-set pfsession_isol_passthrough src,src --jump ACCEPT\n";
     }
 
     # add passthroughs required by the provisionings
     generate_provisioning_passthroughs();
 
     $logger->info("Adding NAT Masquerade statement.");
-    my $mgmt_int = $management_network->tag("int");
-    my $SNAT_ip;
-    if (defined($management_network->{'Tip'}) && $management_network->{'Tip'} ne '') {
-        if (defined($management_network->{'Tvip'}) && $management_network->{'Tvip'} ne '') {
-            $SNAT_ip = $management_network->{'Tvip'};
-        } else {
-            $SNAT_ip = $management_network->{'Tip'};
-       }
+    my ($SNAT_ip, $mgmt_int);
+    if ($management_network) {
+        $mgmt_int = $management_network->tag("int");
+        if (defined($management_network->{'Tip'}) && $management_network->{'Tip'} ne '') {
+            if (defined($management_network->{'Tvip'}) && $management_network->{'Tvip'} ne '') {
+                $SNAT_ip = $management_network->{'Tvip'};
+            } else {
+                $SNAT_ip = $management_network->{'Tip'};
+           }
+        }
     }
 
-    foreach my $network ( keys %ConfigNetworks ) {
-        my $network_obj = new Net::Netmask( $network, $ConfigNetworks{$network}{'netmask'} );
-        if ( pf::config::is_network_type_inline($network) ) {
-            my $nat = $ConfigNetworks{$network}{'nat_enabled'};
-            if (defined ($nat) && (isenabled($nat))) {
+    if ($SNAT_ip) {
+        foreach my $network ( keys %ConfigNetworks ) {
+            my $network_obj = new Net::Netmask( $network, $ConfigNetworks{$network}{'netmask'} );
+            if ( pf::config::is_network_type_inline($network) ) {
+                my $nat = $ConfigNetworks{$network}{'nat_enabled'};
+                if (defined ($nat) && (isenabled($nat))) {
+                    $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $mgmt_int -j SNAT --to $SNAT_ip\n";
+                }
+            } else {
                 $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $mgmt_int -j SNAT --to $SNAT_ip\n";
             }
-        } else {
-            $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $mgmt_int -j SNAT --to $SNAT_ip\n";
         }
     }
 
@@ -474,11 +545,13 @@ sub generate_nat_redirect_rules {
     my $rules = '';
 
     # Exclude the OAuth from the DNAT
-    my $passthrough_enabled = isenabled($Config{'trapping'}{'passthrough'});
+    my $passthrough_enabled = (isenabled($Config{'fencing'}{'passthrough'}) || isenabled($Config{'fencing'}{'isolation_passthrough'}));
 
     if ($passthrough_enabled) {
          $rules .= "-A $FW_PREROUTING_INT_INLINE -m set --match-set pfsession_passthrough dst,dst ".
                "--match mark --mark 0x$IPTABLES_MARK_UNREG --jump ACCEPT\n";
+         $rules .= "-A $FW_PREROUTING_INT_INLINE -m set --match-set pfsession_isol_passthrough dst,dst ".
+               "--match mark --mark 0x$IPTABLES_MARK_ISOLATION --jump ACCEPT\n";
     }
 
     # Now, do your magic
@@ -489,22 +562,8 @@ sub generate_nat_redirect_rules {
             # We skip non-inline networks/interfaces
             next if ( !pf::config::is_network_type_inline($network) );
             # Set the correct gateway if it is an inline Layer 3 network
-            my $gateway = $ConfigNetworks{$network}{'gateway'};
-            if ( $ConfigNetworks{$network}{'type'} eq $pf::config::NET_TYPE_INLINE_L3 ) {
-                foreach my $test_network ( keys %ConfigNetworks ) {
-                    my $net_addr = NetAddr::IP->new($test_network,$ConfigNetworks{$test_network}{'netmask'});
-                    my $ip = new NetAddr::IP::Lite clean_ip($ConfigNetworks{$network}{'next_hop'});
-                    if ($net_addr->contains($ip)) {
-                        $gateway = $ConfigNetworks{$test_network}{'gateway'};
-                    }
-                }
-            }
-            # Destination NAT to the portal on the UNREG mark if trapping.registration is enabled
-            if ( isenabled( $Config{'trapping'}{'registration'} ) ) {
-                $rules .=
-                    "-A $FW_PREROUTING_INT_INLINE --protocol $protocol --destination-port $port -s $network/$ConfigNetworks{$network}{'netmask'} " .
-                    "--match mark --mark 0x$IPTABLES_MARK_UNREG --jump DNAT --to $gateway\n";
-            }
+            my $dev = $NetworkConfig{$network}{'interface'}{'int'};
+            my $gateway = $Config{"interface $dev"}{'ip'};
 
             # Destination NAT to the portal on the ISOLATION mark
             $rules .=
@@ -569,27 +628,6 @@ of the inline mode because of time constraints.
 
 =over
 
-=item generate_filter_forward_scanhost
-
-=cut
-
-sub generate_filter_forward_scanhost {
-    my @self = @_;
-    my $logger = get_logger();
-    my $filter_rules = '';
-
-    # TODO don't forget to also add statements to the PREROUTING nat table as in generate_inline_rules
-    my $scan_server = $Config{'scan'}{'host'};
-    if ( $scan_server !~ /^127\.0\.0\.1$/ && $scan_server !~ /^localhost$/i ) {
-        $filter_rules .= "-A FORWARD --destination $scan_server --jump ACCEPT";
-        $filter_rules .= "-A FORWARD --source $scan_server --jump ACCEPT";
-        $logger->info("adding Nessus FILTER passthrough for $scan_server");
-    }
-
-    return $filter_rules;
-}
-
-
 =item update_node
 
 Update session when the ip address change
@@ -649,29 +687,33 @@ sub generate_interception_rules {
         if ($enforcement_type eq $IF_ENFORCEMENT_VLAN) {
             # send everything from vlan interfaces to the vlan chain
             $$nat_if_src_to_chain .= "-A PREROUTING --in-interface $dev --jump $FW_PREROUTING_INT_VLAN\n";
-            if (defined($Config{'trapping'}{'interception_proxy_port'}) && isenabled($Config{'trapping'}{'interception_proxy'})) {
-                foreach my $network ( keys %ConfigNetworks ) {
-                    next if (pf::config::is_network_type_inline($network));
-                    my %net = %{$ConfigNetworks{$network}};
-                    my $ip;
-                    if (defined($net{'next_hop'})) {
-                        $ip = new NetAddr::IP::Lite clean_ip($net{'next_hop'});
-                    } else {
-                        $ip = new NetAddr::IP::Lite clean_ip($net{'gateway'});
-                    }
-                    if ($net_addr->contains($ip)) {
-                        foreach my $intercept_port ( split( ',', $Config{'trapping'}{'interception_proxy_port'} ) ) {
-                            my $destination = $Config{"interface $dev"}{'vip'} || $Config{"interface $dev"}{'ip'};
+            foreach my $network ( keys %ConfigNetworks ) {
+                next if (pf::config::is_network_type_inline($network));
+                my %net = %{$ConfigNetworks{$network}};
+                my $ip;
+                if (defined($net{'next_hop'})) {
+                    $ip = new NetAddr::IP::Lite clean_ip($net{'next_hop'});
+                } else {
+                    $ip = new NetAddr::IP::Lite clean_ip($net{'gateway'});
+                }
+                if ($net_addr->contains($ip)) {
+                    my $destination = $Config{"interface $dev"}{'vip'} || $Config{"interface $dev"}{'ip'};
+                    if (defined($Config{'fencing'}{'interception_proxy_port'}) && isenabled($Config{'fencing'}{'interception_proxy'})) {
+                        foreach my $intercept_port ( split( ',', $Config{'fencing'}{'interception_proxy_port'} ) ) {
                             my $rule = "--protocol tcp --destination-port $intercept_port -s $network/$ConfigNetworks{$network}{'netmask'}";
                             $$nat_prerouting_vlan .= "-A $FW_PREROUTING_INT_VLAN $rule --jump DNAT --to $destination\n";
                         }
                     }
+                    my $rule = "--protocol udp --destination-port 53 -s $network/$ConfigNetworks{$network}{'netmask'}";
+                    $$nat_prerouting_vlan .= "-A $FW_PREROUTING_INT_VLAN $rule --jump DNAT --to $destination\n";
+                    $rule = "--protocol tcp --destination-port 53 -s $network/$ConfigNetworks{$network}{'netmask'}";
+                    $$nat_prerouting_vlan .= "-A $FW_PREROUTING_INT_VLAN $rule --jump DNAT --to $destination\n";
                 }
             }
         }
     }
-    if (defined($Config{'trapping'}{'interception_proxy_port'}) && isenabled($Config{'trapping'}{'interception_proxy'})) {
-        foreach my $intercept_port ( split( ',', $Config{'trapping'}{'interception_proxy_port'} ) ) {
+    if (defined($Config{'fencing'}{'interception_proxy_port'}) && isenabled($Config{'fencing'}{'interception_proxy'})) {
+        foreach my $intercept_port ( split( ',', $Config{'fencing'}{'interception_proxy_port'} ) ) {
             my $rule = "--protocol tcp --destination-port $intercept_port";
             $$input_inter_vlan_if .= "-A $FW_FILTER_INPUT_INT_VLAN $rule --jump ACCEPT\n";
         }
@@ -680,32 +722,43 @@ sub generate_interception_rules {
 
 sub generate_provisioning_passthroughs {
     my $logger = get_logger();
+    $logger->debug("Installing passthroughs for provisioning");
     foreach my $config (tied(%ConfigProvisioning)->search(type => 'sepm')) {
         $logger->info("Adding passthrough for Symantec Endpoint Manager");
-        my $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{'host'},8014 2>&1");
+        my $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{'host'},8014 2>&1");
         my @lines  = pf_run($cmd);
     }
 
     foreach my $config (tied(%ConfigProvisioning)->search(type => 'mobileiron')) {
         $logger->info("Adding passthrough for MobileIron");
         # Allow the host for the onboarding of devices
-        my $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{boarding_host},$config->{boarding_port} 2>&1");
+        my $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{boarding_host},$config->{boarding_port} 2>&1");
         my @lines  = pf_run($cmd);
         # Allow http communication with the MobileIron server
-        $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{boarding_host},80 2>&1");
+        $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{boarding_host},$HTTP_PORT 2>&1");
         @lines  = pf_run($cmd);
         # Allow https communication with the MobileIron server
-        $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{boarding_host},443 2>&1");
+        $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{boarding_host},$HTTPS_PORT 2>&1");
         @lines  = pf_run($cmd);
     }
 
     foreach my $config (tied(%ConfigProvisioning)->search(type => 'opswat')) {
         $logger->info("Adding passthrough for OPSWAT");
-        # Allow http communication with the MobileIron server
-        my $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{host},80 2>&1");
+        # Allow http communication with the OSPWAT server
+        my $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{host},$HTTP_PORT 2>&1");
         my @lines  = pf_run($cmd);
-        # Allow https communication with the MobileIron server
-        $cmd = untaint_chain("LANG=C sudo ipset --add pfsession_passthrough $config->{host},443 2>&1");
+        # Allow https communication with the OPSWAT server
+        $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{host},$HTTPS_PORT 2>&1");
+        @lines  = pf_run($cmd);
+    }
+
+    foreach my $config (tied(%ConfigProvisioning)->search(type => 'sentinelone')) {
+        $logger->info("Adding passthrough for SentinelOne");
+        # Allow http communication with the SentinelOne server
+        my $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{host},$HTTP_PORT 2>&1");
+        my @lines  = pf_run($cmd);
+        # Allow https communication with the SentinelOne server
+        $cmd = untaint_chain("sudo ipset --add pfsession_passthrough $config->{host},$HTTPS_PORT 2>&1");
         @lines  = pf_run($cmd);
     }
 
@@ -720,6 +773,8 @@ sub generate_domain_rules {
         $$filter_forward_domain .= "-A FORWARD -i $name-b -j ACCEPT\n";
     }
 
+    return if !$management_network;
+
     # MOVE ME TO SOMEWHERE - BUT WHERE ????? - ANYWHERE IS BETTER THAN THIS !
     my $domain_network = "169.254.0.0/16";
 
@@ -738,7 +793,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
