@@ -16,8 +16,8 @@ use strict;
 use warnings;
 use Moo;
 extends qw(pf::pfqueue::producer);
-use Redis::Fast;
-use pf::file_paths;
+use pf::Redis;
+use pf::dal;
 use List::MoreUtils qw(all);
 use Sereal::Encoder qw(sereal_encode_with_object);
 use pf::Sereal qw($ENCODER);
@@ -69,7 +69,7 @@ sub _build_redis {
     else {
         $args{server} = $server;
     }
-    return Redis::Fast->new(%args);
+    return pf::Redis->new(%args);
 }
 
 =head2 submit
@@ -87,12 +87,13 @@ sub submit {
     my $redis = $self->redis;
     # Batch the creation of the task and it's ttl and placing it on the queue to improve performance
     $redis->multi(sub {});
-    $redis->hmset($id, data => sereal_encode_with_object($ENCODER, [$task_type, $task_data]), expire => $expire_in, sub {});
+    $redis->hmset($id, data => sereal_encode_with_object($ENCODER, [$task_type, $task_data]), expire => $expire_in, tenant_id => pf::dal->get_tenant(), sub {});
     $redis->expire($id, $expire_in, sub {});
-    $redis->lpush($queue_name, $id, sub {});
     $redis->hincrby($PFQUEUE_COUNTER, $task_counter_id, 1, sub {});
+    $redis->lpush($queue_name, $id, sub {});
     $redis->exec(sub {});
     $redis->wait_all_responses();
+    return $id;
 }
 
 sub submit_delayed {
@@ -108,12 +109,13 @@ sub submit_delayed {
     $time_milli += $delay;
     # Batch the creation of the task and it's ttl and placing it on the queue to improve performance
     $redis->multi(sub {});
-    $redis->hmset($id, data => sereal_encode_with_object($ENCODER, [$task_type, $task_data]), expire => $expire_in, sub {});
+    $redis->hmset($id, data => sereal_encode_with_object($ENCODER, [$task_type, $task_data]), expire => $expire_in, tenant_id => pf::dal->get_tenant(), sub {});
     $redis->expire($id, $expire_in + int($delay / 1000), sub {});
-    $redis->zadd("Delayed:$queue", $time_milli, $id, sub {});
     $redis->hincrby($PFQUEUE_COUNTER, $task_counter_id, 1, sub {});
+    $redis->zadd("Delayed:$queue", $time_milli, $id, sub {});
     $redis->exec(sub {});
     $redis->wait_all_responses();
+    return $id;
 }
 
 
@@ -123,7 +125,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
