@@ -17,6 +17,8 @@ use Moo;
 use pf::log;
 use pf::constants;
 
+has id => (is => 'rw', required => 1);
+
 has ca_cert_path => (is => 'rw');
 
 has server_cert_path => (is => 'rw');
@@ -27,6 +29,8 @@ has server_cert => (is => 'ro' , builder => 1, lazy => 1);
 
 has cn_attribute => (is => 'rw');
 
+has cn_format => (is => 'rw', default => '%s');
+
 has revoke_on_unregistration => (is => 'rw', default => 'N');
 
 =head2 country
@@ -197,7 +201,7 @@ sub ca_cn {
 
 sub user_cn {
     my ($self, $node_info) = @_;
-    my $cn = $node_info->{$self->cn_attribute};
+    my $cn = sprintf($self->cn_format, $node_info->{$self->cn_attribute});
     if( defined($cn) ) {
         return $cn;
     }
@@ -212,7 +216,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
