@@ -15,6 +15,7 @@ use strict;
 use warnings;
 use Moo;
 extends 'pf::provisioner::mobileconfig';
+use fingerbank::Constant;
 
 =head1 Atrributes
 
@@ -25,15 +26,7 @@ The set the default OS Andriod
 =cut
 
 # Will always ignore the oses parameter provided and use [Generic Android]
-has 'oses' => (is => 'ro', default => sub { ['Generic Android'] }, coerce => sub { ['Generic Android'] });
-
-=head2 profile_template
-
-The template to use for profile
-
-=cut
-
-has profile_template => (is => 'rw', default => sub { "pf-profile.xml" });
+has 'oses' => (is => 'ro', default => sub { [$fingerbank::Constant::PARENT_IDS{ANDROID}] }, coerce => sub { [$fingerbank::Constant::PARENT_IDS{ANDROID}] });
 
 =head1 AUTHOR
 
@@ -41,7 +34,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
