@@ -21,7 +21,7 @@ use pf::util qw(clean_mac);
 use WWW::Curl::Easy;
 use XML::Simple;
 use pf::log;
-use pf::iplog;
+use pf::ip4log;
 use pf::ConfigStore::Provisioning;
 
 =head1 Atrributes
@@ -135,10 +135,6 @@ sub set_access_token {
     }
     else{
         $self->{'access_token'} = $access_token;
-        my $cs = pf::ConfigStore::Provisioning->new;
-        $logger->info($self->{'id'});
-        $cs->update($self->{'id'}, {access_token => $access_token});
-        $cs->commit();
     }
 }
 
@@ -172,6 +168,7 @@ sub refresh_access_token {
         $refresh_token = $json_response->{'refresh_token'};
         if (defined $access_token && $access_token ne '') {
             $updated_config->{access_token} = $access_token;
+            $self->set_access_token($access_token);
         }
         else {
             $logger->error("Cannot update the access token for $self->{id}");
@@ -264,7 +261,7 @@ sub validate_ip_in_sepm {
 
 sub authorize {
     my ($self,$mac) = @_;
-    my $ip = pf::iplog::mac2ip($mac);
+    my $ip = pf::ip4log::mac2ip($mac);
     if(defined($ip)){
         my $logger = $self->logger;
         my $result = $self->validate_ip_in_sepm($ip);
@@ -302,7 +299,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
