@@ -25,7 +25,26 @@ use pf::authentication;
 use pf::Connection;
 use pf::constants;
 use pf::constants::trigger qw($TRIGGER_TYPE_ACCOUNTING);
-use pf::config;
+use pf::constants::role qw($VOICE_ROLE);
+use pf::constants::realm;
+use pf::error qw(is_error);
+use pf::config qw(
+    $ROLE_API_LEVEL
+    $WIRELESS
+    $VOIP
+    $NO_VOIP
+    %Config
+    %ConfigDomain
+    $ACCOUNTING_POLICY_TIME
+    $ACCOUNTING_POLICY_BANDWIDTH
+    $WIRED
+    $WIRED_MAC_AUTH
+    $WIRED_802_1X
+    %ConfigFloatingDevices
+    $WIRELESS_MAC_AUTH
+    $WIRELESS_802_1X
+);
+use pf::client;
 use pf::locationlog;
 use pf::node;
 use pf::Switch;
@@ -40,7 +59,14 @@ use pf::radius::constants;
 use List::Util qw(first);
 use pf::util::statsd qw(called);
 use pf::StatsD::Timer;
-use Hash::Merge qw (merge);
+use pf::accounting;
+use pf::cluster;
+use pf::api::queue;
+use pf::access_filter::radius;
+use pf::registration;
+use pf::access_filter::switch;
+use pf::role::pool;
+use pf::dal;
 
 our $VERSION = 1.03;
 
@@ -78,11 +104,14 @@ sub authorize {
     my $timer = pf::StatsD::Timer->new();
     my ($self, $radius_request) = @_;
     my $logger = $self->logger;
+    my ($do_auto_reg, %autoreg_node_defaults);
     my($switch_mac, $switch_ip,$source_ip,$stripped_user_name,$realm) = $self->_parseRequest($radius_request);
     my $RAD_REPLY_REF;
 
+    $self->handleNtlmCaching($radius_request);
+
     $logger->debug("instantiating switch");
-    my $switch = pf::SwitchFactory->instantiate({ switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $source_ip});
+    my $switch = pf::SwitchFactory->instantiate({ switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $switch_ip}, {radius_request => $radius_request});
 
     # is switch object correct?
     if (!$switch) {
@@ -94,8 +123,15 @@ sub authorize {
         goto AUDIT;
     }
 
+    $switch->setCurrentTenant();
+    my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
+
+    $user_name = normalize_username($user_name, $radius_request);
+
+    if (!$mac) {
+        return [$RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "Mac is empty")];
+    }
 
-    my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id) = $switch->parseRequest($radius_request);
     Log::Log4perl::MDC->put( 'mac', $mac );
     my $connection = pf::Connection->new;
     $connection->identifyType($nas_port_type, $eap_type, $mac, $user_name, $switch);
@@ -108,8 +144,10 @@ sub authorize {
         $logger->debug("SSID resolved to: $ssid") if (defined($ssid));
     }
 
+    $self->handleConnectionTypeChange($mac, $connection);
+
     {
-        my $timer = pf::StatsD::Timer->new({ 'stat' => called() . ".getIfIndex"});
+        my $timer = pf::StatsD::Timer->new({ 'stat' => called() . ".getIfIndex", level => 7});
         $port = $switch->getIfIndexByNasPortId($nas_port_id) || $self->_translateNasPortToIfIndex($connection_type, $switch, $port);
     }
 
@@ -121,52 +159,52 @@ sub authorize {
         stripped_user_name => $stripped_user_name,
         realm => $realm,
         nas_port_type => $nas_port_type,
-        eap_type => $eap_type,
+        eap_type => $eap_type // '',
         mac => $mac,
         ifIndex => $port,
+        ifDesc => $ifDesc,
         user_name => $user_name,
-        nas_port_id => $nas_port_type,
+        nas_port_id => $nas_port_type // '',
         session_id => $session_id,
         connection_type => $connection_type,
         connection_sub_type => $connection_sub_type,
         radius_request => $radius_request,
     };
 
-    $logger->trace("received a radius authorization request with parameters: ".
-        "nas port type => $nas_port_type, switch_ip => ($switch_ip), EAP-Type => $eap_type, ".
-        "mac => [$mac], port => $port, username => \"$user_name\"");
+    $logger->trace( sub { "received a radius authorization request with parameters: ".
+        "nas port type => $args->{nas_port_type}, switch_ip => ($switch_ip), EAP-Type => $args->{eap_type}, ".
+        "mac => [$mac], port => $port, username => \"$user_name\"" });
 
     # let's check if an old port sec entry needs to be removed in another switch
     $self->_handleStaticPortSecurityMovement($args);
 
-    # TODO maybe it's in there that we should do all the magic that happened in the FreeRADIUS module
-    # meaning: the return should be decided by _doWeActOnThisCall, not always $RADIUS::RLM_MODULE_NOOP
-    my $weActOnThisCall = $self->_doWeActOnThisCall($args);
-    if ($weActOnThisCall == 0) {
-        $logger->info("We decided not to act on this radius call. Stop handling request from $switch_ip.");
-        $RAD_REPLY_REF = [ $RADIUS::RLM_MODULE_NOOP, ('Reply-Message' => "Not acting on this request") ];
-        goto CLEANUP;
-    }
-
     $logger->info("handling radius autz request: from switch_ip => ($switch_ip), "
         . "connection_type => " . connection_type_to_str($connection_type) . ","
         . "switch_mac => ".( defined($switch_mac) ? "($switch_mac)" : "(Unknown)" ).", mac => [$mac], port => $port, username => \"$user_name\""
         . ( defined $ssid ? ", ssid => $ssid" : '' ) );
 
-    #add node if necessary
-    if ( !node_exist($mac) ) {
-        $logger->info("does not yet exist in database. Adding it now");
-        node_add_simple($mac);
+    my ($status_code, $node_obj) = pf::dal::node->find_or_create({"mac" => $mac});
+    if (is_error($status_code)) {
+        $node_obj = pf::dal::node->new({"mac" => $mac});
     }
+    $node_obj->_load_locationlog;
+    # update last_seen of MAC address as some activity from it has been seen
+    $node_obj->update_last_seen();
+
+    #define the current connection value to instantiate the correct portal
+    my $options = {};
+
+    $options->{'machine_account'} = '';
 
     # Handling machine auth detection
     if ( defined($user_name) && $user_name =~ /^host\// ) {
         $logger->info("is doing machine auth with account '$user_name'.");
-        node_modify($mac, ('machine_account' => $user_name));
+        $node_obj->machine_account($user_name);
+        $options->{'machine_account'} = $user_name;
     }
 
     if (defined($session_id)) {
-         node_modify($mac, ('sessionid' => $session_id));
+        $node_obj->sessionid($session_id);
     }
 
     my $switch_id =  $switch->{_id};
@@ -177,44 +215,63 @@ sub authorize {
         $RAD_REPLY_REF = $self->_switchUnsupportedReply($args);
         goto CLEANUP;
     }
+    my %info;
 
 
     my $role_obj = new pf::role::custom();
 
-    # Vlan Filter
-    my $node_info = node_view($mac);
     $args->{'ssid'} = $ssid;
-    $args->{'node_info'} = $node_info;
+    $args->{'node_info'} = $node_obj;
+    $args->{'fingerbank_info'} = pf::node::fingerbank_info($mac, $node_obj);
     my $result = $role_obj->filterVlan('IsPhone',$args);
     # determine if we need to perform automatic registration
     # either the switch detects that this is a phone or we take the result from the vlan filters
-    my $isPhone = $switch->isPhoneAtIfIndex($mac, $port) || defined($result);
+    if (defined($result)) {
+        $args->{'isPhone'} = $result;
+    } elsif ($port) {
+       $args->{'isPhone'} =$switch->isPhoneAtIfIndex($mac, $port);
+    } else {
+        $args->{'isPhone'} = $FALSE;
+    }
 
-    $args->{'isPhone'} = $isPhone;
+    $options->{'last_connection_sub_type'} = $args->{'connection_sub_type'};
+    $options->{'last_connection_type'}     = connection_type_to_str($args->{'connection_type'});
+    $options->{'last_switch'}              = $switch_id;
+    $options->{'last_port'}                = $args->{'switch'}->{switch_port} if (defined($args->{'switch'}->{switch_port}));
+    $options->{'last_vlan'}                = $args->{'vlan'} if (defined($args->{'vlan'}));
+    $options->{'last_ssid'}                = $args->{'ssid'} if (defined($args->{'ssid'}));
+    $options->{'last_dot1x_username'}      = $args->{'user_name'} if (defined($args->{'user_name'}));
+    $options->{'realm'}               = $args->{'realm'} if (defined($args->{'realm'}));
+    $options->{'radius_request'}      = $args->{'radius_request'};
+    $options->{'fingerbank_info'}     = $args->{'fingerbank_info'};
 
+    my $profile = pf::Connection::ProfileFactory->instantiate($args->{'mac'},$options);
+    $args->{'profile'} = $profile; 
+    
     $args->{'autoreg'} = 0;
     # should we auto-register? let's ask the VLAN object
-    if ($role_obj->shouldAutoRegister($args)) {
+    my ( $status, $status_msg );
+    $do_auto_reg = $role_obj->shouldAutoRegister($args);
+    if ($do_auto_reg) {
         $args->{'autoreg'} = 1;
-        # automatic registration
-        my %autoreg_node_defaults = $role_obj->getNodeInfoForAutoReg($args);
-        $args->{'node_info'} = merge($args->{'node_info'}, \%autoreg_node_defaults);
+        %autoreg_node_defaults = $role_obj->getNodeInfoForAutoReg($args);
+        $node_obj->merge(\%autoreg_node_defaults);
         $logger->debug("[$mac] auto-registering node");
-        if (!node_register($mac, $autoreg_node_defaults{'pid'}, %autoreg_node_defaults)) {
-            $logger->error("auto-registration of node failed");
+        # automatic registration
+        $info{autoreg} = 1;
+        ($status, $status_msg) = pf::registration::setup_node_for_registration($node_obj, \%info);
+        if (is_error($status)) {
+            $logger->error("auto-registration of node failed $status_msg");
+            $do_auto_reg = 0;
+            $RAD_REPLY_REF = [ $RADIUS::RLM_MODULE_USERLOCK, ('Reply-Message' => $status_msg) ];
+            goto CLEANUP;
         }
-        # Commented out as it opens a locationlog even when sending a reject
-        # This shouldn't break anything in the flow as the entry is opened afterwards
-        # This also creates duplicate entries since the VLAN hasn't been computed yet
-        # Can be removed in PF6
-        # jsemaan@inverse.ca
-        #$switch->synchronize_locationlog($port, undef, $mac, $isPhone ? $VOIP : $NO_VOIP,
-        #    $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm);
     }
 
     # if it's an IP Phone, let _authorizeVoip decide (extension point)
-    if ($isPhone) {
+    if ($args->{'isPhone'}) {
         $RAD_REPLY_REF = $self->_authorizeVoip($args);
+        $args->{'user_role'} = $VOICE_ROLE;
         goto CLEANUP;
     }
 
@@ -231,26 +288,43 @@ sub authorize {
 
     # Fetch VLAN depending on node status
     my $role = $role_obj->fetchRoleForNode($args);
-    my $vlan = $role->{vlan} || $switch->getVlanByName($role->{role}) || 0;
-
+    my $vlan;
     $args->{'node_info'}{'source'} = $role->{'source'} if (defined($role->{'source'}) && $role->{'source'} ne '');
     $args->{'node_info'}{'portal'} = $role->{'portal'} if (defined($role->{'portal'}) && $role->{'portal'} ne '');
-
-    $args->{'vlan'} = $vlan;
+    $info{source} = $args->{node_info}{source};
+    $info{portal} = $args->{node_info}{portal};
     $args->{'wasInline'} = $role->{wasInline};
     $args->{'user_role'} = $role->{role};
 
+    my $filter = pf::access_filter::switch->new;
+    my $switch_params = $filter->filter('radius_authorize', $args);
+
+    if (defined($switch_params)) {
+        foreach my $key (keys %{$switch_params}) {
+            $switch->{$key} = $switch_params->{$key};
+        }
+    }
+
+    if (isenabled($switch->{_VlanMap})) {
+        $vlan = $switch->getVlanByName($role->{role}) if (isenabled($switch->{_VlanMap}));
+        $args->{'vlan'} = $vlan;
+        my $vlanpool = new pf::role::pool;
+        $vlan = $vlanpool->getVlanFromPool($args);
+    }
+    $vlan = $role->{vlan} || $vlan || 0;
+    $args->{'vlan'} = $vlan;
+
     #closes old locationlog entries and create a new one if required
     #TODO: Better deal with INLINE RADIUS
     $switch->synchronize_locationlog($port, $vlan, $mac,
-        $isPhone ? $VOIP : $NO_VOIP, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $args->{'user_role'}
-    ) if ( (!$role->{wasInline}) && ($vlan != -1) );
+        $args->{'isPhone'} ? $VOIP : $NO_VOIP, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $args->{'user_role'}, $ifDesc
+    ) if ( (!$role->{wasInline}) && ($vlan ne "-1") );
 
     # does the switch support Dynamic VLAN Assignment, bypass if using Inline
     if (!$switch->supportsRadiusDynamicVlanAssignment() && !$role->{wasInline}) {
         $logger->info(
             "Switch doesn't support Dynamic VLAN assignment. " .
-            "Setting VLAN with SNMP on (" . $switch->{_id} . ") ifIndex $port to $vlan"
+            "Setting VLAN with SNMP on ($switch_id) ifIndex $port to $vlan"
         );
         # WARNING: passing empty switch-lock for now
         # When the _setVlan of a switch who can't do RADIUS VLAN assignment uses the lock we will need to re-evaluate
@@ -260,29 +334,58 @@ sub authorize {
     $RAD_REPLY_REF = $switch->returnRadiusAccessAccept($args);
 
 CLEANUP:
+    if ($do_auto_reg) {
+        pf::registration::finalize_node_registration($node_obj, {}, $options, $pf::constants::realm::RADIUS_CONTEXT);
+    }
+    $status = $node_obj->save;
+    if (is_error($status)) {
+        $logger->error("Cannot save $mac error ($status)");
+    }
+
     # cleanup
     $switch->disconnectRead();
     $switch->disconnectWrite();
 
 AUDIT:
-
+    $args->{'time'} = time;
     push @$RAD_REPLY_REF, $self->_addRadiusAudit($args);
     return $RAD_REPLY_REF;
 }
 
+=item normalize_username
+
+normalize username
+
+=cut
+
+sub normalize_username {
+    my ($username, $radius_request) = @_;
+    if (isdisabled($Config{radius_configuration}{normalize_radius_machine_auth_username})) {
+        return $username;
+    }
+    my $tls_username = $radius_request->{'TLS-Client-Cert-Common-Name'} // '';
+    if ($username eq $tls_username ) {
+       my $radius_username = $radius_request->{'User-Name'};
+       if ( "host/$tls_username" =~ /\Q$radius_username\E/i ) {
+            $username = $radius_username;
+       }
+    }
+    return $username;
+}
+
 =item accounting
 
 =cut
 
 sub accounting {
     my $timer = pf::StatsD::Timer->new();
-    my ($self, $radius_request) = @_;
+    my ($self, $radius_request, $headers) = @_;
     my $logger = $self->logger;
 
     my ( $switch_mac, $switch_ip, $source_ip, $stripped_user_name, $realm ) = $self->_parseRequest($radius_request);
 
     $logger->debug("instantiating switch");
-    my $switch = pf::SwitchFactory->instantiate( { switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $source_ip } );
+    my $switch = pf::SwitchFactory->instantiate( { switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $switch_ip }, {radius_request => $radius_request} );
 
     # is switch object correct?
     if ( !$switch ) {
@@ -292,15 +395,26 @@ sub accounting {
         return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Switch is not managed by PacketFence" ) ];
     }
 
-    my $isStop   = $radius_request->{'Acct-Status-Type'} eq 'Stop';
-    my $isUpdate = $radius_request->{'Acct-Status-Type'} eq 'Interim-Update';
+    $switch->setCurrentTenant();
+    my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
+
+    # update last_seen of MAC address as some activity from it has been seen
+    node_update_last_seen($mac);
+
+    my $isStart   = $radius_request->{'Acct-Status-Type'}  == $ACCOUNTING::START;
+    my $isStop   = $radius_request->{'Acct-Status-Type'}  == $ACCOUNTING::STOP;
+    my $isUpdate = $radius_request->{'Acct-Status-Type'}  == $ACCOUNTING::INTERIM_UPDATE;
+
+    my $connection = pf::Connection->new;
+    $connection->identifyType($nas_port_type, $eap_type, $mac, $user_name, $switch);
+    my $connection_type = $connection->attributesToBackwardCompatible;
+    my $connection_sub_type = $connection->subType;
+
+    if($isStart || $isUpdate){
+        pf::accounting->cache->set($mac, $radius_request);
+    }
 
     if ($isStop || $isUpdate) {
-        my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id) = $switch->parseRequest($radius_request);
-
-        my $connection = pf::Connection->new;
-        $connection->identifyType($nas_port_type, $eap_type, $mac, $user_name, $switch);
-        my $connection_type = $connection->attributesToBackwardCompatible;
 
         $port = $switch->getIfIndexByNasPortId($nas_port_id) || $self->_translateNasPortToIfIndex($connection_type, $switch, $port);
 
@@ -311,10 +425,13 @@ sub accounting {
 
         # On accounting stop/update, check the usage duration of the node
         if ($mac && $user_name) {
-            my $session_time = int $radius_request->{'Acct-Session-Time'};
-            if ($session_time > 0) {
+            my $session_time = int ($radius_request->{'Acct-Session-Time'} // 0);
+            my $output_octets = int ($radius_request->{'Acct-Output-Octets'} // 0);
+            my $input_octets = int ($radius_request->{'Acct-Input-Octets'} // 0);
+            if ($session_time > 0 || $input_octets > 0 || $output_octets > 0) {
                 my $node_attributes = node_attributes($mac);
-                if (defined $node_attributes->{'time_balance'}) {
+                my $apiclient = pf::client::getClient;
+                if (defined $node_attributes->{'time_balance'} && $session_time > 0) {
                     my $time_balance = $node_attributes->{'time_balance'} - $session_time;
                     $time_balance = 0 if ($time_balance < 0);
                     # Only update the node table on a Stop
@@ -326,13 +443,70 @@ sub accounting {
                     }
                     if ($time_balance == 0) {
                         # Trigger violation
-                        violation_trigger($mac, $ACCOUNTING_POLICY_TIME, $TRIGGER_TYPE_ACCOUNTING);
+                        my %violation_data = (
+                            'mac'   => $mac,
+                            'tid'   => $ACCOUNTING_POLICY_TIME,
+                            'type'  => $TRIGGER_TYPE_ACCOUNTING ,
+                        );
+                        $apiclient->notify('trigger_violation', %violation_data );
+                    }
+                }
+                if (defined $node_attributes->{'bandwidth_balance'} && (  $input_octets > 0 || $output_octets > 0)) {
+                    my $total_octets = $output_octets + $input_octets;
+                    my $bandwidth_balance = $node_attributes->{'bandwidth_balance'} - $total_octets;
+                    $bandwidth_balance = 0 if ($bandwidth_balance < 0);
+                    if ($isStop && node_modify($mac, ('bandwidth_balance' => $bandwidth_balance))) {
+                        $logger->info("Session stopped: data was $total_octets octets ($bandwidth_balance octets left)");
+                    }
+                    elsif ($isUpdate) {
+                        $logger->info("Session status: data is $total_octets octets ($bandwidth_balance octets left)");
+                    }
+                    if ($bandwidth_balance == 0) {
+                        # Trigger violation
+                        my %violation_data = (
+                            'mac'   => $mac,
+                            'tid'   => $ACCOUNTING_POLICY_BANDWIDTH,
+                            'type'  => $TRIGGER_TYPE_ACCOUNTING ,
+                        );
+                        $apiclient->notify('trigger_violation', %violation_data );
                     }
                 }
             }
         }
     }
-
+    if(isenabled($Config{radius_configuration}{filter_in_packetfence_accounting})){
+        my %RAD_REPLY_REF;
+        my $node_obj = node_attributes($mac);
+        my $ssid;
+        if (($connection_type & $WIRELESS) == $WIRELESS) {
+            $ssid = $switch->extractSsid($radius_request);
+        }
+        my $args = {
+            switch => $switch,
+            switch_mac => $switch_mac,
+            switch_ip => $switch_ip,
+            source_ip => $source_ip,
+            stripped_user_name => $stripped_user_name,
+            realm => $realm,
+            nas_port_type => $nas_port_type,
+            eap_type => $eap_type // '',
+            mac => $mac,
+            ifIndex => $port,
+            ifDesc => $ifDesc,
+            user_name => $user_name,
+            nas_port_id => $nas_port_type // '',
+            session_id => $session_id,
+            connection_type => $connection_type,
+            connection_sub_type => $connection_sub_type,
+            radius_request => $radius_request,
+            ssid => $ssid,
+            node_info => $node_obj
+        };
+        my $filter = pf::access_filter::radius->new;
+        my $rule = $filter->test($headers->{'X-FreeRADIUS-Server'}.".".$headers->{'X-FreeRADIUS-Section'}, $args);
+        my ($reply, $status) = $filter->handleAnswerInRule($rule,$args,\%RAD_REPLY_REF);
+        return [$status, %$reply];
+    }
     return [ $RADIUS::RLM_MODULE_OK, ('Reply-Message' => "Accounting ok") ];
 }
 
@@ -343,14 +517,14 @@ Update the location log based on the accounting information
 =cut
 
 sub update_locationlog_accounting {
-    my $timer = pf::StatsD::Timer->new({sample_rate => 0.05 });
+    my $timer = pf::StatsD::Timer->new({ sample_rate => 0.05, level => 6 });
     my ($self, $radius_request) = @_;
     my $logger = $self->logger;
 
     my ( $switch_mac, $switch_ip, $source_ip, $stripped_user_name, $realm ) = $self->_parseRequest($radius_request);
 
     $logger->debug("instantiating switch");
-    my $switch = pf::SwitchFactory->instantiate( { switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $source_ip } );
+    my $switch = pf::SwitchFactory->instantiate( { switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $switch_ip }, {radius_request => $radius_request} );
 
     # is switch object correct?
     if ( !$switch ) {
@@ -360,23 +534,26 @@ sub update_locationlog_accounting {
         return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Switch is not managed by PacketFence" ) ];
     }
 
+    $switch->setCurrentTenant();
     if ($switch->supportsRoamingAccounting()) {
-        my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id) = $switch->parseRequest($radius_request);
-        my $connection = pf::Connection->new;
-        $connection->identifyType($nas_port_type, $eap_type, $mac, $user_name, $switch);
-        my $connection_type = $connection->attributesToBackwardCompatible;
-        my $connection_sub_type = $connection->subType;
-        my $ssid;
-        if (($connection_type & $WIRELESS) == $WIRELESS) {
-            $ssid = $switch->extractSsid($radius_request);
-            $logger->debug("SSID resolved to: $ssid") if (defined($ssid));
+        my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
+        my $locationlog_mac = locationlog_last_entry_mac($mac);
+        if (defined($locationlog_mac) && ref($locationlog_mac) eq 'HASH') {
+            my $connection_type = str_to_connection_type($locationlog_mac->{connection_type});
+            my $connection_sub_type = $locationlog_mac->{connection_sub_type};
+            my $ssid;
+            if (($connection_type & $WIRELESS) == $WIRELESS) {
+                $ssid = $switch->extractSsid($radius_request);
+                $logger->debug("SSID resolved to: $ssid") if (defined($ssid));
+            }
+            my $vlan;
+            $vlan = $radius_request->{'Tunnel-Private-Group-ID'} if ( (defined( $radius_request->{'Tunnel-Type'}) && $radius_request->{'Tunnel-Type'} eq '13') && (defined($radius_request->{'Tunnel-Medium-Type'}) && $radius_request->{'Tunnel-Medium-Type'} eq '6') );
+            $port = $switch->getIfIndexByNasPortId($nas_port_id) || $self->_translateNasPortToIfIndex($connection_type, $switch, $port);
+            $switch->synchronize_locationlog($port, $vlan, $mac, undef, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $locationlog_mac->{role}, $ifDesc);
+            return [ $RADIUS::RLM_MODULE_OK, ('Reply-Message' => "Update locationlog from accounting ok") ];
         }
-        my $vlan;
-        $vlan = $radius_request->{'Tunnel-Private-Group-ID'} if ( (defined( $radius_request->{'Tunnel-Type'}) && $radius_request->{'Tunnel-Type'} eq '13') && (defined($radius_request->{'Tunnel-Medium-Type'}) && $radius_request->{'Tunnel-Medium-Type'} eq '6') );
-        my $node_info = node_attributes($mac);
-        $switch->synchronize_locationlog($port, $vlan, $mac, undef, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $node_info->{category});
     }
-    return [ $RADIUS::RLM_MODULE_OK, ('Reply-Message' => "Update locationlog from accounting ok") ];
+    return [ $RADIUS::RLM_MODULE_OK, ('Reply-Message' => "Did not update locationlog from the accounting") ];
 }
 
 =item * _parseRequest
@@ -390,6 +567,7 @@ Takes FreeRADIUS' RAD_REQUEST hash and process it to return
 
 sub _parseRequest {
     my ($self, $radius_request) = @_;
+    my $logger = get_logger();
     my $ap_mac = $self->extractApMacFromRadiusRequest($radius_request);
     # freeradius 2 provides the client IP in NAS-IP-Address not Client-IP-Address (non-standard freeradius1 attribute)
     my $networkdevice_ip = $radius_request->{'NAS-IP-Address'} || $radius_request->{'Client-IP-Address'};
@@ -400,7 +578,13 @@ sub _parseRequest {
     }
     my $realm;
     if (defined($radius_request->{'Realm'})) {
-        $realm = $radius_request->{'Realm'};
+        # Handling possible FreeRADIUS multiple realms
+        if ( ref($radius_request->{'Realm'}) eq 'ARRAY' ) {
+            $realm = $radius_request->{'Realm'}->[0];
+            $logger->info("RADIUS request contains more than one realm. Keeping the first one '$realm'");
+        } else {
+            $realm = $radius_request->{'Realm'};
+        }
     }
     return ($ap_mac, $networkdevice_ip, $source_ip, $stripped_user_name, $realm);
 }
@@ -424,76 +608,6 @@ sub extractApMacFromRadiusRequest {
     return;
 }
 
-=item * _doWeActOnThisCall
-
-Is this request of any interest?
-
-returns 0 for no, 1 for yes
-
-=cut
-
-sub _doWeActOnThisCall {
-    my ($self, $args) = @_;
-    my $logger = $self->logger;
-    $logger->trace("_doWeActOnThisCall called");
-
-    # lets assume we don't act
-    my $do_we_act = 0;
-
-    # TODO we could implement some way to know if the same request is being worked on and drop right here
-
-    # is it wired or wireless? call sub accordingly
-    if (defined($args->{'connection_type'})) {
-
-        if (($args->{'connection_type'} & $WIRELESS) == $WIRELESS) {
-            $do_we_act = $self->_doWeActOnThisCallWireless($args);
-
-        } elsif (($args->{'connection_type'} & $WIRED) == $WIRED) {
-            $do_we_act = $self->_doWeActOnThisCallWired($args);
-        } else {
-            $do_we_act = 0;
-        }
-
-    } else {
-        # we won't act on an unknown request type
-        $do_we_act = 0;
-    }
-    return $do_we_act;
-}
-
-=item * _doWeActOnThisCallWireless
-
-Is this wireless request of any interest?
-
-returns 0 for no, 1 for yes
-
-=cut
-
-sub _doWeActOnThisCallWireless {
-    my ($self, $args) = @_;
-    my $logger = $self->logger;
-    $logger->trace("_doWeActOnThisCallWireless called");
-
-    # for now we always act on wireless radius authorize
-    return 1;
-}
-
-=item * _doWeActOnThisCallWired - is this wired request of any interest?
-
-Pass all the info you can
-
-returns 0 for no, 1 for yes
-
-=cut
-
-sub _doWeActOnThisCallWired {
-    my ($self, $args) = @_;
-    my $logger = $self->logger;
-    $logger->trace("_doWeActOnThisCallWired called");
-
-    # for now we always act on wired radius authorize
-    return 1;
-}
 
 =item * _authorizeVoip - RADIUS authorization of VoIP
 
@@ -506,7 +620,7 @@ Returns the same structure as authorize(), see it's POD doc for details.
 =cut
 
 sub _authorizeVoip {
-    my $timer = pf::StatsD::Timer->new({sample_rate => 0.05 });
+    my $timer = pf::StatsD::Timer->new({ sample_rate => 0.05, level => 7 });
     my ($self, $args) = @_;
     my $logger = $self->logger;
 
@@ -519,12 +633,15 @@ sub _authorizeVoip {
             ('Reply-Message' => "Server reported: VoIP authorization over RADIUS not supported for this network device")
         ];
     }
-    $args->{'switch'}->synchronize_locationlog($args->{'ifIndex'}, $args->{'switch'}->getVlanByName('voice'), $args->{'mac'}, 1, $args->{'connection_type'}, $args->{'connection_sub_type'}, $args->{'user_name'}, $args->{'ssid'});
+    $args->{'switch'}->synchronize_locationlog($args->{'ifIndex'}, $args->{'switch'}->getVlanByName($VOICE_ROLE), $args->{'mac'}, $VOIP, $args->{'connection_type'}, $args->{'connection_sub_type'}, $args->{'user_name'}, $args->{'ssid'}, undef, undef, $VOICE_ROLE, $args->{ifDesc});
 
     my %RAD_REPLY = $args->{'switch'}->getVoipVsa();
     $args->{'switch'}->disconnectRead();
     $args->{'switch'}->disconnectWrite();
-    return [$RADIUS::RLM_MODULE_OK, %RAD_REPLY];
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test('returnAuthorizeVoip', $args);
+    my ($reply, $status) = $filter->handleAnswerInRule($rule,$args,\%RAD_REPLY);
+    return [$status, %$reply];
 }
 
 =item * _translateNasPortToIfIndex - convert the number in NAS-Port into an ifIndex only when relevant
@@ -585,7 +702,7 @@ sub _switchUnsupportedReply {
 }
 
 sub _handleStaticPortSecurityMovement {
-    my $timer = pf::StatsD::Timer->new;
+    my $timer = pf::StatsD::Timer->new({level => 7});
     my ($self,$args) = @_;
     my $logger = $self->logger;
     #determine if $mac is authorized elsewhere
@@ -601,7 +718,7 @@ sub _handleStaticPortSecurityMovement {
         return undef;
     }
 
-    my $oldSwitch = pf::SwitchFactory->instantiate($old_switch_id);
+    my $oldSwitch = pf::SwitchFactory->instantiate($old_switch_id, {radius_request => $args->{radius_request}});
     if (!$oldSwitch) {
         $logger->error("Can not instantiate switch $old_switch_id !");
         return;
@@ -645,7 +762,7 @@ sub _handleAccessFloatingDevices{
     my $logger = $self->logger;
     if( exists( $ConfigFloatingDevices{$args->{'mac'}} ) ){
         my $floatingDeviceManager = new pf::floatingdevice::custom();
-        $floatingDeviceManager->enableMABFloating($args->{'mac'}, $args->{'switch'}, $args->{'port'});
+        $floatingDeviceManager->enableMABFloating($args->{'mac'}, $args->{'switch'}, $args->{'ifIndex'});
     }
 }
 
@@ -701,7 +818,7 @@ sub switch_access {
     my($switch_mac, $switch_ip,$source_ip,$stripped_user_name,$realm) = $self->_parseRequest($radius_request);
 
     $logger->debug("instantiating switch");
-    my $switch = pf::SwitchFactory->instantiate({ switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $source_ip});
+    my $switch = pf::SwitchFactory->instantiate({ switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $switch_ip}, {radius_request => $radius_request});
 
     # is switch object correct?
     if (!$switch) {
@@ -725,9 +842,15 @@ sub switch_access {
         radius_request => $radius_request,
     };
 
-    my ( $return, $message, $source_id ) = pf::authentication::authenticate( { 'username' =>  $radius_request->{'User-Name'}, 'password' =>  $radius_request->{'User-Password'}, 'rule_class' => $Rules::ADMIN }, @{pf::authentication::getInternalAuthenticationSources()} );
+    my ( $return, $message, $source_id, $extra ) = pf::authentication::authenticate( { 
+            'username' =>  $radius_request->{'User-Name'}, 
+            'password' =>  $radius_request->{'User-Password'}, 
+            'rule_class' => $Rules::ADMIN,
+            'context' => $pf::constants::realm::RADIUS_CONTEXT,
+        }, @{pf::authentication::getInternalAuthenticationSources()} );
     if ( defined($return) && $return == $TRUE ) {
-        my $value = &pf::authentication::match($source_id, { username => $radius_request->{'User-Name'}, 'rule_class' => $Rules::ADMIN }, $Actions::SET_ACCESS_LEVEL);
+        my $matched = pf::authentication::match2($source_id, { username => $radius_request->{'User-Name'}, 'rule_class' => $Rules::ADMIN, 'context' => $pf::constants::realm::RADIUS_CONTEXT }, $extra);
+        my $value = $matched->{values}{$Actions::SET_ACCESS_LEVEL} if $matched;
         if ($value) {
             my @values = split(',', $value);
             foreach $value (@values) {
@@ -758,6 +881,7 @@ our %ARGS_TO_RADIUS_ATTRIBUTES = (
     eap_type => 'PacketFence-Eap-Type',
     connection_type => 'PacketFence-Connection-Type',
     user_role => 'PacketFence-Role',
+    time => 'PacketFence-Request-Time',
 );
 
 our %NODE_ATTRIBUTES_TO_RADIUS_ATTRIBUTES = (
@@ -802,6 +926,111 @@ sub _update_audit_stash {
     }
 }
 
+=item handleNtlmCaching
+
+Handle NTLM caching if necessary
+
+=cut
+
+sub handleNtlmCaching {
+    my ($self, $radius_request) = @_;
+    my $domain = $radius_request->{"PacketFence-Domain"};
+    if($domain && isenabled($ConfigDomain{$domain}{ntlm_cache}) && isenabled($ConfigDomain{$domain}{ntlm_cache_on_connection})) {
+        my $client = pf::api::queue->new(queue => "general");
+        $client->notify("cache_user_ntlm", $domain, $radius_request->{"Stripped-User-Name"});
+    }
+}
+
+=head2 checkConnectionTypeChange
+
+Detect if a device has changed its transport type (wired vs wireless) since a MAC shouldn't switch from one to another
+
+=cut
+
+sub handleConnectionTypeChange {
+    my ($self, $mac, $current_connection) = @_;
+    if (isenabled($Config{network}{connection_type_change_detection})) {
+        my $client = pf::api::queue->new(queue => "general");
+        $client->notify("detect_connection_type_transport_change", $mac, $current_connection);
+    }
+}
+
+=head2 radius_proxy
+
+Handle radius proxy request (pre-proxy and post-proxy)
+
+=cut
+
+sub radius_filter {
+    my ($self, $scope, $radius_request) = @_;
+    my $logger = $self->logger;
+    my ($do_auto_reg, %autoreg_node_defaults);
+    my($switch_mac, $switch_ip,$source_ip,$stripped_user_name,$realm) = $self->_parseRequest($radius_request);
+    my %RAD_REPLY_REF;
+
+    $logger->debug("instantiating switch");
+    my $switch = pf::SwitchFactory->instantiate({ switch_mac => $switch_mac, switch_ip => $switch_ip, controllerIp => $switch_ip}, {radius_request => $radius_request});
+
+    # is switch object correct?
+    if (!$switch) {
+        $logger->warn(
+            "Can't instantiate switch ($switch_ip). This request will be failed. "
+            ."Are you sure your switches.conf is correct?"
+        );
+        return [ $RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "Switch is not managed by PacketFence") ];
+    }
+
+    $switch->setCurrentTenant();
+    my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
+
+    $user_name = normalize_username($user_name, $radius_request);
+
+    if (!$mac) {
+        return [$RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "Mac is empty")];
+    }
+    Log::Log4perl::MDC->put( 'mac', $mac );
+    my ($status_code, $node_obj) = pf::dal::node->find_or_create({"mac" => $mac});
+    if (is_error($status_code)) {
+        $node_obj = pf::dal::node->new({"mac" => $mac});
+    }
+    my $connection = pf::Connection->new;
+    $connection->identifyType($nas_port_type, $eap_type, $mac, $user_name, $switch);
+    my $connection_type = $connection->attributesToBackwardCompatible;
+    my $connection_sub_type = $connection->subType;
+    # switch-specific information retrieval
+    my $ssid;
+    if (($connection_type & $WIRELESS) == $WIRELESS) {
+        $ssid = $switch->extractSsid($radius_request);
+        $logger->debug("SSID resolved to: $ssid") if (defined($ssid));
+    }
+    my $args = {
+        switch => $switch,
+        switch_mac => $switch_mac,
+        switch_ip => $switch_ip,
+        source_ip => $source_ip,
+        stripped_user_name => $stripped_user_name,
+        realm => $realm,
+        nas_port_type => $nas_port_type,
+        eap_type => $eap_type // '',
+        mac => $mac,
+        ifIndex => $port,
+        ifDesc => $ifDesc,
+        user_name => $user_name,
+        nas_port_id => $nas_port_type // '',
+        session_id => $session_id,
+        connection_type => $connection_type,
+        connection_sub_type => $connection_sub_type,
+        radius_request => $radius_request,
+        ssid => $ssid,
+        node_info => $node_obj
+
+    };
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test($scope, $args);
+    my ($reply, $status) = $filter->handleAnswerInRule($rule,$args,\%RAD_REPLY_REF);
+    return [$status, %$reply];
+}
+
 =back
 
 =head1 AUTHOR
@@ -810,7 +1039,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
