@@ -19,7 +19,7 @@ use WWW::Curl::Easy;
 use Data::MessagePack;
 
 use base qw(Exporter);
-our @EXPORT = qw(send_rpc_request build_msgpack_request);
+our @EXPORT = qw(send_rpc_request build_msgpack_request send_msgpack_notification);
 
 # Configuration parameter
 use constant SOAP_PORT => '7070'; #TODO: See note1
@@ -119,7 +119,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
