@@ -59,6 +59,8 @@ sub new {
             '_policy'   => undef,
             '_type'     => undef,
             '_status'   => undef,
+            '_oses'     => undef,
+            '_categories' => undef,
     }, $class;
 
     foreach my $value ( keys %data ) {
@@ -92,7 +94,7 @@ sub startScan {
     my $polid = $n->policy_get_id($nessus_clientpolicy);
     if ($polid eq "") {
         $logger->warn("Nessus policy doesnt exist ".$nessus_clientpolicy);
-        return 1;
+        return 0;
     }
     my $scanname = "pf-".$hostaddr."-".$nessus_clientpolicy;
     my $scanid = $n->scan_new($polid, $scanname, $hostaddr);
@@ -114,7 +116,7 @@ sub startScan {
     while (not $n->scan_finished($scanid)) {
         if ($counter > 3600) {
             $logger->info("Nessus scan is older than 1 hour ...");
-            return 1;
+            return 0;
         }
         $logger->info("Nessus is scanning $hostaddr");
         sleep 15;
@@ -140,7 +142,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
