@@ -15,7 +15,7 @@ pf::scan::wmi::rules deny or allow based on rules.
 use strict;
 use warnings;
 
-use pf::config;
+use pf::constants;
 use pf::log;
 use Net::WMIClient qw(wmiclient);
 use Config::IniFiles;
@@ -59,7 +59,10 @@ sub test {
     foreach my $rule  ( @rules ) {
         my $rule_config = $pf::config::ConfigWmi{$rule};
         my ($rc, $result) = $self->runWmi($rules,$rule_config);
-        return $rc if (!$rc);
+        if(!$rc) {
+            $logger->error("Error rule wmi rule '$rule': $result");
+            return $rc;
+        }
         $success = $rc;
         my $action = $rule_config->{'action'};
         my %cfg;
@@ -96,9 +99,13 @@ sub runWmi {
     $request->{'Username'} = $rules->{'_domain'} .'/'. $rules->{'_username'} .'%'. $rules->{'_password'};
     $request->{'Host'} = $rules->{'_scanIp'};
     $request->{'Query'} = $rule->{'request'};
+    $request->{'Namespace'} = $rule->{'namespace'};
+    $request->{'NameSpace'} = $rule->{'namespace'}; #this is to fix an issue in the lib WMIClient
     my ($rc, $ret_string) = wmiclient($request);
-    return ($rc,$self->parseResult($ret_string));
-
+    if ($rc) {
+        return ($rc, $self->parseResult($ret_string));
+    }
+    return ($rc, $ret_string);
 }
 
 =item parseResult
@@ -109,29 +116,25 @@ Parse the result of the wmicli
 
 sub parseResult {
     my ($self, $string) = @_;
+    my $logger = $self->logger;
+    if (!defined ($string)) {
+        $logger->warn("uninitialized response given");
+        return [];
+    }
+    $logger->trace( sub { "The WMI string to parse '$string' " });
     $string =~ s/\r\n/\n/g;
 
-    my @answer = split('\n', $string);
-    my $i = 0;
-    my $line;
+    my ($class, $header, @answers) = split('\n', $string);
+    if (!defined ($header)) {
+        $logger->error("No WMI header given in string '$string'");
+        return [];
+    }
+    my @entries = split(/\|/, $header);
     my @result;
-
-    my $response = {};
-
-    shift @answer;
-    my @entries = split(/\|/,shift @answer);
-
-
-    foreach $line (@answer) {
-        my @values = split(/\|/,$line);
-        my $j = 0;
-        foreach my $elements (@entries) {
-            $response->{"$elements"} = $values[$j];
-            $j++;
-        }
-        $result[$i] = $response;
-        undef $response;
-        $i++;
+    foreach my $answer (@answers) {
+        my %response;
+        @response{@entries} = split(/\|/,$answer);
+        push @result, \%response;
     }
     return \@result;
 }
@@ -224,7 +227,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
