@@ -28,20 +28,19 @@ An example of a new service foo
     has '+launcher' => (default => sub { '%1$s -d' } );
 
 
-To include the new service in pfcmd service
-
-* Add service name to the service regex in pf::pfcmd
-
-* Update the help in pf::pfcmd::help
-
 =cut
 
 use strict;
 
-use pf::file_paths;
+use Moo;
+use pf::constants;
+use pf::file_paths qw($var_dir $install_dir $systemd_unit_dir);
 use pf::log;
 use pf::util;
-use Moo;
+use pf::util::console;
+
+use Term::ANSIColor;
+
 use File::Slurp qw(read_file);
 use Proc::ProcessTable;
 use List::Util qw(first);
@@ -71,39 +70,15 @@ has shouldCheckup => ( is => 'rw', default => sub { 1 } );
 
 =head2 launcher
 
-sprintf-formatted string that control how the services should be started
-  %1$s: is the service executable
-  %2$s: optional parameters
+Method that launches the service.
 
 =cut
 
-has launcher => ( is => 'rw', lazy => 1);
+has launcher => ( is => 'rw', lazy => 1, builder => '_build_launcher' );
 
-=head2 dependsOnServices
+has pidFile => ( is => 'ro', lazy => 1, builder => '_buildpidFile' );
 
-services that this service needs in order to start
-
-=cut
-
-has dependsOnServices => (is => 'ro', default => sub { [qw( httpd.admin)] } );
-
-=head2 orderIndex
-
-Value to use when sorting services for the start or stop order.
-Lower values start first and are stopped last.
-
-=cut
-
-has orderIndex => ( is => 'ro', builder => 1, lazy => 1 );
-
-sub _build_orderIndex { 
-    my ($self) = @_;
-    require pf::config;
-    my $name = $self->name;
-    $name =~ s/\./_/g ; 
-    my $index = $pf::config::Config{'services'}{"${name}_order"} // 100 ;
-    return $index;
-}
+sub _buildpidFile { my $self = shift; return $var_dir . "/run/" . $self->name . ".pid"; }
 
 =head2 executable
 
@@ -113,22 +88,6 @@ executable of service
 
 has executable => (is => 'rw', builder => 1, lazy => 1 );
 
-=head2 lastPid
-
-The last pid retrived from the pidFile
-
-=cut
-
-has lastPid => (is => 'rw');
-
-=head2 inotify
-
-The inotify object used to watch for pidfile
-
-=cut
-
-has inotify => (is => 'rw', builder => 1, lazy => 1 );
-
 =head2 isvirtual
 
 If the service is a virtual service
@@ -153,19 +112,11 @@ If set then the service will not cause an error if it fails to start
 
 has optional => ( is => 'rw', default => sub { 0 } );
 
+
 =head1 Methods
 
-=head2 _build_inotify
-
-builds the inotify object
-
 =cut
 
-sub _build_inotify {
-    my $inotify = Linux::Inotify2->new or die "unable to setup inotify object $!";
-    return $inotify;
-}
-
 =head2 start
 
 start the service
@@ -187,15 +138,15 @@ sub start {
 
 =head2 preStartSetup
 
-work for starting a servicw
+Stub. Implement as needed in subclasses.
 
 =cut
 
 sub preStartSetup {
-    my ($self,$quick) = @_;
-    $self->removeStalePid($quick);
-    $self->generateConfig($quick) unless $quick;
-    $self->_setupWatchForPidCreate;
+    my ( $self, $quick ) = @_;
+    unless ( $self->isEnabled ) {
+        $self->sysdEnable();
+    }
     return 1;
 }
 
@@ -212,59 +163,34 @@ sub startService {
 
 =head2 postStartCleanup
 
-Cleanup work after the starting the service
+Stub method to be implemented in services if needed.
 
 =cut
 
 sub postStartCleanup {
     my ($self,$quick) = @_;
-    my $pidFile = $self->pidFile;
-    $pidFile = untaint_chain($pidFile);
-    my $result = 0;
-    my $inotify = $self->inotify;
-    unless (-e $pidFile) {
-        my $timedout;
-        eval {
-            local $SIG{ALRM} = sub { die "alarm clock restart" };
-            alarm 60;
-            eval {
-                 1 while $inotify->poll && !-e $pidFile;
-            };
-            alarm 0;
-            $timedout = 1 if $@ && $@ =~ /^alarm clock restart/;
-        };
-        alarm 0;
-        my $logger = get_logger();
-        $logger->warn($self->name . " timed out trying to start" ) if $timedout;
+    my $logger = get_logger();
+    unless ($self->pid) { 
+        $logger->error("$self->name died or has failed to start");
+        return $FALSE;
     }
-    return -e $pidFile;
+    return $TRUE;
 }
 
 
-=head2 _setupWatchForPidCreate
+=head2 _build_launcher
 
-This setups a watch on the run directory to wait for the pid to
+Build the command to lauch the service.
 
-=cut
-
-sub _setupWatchForPidCreate {
+=cut 
+sub _build_launcher {
     my ($self) = @_;
-    my $inotify = $self->inotify;
-    my $pidFile = $self->pidFile;
-    my $run_dir = "$var_dir/run";
-    $inotify->watch ($run_dir, IN_CREATE, sub {
-        my $e = shift;
-        my $name = $e->fullname;
-        if($pidFile eq $name) {
-             $e->w->cancel;
-        }
-    });
+    my $name = $self->{name};
+    return "sudo systemctl start packetfence-" . $name;
 }
 
 =head2 _build_executable
-
 the builder the executable attribute
-
 =cut
 
 sub _build_executable {
@@ -289,17 +215,53 @@ sub restart {
 
 =head2 status
 
-returns the pid or list of pids for the servie(s)
+returns the pid or list of pids for the service(s)
 
 =cut
 
 sub status {
     my ($self,$quick) = @_;
-    $self->removeStalePid($quick);
     my $pid = $self->pid;
     return $pid ? $pid : "0";
 }
 
+
+sub print_status {
+    my ($self) = @_;
+    my @output = `systemctl --all --no-pager`;
+    my $header = shift @output;
+    my $name   = $self->name;
+    my $colors = pf::util::console::colors();
+    my $loop = $TRUE;
+    for my $output (@output) {
+        if ($output =~ /(packetfence-$name\.service)\s+loaded\s+active/) {
+            my $service = $1;
+            $service .= (" " x (50 - length($service)));
+            print "$service\t$colors->{success}started   ".$self->pid."$colors->{reset}\n";
+            $loop = $FALSE;
+        } elsif ($output =~ /(packetfence-$name\.service)\s+loaded.*/) {
+            my $service = $1;
+            if ($name =~ /(radiusd).*/) {
+                $name = $1;
+            }
+            my $manager = pf::services::get_service_manager($name);
+            my $isManaged = $manager->isManaged;
+            $service .= (" " x (50 - length($service)));
+            if ($isManaged && !$manager->optional) {
+                print "$service\t$colors->{error}stopped   ".$self->pid."$colors->{reset}\n";
+            } else {
+                print "$service\t$colors->{warning}stopped   ".$self->pid."$colors->{reset}\n";
+            }
+            $loop = $FALSE;
+        }
+    }
+    if ($loop) {
+       my $service = "packetfence-$name.service";
+       $service .= (" " x (50 - length($service)));
+       print "$service\t$colors->{warning}disabled  ".$self->pid."$colors->{reset}\n";
+    }
+}
+
 =head2 pid
 
 Returns the pid of the service
@@ -308,20 +270,29 @@ Returns the pid of the service
 
 sub pid {
     my ($self) = @_;
-    $self->lastPid($self->pidFromFile);
-    return $self->lastPid;
+    my $logger = get_logger();
+    my $name = $self->{name};
+    my $pid = `sudo systemctl show -p MainPID packetfence-$name`;
+    chomp $pid;
+    $pid = (split(/=/, $pid))[1];
+    if (defined $pid) {
+        $logger->debug("sudo systemctl packetfence-$name returned $pid");
+    } else {
+        $logger->error("Error getting pid for $name");
+    }
+    return $pid;
 }
 
 =head2 stop
 
-Stop the service waitinf for it to shutdown
+Stop the service waiting for it to shutdown
 
 =cut
 
 sub stop {
     my ($self,$quick) = @_;
-    my $pid = $self->pid;
-    if ($pid) {
+    my @pids = $self->pid;
+    if (@pids) {
         $self->preStopSetup($quick);
         $self->stopService($quick);
         $self->postStopCleanup($quick);
@@ -333,13 +304,14 @@ sub stop {
 
 =head2 preStopSetup
 
-the pre stop setup
+Stub. Implement in subclasses if needed.
 
 =cut
 
 sub preStopSetup {
     my ($self) = @_;
-    $self->inotify->watch($self->pidFile, IN_DELETE_SELF);
+    return 1;
+    
 }
 
 =head2 stopService
@@ -350,65 +322,37 @@ sub stopService {
     my ($self) = @_;
     my $name = $self->name;
     my $logger = get_logger();
-    my $pid = $self->lastPid;
-    $logger->info("Sending TERM signal to $name with pid $pid");
-    my $count = kill 'TERM',$pid;
+    my $pid    = $self->pid;
+    $logger->info("Stopping $name with pid $pid");
+    `sudo systemctl stop packetfence-$name`;
+    if ( $? == -1 ) {
+        $logger->error("failed to execute: $!\n");
+    }
+    elsif ( $? & 127 ) {
+        $logger->error(sprintf("child died with signal %d, %s coredump\n", 
+                ( $? & 127 ), 
+                (( $? & 128 ) ? 'with' : 'without')));
+    }
+    else {
+        $logger->info(sprintf("child exited with value %d\n", $? >> 8));
+    }
 }
 
 =head2 postStopCleanup
 
+Checks to see if the process is still running.
+Override in subclasses to perform additonal cleanup actions.
+
 =cut
 
 sub postStopCleanup {
     my ($self,$quick) = @_;
     my $logger = get_logger();
-    my $name = $self->name;
-    my $pid = $self->lastPid;
-    my $inotify = $self->inotify;
-    my $pidFile = $self->pidFile;
-    my $timedout;
-    #give the kill a little time
-    $inotify->blocking(0);
-    $self->removeStalePid($quick);
-    my $timer = Linux::FD::Timer->new('monotonic');
-    $timer->set_timeout(0.1,0.1);
-    $timer->receive;
-    eval {
-        local $SIG{ALRM} = sub { die "alarm clock restart" };
-        alarm 60;
-        eval {
-            until($inotify->read) {
-                die $! if defined $! && $! != EINTR && $! != EAGAIN;
-                $self->removeStalePid;
-                #give it some time
-                $timer->receive;
-            }
-        };
-        alarm 0;
-        $timedout = 1 if $@ && $@ =~ /^alarm clock restart/;
-        $logger->error("Error: $@") if $@;
-    };
-    alarm 0;
-    $logger->info("Timed out waiting for process $name to stop") if $timedout;
-    if ($self->isAlive($pid)) {
-        kill 'KILL',$pid;
+    if ($self->pid) { 
+        $logger->error("$self->name failed to stop");
+        return $FALSE;
     }
-    $self->removeStalePid;
-}
-
-=head2 watch
-
-If the service is stopped start the service
-
-=cut
-
-sub watch {
-    my ($self) = @_;
-    $self->removeStalePid;
-    unless($self->pid) {
-        return $self->start(1);
-    }
-    return;
+    return $TRUE;
 }
 
 =head2 generateConfig
@@ -421,13 +365,13 @@ sub generateConfig { 1 }
 
 =head2 launchService
 
-launch the service using the launcher and arguements passed
+launch the service using the launcher and arguments passed
 
 =cut
 
 sub launchService {
     my ($self) = @_;
-    my $cmdLine = $self->_cmdLine;
+    my $cmdLine = $self->launcher;
     if ($cmdLine =~ /^(.+)$/) {
         $cmdLine = $1;
         my $logger = get_logger();
@@ -443,93 +387,28 @@ sub launchService {
 
 =head2 _cmdLine
 
-TODO: documention
+Build the command string from the launcher and the cmdLineArgs
 
 =cut
 
 sub _cmdLine {
     my ($self) = @_;
-    my $launcher = $self->launcher;
-    $launcher =~ /^(.*)$/;
-    $launcher = $1;
-    my @cmdLineArgs = map { /^(.*)$/;$1 }  $self->_cmdLineArgs;
-    my $cmdLine = sprintf($launcher, map { /^(.*)$/;$1 }  @cmdLineArgs);
-    return $cmdLine;
+    return $self->executable;
 }
 
 
 =head2 _cmdLineArgs
 
-TODO: documention
+Return the list if values to replace in the launcher
 
 =cut
 
 sub _cmdLineArgs {
     my ($self) = @_;
-    return ($self->executable);
+    return undef;
 }
 
 
-=head2 pidFile
-
-return the pid file of the service
-
-=cut
-
-sub pidFile {
-    my ($self) = @_;
-    my $name = $self->name;
-    return "$var_dir/run/$name.pid";
-}
-
-=head2 pidFromFile
-
-get the pid from the pid file
-
-=cut
-
-sub pidFromFile {
-    my ($self) = @_;
-    my $name = $self->name;
-    my $logger = get_logger();
-    my $pid;
-    my $pid_file = $self->pidFile;
-    if (-e $pid_file) {
-        eval {chomp( $pid = read_file($pid_file) );};
-    }
-    $pid = 0 unless $pid;
-    if($pid) {
-        $logger->info("pidof -x $name returned $pid");
-        if($pid =~ /^\s*(\d*)\s*$/) {
-            $pid = $1;
-        }
-    }
-    return $pid;
-}
-
-=head2 removeStalePid
-
-removes the stale PID file
-
-=cut
-
-sub removeStalePid {
-    my ($self,$quick) = @_;
-    return if $quick;
-    my $logger = get_logger();
-    my $pid = $self->pidFromFile;
-    my $pidFile = $self->pidFile;
-    $pidFile = untaint_chain($pidFile);
-    if($pid && $pid =~ /^(.*)$/) {
-        $pid = $1;
-        $logger->info("verifying process $pid");
-        my $result = $self->isAlive;
-        unless ($result) {
-            $logger->info("removing stale pid file $pidFile");
-            unlink $pidFile if -e $pidFile;
-        }
-    }
-}
 
 =head2 isAlive
 
@@ -538,14 +417,17 @@ checks if process is alive
 =cut
 
 sub isAlive {
-    my ($self,$pid) = @_;
-    my $result;
-    $pid = $self->pid unless defined $pid;
-    $result = kill 0 , $pid if $pid;
-    return $result;
+    my ($self) = @_;
+    my $logger = get_logger();
+    my $name = $self->{name};
+    my $res = system("sudo systemctl status packetfence-$name");
+    my $alive = $res == 0;
+    $logger->debug("sudo systemctl status packetfence-$name returned code $res");
+    return $alive;
 }
 
 
+
 =head2 isManaged
 
 return true is the service is currently managed by packetfence
@@ -557,9 +439,62 @@ sub isManaged {
     require pf::config;
     my $name = $self->name;
     $name =~ s/\./_/g;
-    return $self->forceManaged || isenabled($pf::config::Config{'services'}{$name});
+    return $self->forceManaged
+      || isenabled( $pf::config::Config{'services'}{$name} );
 }
 
+=head2 isEnabled
+
+Return true if systemd consider the service as enabled
+
+=cut 
+
+sub isEnabled {
+    my ($self) = @_;
+    my $name   = $self->name;
+    my $state  = `sudo systemctl show -p UnitFileState packetfence-$name`;
+    chomp $state;
+    $state = ( split( /=/, $state ) )[1];
+    if ( defined $state and $state eq "enabled" ) {
+        return $TRUE;
+    }
+    else {
+        return $FALSE;
+    }
+}
+
+=head2 systemdTarget
+
+systemdTarget
+
+=cut
+
+sub systemdTarget {
+    my ($self) = @_;
+    return "packetfence-" . $self->name;
+}
+
+=head2 sysdEnable 
+
+Enable the service in systemd.
+
+=cut
+
+sub sysdEnable {
+    my $self = shift;
+    return system( "sudo systemctl enable " . $self->systemdTarget) == 0;
+}
+
+=head2 sysdDisable
+
+Disable the service in systemd.
+
+=cut
+
+sub sysdDisable {
+    my $self = shift;
+    return system( "sudo systemctl disable " . $self->systemdTarget) == 0;
+}
 
 =head1 AUTHOR
 
@@ -568,7 +503,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -590,4 +525,3 @@ USA.
 =cut
 
 1;
-
