@@ -1,4 +1,5 @@
 package pf::services::manager::httpd_aaa;
+
 =head1 NAME
 
 pf::services::manager::httpd_aaa
@@ -14,10 +15,18 @@ pf::services::manager::httpd_aaa
 use strict;
 use warnings;
 use Moo;
+use pf::config qw(%Config $OS);
+use pf::file_paths qw(
+    $install_dir
+);
 
-extends 'pf::services::manager::httpd';
+extends 'pf::services::manager::httpd_webservices';
 
-has '+name' => (default => sub { 'httpd.aaa' } );
+has '+name' => ( default => sub {'httpd.aaa'} );
+
+sub port {
+    return $Config{ports}{aaa};
+}
 
 
 =head1 AUTHOR
@@ -27,7 +36,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -49,4 +58,3 @@ USA.
 =cut
 
 1;
-
