@@ -1,4 +1,5 @@
 package pf::services::manager::httpd_proxy;
+
 =head1 NAME
 
 pf::services::manager::httpd_proxy add documentation
@@ -14,7 +15,7 @@ pf::services::manager::httpd_proxy
 use strict;
 use warnings;
 use Moo;
-use pf::config;
+use pf::config qw(%Config @internal_nets);
 use pf::util;
 
 extends 'pf::services::manager::httpd';
@@ -23,7 +24,23 @@ has '+name' => (default => sub { 'httpd.proxy' } );
 
 sub isManaged {
     my ($self) = @_;
-    return  isenabled($Config{'trapping'}{'interception_proxy'}) && $self->SUPER::isManaged();
+    return  isenabled($Config{'fencing'}{'interception_proxy'}) && $self->SUPER::isManaged();
+}
+
+sub additionalVars {
+    my ($self) = @_;
+    my %vars = (
+        proxy_ports => [split(/ *, */,$Config{'fencing'}{'interception_proxy_port'})],
+    );
+    return %vars;
+}
+
+sub port { 444 }
+
+sub vhosts {
+    return [map {
+        (defined $_->{Tvip} && $_->{Tvip} ne '') ?  $_->{Tvip} : $_->{Tip}
+    } @internal_nets];
 }
 
 =head1 AUTHOR
@@ -33,7 +50,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -55,4 +72,3 @@ USA.
 =cut
 
 1;
-
