@@ -1,4 +1,5 @@
 package pf::services::manager::iptables;
+
 =head1 NAME
 
 pf::services::manager::iptables add documentation
@@ -14,10 +15,11 @@ pf::services::manager::iptables
 use strict;
 use warnings;
 use Moo;
-use pf::file_paths;
-use pf::config;
+use pf::file_paths qw($install_dir);
 use pf::log;
 use pf::util;
+use pf::iptables;
+use pf::config qw(%Config);
 
 extends 'pf::services::manager';
 
@@ -25,10 +27,6 @@ has '+name' => (default => sub { 'iptables' } );
 
 has '+shouldCheckup' => ( default => sub { 1 }  );
 
-has '+launcher' => ( default => sub {"iptables"} );
-
-has '+dependsOnServices' => (is => 'ro', default => sub { [] } );
-
 has 'runningServices' => (is => 'rw', default => sub { 0 } );
 
 
@@ -41,15 +39,12 @@ start iptables
 sub startService {
     my ($self) = @_;
     my $technique;
-    unless ($self->runningServices) {
+    unless ($self->isAlive()) {
         $technique = getIptablesTechnique();
         $technique->iptables_save($install_dir . '/var/iptables.bak');
     }
     $technique ||= getIptablesTechnique();
     $technique->iptables_generate();
-    open(my $fh, '>>'.$self->pidFile);
-    print $fh "-1";
-    close($fh);
     return 1;
 }
 
@@ -66,37 +61,86 @@ sub getIptablesTechnique {
     return $iptables->{_technique};
 }
 
+=head2 start
+
+Wrapper around systemctl. systemctl should in turn call the actuall _start.
+
+=cut
+
+sub start {
+    my ($self,$quick) = @_;
+    system('sudo systemctl start packetfence-iptables');
+    return $? == 0;
+}
+
+=head2 _start
+
+start the service (called from systemd)
+
+=cut
+
+sub _start {
+    my ($self) = @_;
+    my $result = 0;
+    unless ( $self->isAlive() ) {
+        $result = $self->startService();
+    }
+    return $result;
+}
+
+sub startAndCheck {
+    my ($self) = @_;
+
+    while(1) {
+        $self->_start() unless($self->isAlive());
+        sleep 60;
+    }
+}
 
 =head2 stop
 
-stop iptables
+Wrapper around systemctl. systemctl should in turn call the actual _stop.
 
 =cut
 
 sub stop {
     my ($self) = @_;
-    my $count = $self->runningServices;
-    getIptablesTechnique->iptables_restore( $install_dir . '/var/iptables.bak');
-    unlink $self->pidFile;
+    system('sudo systemctl stop packetfence-iptables');
+    return 1;
+}
+
+=head2 _stop
+
+stop iptables (called from systemd)
+
+=cut
+
+sub _stop {
+    my ($self) = @_;
+    my $logger = get_logger();
+    if ( $self->isAlive() ) {
+        getIptablesTechnique->iptables_restore( $install_dir . '/var/iptables.bak' );
+    }
     return 1;
 }
 
 =head2 isAlive
 
 Check if iptables is alive.
-Since it's never really stopped than we check if the fake PID exists
+Since it's never really stopped then we check if the fake PID exists
 
 =cut
 
 sub isAlive {
-    my ($self,$pid) = @_;
+    my ($self) = @_;
+    my $logger = get_logger();
     my $result;
-    $pid = $self->pid;
-    my $rules_applied = defined(pf_run("iptables -S | grep ".$pf::iptables::FW_FILTER_INPUT_MGMT));
-    return (defined($pid) && $rules_applied);
+    my $pid = $self->pid;
+    my $_EXIT_CODE_EXISTS = "0";
+    my $rules_applied = defined( pf_run( "sudo " . $Config{'services'}{"iptables_binary"} . " -S | grep " . $pf::iptables::FW_FILTER_INPUT_MGMT ,accepted_exit_status => [$_EXIT_CODE_EXISTS]) );
+    return ($pid && $rules_applied);
 }
 
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
@@ -104,7 +148,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
