@@ -17,16 +17,32 @@ use Moo;
 use IPC::Cmd qw[can_run run];
 use List::MoreUtils qw(uniq);
 use POSIX;
-use pf::config;
+use pf::config qw(
+    %Config
+    @portal_ints
+    @listen_ints
+    @dhcplistener_ints
+    @radius_ints
+);
+use pf::file_paths qw(
+    $generated_conf_dir
+    $install_dir
+    $var_dir
+    $conf_dir
+);
 use pf::log;
 use pf::util;
+use pf::constants qw($SPACE $SPACE_NUMBERS);
 use pf::cluster;
 
 extends 'pf::services::manager';
 
 has '+name' => (default => sub { 'keepalived' } );
 
-has '+launcher' => (default => sub { "sudo %1\$s -f $generated_conf_dir/keepalived.conf --pid $var_dir/run/keepalived.pid" } );
+sub _cmdLine {
+    my $self = shift;
+    $self->executable . " -f $generated_conf_dir/keepalived.conf --pid=" . $self->pidFile;
+}
 
 sub executable {
     my ($self) = @_;
@@ -34,6 +50,7 @@ sub executable {
     return $service;
 }
 
+
 sub generateConfig {
     my ($self,$quick) = @_;
     my $logger = get_logger();
@@ -42,32 +59,42 @@ sub generateConfig {
 
     my %tags;
     $tags{'template'} = "$conf_dir/keepalived.conf";
-    $tags{'emailaddr'} = $Config{'alerting'}{'emailaddr'};
-    $tags{'fromaddr'} = $Config{'alerting'}{'fromaddr'} || 'root@localhost';
+    
+    # split email addresses then rejoin them with line feed and indent
+    $tags{'emailaddr'} = join("\n" . ($SPACE x $SPACE_NUMBERS), split( /\s*,\s*/, $Config{'alerting'}{'emailaddr'}));
+    
+    $tags{'fromaddr'} = $Config{'alerting'}{'fromaddr'} || "keepalived\@$host_id";
     $tags{'smtpserver'} = $Config{'alerting'}{'smtpserver'};
+    $tags{'router_id'} = "PacketFence-$host_id";
 
     $tags{'vrrp'} = '';
     $tags{'mysql_backend'} = '';
-    my @ints = uniq(@listen_ints,@dhcplistener_ints, map { $_->{'Tint'} } @portal_ints);
+    my @ints = uniq(@listen_ints,@dhcplistener_ints, (map { $_->{'Tint'} } @portal_ints, @radius_ints));
     foreach my $interface ( @ints ) {
         my $cfg = $Config{"interface $interface"};
         next unless $cfg;
-        next if ($cfg->{type} =~ qr/(?:dhcplistener|dhcp-listener)/);
         my $priority = 100 - pf::cluster::cluster_index();
         my $cluster_ip = pf::cluster::cluster_ip($interface);
         $tags{'vrrp'} .= <<"EOT";
 vrrp_instance $cfg->{'ip'} {
   virtual_router_id $Config{'active_active'}{'virtual_router_id'}
-  advert_int 1
+  advert_int 5
   priority $priority
   state MASTER
   interface $interface
+  preempt_delay 30
   virtual_ipaddress {
     $cluster_ip dev $interface
   }
 EOT
-        if(defined($cfg->{type}) && $cfg->{type} =~ /management/){
-            $tags{'vrrp'} .= "  notify \"$install_dir/bin/cluster/management_update\"\n";
+        if (isenabled($Config{'active_active'}{'vrrp_unicast'})) {
+        my $active_members = join("\n", grep( {$_ ne $cfg->{'ip'}} values %{pf::cluster::members_ips($interface)}));
+        $tags{'vrrp'} .= << "EOT";
+unicast_src_ip $cfg->{'ip'}
+unicast_peer {
+$active_members
+}
+EOT
         }
         $tags{'vrrp'} .= "  notify_master \"$install_dir/bin/cluster/pfupdate --mode=master\"\n";
         $tags{'vrrp'} .= "  notify_backup \"$install_dir/bin/cluster/pfupdate --mode=slave\"\n";
@@ -104,7 +131,12 @@ sub stop {
 
 sub isManaged {
     my ($self) = @_;
-    return $cluster_enabled; 
+    my $name = $self->name;
+    if (isenabled($pf::config::Config{'services'}{$name})) {
+        return $cluster_enabled;
+    } else {
+        return 0;
+    }
 }
 
 =head1 AUTHOR
@@ -115,7 +147,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
