@@ -20,13 +20,6 @@ extends 'pf::services::manager';
 
 has '+name' => ( default => sub { 'pfmon' } );
 
-has '+launcher' => (default => sub { '%1$s -d' } );
-
-sub isManaged {
-    my ($self) = @_;
-    return $self->SUPER::isManaged() && (!$pf::cluster::cluster_enabled || pf::cluster::is_management());
-}
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
@@ -34,7 +27,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -56,4 +49,3 @@ USA.
 =cut
 
 1;
-
