@@ -13,13 +13,13 @@ pf::services::manager::roles::is_managed_vlan_inline_enforcement
 
 use strict;
 use warnings;
-use pf::config;
+use pf::config qw(is_inline_enforcement_enabled is_vlan_enforcement_enabled is_dns_enforcement_enabled);
 
 use Moo::Role;
 
 around isManaged => sub {
     my $orig = shift;
-    return (is_inline_enforcement_enabled() || is_vlan_enforcement_enabled()) && $orig->(@_);
+    return (is_inline_enforcement_enabled() || is_vlan_enforcement_enabled() || is_dns_enforcement_enabled()) && $orig->(@_);
 };
 
 =head1 AUTHOR
@@ -28,7 +28,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
