@@ -14,8 +14,15 @@ pf::services::manager::snmptrapd
 use strict;
 use warnings;
 use Moo;
+use pf::cluster;
 use pf::constants;
-use pf::config;
+use pf::config qw($management_network %Config);
+use pf::file_paths qw(
+    $install_dir
+    $generated_conf_dir
+    $var_dir
+    $conf_dir
+);
 use pf::SwitchFactory;
 use pf::util;
 use pf::log;
@@ -24,14 +31,26 @@ extends 'pf::services::manager';
 
 has '+name' => (default => sub { 'snmptrapd' } );
 
-my $management_ip = '';
-
-if (ref($management_network)) {
-    $management_ip = defined($management_network->tag('vip')) ? $management_network->tag('vip') : $management_network->tag('ip');
-    $management_ip .= ':162';
+sub _cmdLine {
+    my $self = shift;
+    $self->executable
+        . " -f -n -c $generated_conf_dir/snmptrapd.conf -C -A -Lf $install_dir/logs/snmptrapd.log -p $install_dir/var/run/snmptrapd.pid -On " . getManagementIp();
 }
 
-has '+launcher' => (default => sub { "%1\$s -n -c $generated_conf_dir/snmptrapd.conf -C -A -Lf $install_dir/logs/snmptrapd.log -p $install_dir/var/run/snmptrapd.pid -On $management_ip" } );
+sub getManagementIp {
+    my $management_ip = '';
+
+    if (ref($management_network)) {
+        if ( $pf::cluster::cluster_enabled ) {
+            $management_ip = pf::cluster::management_cluster_ip();
+        } else {
+            $management_ip = defined($management_network->tag('vip')) ? $management_network->tag('vip') : $management_network->tag('ip');
+        }
+
+        $management_ip .= ':162';
+    }
+    return $management_ip;
+}
 
 =head2 generateConfig
 
@@ -47,17 +66,24 @@ sub generateConfig {
     my %tags;
     $tags{'authLines'} = '';
     $tags{'userLines'} = '';
+    $tags{'snmpTrapdAddr'} = '';
+    $tags{'perlaction'} = '';
+    my $management_ip = getManagementIp();
+    if ($management_ip) {
+        $tags{'snmpTrapdAddr'} = "snmpTrapdAddr $management_ip";
+    }
+    $tags{perlaction} = "perl do \"/usr/local/pf/lib/pf/snmptrapd.pm\";\n";
 
     foreach my $user_key ( sort keys %$snmpv3_users ) {
         $tags{'userLines'} .= "createUser " . $snmpv3_users->{$user_key} . "\n";
 
         # grabbing only the username portion of the key
         my (undef, $username) = split(/ /, $user_key);
-        $tags{'authLines'} .= "authUser log $username priv\n";
+        $tags{'authLines'} .= "authUser execute,log $username priv\n";
     }
 
     foreach my $community ( sort keys %$snmp_communities ) {
-        $tags{'authLines'} .= "authCommunity log $community\n";
+        $tags{'authLines'} .= "authCommunity execute,log $community\n";
     }
 
     $tags{'template'} = "$conf_dir/snmptrapd.conf";
@@ -108,7 +134,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
