@@ -17,10 +17,9 @@ use warnings;
 
 BEGIN {
     use Exporter ();
-    our ( @ISA, @EXPORT, @EXPORT_OK );
+    our ( @ISA, @EXPORT );
     @ISA = qw(Exporter);
     @EXPORT = qw(decompose_dhcp decode_dhcp dhcp_message_type_to_string dhcp_summary make_pcap_filter);
-    @EXPORT_OK = qw();
 }
 
 use NetPacket::Ethernet;
@@ -29,6 +28,7 @@ use NetPacket::UDP;
 use Readonly;
 
 use pf::util qw(int2ip clean_mac);
+use pf::option82 qw(get_switch_from_option82);
 
 our @ascii_options = (
     4, # Time Server (RFC2132)
@@ -255,40 +255,81 @@ On cisco, option 82 can be populated on the layer 3 switch when relaying by ente
 
 sub _decode_dhcp_option82 {
     my ($dhcp_ref) = @_;
-
+    my $option82 = $dhcp_ref->{'options'}{'82'};
     my %sub_opt_82;
-    my @option82 = @{$dhcp_ref->{'options'}{'82'}};
-    while ( @option82 ) {
-        my $subopt = shift( @option82 );
-        my $len = shift( @option82 );
-
+    my @options = @$option82;
+    while ( @options ) {
+        my $subopt = shift( @options );
+        my $len = shift( @options );
         while ($len) {
-            my $val = shift( @option82 );
+            my $val = shift( @options );
             push( @{ $sub_opt_82{$subopt} }, $val );
             $len--;
         }
     }
+    my %new_option = (
+        '_raw' => $option82,
+        '_subopts' => \%sub_opt_82,
+    );
 
     # stripping option82 arrayref and pushing an hashref instead with raw = options 82 array ref
-    $dhcp_ref->{'options'}{'82'} = {
-        '_raw' => $dhcp_ref->{'options'}{'82'},
-        '_subopts' => \%sub_opt_82,
-    };
+    $dhcp_ref->{'options'}{'82'} = \%new_option;
     if ( defined( $sub_opt_82{'1'} ) ) {
-
-        # TODO not sure this is the good stuff
-        my ( $vlan, $module, $port ) = unpack('nCC', pack("C*", @{$sub_opt_82{'1'}}));
-        $dhcp_ref->{'options'}{'82'}{'vlan'} = $vlan;
-        $dhcp_ref->{'options'}{'82'}{'module'} = $module;
-        $dhcp_ref->{'options'}{'82'}{'port'} = $port;
+        _decode_dhcp_option82_suboption1(\%new_option, $sub_opt_82{'1'});
     }
 
     if ( defined( $sub_opt_82{'2'} ) ) {
-        $dhcp_ref->{'options'}{'82'}{'switch'} = clean_mac( unpack("H*", pack("C*", @{$sub_opt_82{'2'}})) );
+        _decode_dhcp_option82_suboption2(\%new_option, $sub_opt_82{'2'});
     }
 
 }
 
+=item _decode_dhcp_option82_suboption1
+
+Decode the dhcp option82 sub option1
+
+Reference http://mincebert.blogspot.ca/2013/09/dhcp-option-82-cisco-switches-and.html
+
+=cut
+
+#TODO move the responsibility of parsing this to the switch
+#As this is cisco specific
+
+sub _decode_dhcp_option82_suboption1 {
+    my ($option, $sub_option) = @_;
+    my ($type, $length, @chars) = @$sub_option;
+    my $data = pack("C*", @chars);
+    if ($type == 0) {
+        @{$option}{qw(vlan module port)} = unpack("nCC", $data);
+    }
+    elsif ($type == 1) {
+        $option->{circuit_id_string} = $data;
+    }
+}
+
+=item _decode_dhcp_option82_suboption2
+
+Decode the dhcp option82 sub option2
+
+Reference http://mincebert.blogspot.ca/2013/09/dhcp-option-82-cisco-switches-and.html
+
+=cut
+
+#TODO move the responsibility of parsing this to the switch
+#As this is cisco specific
+
+sub _decode_dhcp_option82_suboption2 {
+    my ($option, $sub_option) = @_;
+    my ($type, $length, @chars) = @$sub_option;
+    my $data = pack("C*", @chars);
+    if ($type == 0) {
+        $option->{switch} = clean_mac(unpack("H*", $data));
+        $option->{switch_id} =  get_switch_from_option82($option->{switch});
+    }
+    elsif ($type == 1) {
+        $option->{host} = $data;
+    }
+}
 
 =item make_pcap_filter
 
@@ -307,7 +348,6 @@ sub make_pcap_filter {
     return "((port 67 or port 68 or port 767) and ( $type_filter )) or (port 546 or port 547)";
 }
 
-
 =back
 
 =head1 AUTHOR
@@ -316,7 +356,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
