@@ -14,28 +14,39 @@ pf::util::pfqueue - pfqueue
 
 use strict;
 use warnings;
-use pf::file_paths;
 use pf::log;
 use pf::config::pfqueue;
-use Redis::Fast;
+use pf::Redis;
 
 BEGIN {
     use Exporter ();
-    our ( @ISA, @EXPORT, @EXPORT_OK );
+    our ( @ISA, @EXPORT_OK );
     @ISA = qw(Exporter);
     @EXPORT_OK = qw(task_counter_id consumer_redis_client);
 }
 
+=head1 SUBROUTINES
+
 =head2 $id = task_counter_id($queue, $type, $args)
 
+Create the counter id for a queue task
+
 =cut
 
 sub task_counter_id {
     my ($queue, $type, $args) = @_;
     my $counter_id = "${queue}:${type}";
-    if ($type eq 'api' && ref ($args) eq 'ARRAY') {
+    my $args_ref = ref ($args);
+    if ($type eq 'api' && $args_ref eq 'ARRAY') {
         $counter_id .= ":" . $args->[0];
     }
+    elsif ($type eq 'pfsnmp_parsing' && $args_ref eq 'ARRAY') {
+        $counter_id .= ":" . $args->[0]->{switchIp};
+    }
+    elsif ($type eq 'pfsnmp' && $args_ref eq 'HASH') {
+        $counter_id .= join(":","", $args->{switchId}, $args->{trapIfIndex}, $args->{'trapType'});
+    }
+
     return $counter_id;
 }
 
@@ -45,19 +56,16 @@ sub task_counter_id {
 
 sub consumer_redis_client {
     my ($self) = @_;
-    return Redis::Fast->new( %{$ConfigPfqueue{consumer}{redis_args}});
+    return pf::Redis->new( %{$ConfigPfqueue{consumer}{redis_args}});
 }
 
-
-=head1 SUBROUTINES
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
