@@ -8,7 +8,7 @@ dispatcher.pm
 use strict;
 use warnings;
 
-use Apache2::Const -compile => qw(OK DECLINED HTTP_MOVED_TEMPORARILY);
+use Apache2::Const -compile => qw(OK DECLINED HTTP_MOVED_TEMPORARILY HTTP_NOT_IMPLEMENTED);
 use Apache2::Request;
 use Apache2::RequestIO ();
 use Apache2::RequestRec ();
@@ -27,7 +27,13 @@ BEGIN {
 }
 
 use pf::log;
-use pf::config;
+use pf::config qw(
+    %Config
+    %CAPTIVE_PORTAL
+    $HTTP
+    $HTTPS
+);
+use pf::constants qw($TRUE $FALSE);
 use pf::util;
 use pf::web::constants;
 use pf::web::filter;
@@ -36,6 +42,10 @@ use pf::proxypassthrough::constants;
 use pf::Portal::Session;
 use pf::web::externalportal;
 use pf::inline;
+use pf::db;
+
+# Only call pf::web::util::is_certificate_self_signed once
+my $IS_SELF_SIGNED = pf::web::util::is_certificate_self_signed();
 
 =head1 SUBROUTINES
 
@@ -53,13 +63,25 @@ Reference: http://perl.apache.org/docs/2.0/user/handlers/http.html#PerlTransHand
 =cut
 
 sub handler {
+    my $res;
+    eval {
+        local $SIG{ALRM} = sub { die "Timeout reached" };
+        alarm $Config{captive_portal}{request_timeout};
+        $res = _handler(@_);
+        alarm 0;
+    };
+    die $@ if($@);
+
+    return $res;
+}
+
+sub _handler {
     my $r = Apache::SSLLookup->new(shift);
     my $logger = get_logger();
-
+            
     my $hostname = $r->hostname || $r->connection->local_ip();
     my $uri = $r->uri;
     my $url = $r->construct_url;
-    my $user_agent = $r->headers_in->{'User-Agent'};
 
     $logger->debug("hitting handler with URI '$uri' (URL: $url)");
 
@@ -70,27 +92,6 @@ sub handler {
     my $result = $filter->test($r);
     return $result if $result;
 
-    # Proxy passthrough
-    if ( ($hostname =~ /$PROXYPASSTHROUGH::ALLOWED_PASSTHROUGH_DOMAINS/o && $PROXYPASSTHROUGH::ALLOWED_PASSTHROUGH_DOMAINS ne '')
-      || ($hostname =~ /$PROXYPASSTHROUGH::ALLOWED_PASSTHROUGH_REMEDIATION_DOMAINS/o && $PROXYPASSTHROUGH::ALLOWED_PASSTHROUGH_REMEDIATION_DOMAINS ne '') ) {
-        $logger->info("URI '$uri' (URL: $url) match proxy passthrough configuration.");
-        return proxy_redirect($r);
-    }
-
-    # Captive-portal detection mecanism
-    # Ability to bypass captive-portal detection mecanism
-    my $captive_portal_detection_mecanism_urls = pf::web::util::build_captive_portal_detection_mecanisms_regex;
-    if ( ($url =~ /$captive_portal_detection_mecanism_urls/o || $user_agent =~ /CaptiveNetworkSupport/s) && isenabled($Config{'captive_portal'}{'detection_mecanism_bypass'}) ) {
-        $logger->info("Dealing with a endpoint / browser with captive-portal detection capabilities while having captive-portal detection mecanism bypass enabled. Proxying");
-        return proxy_redirect($r);
-    }
-    # Enforce HTTP instead of HTTPS when dealing with captive-portal detection mecanism and having a self-signed SSL certificate
-    elsif ( ($url =~ /$captive_portal_detection_mecanism_urls/o || $user_agent =~ /CaptiveNetworkSupport/s)
-      && isenabled($Config{'captive_portal'}{'secure_redirect'}) && pf::web::util::is_certificate_self_signed ) {
-        $logger->info("Dealing with a endpoint / browser with captive-portal detection capabilities while having a self-signed SSL certificate. Using HTTP instead of HTTPS");
-        return html_redirect($r, { secure => $FALSE });
-    }
-
     # Captive-portal static resources
     # We don't want to continue in dispatcher in this case and we simply serve it
     # - Images
@@ -103,13 +104,6 @@ sub handler {
         return Apache2::Const::DECLINED;
     }
 
-    # Captive-portal resource | RELEASE
-    if ( $uri =~ /$WEB::URL_RELEASE/o ) {
-        $logger->debug("URI '$uri' (URL: $url) is a RELEASE request");
-        $r->handler('modperl');
-        $r->set_handlers( PerlResponseHandler => ['pf::web::release'] );
-        return Apache2::Const::OK;
-    }
 
     # Captive-portal resource | WISPr
     if ( $uri =~ /$WEB::URL_WISPR/o ) {
@@ -119,9 +113,17 @@ sub handler {
         return Apache2::Const::OK;
     }
 
+    # Openvas hook
+    if ($uri =~ m#/hook/openvas#) {
+        $logger->debug("URI '$uri' (URL: $url) is an OpenVAS request");
+        $r->handler('modperl');
+        $r->set_handlers( PerlResponseHandler => ['pf::web::openvashook'] );
+        return Apache2::Const::DECLINED;
+    }
+
     # Billing hooks
-    if ($r->uri =~ m#/hook/billing#) {
-        $logger->trace("Found the hook");
+    if ($uri =~ m#/hook/billing#) {
+        $logger->debug("URI '$uri' (URL: $url) is a billing request");
         $r->handler('modperl');
         $r->set_handlers( PerlResponseHandler => ['pf::web::billinghook'] );
         return Apache2::Const::DECLINED;
@@ -131,7 +133,7 @@ sub handler {
     # We don't want to continue in the dispatcher if the requested URI is supposed to reach the captive-portal (Catalyst)
     # - Captive-portal itself
     # - Violation pages
-    # - Portal profile filters are handled by Catalyst
+    # - Connection profile filters are handled by Catalyst
     # See L<pf::web::constants::CAPTIVE_PORTAL_RESOURCES>
     if ( $uri =~ /$WEB::CAPTIVE_PORTAL_RESOURCES/o ) {
         $logger->debug("URI '$uri' (URL: $url) is properly handled and should now continue to the captive-portal / Catalyst");
@@ -147,30 +149,14 @@ sub handler {
         return Apache2::Const::DECLINED;
     }
 
-    # Redirect everything else to the captive-portal URL
-    $r->handler('modperl');
-    $r->set_handlers( PerlResponseHandler => \&html_redirect );
-    return Apache2::Const::OK;
-}
-
-=item html_redirect
-
-=cut
-
-sub html_redirect {
-    my ($r, $params) = @_;
-    my $logger = get_logger();
-
-    $logger->debug("hitting html_redirect with URI '" . $r->uri . "' (URL: " . $r->construct_url . ")");
-    $logger->debug(sub { "'html_redirect' called with the following parameters: " . join(", ", map { "$_ => $params->{$_}" } keys %$params) }) if defined($params);
-
-    my $proto;
-    if ( defined($params->{'secure'}) && $params->{'secure'} ne "" ) {
-        $proto = isenabled($params->{'secure'}) ? $HTTPS : $HTTP;
-    } else {
-        $proto = isenabled($Config{'captive_portal'}{'secure_redirect'}) ? $HTTPS : $HTTP;
+    if(db_readonly_mode) {
+        get_logger->info("Server is in read-only mode, redirecting to the captive portal");
+        redirect_to_portal($r);
+        return Apache2::Const::HTTP_MOVED_TEMPORARILY;
     }
 
+    #Keep backward compatibilities for external portal
+
     my $captive_portal_domain = $Config{'general'}{'hostname'}.".".$Config{'general'}{'domain'};
     my $ip = defined($r->headers_in->{'X-Forwarded-For'}) ? $r->headers_in->{'X-Forwarded-For'} : $r->connection->remote_ip;
     $ip = new NetAddr::IP::Lite clean_ip($ip);
@@ -179,24 +165,17 @@ sub html_redirect {
     # Destination URL handling
     # We first must detect the destination URL for different use cases:
     # - We want to keep it so we can redirect the user to the originally requested URL once the registration completed
-    # - We want to be able to detect a potential captive-portal detection mecanism to disable HTTPS since it may cause issues
+    # - We want to be able to detect a potential captive-portal detection mechanism to disable HTTPS since it may cause issues
     my $destination_url = "";
-    my $url = $r->construct_url;
 
     # Keeping destination URL unless it is the captive-portal itself or some sort of captive-portal detection URLs
-    my $captive_portal_detection_mecanism_urls = pf::web::util::build_captive_portal_detection_mecanisms_regex;
-    if ( ($url !~ m#://\Q$captive_portal_domain\E/#) && ($url !~ /$captive_portal_detection_mecanism_urls/o) && ($user_agent !~ /CaptiveNetworkSupport/s) ) {
+    my $captive_portal_detection_mechanism_urls = pf::web::util::build_captive_portal_detection_mechanisms_regex;
+    if ( ($url !~ m#://\Q$captive_portal_domain\E/#) && ($url !~ /$captive_portal_detection_mechanism_urls/o) && ($user_agent !~ /CaptiveNetworkSupport/s) ) {
         $destination_url = Apache2::Util::escape_path($url,$r->pool);
         $logger->debug("We set the destination URL to $destination_url for further usage");
         $r->pnotes(destination_url => $destination_url);
     }
 
-    # Configuring redirect URLs for both the portal and the WISPr(need to be part of the header in case of a WISPr client)
-    my $portal_url = APR::URI->parse($r->pool,"$proto://".${captive_portal_domain}."/captive-portal");
-    $portal_url->query("destination_url=$destination_url&".$r->args);
-    my $wispr_url = APR::URI->parse($r->pool,"$proto://".${captive_portal_domain}."/wispr");
-    $wispr_url->query($r->args);
-
     # External captive-portal / Webauth handling
     # In the case of an external captive-portal, we want to use a different URL (the hostname to which the network equipment send the request, which is PacketFence but maybe not the configured hostname in pf.conf)
     # We also need to keep track of the CGI session by setting a cookie
@@ -208,14 +187,33 @@ sub html_redirect {
             $logger->debug("We are dealing with an external captive-portal / webauth request. Adjusting the redirect URL accordingly");
             $r->err_headers_out->add('Set-Cookie' => "CGISESSION_PF=".  $cgi_session_id . "; path=/");
             $destination_url = $external_portal_destination_url if ( defined($external_portal_destination_url) );
-
-            # Re-Configuring redirect URLs for both the portal and the WISPr(need to be part of the header in case of a WISPr client)
-            $portal_url = APR::URI->parse($r->pool,"$proto://".$r->hostname."/captive-portal");
-            $portal_url->query("destination_url=$destination_url&".$r->args);
-            $wispr_url = APR::URI->parse($r->pool,"$proto://".$r->hostname."/wispr");
-            $wispr_url->query($r->args);
+            
+            redirect_to_portal($r, $destination_url);
+            return Apache2::Const::HTTP_MOVED_TEMPORARILY;
         }
+        return  Apache2::Const::HTTP_NOT_IMPLEMENTED;
     }
+    return Apache2::Const::HTTP_NOT_IMPLEMENTED;
+}
+
+=head2 redirect_to_portal
+
+Redirect a user to the captive portal
+
+=cut
+
+sub redirect_to_portal {
+    my ($r, $destination_url) = @_;
+    $destination_url //= "";
+    my $logger = get_logger();
+
+    my $proto = isenabled($Config{'captive_portal'}{'secure_redirect'}) ? $HTTPS : $HTTP;
+
+    # Re-Configuring redirect URLs for both the portal and the WISPr(need to be part of the header in case of a WISPr client)
+    my $portal_url = APR::URI->parse($r->pool,"$proto://".$r->hostname."/captive-portal");
+    $portal_url->query("destination_url=$destination_url&".$r->args);
+    my $wispr_url = APR::URI->parse($r->pool,"$proto://".$r->hostname."/wispr");
+    $wispr_url->query($r->args);
 
     my $stash = {
         'portal_url'    => $portal_url->unparse(),
@@ -236,29 +234,6 @@ sub html_redirect {
     $r->err_headers_out->add('Expire' => '10');
     $r->custom_response(Apache2::Const::HTTP_MOVED_TEMPORARILY, $response);
 
-    return Apache2::Const::HTTP_MOVED_TEMPORARILY;
-}
-
-=item proxy_redirect
-
-=cut
-
-sub proxy_redirect {
-    my ($r) = @_;
-    my $logger = get_logger();
-
-    $logger->debug("hitting proxy_redirect with URI '" . $r->uri . "' (URL: " . $r->construct_url . ")");
-
-    my $parsed_request = APR::URI->parse($r->pool, $r->uri);
-    $parsed_request->hostname($r->hostname);
-    ( $r->is_https ) ? $parsed_request->scheme('https') : $parsed_request->scheme('http');
-    $parsed_request->path($r->uri);
-    $r->set_handlers(PerlResponseHandler => []);
-    $r->filename("proxy:" . $parsed_request->unparse);
-    $r->proxyreq(2);
-    $r->handler('proxy-server');
-
-    return Apache2::Const::OK;
 }
 
 =back
@@ -269,7 +244,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
