@@ -20,7 +20,7 @@ use warnings;
 use base 'pfconfig::backend';
 use Cache::BDB;
 use pfconfig::empty_string;
-use pf::file_paths;
+use pf::file_paths qw($pfconfig_cache_dir);
 
 sub init {
     my ($self) = @_;
@@ -37,7 +37,7 @@ sub set {
 
     # BDB doesn't write empty strings
     # We workaround it using a class that represents an empty string
-    if ( "$value" eq '' ) {
+    if ( defined($value) && "$value" eq '' ) {
         $value = pfconfig::empty_string->new;
     }
     $self->SUPER::set( $key, $value );
@@ -66,15 +66,13 @@ sub list {
     return keys %{ $self->{cache}->get_bulk() };
 }
 
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
