@@ -32,32 +32,15 @@ use warnings;
 
 use IO::Socket::UNIX qw( SOCK_STREAM );
 use JSON::MaybeXS;
-use pfconfig::timeme;
-use pfconfig::log;
-use pfconfig::util qw($undef_element);
+use pf::log;
+use pfconfig::util qw($undef_element normalize_namespace_query);
+use pf::config::tenant;
 use pfconfig::constants;
-use Sereal::Encoder;
-use Sereal::Decoder;
+use Sereal::Decoder qw(sereal_decode_with_object);
 use Time::HiRes qw(stat time);
+use pf::Sereal qw($DECODER);
 use bytes;
 
-=head2 ENCODER
-
-The encoder for the communications with pfconfig
-See CLONE where this needs to be recreated
-
-=cut
-
-our $ENCODER = Sereal::Encoder->new;
-
-=head2 DECODER
-
-The decoder for the communications with pfconfig
-See CLONE where this needs to be recreated
-
-=cut
-
-our $DECODER = Sereal::Decoder->new;
 
 =head2 new
 
@@ -66,10 +49,10 @@ Creates the object but shouldn't be used since it's made as an interface to use
 =cut
 
 sub new {
-    my ($class) = @_;
+    my ($class, @args) = @_;
     my $self = bless {}, $class;
 
-    $self->init();
+    $self->init(@args);
 
     return $self;
 }
@@ -119,7 +102,12 @@ sub get_from_subcache {
     if ( defined( $self->{_subcache}{$key} ) ) {
         my $valid = $self->is_valid();
         if ($valid) {
-            return $self->{_subcache}{$key};
+            if ($self->{_scoped_by_tenant_id}) {
+                my $tenant_id = pf::config::tenant::get_tenant();
+                return $self->{_subcache}{$tenant_id}{$key};
+            } else {
+                return $self->{_subcache}{$key};
+            }
         }
         else {
             $self->{_subcache}    = {};
@@ -132,17 +120,19 @@ sub get_from_subcache {
 
 =head2 get_from_subcache
 
-Sets an element in the subcache so it can be reused accross accesses
+Sets an element in the subcache so it can be reused across accesses
 
 =cut
 
 sub set_in_subcache {
-    my ( $self, $key, $result ) = @_;
-
-    $self->{memorized_at} = time unless $self->{memorized_at};
-    $self->{_subcache}    = {}   unless $self->{_subcache};
-    $self->{_subcache}{$key} = $result;
-
+    my ($self, $key, $result) = @_;
+    $self->{memorized_at} //= time;
+    if ($self->{_scoped_by_tenant_id}) {
+        my $tenant_id = pf::config::tenant::get_tenant();
+        $self->{_subcache}{$tenant_id}{$key} = $result;
+    } else {
+        $self->{_subcache}{$key} = $result;
+    }
 }
 
 =head2 compute_from_subcache
@@ -155,23 +145,20 @@ sub compute_from_subcache {
     my ($self, $key, $on_miss) = @_;
 
     my $subcache_value = $self->get_from_subcache($key);
-    if(defined($subcache_value) && ref($subcache_value) eq "pfconfig::undef_element"){
+    if (defined($subcache_value) && ref($subcache_value) eq "pfconfig::undef_element") {
         return undef;
-    }
-    elsif(defined($subcache_value)){
+    } elsif (defined($subcache_value)) {
         return $subcache_value;
     }
 
     my $result = $on_miss->();
-    if(defined($result)){
-        $self->set_in_subcache($key,$result);
-    }
-    else {
+    if (defined($result)) {
+        $self->set_in_subcache($key, $result);
+    } else {
         $self->set_in_subcache($key, $undef_element);
     }
 
     return $result;
-
 }
 
 =head2 _get_from_socket
@@ -185,13 +172,13 @@ Will receive the amount of lines of the reply then the reply as a Sereal string
 
 sub _get_from_socket {
     my ( $self, $what, $method, %additionnal_info ) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     $method = $method || $self->{element_socket_method};
 
     my %info;
     my $payload;
-    %info = ( ( method => $method, key => $what ), %additionnal_info );
+    %info = ( ( method => $method, key => $what, tenant_id => pf::config::tenant::get_tenant() ), %additionnal_info );
     $payload = encode_json( \%info );
 
     my $socket;
@@ -226,7 +213,7 @@ sub _get_from_socket {
     # it returns it as a sereal hash
     my $result;
     if ( $response && $response ne "undef\n" ) {
-        eval { $result = $DECODER->decode($response); };
+        eval { $result = sereal_decode_with_object($DECODER, $response); };
         if ($@) {
             print STDERR $@;
             print STDERR "$what $response";
@@ -248,40 +235,47 @@ Uses the control files in var/control and the memorized_at hash to know if a nam
 
 sub is_valid {
     my ($self)         = @_;
-    my $logger         = pfconfig::log::get_logger;
+    my $logger         = $self->logger;
     my $what           = $self->{_namespace};
-    my $control_file   = pfconfig::util::control_file_path($what);
-    my $file_timestamp = ( stat($control_file) )[9];
+    my $control_file   = $self->{_control_file_path};
+    my $file_timestamp = (  stat($control_file) )[9];
 
     unless ( defined($file_timestamp) ) {
         $logger->warn("Filesystem timestamp is not set for $what. Considering memory as invalid.");
         return 0;
     }
 
-    my $memory_timestamp = $self->{memorized_at} || time;
+    my $memory_timestamp = $self->{memorized_at} // 0;
 
 #$logger->trace("Control file has timestamp $file_timestamp and memory has timestamp $memory_timestamp for key $what");
 # if the timestamp of the file is after the one we have in memory
 # then we are expired
-    if ( $memory_timestamp > $file_timestamp ) {
-        $logger->trace("Memory configuration is still valid for key $what in local cached_hash");
+    if ( $memory_timestamp >= $file_timestamp ) {
+        $logger->trace( sub { "Memory configuration is still valid for key $what in local cached_hash" });
         return 1;
     }
     else {
-        $logger->info("Memory configuration is not valid anymore for key $what in local cached_hash");
+            $logger->debug("Memory configuration is not valid anymore for key $what in local cached_hash");
         return 0;
     }
 }
 
-=head2 CLONE
+sub logger {
+    my ($self) = @_;
+    return $self->{logger} if defined $self->{logger};
+    $self->{logger} = get_logger(ref($self) || $self);
+    return $self->{logger};
+}
 
-Called when cloning the module. Used to create new encoders, if not they'll be undefed
+=head2 set_namespace
+
+Set the namespace of this object while normalizing it if needed
 
 =cut
 
-sub CLONE {
-    $ENCODER = Sereal::Encoder->new;
-    $DECODER = Sereal::Decoder->new;
+sub set_namespace {
+    my ($self, $namespace) = @_;
+    $self->{_namespace} = normalize_namespace_query($namespace);
 }
 
 =head1 AUTHOR
@@ -290,7 +284,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
