@@ -46,8 +46,7 @@ use warnings;
 use Tie::Array;
 use IO::Socket::UNIX qw( SOCK_STREAM );
 use JSON::MaybeXS;
-use pfconfig::timeme;
-use pfconfig::log;
+use pf::log;
 use pfconfig::cached;
 our @ISA = ( 'Tie::Array', 'pfconfig::cached' );
 
@@ -58,15 +57,13 @@ Constructor of the array
 =cut
 
 sub TIEARRAY {
-    my ( $class, $config ) = @_;
+    my ( $class, $config, %extra ) = @_;
     my $self = bless {}, $class;
-
     $self->init();
-
-    $self->{"_namespace"} = $config;
-
+    $self->set_namespace($config);
+    $self->{"_scoped_by_tenant_id"} = $extra{tenant_id_scoped};
+    $self->{"_control_file_path"} = pfconfig::util::control_file_path($self->{_namespace});
     $self->{element_socket_method} = "array_element";
-
     return $self;
 }
 
@@ -80,7 +77,7 @@ Other than that it proxies the call to pfconfig
 
 sub FETCH {
     my ( $self, $index ) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     my $result = $self->compute_from_subcache($index, sub {
       my $reply = $self->_get_from_socket("$self->{_namespace};$index");
@@ -101,7 +98,7 @@ Proxies the call to pfconfig
 
 sub FETCHSIZE {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
     my $result = $self->compute_from_subcache("__PFCONFIG_ARRAY_SIZE__", sub {
         my $reply = $self->_get_from_socket( $self->{_namespace}, "array_size" );
         return defined $reply ? $reply->{size} : 0;
@@ -133,7 +130,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
