@@ -46,9 +46,9 @@ use warnings;
 use Tie::Hash;
 use IO::Socket::UNIX qw( SOCK_STREAM );
 use JSON::MaybeXS;
-use pfconfig::timeme;
 use List::MoreUtils qw(first_index);
-use pfconfig::log;
+use pf::log;
+use pf::config::tenant;
 use pfconfig::cached;
 our @ISA = ( 'Tie::StdHash', 'pfconfig::cached' );
 
@@ -59,15 +59,13 @@ Constructor of the hash
 =cut
 
 sub TIEHASH {
-    my ( $class, $config ) = @_;
+    my ( $class, $config, %extra ) = @_;
     my $self = bless {}, $class;
-
     $self->init();
-
-    $self->{"_namespace"} = $config;
-
+    $self->set_namespace($config);
+    $self->{"_scoped_by_tenant_id"} = $extra{tenant_id_scoped};
+    $self->{"_control_file_path"} = pfconfig::util::control_file_path($self->{_namespace});
     $self->{element_socket_method} = "hash_element";
-
     return $self;
 }
 
@@ -81,15 +79,21 @@ Other than that it proxies the call to pfconfig
 
 sub FETCH {
     my ( $self, $key ) = @_;
-    my $logger = pfconfig::log::get_logger;
-
+    my $logger = $self->logger;
     unless ( defined($key) ) {
         my $caller = ( caller(1) )[3];
         $logger->error("Accessing hash $self->{_namespace} with undef key. Caller : $caller.");
         return undef;
     }
 
-    return $self->{_internal_elements}{$key} if defined( $self->{_internal_elements}{$key} );
+    if ($self->{_scoped_by_tenant_id}) {
+        my $tenant_id = pf::config::tenant::get_tenant();
+        if( defined $self->{_internal_elements}{$tenant_id}{$key}) {
+            return  $self->{_internal_elements}{$tenant_id}{$key}
+        }
+    } elsif (defined( $self->{_internal_elements}{$key} )) {
+        return $self->{_internal_elements}{$key};
+    }
 
     my $result = $self->compute_from_subcache($key, sub {
         my $reply = $self->_get_from_socket("$self->{_namespace};$key");
@@ -109,7 +113,7 @@ Call it using tied(%hash)->keys
 
 sub keys {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     my $keys = $self->compute_from_subcache("__PFCONFIG_HASH_KEYS__", sub {
         return $self->_get_from_socket( $self->{_namespace}, "keys" );
@@ -127,7 +131,7 @@ Proxies to pfconfig
 
 sub FIRSTKEY {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     return $self->compute_from_subcache("__PFCONFIG_FIRST_KEY__", sub {
         my $first_key = $self->_get_from_socket( $self->{_namespace}, "next_key", ( last_key => undef ) );
@@ -144,7 +148,7 @@ Proxies to pfconfig
 
 sub NEXTKEY {
     my ( $self, $last_key ) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     return $self->compute_from_subcache("__PFCONFIG_NEXT_KEY_${last_key}__", sub {
         return $self->_get_from_socket( $self->{_namespace}, "next_key", ( last_key => $last_key ) )->{next_key};
@@ -160,11 +164,13 @@ Stores it without any saving capability
 
 sub STORE {
     my ( $self, $key, $value ) = @_;
-    my $logger = pfconfig::log::get_logger;
-
-    $self->{_internal_elements} = {} unless ( defined( $self->{_internal_elements} ) );
-
-    $self->{_internal_elements}{$key} = $value;
+    my $logger = $self->logger;
+    if ($self->{_scoped_by_tenant_id}) {
+        my $tenant_id = pf::config::tenant::get_tenant();
+        $self->{_internal_elements}{$tenant_id}{$key} = $value;
+    } else {
+        $self->{_internal_elements}{$key} = $value;
+    }
 }
 
 =head2 STORE
@@ -176,6 +182,7 @@ Proxies to pfconfig
 
 sub EXISTS {
     my ( $self, $key ) = @_;
+    return undef unless defined $key;
     return $self->compute_from_subcache("__PFCONFIG_KEY_EXISTS_${key}__", sub {
         my $reply =  $self->_get_from_socket( $self->{_namespace}, "key_exists", ( search => $key ) );
         return defined $reply ? $reply->{result} : undef;
@@ -232,7 +239,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
