@@ -23,7 +23,7 @@ the object is used
 
 This class is used with tiying
 
-Example : 
+Example :
 my $object;
 tie $object, 'pfconfig::cached_scalar', 'resource::fqdn';
 print $hash{_ip};
@@ -31,7 +31,7 @@ print $hash{_ip};
 This ties $object to the namespace 'resource::fqdn' defined in
 lib/pfconfig/namespaces/ and served though pfconfig
 
-In order to call a method on this tied object 
+In order to call a method on this tied object
 my $zammit = tied($object)->zammit
 
 =cut
@@ -41,8 +41,7 @@ use warnings;
 
 use Tie::Scalar;
 use IO::Socket::UNIX qw( SOCK_STREAM );
-use pfconfig::timeme;
-use pfconfig::log;
+use pf::log;
 use pfconfig::cached;
 our @ISA = ( 'Tie::Scalar', 'pfconfig::cached' );
 
@@ -53,15 +52,13 @@ Constructor of the object
 =cut
 
 sub TIESCALAR {
-    my ( $class, $config ) = @_;
-    my $self = bless {}, $class;
-
+    my ($class, $config, %extra) = @_;
+    my $self = bless { }, $class;
     $self->init();
-
-    $self->{"_namespace"} = $config;
-
-    $self->{element_socket_method} = "element";
-
+    $self->set_namespace($config);
+    $self->{"_scoped_by_tenant_id"} = $extra{tenant_id_scoped};
+    $self->{"_control_file_path"} = pfconfig::util::control_file_path($self->{_namespace});
+    $self->{"element_socket_method"} = "element";
     return $self;
 }
 
@@ -75,7 +72,7 @@ Other than that it proxies the call to pfconfig
 
 sub FETCH {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = $self->logger;
 
     my $subcache_value = $self->get_from_subcache("myself");
     return $subcache_value if defined($subcache_value);
@@ -88,7 +85,17 @@ sub FETCH {
     return $result;
 }
 
-=back
+=head2 STORE
+
+Log attempts to store something in a pfconfig::cached_scalar
+
+=cut
+
+sub STORE {
+    my ($self) = @_;
+    $self->logger->logcroak("Trying to store a value in $self->{_namespace}");
+    return ;
+}
 
 =head1 AUTHOR
 
@@ -96,7 +103,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
