@@ -15,7 +15,16 @@ Configuration access to pfconfig.conf
 =cut
 
 use pfconfig::constants;
-use Config::IniFiles;
+use UNIVERSAL::require;
+use pf::IniFiles;
+use pf::util;
+use pf::log;
+
+=head2 new
+
+Create a new pfconfig configuration object
+
+=cut
 
 sub new {
     my ($class) = @_;
@@ -24,22 +33,58 @@ sub new {
     return $self;
 }
 
+=head2 init
+
+Init the pfconfig configuration object
+
+=cut
+
 sub init {
     my ($self) = @_;
     my $file = $pfconfig::constants::CONFIG_FILE_PATH;
 
     my %cfg;
-    tie %cfg, 'Config::IniFiles', ( -file => $file );
+    tie %cfg, 'pf::IniFiles', ( -file => $file );
 
     $self->{cfg} = \%cfg;
 }
 
+=head2 section
+
+Get a configuration section
+
+=cut
+
 sub section {
     my ( $self, $name ) = @_;
     return $self->{cfg}{$name};
 }
 
-=back
+=head2 get_backend
+
+Get the backend object defined in the configuration or the default one
+
+=cut
+
+sub get_backend {
+    my ( $self ) = @_;
+    my $cfg    = $self->section('general');
+    my $logger = get_logger;
+
+    my $name = $cfg->{backend} || $pfconfig::constants::DEFAULT_BACKEND;
+
+    my $type   = "pfconfig::backend::$name";
+
+    $type = untaint_chain($type);
+
+    # load the module to instantiate
+    if ( !( eval "$type->require()" ) ) {
+        $logger->error( "Can not load namespace $name " . "Read the following message for details: $@" );
+    }
+
+    $self->{cache} = $type->new();
+}
+
 
 =head1 AUTHOR
 
@@ -47,7 +92,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
