@@ -31,20 +31,24 @@ In order to access the configuration namespaces :
 use strict;
 use warnings;
 
-use JSON::MaybeXS;
 use Config::IniFiles;
+use JSON::MaybeXS;
 use List::MoreUtils qw(any firstval uniq);
 use Scalar::Util qw(refaddr reftype tainted blessed);
 use UNIVERSAL::require;
-use pfconfig::log;
+use pf::log;
 use pf::util;
+use Fcntl;
 use Time::HiRes qw(stat time);
 use File::Find;
-use pfconfig::util;
+use pfconfig::util qw(normalize_namespace_query);
 use POSIX;
 use POSIX::2008;
 use List::MoreUtils qw(first_index);
 use Tie::IxHash;
+use pfconfig::config;
+use pf::constants::user;
+use pf::config::tenant;
 
 =head2 config_builder
 
@@ -55,11 +59,10 @@ See it as a mini-factory
 
 sub config_builder {
     my ( $self, $namespace ) = @_;
-    my $logger = pfconfig::log::get_logger;
-
+    my $logger = get_logger;
     my $elem = $self->get_namespace($namespace);
     my $tmp  = $elem->build();
-
+    $self->{scoped_by_tenant_id}{$namespace} = $elem->{_scoped_by_tenant_id};
     return $tmp;
 }
 
@@ -72,7 +75,7 @@ Dynamicly requires the namespace module and instanciates the object associated t
 sub get_namespace {
     my ( $self, $name ) = @_;
 
-    my $logger = pfconfig::log::get_logger;
+    my $logger = get_logger;
 
     my $full_name = $name;
 
@@ -110,7 +113,7 @@ sub is_overlayed_namespace {
 =head2 overlayed_namespaces
 
 Returns the overlayed namespaces for a static namespace
-  ex : 
+  ex :
     static namespace : "config::Pf"
     overlayed namespaces : ("config::Pf(some-argument)", "config::Pf(another-argument)")
 
@@ -119,6 +122,11 @@ Returns the overlayed namespaces for a static namespace
 sub overlayed_namespaces {
     my ($self, $base_namespace) = @_;
 
+    # Namespace is an empty overlay
+    if($base_namespace =~ /(.+)\(\)$/) {
+        $base_namespace = $1;
+    }
+
     # An overlayed namespace can't have overlayed namespaces
     return () if $self->is_overlayed_namespace($base_namespace);
 
@@ -127,7 +135,7 @@ sub overlayed_namespaces {
     $base_namespace = quotemeta($base_namespace);
     foreach my $namespace (@namespaces){
         if($namespace =~ /^$base_namespace/){
-            push @overlayed_namespaces, $namespace;
+            push @overlayed_namespaces, $namespace if $self->is_overlayed_namespace($namespace);
         }
     }
     return @overlayed_namespaces;
@@ -141,7 +149,37 @@ Returns an Array ref of all the overlayed namespaces persisted in the backend
 
 sub all_overlayed_namespaces {
     my ($self) = @_;
-    return [ $self->{cache}->list_matching('\(.*\)$') ];
+    return [ uniq($self->{cache}->list_matching('\(.+\)$'), $self->list_control_overlayed_namespaces()) ];
+}
+
+=head2 list_control_overlayed_namespaces
+
+List all the overlayed namespaces contained in the control directory
+
+=cut
+
+sub list_control_overlayed_namespaces {
+    my ($self) = @_;
+    my $control_dir = $pfconfig::constants::CONTROL_FILE_DIR;
+    my @modules;
+    find(
+        {   wanted => sub {
+                my $module = $_;
+                #Ignore directories
+                return if -d $module;
+                $module =~ s/$control_dir\///g;
+                return if $module !~ /-control$/;
+                $module =~ s/\-control$//g;
+                if($module =~ /\(.*\)$/) {
+                    push @modules, $module;
+                }
+            },
+            no_chdir => 1
+        },
+        $control_dir
+    );
+    @modules = sort @modules;
+    return @modules;
 }
 
 =head2 new
@@ -167,23 +205,9 @@ Creates the backend and internal data structures for the L1 and L2 cache
 
 sub init_cache {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
-
-    my $cfg    = pfconfig::config->new->section('general');
-
-    my $name = $cfg->{backend} || $pfconfig::constants::DEFAULT_BACKEND;
-
-    my $type   = "pfconfig::backend::$name";
-
-    $type = untaint_chain($type);
-
-    # load the module to instantiate
-    if ( !( eval "$type->require()" ) ) {
-        $logger->error( "Can not load namespace $name " . "Read the following message for details: $@" );
-    }
-
-    $self->{cache} = $type->new();
+    my $logger = get_logger;
 
+    $self->{cache} = pfconfig::config->new->get_backend;
     $self->{memory}       = {};
     $self->{memorized_at} = {};
 }
@@ -197,26 +221,11 @@ That sends the signal that the raw memory is expired
 
 sub touch_cache {
     my ( $self, $what ) = @_;
-    my $logger = pfconfig::log::get_logger;
     $what =~ s/\//;/g;
+    $what = normalize_namespace_query($what);
     my $filename = pfconfig::util::control_file_path($what);
     $filename = untaint_chain($filename);
-
-    if ( !-e $filename ) {
-        my $fh;
-        unless ( open( $fh, ">$filename" ) ) {
-            $logger->error("Can't create $filename\nPlease run 'pfcmd fixpermissions'");
-            return 0;
-        }
-        close($fh);
-    }
-    if ( -e $filename ) {
-        my $command = 'touch --date=@'.time.' '."'".$filename."'";
-        $command = untaint_chain($command);
-        `$command`;
-    }
-    my ( undef, undef, $uid, $gid ) = getpwnam('pf');
-    chown( $uid, $gid, $filename );
+    touch_file($filename);
 }
 
 =head2 get_cache
@@ -229,32 +238,42 @@ It should not have to build the L3 since that's the slowest. The L3 should be bu
 
 sub get_cache {
     my ( $self, $what ) = @_;
-    my $logger = pfconfig::log::get_logger;
 
+    $what = normalize_namespace_query($what);
+
+    my $logger = get_logger;
     # we look in raw memory and make sure that it's not expired
-    my $memory = $self->{memory}->{$what};
-    if ( defined($memory) && $self->is_valid($what) ) {
-        $logger->debug("Getting $what from memory");
-        return $memory;
-    }
-    else {
+    my $memory = $self->{memory}{$what};
+    unless (defined($memory) && $self->is_valid($what)) {
         my $cached = $self->{cache}->get($what);
-
         # raw memory is expired but cache is not
         if ($cached) {
             $logger->debug("Getting $what from cache backend");
-            $self->{memory}->{$what}       = $cached;
-            $self->{memorized_at}->{$what} = time;
-            return $cached;
-        }
-
-        # everything is expired. need to rebuild completely
-        else {
-            my $result = $self->cache_resource($what);
-            return $result;
+            $memory = $cached;
+            $self->{memory}{$what} = $cached;
+            $self->{memorized_at}{$what} = time;
+        } else {
+            # everything is expired. need to rebuild completely
+            $memory = $self->cache_resource($what);
         }
     }
 
+    if (defined $memory && $self->is_tenant_scoped($what)) {
+        $memory = $memory->{pf::config::tenant::get_tenant()};
+    }
+
+    return $memory;
+}
+
+=head2 is_tenant_scoped
+
+is_tenant_scoped
+
+=cut
+
+sub is_tenant_scoped {
+    my ($self, $key) = @_;
+    return $self->{scoped_by_tenant_id}{$key};
 }
 
 =head2 post_process_element
@@ -265,17 +284,40 @@ For now, it is used only to transform non-ordered hashes into ordered ones so fo
 =cut
 
 sub post_process_element {
-    my ($self, $element) = @_;
-    if(ref($element) eq 'HASH'){
-        tie my %copy, 'Tie::IxHash';
-        my @keys = keys(%$element);
-        @keys = sort(@keys);
-        foreach my $key (@keys){
-            $copy{$key} = $element->{$key};
+    my ($self, $what, $element) = @_;
+    if (!$self->is_tenant_scoped($what)) {
+        if (ref($element) eq 'HASH') {
+            return $self->tie_ixhash_copied($element);
         }
-        return \%copy;
+
+        return $element;
     }
-    return $element;
+
+    if (ref($element) ne 'HASH' ) {
+        return $element;
+    }
+
+    my %copy;
+    while (my ($k, $v) = each %$element) {
+        $copy{$k} = ref($v) eq 'HASH' ? $self->tie_ixhash_copied($v) : $v;
+    }
+
+    return \%copy;
+}
+
+=head2 tie_ixhash_copied
+
+tie_ixhash_copied
+
+=cut
+
+sub tie_ixhash_copied {
+    my ($self, $hash) = @_;
+    tie my %copy, 'Tie::IxHash';
+    my @keys = keys(%$hash);
+    @keys = sort(@keys);
+    @copy{@keys} = @{$hash}{@keys};
+    return \%copy;
 }
 
 =head2 cache_resource
@@ -286,16 +328,16 @@ Builds the resource associated to a namespace and then caches it in the L1 and L
 
 sub cache_resource {
     my ( $self, $what ) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = get_logger;
 
     $logger->debug("loading $what from outside");
     my $result = $self->config_builder($what);
     # inflates the element if necessary
-    $result = $self->post_process_element($result);
+    $result = $self->post_process_element($what, $result);
     my $cache_w = $self->{cache}->set( $what, $result, 864000 );
     $logger->trace("Cache write gave : $cache_w");
     unless ($cache_w) {
-        my $message = "Could not write namespace $what to L2 cache ! This is bad.";
+        my $message = "Could not write namespace $what to L2 cache !";
         print STDERR $message . "\n";
         $logger->error($message);
     }
@@ -316,7 +358,7 @@ Uses the control files in var/control and the memorized_at hash to know if a nam
 
 sub is_valid {
     my ( $self, $what ) = @_;
-    my $logger         = pfconfig::log::get_logger;
+    my $logger         = get_logger;
     my $control_file   = pfconfig::util::control_file_path($what);
     my $file_timestamp = ( stat($control_file) )[9];
 
@@ -335,12 +377,12 @@ sub is_valid {
 
     # if the timestamp of the file is after the one we have in memory
     # then we are expired
-    if ( $memory_timestamp > $file_timestamp ) {
+    if ( $memory_timestamp >= $file_timestamp ) {
         $logger->trace("Memory configuration is still valid for key $what");
         return 1;
     }
     else {
-        $logger->info("Memory configuration is not valid anymore for key $what");
+        $logger->debug("Memory configuration is not valid anymore for key $what");
         return 0;
     }
 }
@@ -359,7 +401,9 @@ To fully expire a namespace with it's child resources and overlayed namespaces,
 
 sub expire {
     my ( $self, $what, $light ) = @_;
-    my $logger = pfconfig::log::get_logger;
+    $what = normalize_namespace_query($what);
+
+    my $logger = get_logger;
     if(defined($light) && $light){
         $logger->info("Light expiring resource : $what");
         delete $self->{memorized_at}->{$what};
@@ -372,6 +416,16 @@ sub expire {
 
     unless($self->is_overlayed_namespace($what)){
         my $namespace = $self->get_namespace($what);
+        # expire overlayed namespaces
+        my @overlayed_namespaces = $self->overlayed_namespaces($what);
+        foreach my $namespace (@overlayed_namespaces){
+            # prevent deep recursion on namespace itself
+            next if $namespace eq $what;
+
+            $logger->info("Expiring overlayed resource from base resource $what.");
+            $self->expire($namespace, $light);
+        }
+
         if ( $namespace->{child_resources} ) {
             foreach my $child_resource ( @{ $namespace->{child_resources} } ) {
                 $logger->info("Expiring child resource $child_resource. Master resource is $what");
@@ -379,12 +433,6 @@ sub expire {
             }
         }
 
-        # expire overlayed namespaces
-        my @overlayed_namespaces = $self->overlayed_namespaces($what);
-        foreach my $namespace (@overlayed_namespaces){
-            $logger->info("Expiring overlayed resource from base resource $what.");
-            $self->expire($namespace, $light);
-        }
     }
 }
 
@@ -460,8 +508,10 @@ sub preload_all {
     my @namespaces = $self->list_namespaces;
     print "\n------------------\n";
     foreach my $namespace (@namespaces) {
+        $namespace = normalize_namespace_query($namespace);
         print "Preloading $namespace\n";
         $self->get_cache($namespace);
+        $self->config_builder($namespace);
     }
     print "------------------\n";
 }
@@ -474,17 +524,10 @@ Method that expires all the namespaces defined by list_namespaces
 
 sub expire_all {
     my ($self, $light) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = get_logger;
     my @namespaces = $self->list_top_namespaces;
     foreach my $namespace (@namespaces) {
-        if(defined($light) && $light){
-            $logger->info("Light expiring $namespace");
-            delete $self->{memorized_at}->{$namespace};
-        }
-        else{
-            $logger->info("Hard expiring $namespace");
-            $self->expire($namespace);
-        }
+        $self->expire($namespace, $light);
     }
 }
 
@@ -494,7 +537,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
