@@ -28,7 +28,8 @@ use strict;
 use warnings;
 
 use JSON::MaybeXS;
-use pfconfig::log;
+use pf::log;
+use pf::IniFiles;
 
 use base 'pfconfig::namespaces::resource';
 
@@ -36,13 +37,14 @@ sub init {
     my ($self) = @_;
     $self->{expandable_params} = [];
     $self->{child_resources}   = [];
+    $self->{added_params}      = {};
 }
 
 sub _parse_error {
     my ($self) = @_;
-    my $message = "Can't parse ".$self->{file}. " : ".join(', ', @Config::IniFiles::errors);
+    my $message = "Can't parse ".$self->{file}. " : ".join(', ', @pf::IniFiles::errors);
     print STDERR "$message\n";
-    pfconfig::log::get_logger->error($message);
+    get_logger->error($message);
     $self->{parse_error} = $message;
 }
 
@@ -51,12 +53,10 @@ sub build {
 
     my %tmp_cfg;
 
-    my %added_params = ();
+    $self->{added_params}->{-file} = $self->{file};
+    $self->{added_params}->{-allowempty} = 1;
 
-    $added_params{-file} = $self->{file};
-    $added_params{-allowempty} = 1;
-
-    tie %tmp_cfg, 'Config::IniFiles', %added_params or $self->_parse_error();
+    tie %tmp_cfg, 'pf::IniFiles', %{$self->{added_params}} or $self->_parse_error();
 
     @{ $self->{ordered_sections} } = keys %tmp_cfg;
 
@@ -76,7 +76,7 @@ sub build {
 
 sub do_defaults {
     my ($self)  = @_;
-    my $logger  = pfconfig::log::get_logger;
+    my $logger  = get_logger;
     my %tmp_cfg = %{ $self->{cfg} };
     unless ( defined( $self->{default_section} ) ) {
         $logger->debug("No default section defined when building $self->{file}");
@@ -152,7 +152,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
