@@ -20,8 +20,9 @@ use warnings;
 
 use pfconfig::namespaces::config;
 use Data::Dumper;
-use pfconfig::log;
-use pf::file_paths;
+use pf::log;
+use pf::file_paths qw($domain_config_file);
+use Sys::Hostname;
 
 use base 'pfconfig::namespaces::config';
 
@@ -34,7 +35,15 @@ sub init {
 sub build_child {
     my ($self) = @_;
 
-    my %tmp_cfg = %{$self->{cfg}}; 
+    my %tmp_cfg = %{$self->{cfg}};
+
+    # Inflate %h to the host machine name
+    # This is done since Samba 4+ doesn't inflate it itself anymore
+    while(my ($id, $cfg) = each(%tmp_cfg)){
+        if(lc($cfg->{server_name}) eq "%h") {
+            $cfg->{server_name} = [split(/\./,hostname())]->[0];
+        }
+    }
 
     $self->{cfg} = \%tmp_cfg;
 
@@ -42,16 +51,13 @@ sub build_child {
 
 }
 
-
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
