@@ -18,7 +18,7 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pf::file_paths;
+use pf::file_paths qw($floating_devices_config_file);
 
 use base 'pfconfig::namespaces::config';
 
@@ -49,7 +49,6 @@ sub build_child {
 
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -57,7 +56,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
