@@ -17,29 +17,57 @@ This module creates the configuration hash associated to networks.conf
 use strict;
 use warnings;
 
+use pf::log;
 use pfconfig::namespaces::config;
-use pf::file_paths;
+use pf::constants;
+use pf::file_paths qw($network_config_file);
 use pf::constants::config;
 use pfconfig::util qw(is_type_inline);
 
 use base 'pfconfig::namespaces::config';
 
 sub init {
-    my ($self) = @_;
+    my ($self, $host_id) = @_;
+    $self->{cluster_name} = ($host_id ? $self->{cache}->get_cache("resource::clusters_hostname_map")->{$host_id} : undef) // "DEFAULT";
+
     $self->{file}            = $network_config_file;
     $self->{child_resources} = [
-        'interfaces'
+        'interfaces',
+        'resource::network_config'
     ];
+    
+    $self->{cluster_config}  = $self->{cluster_name} ? $self->{cache}->get_cache("config::Cluster(".$self->{cluster_name}.")") : {};
 }
 
 sub build_child {
     my ($self) = @_;
 
+    my $logger = get_logger;
+
     my %ConfigNetworks = %{ $self->{cfg} };
 
     my ($config) = @_;
     $self->cleanup_whitespaces( \%ConfigNetworks );
 
+    my %ConfigCluster  = %{ $self->{cluster_config} };
+
+    # for cluster overlaying
+    if(defined($self->{cluster_name}) && exists($ConfigCluster{CLUSTER})){
+        $logger->debug("Doing the network overlaying for cluster");
+        while(my ($key, $config) = (each %{$ConfigCluster{CLUSTER}})){
+            if($key =~ /^network ([0-9.]+)/){
+                my $net = $1;
+                $logger->debug("Reconfiguring network $net with cluster information");
+                while(my ($param, $value) = each(%$config)) {
+                    $ConfigNetworks{$net}{$param} = $value;
+                }
+            }
+        }
+    }
+    elsif(defined($self->{host_id})){
+        $logger->warn("A host was defined for the config::Pf namespace but no cluster configuration was found. This is not a big issue but it's worth noting.")
+    }
+
     return \%ConfigNetworks;
 
 }
@@ -55,10 +83,28 @@ sub is_network_type_vlan_reg {
 
     my $result = get_network_type($type);
     if ( defined($result) && $result eq $pf::constants::config::NET_TYPE_VLAN_REG ) {
-        return 1;
+        return $TRUE;
     }
     else {
-        return 0;
+        return $FALSE;
+    }
+}
+
+=head2 is_network_type_dns_enforcement
+
+Returns true if given network is of type dns-enforcement and false otherwise.
+
+=cut
+
+sub is_network_type_dns_enforcement {
+    my ($type) = @_;
+
+    my $result = get_network_type($type);
+    if ( defined($result) && $result eq $pf::constants::config::NET_TYPE_DNS_ENFORCEMENT ) {
+        return $TRUE;
+    }
+    else {
+        return $FALSE;
     }
 }
 
@@ -73,10 +119,10 @@ sub is_network_type_vlan_isol {
 
     my $result = get_network_type($type);
     if ( defined($result) && $result eq $pf::constants::config::NET_TYPE_VLAN_ISOL ) {
-        return 1;
+        return $TRUE;
     }
     else {
-        return 0;
+        return $FALSE;
     }
 }
 
@@ -91,10 +137,10 @@ sub is_network_type_inline {
 
     my $result = get_network_type($type);
     if ( defined($result) && $result eq $pf::constants::config::NET_TYPE_INLINE ) {
-        return 1;
+        return $TRUE;
     }
     else {
-        return 0;
+        return $FALSE;
     }
 }
 
@@ -117,6 +163,12 @@ sub get_network_type {
         # vlan-isolation
         return $pf::constants::config::NET_TYPE_VLAN_ISOL;
 
+    }
+    elsif ( $type =~ /^$pf::constants::config::NET_TYPE_DNS_ENFORCEMENT$/i ) {
+
+        # dns-enforcement
+        return $pf::constants::config::NET_TYPE_DNS_ENFORCEMENT;
+
     }
     elsif ( is_type_inline($type) ) {
 
@@ -145,7 +197,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
