@@ -19,12 +19,18 @@ use warnings;
 
 use JSON::MaybeXS;
 use pfconfig::namespaces::config;
-use Config::IniFiles;
+use pf::IniFiles;
 use File::Slurp qw(read_file);
-use pfconfig::log;
-use pf::file_paths;
+use pf::log;
+use pf::file_paths qw(
+    $pf_default_file
+    $pf_config_file
+    $log_dir
+);
 use pf::util;
+use pf::constants::config qw($DEFAULT_SMTP_PORT $DEFAULT_SMTP_PORT_SSL $DEFAULT_SMTP_PORT_TLS %ALERTING_PORTS);
 use List::MoreUtils qw(uniq);
+use DateTime::TimeZone;
 
 use base 'pfconfig::namespaces::config';
 
@@ -34,9 +40,9 @@ sub build {
 
     my %tmp_cfg;
 
-    my $pf_conf_defaults = Config::IniFiles->new( -file => $pf_default_file );
+    my $pf_conf_defaults = pf::IniFiles->new( -file => $pf_default_file );
 
-    tie %tmp_cfg, 'Config::IniFiles', ( -file => $self->{file}, -import => $pf_conf_defaults );
+    tie %tmp_cfg, 'pf::IniFiles', ( -file => $self->{file}, -import => $pf_conf_defaults );
 
     # for pfcmd checkup
     $self->{_file_cfg} = {%tmp_cfg};
@@ -56,13 +62,23 @@ sub build {
 }
 
 sub init {
-    my ($self, $host_id) = @_;
+    my ($self, $host_id, $cluster_name) = @_;
+    # This namespace supports optionnaly specifying the cluster name so that consummers can get the CLUSTER configuration of each cluster
+    # If the cluster_name isn't specified, it falls back to a lookups in the clusters hostname map
+    if($cluster_name) {
+        $self->{cluster_name} = $cluster_name;
+    }
+    else {
+        $self->{cluster_name} = ($host_id ? $self->{cache}->get_cache("resource::clusters_hostname_map")->{$host_id} : undef) // "DEFAULT";
+    }
+
     $self->{file}            = $pf_config_file;
     $self->{default_config}  = $self->{cache}->get_cache('config::PfDefault');
     $self->{doc_config}      = $self->{cache}->get_cache('config::Documentation');
-    $self->{cluster_config}  = $self->{cache}->get_cache('config::Cluster');
 
-    $self->{child_resources} = [ 'resource::CaptivePortal', 'resource::Database', 'resource::fqdn', 'config::Pfdetect' ];
+    $self->{cluster_config}  = $self->{cluster_name} ? $self->{cache}->get_cache("config::Cluster(".$self->{cluster_name}.")") : {};
+
+    $self->{child_resources} = [ 'resource::CaptivePortal', 'resource::Database', 'resource::fqdn', 'config::Pfdetect', 'resource::trapping_range', 'resource::stats_levels', 'resource::passthroughs', 'resource::isolation_passthroughs', 'resource::network_config' ];
     if(defined($host_id)){
         push @{$self->{child_resources}}, "interfaces($host_id)";
     }
@@ -74,7 +90,7 @@ sub init {
 
 sub build_child {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = get_logger;
 
     my %Config         = %{ $self->{cfg} };
     my %Doc_Config     = %{ $self->{doc_config} };
@@ -87,12 +103,14 @@ sub build_child {
         while(my ($key, $config) = (each %{$ConfigCluster{$self->{host_id}}})){
             if($key =~ /^interface /){
                 $logger->debug("Reconfiguring interface $key with cluster information");
-                $Config{$key} = $config;
+                while(my ($param, $value) = each(%$config)) {
+                    $Config{$key}{$param} = $value;
+                }
             }
         }
     }
     elsif(defined($self->{host_id})){
-        $logger->warn("A host was defined for the config::Pf namespace but no cluster configuration was found. This is not a big issue but it's worth noting.")
+        $logger->warn("A host was defined (".$self->{host_id}.") for the config::Pf namespace but no cluster configuration was found. This is not a big issue but it's worth noting.")
     }
 
     my @time_values = grep { my $t = $Doc_Config{$_}{type}; defined $t && $t eq 'time' } keys %Doc_Config;
@@ -103,38 +121,49 @@ sub build_child {
         $Config{$group}{$item} = normalize_time( $Config{$group}{$item} ) if ( $Config{$group}{$item} );
     }
 
-    # determine absolute paths
-    foreach my $val ("alerting.log") {
+    foreach my $val ("fencing.passthroughs", "fencing.isolation_passthroughs", "captive_portal.other_domain_names") {
         my ( $group, $item ) = split( /\./, $val );
-        if ( !File::Spec->file_name_is_absolute( $Config{$group}{$item} ) ) {
-            $Config{$group}{$item} = File::Spec->catfile( $log_dir, $Config{$group}{$item} );
-        }
+        $Config{$group}{$item} = [ split( /\s*,\s*/, $Config{$group}{$item}  // '' ) ];
     }
 
-    $Config{trapping}{passthroughs} = [ split( /\s*,\s*/, $Config{trapping}{passthroughs} || '' ) ];
-
     # We're looking for the merged_list configurations and we merge the default value with
     # the user defined value
     while( my( $key, $value ) = each %Doc_Config ){
         if(defined($value->{type}) && $value->{type} eq "merged_list"){
             my ($category, $attribute) = split /\./, $key;
             my $additionnal = $Config{$category}{$attribute} || '';
-            $Config{$category}{$attribute} = [ split( /\s*,\s*/, $Default_Config{$category}{$attribute}), split( /\s*,\s*/, $additionnal ) ];
+            $Config{$category}{$attribute} = [ split( /\s*,\s*/, $Default_Config{$category}{$attribute} // ''), split( /\s*,\s*/, $additionnal ) ];
             $Config{$category}{$attribute} = [ uniq @{$Config{$category}{$attribute}} ];
         }
+
+        if(defined($value->{type}) && $value->{type} eq "fingerbank_device_transition") {
+            my @transitions;
+            my ($category, $attribute) = split /\./, $key;
+            my $data = $Config{$category}{$attribute} || '';
+            my @pairs = split(/\s*,\s*/, $data);
+            foreach my $pair (@pairs) {
+                my @info = split('->', $pair);
+                push @transitions, { from => $info[0], to => $info[1] };
+            }
+
+            $Config{$category}{$attribute} = \@transitions;
+        }
     }
 
     $Config{network}{dhcp_filter_by_message_types}
         = [ split( /\s*,\s*/, $Config{network}{dhcp_filter_by_message_types} || '' ) ];
 
-    # Fetch default OMAPI key_base64 (conf/pf_omapi_key file) if none is provided
-    if ( ($Config{omapi}{key_base64} eq '') && (-e $pf_omapi_key_file)) {
-        $Config{omapi}{key_base64} = read_file($pf_omapi_key_file);
-        $Config{omapi}{key_base64}=~ s/\R//g;   # getting rid of any carriage return
+    if (($Config{alerting}{smtp_port} // 0) == 0) {
+        $Config{alerting}{smtp_port} = $ALERTING_PORTS{$Config{alerting}{smtp_encryption}} // $DEFAULT_SMTP_PORT;
+    }
+
+    unless ($Config{general}{timezone}) {
+        my $tz = DateTime::TimeZone->new(name => 'local')->name();
+        $logger->info("No timezone defined, using $tz");
+        $Config{general}{timezone} = $tz;
     }
 
     return \%Config;
-
 }
 
 =head1 AUTHOR
@@ -143,7 +172,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
