@@ -18,7 +18,7 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use Config::IniFiles;
+use pf::file_paths qw($pf_default_file);
 
 use base 'pfconfig::namespaces::config';
 
@@ -34,7 +34,6 @@ sub build_child {
     return $self->{cfg};
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -42,7 +41,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
