@@ -18,38 +18,38 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pf::file_paths;
-use pf::util;
+use pf::file_paths qw($pfdetect_config_file);
+use pf::IniFiles;
+use pf::log;
+use pf::config::builder::pfdetect;
 
-use base 'pfconfig::namespaces::config';
+use base 'pfconfig::namespaces::resource';
 
 sub init {
     my ($self) = @_;
     $self->{file} = $pfdetect_config_file;
-    $self->{config} = $self->{cache}->get_cache('config::Pf');
 }
 
-sub build_child {
+sub build {
     my ($self) = @_;
-    my %tmp_cfg = %{ $self->{cfg} };
-
-    # There for backward compatibility for when suricata or snort is configured directly in PacketFence
-    # Should this feature go, the code below can be removed
-    # This will start a pfdetect process if the detection engine is enabled in PacketFence
-    if( 
-      isenabled($self->{config}->{trapping}->{detection}) &&
-      $self->{config}->{trapping}->{detection_engine} ne "none"
-    ) {
-      $tmp_cfg{pf_detection_engine} = { 
-                                        path => "/usr/local/pf/var/alert", 
-                                        type => $self->{config}->{trapping}->{detection_engine} 
-                                      };
+    my $file = $self->{file};
+    my $ini = pf::IniFiles->new(-file => $file, -allowempty => 1);
+    unless ($ini) {
+        my $error_msg = join("\n", @pf::IniFiles::errors, "");
+        get_logger->error($error_msg);
+        return {};
     }
 
-    return \%tmp_cfg;
-}
+    my $builder = pf::config::builder::pfdetect->new();
+    my ($errors, $data) = $builder->build($ini);
+    for my $err (@{ $errors // [] }) {
+        my $error_msg =  "$file: $err->{rule}) $err->{message}";
+        get_logger->error($error_msg);
+        warn($error_msg);
+    }
 
-=back
+    return $data;
+}
 
 =head1 AUTHOR
 
@@ -57,7 +57,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
