@@ -18,13 +18,20 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pf::file_paths;
+use pf::file_paths qw(
+    $profiles_config_file
+    $profiles_default_config_file
+    $captiveportal_default_profile_templates_path
+    $captiveportal_templates_path
+    $captiveportal_profile_templates_path
+);
 use pf::util;
 use pfconfig::namespaces::resource::guest_self_registration;
-use pf::constants::Portal::Profile;
+use pf::constants::Connection::Profile;
 use pf::filter_engine::profile;
 use pf::factory::condition::profile;
 use List::MoreUtils qw(uniq);
+use File::Spec::Functions;
 
 use base 'pfconfig::namespaces::config';
 
@@ -32,7 +39,9 @@ sub init {
     my ($self) = @_;
     $self->{file}            = $profiles_config_file;
     $self->{default_section} = "default";
-    $self->{child_resources} = [ 'FilterEngine::Profile', 'resource::URI_Filters' ];
+    $self->{child_resources} = [ 'FilterEngine::Profile', 'resource::URI_Filters', 'resource::ProfileReverseLookup'];
+    my $defaults = pf::IniFiles->new(-file => $profiles_default_config_file);
+    $self->{added_params}{'-import'} = $defaults;
 }
 
 sub build_child {
@@ -40,11 +49,33 @@ sub build_child {
     my @uri_filters;
     my %Profiles_Config = %{ $self->{cfg} };
     $self->cleanup_whitespaces( \%Profiles_Config );
+    my %reverseLookup;
 
     while ( my ( $key, $profile ) = each %Profiles_Config ) {
-        foreach my $field (qw(locale mandatory_fields custom_fields_authentication_sources sources filter provisioners)) {
+        foreach my $field (qw(locale sources provisioners billing_tiers scans)) {
             $profile->{$field} = [ split( /\s*,\s*/, $profile->{$field} || '' ) ];
         }
+        foreach my $field (qw(filter)) {
+            $profile->{$field} = [ map {s/,,/,/g;$_} split( /\s*(?<!,),(?!,)\s*/ , $profile->{$field} || '' ) ];
+        }
+        foreach my $field (qw(sources provisioners billing_tiers scans device_registration root_module)) {
+            my $values = $profile->{$field};
+            if (ref ($values) eq '') {
+                next if !defined $values || $values eq '';
+
+                $values = [$values];
+            }
+
+            for my $val (@$values) {
+                push @{$reverseLookup{$field}{$val}}, $key;
+            }
+        }
+        my @template_paths = ($captiveportal_default_profile_templates_path, $captiveportal_templates_path);
+        if ($key eq 'default') {
+            $profile->{template_paths} = [@template_paths];
+        } else {
+            $profile->{template_paths} = [catdir($captiveportal_profile_templates_path, $key), @template_paths];
+        }
     }
 
     my @profiles = @{ $self->{ordered_sections} };
@@ -62,7 +93,7 @@ sub build_child {
         $profile->{'description'} = ''
             if $profile_id ne 'default' && $profile->{'description'} eq $default_description;
         $profile->{block_interval} = normalize_time( $profile->{block_interval}
-                || $pf::constants::Portal::Profile::BLOCK_INTERVAL_DEFAULT_VALUE );
+                || $pf::constants::Connection::Profile::BLOCK_INTERVAL_DEFAULT_VALUE );
         foreach my $filter (@{$profile->{filter}}) {
             if ($filter =~ $pf::factory::condition::profile::PROFILE_FILTER_REGEX) {
                 push @uri_filters,$3 if $1 eq 'uri';
@@ -72,6 +103,7 @@ sub build_child {
     @uri_filters = uniq @uri_filters;
     $self->{uri_filters} = \@uri_filters;
     $self->{engine_profile} = pf::filter_engine::profile->new({ ordered_ids => \@profiles, config => \%Profiles_Config });
+    $self->{reverseLookup} = \%reverseLookup;
 
     return \%Profiles_Config;
 
@@ -83,7 +115,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
