@@ -18,23 +18,38 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pf::file_paths;
+use pf::file_paths qw($provisioning_config_file);
 
 use base 'pfconfig::namespaces::config';
 
 sub init {
     my ($self) = @_;
     $self->{file} = $provisioning_config_file;
+    $self->{child_resources} = ['resource::ProvisioningReverseLookup'];
 }
 
 sub build_child {
     my ($self) = @_;
 
     my %tmp_cfg = %{ $self->{cfg} };
+    my %reverseLookup;
 
-    foreach my $key ( keys %tmp_cfg ) {
-        $self->cleanup_after_read( $key, $tmp_cfg{$key} );
+    while ( my ($key, $provisioner) = each %tmp_cfg) {
+        $self->cleanup_after_read($key, $provisioner);
+        foreach my $field (qw(pki_provider)) {
+            my $values = $provisioner->{$field};
+            if (ref ($values) eq '') {
+                next if !defined $values || $values eq '';
+
+                $values = [$values];
+            }
+
+            for my $val (@$values) {
+                push @{$reverseLookup{$field}{$val}}, $key;
+            }
+        }
     }
+    $self->{reverseLookup} = \%reverseLookup;
 
     return \%tmp_cfg;
 
@@ -42,11 +57,9 @@ sub build_child {
 
 sub cleanup_after_read {
     my ( $self, $id, $data ) = @_;
-    $self->expand_list( $data, qw(category) );
-    $data->{oses} = [ split /\n/, $data->{oses} || '' ]
+    $self->expand_list( $data, qw(category oses) );
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -54,7 +67,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
