@@ -19,8 +19,8 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pfconfig::log;
-use pf::file_paths;
+use pf::log;
+use pf::file_paths qw($scan_config_file);
 
 use base 'pfconfig::namespaces::config';
 
@@ -50,15 +50,13 @@ sub cleanup_after_read {
     }
 }
 
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
