@@ -18,18 +18,24 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use Config::IniFiles;
-use pfconfig::log;
-use pf::file_paths;
+use pf::IniFiles;
+use pf::log;
+use pf::file_paths qw($switches_config_file $switches_default_config_file);
 use pf::util;
 use List::MoreUtils qw(any uniq);
 
 use base 'pfconfig::namespaces::config';
 
 sub init {
-    my ($self) = @_;
+    my ($self, $host_id) = @_;
     $self->{file}            = $switches_config_file;
-    $self->{child_resources} = [ 'resource::default_switch', 'resource::switches_ranges' ];
+    $self->{child_resources} = [ 'resource::default_switch', 'resource::switches_group', 'resource::switches_ranges', 'interfaces::management_network', 'resource::SwitchTypesConfigured', 'resource::cli_switches', 'resource::SwitchReverseLookup' ];
+
+    $host_id //= "";
+    $self->{management_network} = $self->{cache}->get_cache("interfaces::management_network($host_id)");
+    $self->{local_secret} = $self->{cache}->get_cache('resource::local_secret');
+    my $defaults = pf::IniFiles->new(-file => $switches_default_config_file);
+    $self->{added_params}{'-import'} = $defaults;
 }
 
 sub build_child {
@@ -46,7 +52,6 @@ sub build_child {
         SNMPCommunityTrap => 'public'
     };
 
-
     my @keys;
     # default is always first
     push @keys, "default";
@@ -69,7 +74,7 @@ sub build_child {
         }
     }
 
-    foreach my $switch ( values %tmp_cfg ) {
+    while ( my ($name, $switch) = each %tmp_cfg) {
 
         # transforming uplink and inlineTrigger to arrays
         foreach my $key (qw(uplink inlineTrigger)) {
@@ -77,17 +82,19 @@ sub build_child {
             $switch->{$key} = [ split /\s*,\s*/, $value ];
         }
 
+        $self->updateReverseLookup($name, $switch, qw(group));
         # transforming vlans and roles to hashes
-        my %merged = ( Vlan => {}, Role => {}, AccessList => {} );
-        foreach my $key ( grep {/(Vlan|Role|AccessList)$/} keys %{$switch} ) {
+        my %merged = ( Vlan => {}, Role => {}, AccessList => {} , Url => {} );
+        foreach my $key ( grep {/(Vlan|Role|AccessList|Url)$/} keys %{$switch} ) {
             next unless my $value = $switch->{$key};
-            if ( my ( $type_key, $type ) = ( $key =~ /^(.+)(Vlan|Role|AccessList)$/ ) ) {
+            if ( my ( $type_key, $type ) = ( $key =~ /^(.+)(Vlan|Role|AccessList|Url)$/ ) ) {
                 $merged{$type}{$type_key} = $value;
             }
         }
         $switch->{roles}        = $merged{Role};
         $switch->{vlans}        = $merged{Vlan};
         $switch->{access_lists} = $merged{AccessList};
+        $switch->{urls}         = $merged{Url};
         $switch->{VoIPEnabled}  = (
             $switch->{VoIPEnabled} =~ /^\s*(y|yes|true|enabled|1)\s*$/i
             ? 1
@@ -106,6 +113,21 @@ sub build_child {
         }
     }
 
+    if($self->{management_network}){
+        my @management_ips;
+        push @management_ips, $self->{management_network}->tag('vip') if(defined($self->{management_network}->tag('vip')));
+        push @management_ips, $self->{management_network}->tag('ip') if(defined($self->{management_network}->tag('ip')));
+        foreach my $management_ip (@management_ips){
+            $tmp_cfg{$management_ip} = {
+                type => 'PacketFence',
+                mode => 'production',
+                radiusSecret => $self->{local_secret},
+                SNMPVersionTrap   => '1',
+                SNMPCommunityTrap => 'public'
+            };
+        }
+    }
+
     foreach my $key ( keys %tmp_cfg ) {
         $self->cleanup_after_read( $key, $tmp_cfg{$key} );
     }
@@ -114,9 +136,25 @@ sub build_child {
 
 }
 
+sub updateReverseLookup {
+    my ( $self, $key, $data, @fields ) = @_;
+    foreach my $field (@fields) {
+        my $values = $data->{$field};
+        if ( ref($values) eq '' ) {
+            next if !defined $values || $values eq '';
+
+            $values = [$values];
+        }
+
+        for my $val (@$values) {
+            push @{ $self->{reverseLookup}{$field}{$val} }, $key;
+        }
+    }
+}
+
 sub cleanup_after_read {
     my ( $self, $id, $switch ) = @_;
-    my $logger = pfconfig::log::get_logger();
+    my $logger = get_logger();
 
     if ( $switch->{uplink} && $switch->{uplink} eq 'dynamic' ) {
         $switch->{uplink_dynamic} = 'dynamic';
@@ -133,15 +171,13 @@ sub _splitInlineTrigger {
     return { type => $type, value => $value };
 }
 
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
@@ -167,4 +203,3 @@ USA.
 # vim: set shiftwidth=4:
 # vim: set expandtab:
 # vim: set backspace=indent,eol,start:
-
