@@ -19,8 +19,8 @@ use strict;
 use warnings;
 
 use pfconfig::namespaces::config;
-use pfconfig::log;
-use pf::file_paths;
+use pf::log;
+use pf::file_paths qw($wmi_config_file);
 
 use base 'pfconfig::namespaces::config';
 
@@ -49,15 +49,13 @@ sub cleanup_after_read {
     $self->expand_list($item, $self->{expandable_params});
 }
 
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
