@@ -15,19 +15,22 @@ pfconfig::namespaces::interfaces
 use strict;
 use warnings;
 
-use pfconfig::log;
+use pf::log;
 use pf::constants::config qw(%NET_INLINE_TYPES);
 use pfconfig::namespaces::config::Pf;
 use pfconfig::util qw(is_type_inline);
-use Net::Netmask;
+use pfconfig::objects::Net::Netmask;
 use Net::Interface;
 use Socket;
 use pf::util;
+use List::MoreUtils qw(uniq);
+use pf::config::cluster;
 
 use base 'pfconfig::namespaces::resource';
 
 sub init {
     my ($self, $host_id) = @_;
+    $host_id //= "";
     $self->{_interfaces} = {
         listen_ints             => [],
         dhcplistener_ints       => [],
@@ -36,6 +39,7 @@ sub init {
         inline_enforcement_nets => [],
         vlan_enforcement_nets   => [],
         portal_ints             => [],
+        radius_ints             => [],
         monitor_int             => '',
         management_network      => '',
     };
@@ -46,25 +50,29 @@ sub init {
         'interfaces::monitor_int',             'interfaces::management_network',
         'interfaces::portal_ints',             'interfaces::inline_nets',
         'interfaces::routed_isolation_nets',   'interfaces::routed_registration_nets',
+        'interfaces::radius_ints',             'resource::network_config',
     ];
     if($host_id){
         @{$self->{child_resources}} = map { "$_($host_id)" } @{$self->{child_resources}}; 
     }
+
     $self->{config_resource} = pfconfig::namespaces::config::Pf->new( $self->{cache}, $host_id );
     #$self->{cluster_enabled} = pfconfig::namespaces::resource::cluster_enabled->new( $self->{cache} )->build();
-    require pf::cluster;
-    $self->{cluster_enabled} = $pf::cluster::cluster_enabled;
+    $self->{cluster_enabled} = $pf::config::cluster::cluster_enabled;
 }
 
 sub build {
     my ($self) = @_;
-    my $logger = pfconfig::log::get_logger;
+    my $logger = get_logger;
 
     my $config = $self->{config_resource};
     $self->{config} = $config->build();
     my %Config = %{ $self->{config} };
 
-    foreach my $interface ( $config->GroupMembers("interface") ) {
+    foreach my $section ( @{$config->{ordered_sections}} ) {
+        next unless($section =~ /^interface /);
+        my $interface = $section;
+
         my $int_obj;
         my $int = $interface;
         $int =~ s/interface //;
@@ -73,12 +81,17 @@ sub build {
         my $mask = $Config{$interface}{'mask'};
         my $type = $Config{$interface}{'type'};
 
+        my $ipv6_address    = $Config{$interface}{'ipv6_address'} if ( defined($Config{$interface}{'ipv6_address'}) && $Config{$interface}{'ipv6_address'} ne '' );
+        my $ipv6_prefix     = $Config{$interface}{'ipv6_prefix'} if ( defined($Config{$interface}{'ipv6_prefix'}) && $Config{$interface}{'ipv6_prefix'} ne '' );
+
         if ( defined($ip) && defined($mask) ) {
             $ip =~ s/ //g;
             $mask =~ s/ //g;
-            $int_obj = new Net::Netmask( $ip, $mask );
+            $int_obj = pfconfig::objects::Net::Netmask->new( $ip, $mask );
             $int_obj->tag( "ip",  $ip );
             $int_obj->tag( "int", $int );
+            $int_obj->tag( "ipv6_address", $ipv6_address ) if ( defined($ipv6_address) && $ipv6_address ne '' );
+            $int_obj->tag( "ipv6_prefix", $ipv6_prefix ) if ( defined($ipv6_prefix) && $ipv6_prefix ne '' );
         }
 
         if ( !defined($type) ) {
@@ -89,7 +102,7 @@ sub build {
         }
 
         die "Missing mandatory element ip or netmask on interface $int"
-            if ( $type =~ /internal|managed|management|portal/ && !defined($int_obj) );
+            if ( $type =~ /internal|managed|management|portal|radius/ && !defined($int_obj) );
 
         foreach my $type ( split( /\s*,\s*/, $type ) ) {
             if ( $type eq 'internal' ) {
@@ -113,7 +126,10 @@ sub build {
                 # adding management to dhcp listeners by default (if it's not already there)
                 push @{ $self->{_interfaces}->{dhcplistener_ints} }, $int
                     if ( not scalar grep( { $_ eq $int } @{ $self->{_interfaces}->{dhcplistener_ints} } ) );
-
+                if ($self->{cluster_enabled}) {
+                    push @{ $self->{_interfaces}->{ha_ints} }, $int_obj;
+                    @{ $self->{_interfaces}->{ha_ints} }= uniq @{ $self->{_interfaces}->{ha_ints} };
+                }
             }
             elsif ( $type eq 'monitor' ) {
                 $self->{_interfaces}->{monitor_int} = $int;
@@ -122,12 +138,18 @@ sub build {
                 push @{ $self->{_interfaces}->{dhcplistener_ints} }, $int;
             }
             elsif ( $type eq 'high-availability' ) {
-                push @{ $self->{_interfaces}->{ha_ints} }, $int;
+                push @{ $self->{_interfaces}->{ha_ints} }, $int_obj;
+                @{ $self->{_interfaces}->{ha_ints} }= uniq @{ $self->{_interfaces}->{ha_ints} };
             }
             elsif ( $type eq 'portal' ) {
                 $int_obj->tag( "vip", $self->_fetch_virtual_ip( $int, $interface ) );
                 push @{ $self->{_interfaces}->{portal_ints} }, $int_obj;
             }
+            elsif ( $type eq 'radius' ) {
+                $int_obj->tag( "vip", $self->_fetch_virtual_ip( $int, $interface ) );
+                push @{ $self->{_interfaces}->{radius_ints} }, $int_obj;
+            }
+
         }
     }
 
@@ -165,7 +187,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
