@@ -19,8 +19,9 @@ use pfconfig::namespaces::config::Network;
 use base 'pfconfig::namespaces::interfaces';
 
 sub init {
-    my ($self) = @_;
-    $self->{network_config} = $self->{cache}->get_cache('config::Network');
+    my ($self, $host_id) = @_;
+    $host_id //= "";
+    $self->{network_config} = $self->{cache}->get_cache("config::Network($host_id)");
 }
 
 sub build {
@@ -37,7 +38,6 @@ sub build {
     return \@inline_nets;
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -45,7 +45,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
