@@ -4,8 +4,6 @@ package pfconfig::namespaces::resource::authentication_lookup;
 
 pfconfig::namespaces::resource::authentication_lookup
 
-=nfamous archivescut
-
 =head1 DESCRIPTION
 
 pfconfig::namespaces::resource::authentication_lookup
@@ -28,15 +26,13 @@ sub build {
     return $self->{_authentication_config}->{authentication_lookup};
 }
 
-=back
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
