@@ -32,12 +32,11 @@ sub build {
     my %ConfigDomain = %{$self->{domains}};
     my %domain_dns_servers;
     foreach my $key ( keys %ConfigDomain ) {
-        $domain_dns_servers{$ConfigDomain{$key}->{dns_name}} = $ConfigDomain{$key}->{dns_server} if (isenabled($ConfigDomain{$key}->{registration}));
+        $domain_dns_servers{$ConfigDomain{$key}->{dns_name}} = [ split(/\s*,\s*/, $ConfigDomain{$key}->{dns_servers}) ] if (isenabled($ConfigDomain{$key}->{registration}));
     }
     return \%domain_dns_servers;
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -45,7 +44,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
