@@ -19,22 +19,15 @@ use base 'pfconfig::namespaces::resource';
 
 sub init {
     my ($self) = @_;
-
-    # we depend on the switch configuration object (russian doll style)
-    $self->{default_config} = $self->{cache}->get_cache('config::PfDefault');
-    $self->{config}         = $self->{cache}->get_cache('config::Pf');
+    $self->{config} = $self->{cache}->get_cache('config::Pf');
 }
 
 sub build {
     my ($self) = @_;
-    my $fqdn = sprintf( "%s.%s",
-        $self->{config}{'general'}{'hostname'} || $self->{default_config}{'general'}{'hostname'},
-        $self->{config}{'general'}{'domain'}   || $self->{default_config}{'general'}{'domain'} );
-
+    my $fqdn = join(".", @{$self->{config}{'general'}}{'hostname', 'domain'});
     return $fqdn;
 }
 
-=back
 
 =head1 AUTHOR
 
@@ -42,7 +35,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
