@@ -21,7 +21,7 @@ use pf::constants::config qw(%NET_INLINE_TYPES);
 use pf::util::networking qw(syswrite_all sysread_all read_data_with_length);
 use pfconfig::constants;
 use pfconfig::undef_element;
-use pfconfig::log;
+use pf::log;
 use pfconfig::constants;
 use IO::Socket::UNIX;
 use Sereal::Decoder;
@@ -30,6 +30,7 @@ use Readonly;
 our @EXPORT_OK = qw(
     is_type_inline
     $undef_element
+    normalize_namespace_query
 );
 
 Readonly our $undef_element => pfconfig::undef_element->new;
@@ -40,13 +41,15 @@ sub fetch_socket {
 
     # The line below will log any request to pfconfig for debugging purposes
     # As the logging cost even in trace is high, it's commented out
-    #pfconfig::log::get_logger->info("Doing request to pfconfig with payload : '$payload'");
+    #get_logger->info("Doing request to pfconfig with payload : '$payload'");
 
     # we ask the cachemaster for our namespaced key
     $payload .= "\n";
     my $bytes_sent = syswrite_all($socket,$payload);
     read_data_with_length($socket,my $sereal_buffer);
-    return $sereal_buffer;
+    ## Match all bytes to always untaint
+    $sereal_buffer =~ /\A^(.*)\z/ms;
+    return $1;
 }
 
 sub fetch_decode_socket {
@@ -79,6 +82,7 @@ sub parse_namespace {
         $args =~ s/[)]{1}$//;
         @args_list = split(',', $args);
     }
+
     return ($namespace, @args_list);
 }
 
@@ -102,13 +106,31 @@ sub is_type_inline {
     return exists $NET_INLINE_TYPES{$type};
 }
 
+=head2 normalize_namespace_query
+
+Method that normalizes a namespace query
+
+=cut
+
+sub normalize_namespace_query {
+    my ($ns) = @_;
+    
+    # Normalize all namespaces to end with parentheses without arguments if its not already overlayed
+    # Can't use is_overlayed_namespace since it requires args to be between the parentheses
+    if($ns !~ /\)$/) {
+        $ns .= "()";
+    }
+    
+    return $ns;
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2016 Inverse inc.
+Copyright (C) 2005-2018 Inverse inc.
 
 =head1 LICENSE
 
